@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2011, 2012 Herve Quatremain
+# Copyright (C) 2011-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -62,7 +62,8 @@ def mk(sql_session, current_cwd, arguments):
         basename, p = path_cal.get_new_paths(sql_session, arg,
                                              current_cwd, True)
         if not p:
-            sys.stderr.write(_("mk: `%s': no such directory\n") % arg)
+            sys.stderr.write(_("mk: `%s': no such directory\n")
+                             % arg.decode('utf-8'))
             return 1
         paths.append([basename, p])
     if not paths:
