@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2011, 2012 Herve Quatremain
+# Copyright (C) 2011-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -64,7 +64,8 @@ def rmdir(sql_session, current_cwd, arguments, workload=None):
             p = path_cal.get_paths(sql_session, arg, current_cwd, True,
                                    workload=workload)
             if not p:
-                sys.stderr.write(_("rmdir: `%s': no such directory\n") % arg)
+                sys.stderr.write(_("rmdir: `%s': no such directory\n")
+                                 % arg.decode('utf-8'))
             else:
                 paths.extend(p)
     else:
