@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2011, 2012 Herve Quatremain
+# Copyright (C) 2011-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -100,7 +100,8 @@ def cat(sql_session, arguments, workload=None):
     for a in args:
         env_list = environments_utils.name2env_list(session, a, workload)
         if not env_list:
-            sys.stderr.write(_("cat: `%s': no such environment group\n") % a)
+            sys.stderr.write(_("cat: `%s': no such environment group\n")
+                             % a.decode('utf-8'))
         else:
             first = True
             for e in env_list:
