@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2011, 2012 Herve Quatremain
+# Copyright (C) 2011-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -90,7 +90,7 @@ def ls(sql_session, arguments, workload=None):
             env_list = environments_utils.name2env_list(session, a, workload)
             if not env_list:
                 sys.stderr.write(_("ls: `%s': no such environment group\n")
-                                 % a)
+                                 % a.decode('utf-8'))
             else:
                 for e in env_list:
                     _print_env(e, long_listing)
