@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2011-2013 Herve Quatremain
+# Copyright (C) 2011-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -21,6 +21,7 @@
 
 import sys
 import getopt
+import time
 
 from sqlalchemy import desc
 
@@ -35,7 +36,6 @@ from tables.job_command import job_command
 from tables.job_arguments import job_arguments
 from tables.job_loadenv import job_loadenv
 from tables.job_detach import job_detach
-from tables.job_manual import job_manual
 from tables.job_manual_command import job_manual_command
 from tables.job_file_out import job_file_out
 from tables.job_file_err import job_file_err
@@ -69,7 +69,6 @@ from tables.job_retries_interval_s import job_retries_interval_s
 from tables.job_start_limit_s import job_start_limit_s
 from tables.job_loadenv_s import job_loadenv_s
 from tables.job_detach_s import job_detach_s
-from tables.job_manual_s import job_manual_s
 from tables.job_manual_command_s import job_manual_command_s
 from tables.job_environment_s import job_environment_s
 from tables.constraint_file_s import constraint_file_s
@@ -94,6 +93,7 @@ def usage():
                      Name   : Convert
                      Type   : Job
                   Enabled   : True
+                   Manual   : False
                      Host   : flower.example.com (2006/SSL)
                  Calendar   : /Samples/Every Friday
                Start time   : 18h14
@@ -104,7 +104,6 @@ def usage():
               Output file * : /dev/null
                Error file * : /dev/null
                    Detach * : false
-                   Manual * : false
      Alert cmd for manual * : cat "$SCHEDWI_TEMPLATE" | mail -s "waiting" root@localhost
       Linux Control Group * : schedwi
              Max duration * : No limit
@@ -194,13 +193,8 @@ def cat(sql_session, current_cwd, arguments, workload=None):
         else:
             first = False
         session = sql_session.open_session()
-        if workload is None:
-            query = session.query(job_main)
-        else:
-            query = session.query(job_main_s)
-            query = query.filter(job_main_s.workload_date == workload)
         try:
-            job = query.filter_by(id=p.id[-1]).one()
+            job = simple_queries_job.sql_get_job(session, p.id[-1], workload)
         except:
             sys.stderr.write(_("cat: no such job or jobset\n"))
             error = True
@@ -213,12 +207,14 @@ def cat(sql_session, current_cwd, arguments, workload=None):
                                                       workload))
             d = status_utils.get_status_duration(session, job.id, workload)
             _print_val(_("Duration"), True, "%d (%dh%02dm%02ds)",
-                       (d, d / 3600, d / 60, d % 60), False)
+                       (d, d / 3600, d / 60 % 60, d % 60), False)
         _print_val(_("Type"), True,
                    "%s", _("Jobset") if not job.type else _("Job"),
                    True if workload is None else job_main_s.rw_type)
         _print_val(_("Enabled"), True, "%s", bool(job.enabled),
                    True if workload is None else job_main_s.rw_enabled)
+        _print_val(_("Manual"), True, "%s", bool(job.manual),
+                   True if workload is None else job_main_s.rw_manual)
 
         in_object, obj = sql_hierarchy.get_cluster_or_host(session, p,
                                                            workload)
@@ -271,18 +267,25 @@ def cat(sql_session, current_cwd, arguments, workload=None):
                                                      workload)
             if j is not None:
                 start_time = j.start_time
-                _print_val(
-                    _("Start time"), False, "%02dh%02d",
-                    (start_time / 100, start_time % 100),
-                    True if workload is None else job_main_s.rw_start_time)
+                if workload is None:
+                    _print_val(_("Start time"), False, "%02dh%02d",
+                               (start_time / 100, start_time % 100), True)
+                else:
+                    _print_val(_("Start time"), False, "%s",
+                               time.strftime('%c', time.localtime(start_time)),
+                               job_main_s.rw_start_time)
             else:
                 _print_val(
                     _("Start time"), False, "%02dh%02d", (0, 0),
                     True if workload is None else job_main_s.rw_start_time)
         else:
-            _print_val(_("Start time"), True, "%02dh%02d",
-                       (job.start_time / 100, job.start_time % 100),
-                       True if workload is None else job_main_s.rw_start_time)
+            if workload is None:
+                _print_val(_("Start time"), True, "%02dh%02d",
+                           (job.start_time / 100, job.start_time % 100), True)
+            else:
+                _print_val(_("Start time"), True, "%s",
+                           time.strftime('%c', time.localtime(job.start_time)),
+                           job_main_s.rw_start_time)
         sql_session.close_session(session)
 
         in_object, obj = sql_hierarchy.get(
@@ -309,11 +312,9 @@ def cat(sql_session, current_cwd, arguments, workload=None):
             params = list()
             for param in lst:
                 if param.position == -1:
-                    _print_val(
-                        _("Parameters"),
-                        in_object,
-                        True if workload is None
-                        else job_main_s.rw_job_arguments)
+                    _print_val(_("Parameters"), in_object, None, None,
+                               True if workload is None
+                               else job_main_s.rw_job_arguments)
                     break
                 params.append('"' + param.argument + '"')
             else:
@@ -383,15 +384,6 @@ def cat(sql_session, current_cwd, arguments, workload=None):
             _print_val(_("Detach"), in_object, "%s", bool(obj.detach),
                        True if workload is None else job_main_s.rw_job_detach)
 
-        in_object, obj = sql_hierarchy.get(
-            sql_session,
-            p,
-            job_manual if workload is None else job_manual_s,
-            workload)
-        if obj is not None:
-            _print_val(_("Manual"), in_object, "%s", bool(obj.manual),
-                       True if workload is None else job_main_s.rw_job_manual)
-
         in_object, obj = sql_hierarchy.get(
             sql_session,
             p,
