@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2012, 2013 Herve Quatremain
+# Copyright (C) 2012-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -68,8 +68,6 @@ from tables.job_loadenv import job_loadenv
 from tables.job_loadenv_s import job_loadenv_s
 from tables.job_detach import job_detach
 from tables.job_detach_s import job_detach_s
-from tables.job_manual import job_manual
-from tables.job_manual_s import job_manual_s
 from tables.job_manual_command import job_manual_command
 from tables.job_manual_command_s import job_manual_command_s
 from tables.job_stat import job_stat
@@ -94,7 +92,7 @@ Options:
   --cluster=PATTERN     search by cluster name.
   --calendar=PATTERN    search for jobs and jobsets with the specified
                         calendar.
-  --start=TIME          search by start time (HH:MM).
+  --start=TIME          search by start time (HH:MM) - not for planned jobs.
   --command=PATTERN     search by command name.
   --parameter=PATTERN   search in the command parameters.
   --return=N            search by the return code (equal or below means
@@ -480,8 +478,8 @@ def find(sql_session, current_cwd, arguments, workload=None):
             try:
                 if workload is None:
                     query = _filter_time(query, job_main.start_time, a)
-                else:
-                    query = _filter_time(query, job_main_s.start_time, a)
+                #else:
+                #    query = _filter_time(query, job_main_s.start_time, a)
             except:
                 sql_session.cancel_session(session)
                 sys.stderr.write(_("find: unknown time format (--start=%s). \
@@ -670,12 +668,9 @@ Should be `H:M' or `H:M AM/PM'\n") % a)
 
         elif o == "--manual":
             if workload is None:
-                query = _filter_boolean(query, job_manual.manual, a)
-                query = query.filter(job_manual.job_id == job_main.id)
+                query = _filter_boolean(query, job_main.manual, a)
             else:
-                query = _filter_boolean(query, job_manual_s.manual, a)
-                query = query.filter(job_manual_s.job_id == job_main_s.id)
-                query = query.filter(job_manual_s.workload_date == workload)
+                query = _filter_boolean(query, job_main_s.manual, a)
 
         elif o == "--manual-cmd":
             if workload is None:
