@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2012, 2013 Herve Quatremain
+# Copyright (C) 2012-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -37,7 +37,7 @@ Option:
     """))
 
 
-def rmln(sql_session, current_cwd, arguments):
+def rmln(sql_session, current_cwd, arguments, workload=None):
     """Remove dependency links.
 
     @param sql_session:
@@ -46,6 +46,8 @@ def rmln(sql_session, current_cwd, arguments):
                 current working directory (jobset)
     @param arguments:
                 arguments passed to the command.
+    @param workload:
+                workload to use.
     @return:    0 means success. 1 indicates an error.
     """
     try:
@@ -60,7 +62,8 @@ def rmln(sql_session, current_cwd, arguments):
     paths = list()
     if args:
         for arg in args:
-            p = path.get_paths(sql_session, arg, current_cwd)
+            p = path.get_paths(sql_session, arg, current_cwd,
+                               workload=workload)
             if not p:
                 sys.stderr.write(_("rmln: `%s': no such job or jobset\n")
                                  % arg)
@@ -73,12 +76,13 @@ def rmln(sql_session, current_cwd, arguments):
         sys.stderr.write(_("rmln: no such job or jobset\n"))
         return 1
     if len(paths) < 2:
-        sys.stderr.write(_("rmln: no enough operand or unknown job/jobset\n"))
+        sys.stderr.write(
+            _("rmln: not enough operands or unknown job/jobset\n"))
         return 1
     source = paths.pop(0)
     session = sql_session.open_session()
     try:
-        source_job = sql_get_job(session, source.id[-1])
+        source_job = sql_get_job(session, source.id[-1], workload)
     except:
         sys.stderr.write(_("rmln: no such source job or jobset\n"))
         sql_session.cancel_session(session)
