@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2011-2013 Herve Quatremain
+# Copyright (C) 2011-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -35,7 +35,6 @@ from tables.job_file_err import job_file_err
 from tables.job_control_group import job_control_group
 from tables.job_loadenv import job_loadenv
 from tables.job_detach import job_detach
-from tables.job_manual import job_manual
 from tables.job_manual_command import job_manual_command
 from tables.job_success_return_code import job_success_return_code
 from tables.job_command import job_command
@@ -100,7 +99,6 @@ Options:
   --deldetach             use the value defined in the parent jobset instead.
   --manual=True|False     ask confirmation (True) to operators to start the
                           job or not (False).
-  --delmanual             use the value defined in the parent jobset instead.
   --manual-cmd=COMMAND    for manual jobs, command/script to run to alert
                           operators that a job is waiting for a start
                           confirmation. The following environment variables
@@ -108,8 +106,9 @@ Options:
                           SCHEDWI_TEMPLATE (the path to a text file that
                           contains the message to send to operators),
                           SCHEDWI_JOBPATH, SCHEDWI_JOBID, SCHEDWI_START_TIME,
-                          SCHEDWI_START_TIME_EPOCH, SCHEDWI_TIME_LIMIT and
-                          SCHEDWI_TIME_LIMIT_EPOCH.
+                          SCHEDWI_START_TIME_EPOCH, SCHEDWI_TIME_LIMIT,
+                          SCHEDWI_TIME_LIMIT_EPOCH, SCHEDWI_URN and
+                          SCHEDWI_PASSWORD.
   --delmanual-cmd         use the value defined in the parent jobset instead.
   --cgroup=NAME           Linux Control Group name to set for the job.  This
                           name is relative to the controllers mount point.
@@ -186,7 +185,6 @@ def parse_args(argv):
                                       "detach=",
                                       "deldetach",
                                       "manual=",
-                                      "delmanual",
                                       "manual-cmd=",
                                       "delmanual-cmd",
                                       "cgroup=",
@@ -213,12 +211,11 @@ def parse_args(argv):
     return (optlist, args)
 
 
-def set(session, current_cwd, current_cwd_cal, job, opts):
+def set(session, current_cwd_cal, job, opts):
     """Change jobs and jobsets parameters.
 
     Arguments:
     session -- SQLAlchemy session
-    current_cwd -- current working jobset (a path.Path object)
     current_cwd_cal -- current working calendar directory (a path_cal.PathCal
                        object)
     job -- job object to change
@@ -239,11 +236,13 @@ def set(session, current_cwd, current_cwd_cal, job, opts):
             try:
                 host = host_utils.name2host(session, a)
             except NoResultFound:
-                sys.stderr.write(_("No such host (--host=%s)\n") % a)
+                sys.stderr.write(_("No such host (--host=%s)\n")
+                                 % a.decode('utf-8'))
                 return 1
             except MultipleResultsFound:
                 sys.stderr.write(_("More than one host match the provided \
-name (--host=%s)\n") % a)
+name (--host=%s)\n")
+                                 % a.decode('utf-8'))
                 return 1
             job.job_host = job_host(host.id)
             del job.job_cluster
@@ -255,22 +254,26 @@ name (--host=%s)\n") % a)
             try:
                 cluster = cluster_utils.name2cluster(session, a)
             except NoResultFound:
-                sys.stderr.write(_("No such cluster (--cluster=%s)\n") % a)
+                sys.stderr.write(_("No such cluster (--cluster=%s)\n")
+                                 % a.decode('utf-8'))
                 return 1
             except MultipleResultsFound:
                 sys.stderr.write(_("More than one cluster match the provided \
-name (--cluster=%s)\n") % a)
+name (--cluster=%s)\n")
+                                 % a.decode('utf-8'))
                 return 1
             job.job_cluster = job_cluster(cluster.id)
             del job.job_host
             if cluster_utils.num_host_in_cluster(session, cluster.id) == 0:
                 sys.stderr.write(_("Warning: the given cluster (--cluster=%s) \
-does not contain any host.\n") % a)
+does not contain any host.\n")
+                                 % a.decode('utf-8'))
                 sys.stderr.write(_("When this %s will start, the parent \
 host/cluster details are then going to be used instead.\n") %
                                  (_("jobset") if job.type == 0 else _("job")))
                 sys.stderr.write(_("You may however add hosts to this cluster \
-which the `clust set --host=HOSTNAME[:PORT] \"%s\"' command.\n") % a)
+which the `clust set --host=HOSTNAME[:PORT] \"%s\"' command.\n")
+                                 % a.decode('utf-8'))
 
         elif o == "--delcluster":
             del job.job_cluster
@@ -278,7 +281,8 @@ which the `clust set --host=HOSTNAME[:PORT] \"%s\"' command.\n") % a)
         elif o == "--calendar":
             c = path_cal.PathCal(session, path=a, cwd=current_cwd_cal)
             if not c:
-                sys.stderr.write(_("Unknown calendar %s (--calendar)\n") % a)
+                sys.stderr.write(_("Unknown calendar %s (--calendar)\n")
+                                 % a.decode('utf-8'))
                 return 1
             job.cal_id = c.id[-1]
 
@@ -431,11 +435,9 @@ number of minutes for the job to be started past its start time \
 
         elif o == "--manual":
             if a[0] in (_('Y'), _('y'), '1', _('t'), _('T')):
-                job.job_manual = job_manual(1)
+                job.manual = 1
             else:
-                job.job_manual = job_manual(0)
-        elif o == "--delmanual":
-            del job.job_manual
+                job.manual = 0
 
         elif o == "--manual-cmd":
             job.job_manual_command = job_manual_command(a)
@@ -446,7 +448,8 @@ number of minutes for the job to be started past its start time \
             try:
                 env = environments_utils.name2env(session, a)
             except NoResultFound:
-                sys.stderr.write(_("No such environment %s (--addenv)\n") % a)
+                sys.stderr.write(_("No such environment %s (--addenv)\n")
+                                 % a.decode('utf-8'))
                 return 1
             try:
                 envs.remove(env.id)
@@ -458,7 +461,8 @@ number of minutes for the job to be started past its start time \
             try:
                 env = environments_utils.name2env(session, a)
             except NoResultFound:
-                sys.stderr.write(_("No such environment %s (--delenv)\n") % a)
+                sys.stderr.write(_("No such environment %s (--delenv)\n")
+                                 % a.decode('utf-8'))
                 return 1
             for e in job.job_environment:
                 if env.id == e.env_id:
@@ -486,11 +490,12 @@ number of minutes for the job to be started past its start time \
                 host = host_utils.name2host(session, h)
             except NoResultFound:
                 sys.stderr.write(_("No such host %s (--addfile=%s)\n")
-                                 % (h, a))
+                                 % (h.decode('utf-8'), a.decode('utf-8')))
                 return 1
             except MultipleResultsFound:
                 sys.stderr.write(_("More than one host matches the provided \
-name %s (--addfile=%s)\n") % (h, a))
+name %s (--addfile=%s)\n")
+                                 % (h.decode('utf-8'), a.decode('utf-8')))
                 return 1
             try:
                 constraint_files.remove(constraint_file(host.id, filename, 1))
@@ -516,11 +521,12 @@ name %s (--addfile=%s)\n") % (h, a))
                 host = host_utils.name2host(session, h)
             except NoResultFound:
                 sys.stderr.write(_("No such host %s (--delfile=%s)\n")
-                                 % (h, a))
+                                 % (h.decode('utf-8'), a.decode('utf-8')))
                 return 1
             except MultipleResultsFound:
                 sys.stderr.write(_("More than one host match the provided \
-name %s (--delfile=%s)\n") % (h, a))
+name %s (--delfile=%s)\n")
+                                 % (h.decode('utf-8'), a.decode('utf-8')))
                 return 1
             try:
                 job.constraint_file.remove(constraint_file(host.id,
