@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2011-2013 Herve Quatremain
+# Copyright (C) 2011-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -22,6 +22,7 @@
 import getopt
 import time
 import sys
+from datetime import datetime, timedelta
 
 from sqlalchemy.orm.exc import NoResultFound, MultipleResultsFound
 
@@ -36,7 +37,6 @@ from tables.job_file_err_s import job_file_err_s
 from tables.job_control_group_s import job_control_group_s
 from tables.job_loadenv_s import job_loadenv_s
 from tables.job_detach_s import job_detach_s
-from tables.job_manual_s import job_manual_s
 from tables.job_manual_command_s import job_manual_command_s
 from tables.job_success_return_code_s import job_success_return_code_s
 from tables.job_command_s import job_command_s
@@ -61,13 +61,14 @@ def usage():
 Change a job or jobset parameter.
 
 Options:
+  --enable=True|False     enable (True) or disable (False) the job/jobset.
   --host=HOSTNAME[:PORT]  host on which the job/jobset must be running.
   --delhost               remove the hostname so that the one from the
                           parent jobset is going to be used instead.
   --cluster=NAME          cluster on which the job/jobset must be running.
   --delcluster            remove the cluster so that the one from the
                           parent jobset is going to be used instead.
-  --start=TIME            start time of the job (HH:MM).
+  --start=TIME            start time of the job (HH:MM or `now').
   --delstart              use the start time of the parent jobset.
   --command=COMMAND       command to run (if set to `-', no command will be
                           started and the job will complete immediately)
@@ -101,7 +102,6 @@ Options:
   --deldetach             use the value defined in the parent jobset instead.
   --manual=True|False     ask confirmation (True) to operators to start the
                           job or not (False).
-  --delmanual             use the value defined in the parent jobset instead.
   --manual-cmd=COMMAND    for manual jobs, command/script to run to alert
                           operators that a job is waiting for a start
                           confirmation. The following environment variables
@@ -109,8 +109,9 @@ Options:
                           SCHEDWI_TEMPLATE (the path to a text file that
                           contains the message to send to operators),
                           SCHEDWI_JOBPATH, SCHEDWI_JOBID, SCHEDWI_START_TIME,
-                          SCHEDWI_START_TIME_EPOCH, SCHEDWI_TIME_LIMIT and
-                          SCHEDWI_TIME_LIMIT_EPOCH.
+                          SCHEDWI_START_TIME_EPOCH, SCHEDWI_TIME_LIMIT,
+                          SCHEDWI_TIME_LIMIT_EPOCH, SCHEDWI_URN and
+                          SCHEDWI_PASSWORD.
   --delmanual-cmd         use the value defined in the parent jobset instead.
   --cgroup=NAME           Linux Control Group name to set for the job.  This
                           name is relative to the controllers mount point.
@@ -170,6 +171,7 @@ def parse_args(argv):
     """
     optlist, args = getopt.getopt(argv, "h",
                                   [
+                                      "enable=",
                                       "host=",
                                       "delhost",
                                       "cluster=",
@@ -189,10 +191,9 @@ def parse_args(argv):
                                       "delstdout",
                                       "stderr=",
                                       "delstderr",
-                                      "detach",
+                                      "detach=",
                                       "deldetach",
                                       "manual=",
-                                      "delmanual",
                                       "manual-cmd=",
                                       "delmanual-cmd",
                                       "cgroup=",
@@ -236,15 +237,23 @@ def set(session, job, opts, workload):
     envs = list()
     status_code = 0
     for o, a in opts:
+        if o == "--enable":
+            if a[0] in (_('Y'), _('y'), '1', _('t'), _('T')):
+                job.enabled = 1
+            else:
+                job.enabled = 0
+
         if o == "--host":
             try:
                 host = host_utils.name2host(session, a)
             except NoResultFound:
-                sys.stderr.write(_("No such host (--host=%s)\n") % a)
+                sys.stderr.write(_("No such host (--host=%s)\n")
+                                 % a.decode('utf-8'))
                 return 1
             except MultipleResultsFound:
                 sys.stderr.write(_("More than one host match the provided \
-name (--host=%s)\n") % a)
+name (--host=%s)\n")
+                                 % a.decode('utf-8'))
                 return 1
             job.job_host = job_host_s(host.id, workload)
             del job.job_cluster
@@ -256,39 +265,51 @@ name (--host=%s)\n") % a)
             try:
                 cluster = cluster_utils.name2cluster(session, a)
             except NoResultFound:
-                sys.stderr.write(_("No such cluster (--cluster=%s)\n") % a)
+                sys.stderr.write(_("No such cluster (--cluster=%s)\n")
+                                 % a.decode('utf-8'))
                 return 1
             except MultipleResultsFound:
                 sys.stderr.write(_("More than one cluster match the provided \
-name (--cluster=%s)\n") % a)
+name (--cluster=%s)\n")
+                                 % a.decode('utf-8'))
                 return 1
             job.job_cluster = job_cluster_s(cluster.id, workload)
             del job.job_host
             if cluster_utils.num_host_in_cluster(session, cluster.id) == 0:
                 sys.stderr.write(_("Warning: the given cluster (--cluster=%s) \
-does not contain any host.\n") % a)
+does not contain any host.\n")
+                                 % a.decode('utf-8'))
                 sys.stderr.write(_("When this %s will start, the parent \
 host/cluster details are then going to be used instead.\n") %
                                  (_("jobset") if job.type == 0 else _("job")))
                 sys.stderr.write(_("You may however add hosts to this cluster \
-which the `clust set --host=HOSTNAME[:PORT] \"%s\"' command.\n") % a)
+which the `clust set --host=HOSTNAME[:PORT] \"%s\"' command.\n")
+                                 % a.decode('utf-8'))
 
         elif o == "--delcluster":
             del job.job_cluster
 
         elif o == "--start":
-            for fmt in ("%H:%M", "%I:%M %p", "%Hh%M", "%Ih%M %p"):
-                try:
-                    tstr = time.strptime(a, fmt)
-                except ValueError:
-                    continue
-                else:
-                    break
+            if a.lower() in (_('now'), 'now'):
+                job.start_time = int(time.time())
             else:
-                sys.stderr.write(_("Unknown time format (--start).  Should be \
-`H:M' or `H:M AM/PM'\n"))
-                return 1
-            job.start_time = tstr.tm_hour * 100 + tstr.tm_min
+                for fmt in ("%H:%M", "%I:%M %p", "%Hh%M", "%Ih%M %p"):
+                    try:
+                        tstr = time.strptime(a, fmt)
+                    except ValueError:
+                        continue
+                    else:
+                        break
+                else:
+                    sys.stderr.write(_("Unknown time format (--start).  \
+Should be `H:M', `H:M AM/PM' or `now'\n"))
+                    return 1
+                now = datetime.now()
+                if tstr.tm_hour * 100 + tstr.tm_min < \
+                   now.hour * 100 + now.minute:
+                    now = now + timedelta(days=1)
+                job.start_time = int(time.mktime(now.replace(
+                    hour=tstr.tm_hour, minute=tstr.tm_min).timetuple()))
 
         elif o == "--delstart":
             job.start_time = -1
@@ -338,7 +359,7 @@ which the `clust set --host=HOSTNAME[:PORT] \"%s\"' command.\n") % a)
             del job.job_file_err
         elif o == "--cgroup":
             job.job_control_group = job_control_group_s(a, workload)
-        elif o == "--delstderr":
+        elif o == "--delcgroup":
             del job.job_control_group
         elif o == "--duration":
             try:
@@ -396,8 +417,9 @@ the number of minutes between retries\n"))
                     if v < 0:
                         raise ValueError
                 except:
-                    sys.stderr.write(_("Wrong value for --limit.  Must be \
-the number of minutes allowed for the job to complete (0 means no limit)\n"))
+                    sys.stderr.write(_("Wrong value for --limit.  Must be the \
+number of minutes for the job to be started past its start time \
+(0 means no limit)\n"))
                     return 1
             job.job_start_limit = job_start_limit_s(v, workload)
 
@@ -422,11 +444,9 @@ the number of minutes allowed for the job to complete (0 means no limit)\n"))
 
         elif o == "--manual":
             if a[0] in (_('Y'), _('y'), '1', _('t'), _('T')):
-                job.job_manual = job_manual_s(1, workload)
+                job.manual = 1
             else:
-                job.job_manual = job_manual_s(0, workload)
-        elif o == "--delmanual":
-            del job.job_manual
+                job.manual = 0
 
         elif o == "--manual-cmd":
             job.job_manual_command = job_manual_command_s(a, workload)
@@ -437,7 +457,8 @@ the number of minutes allowed for the job to complete (0 means no limit)\n"))
             try:
                 env = environments_utils.name2env(session, a, workload)
             except NoResultFound:
-                sys.stderr.write(_("No such environment %s (--addenv)\n") % a)
+                sys.stderr.write(_("No such environment %s (--addenv)\n")
+                                 % a.decode('utf-8'))
                 return 1
             try:
                 envs.remove(env.id)
@@ -449,7 +470,8 @@ the number of minutes allowed for the job to complete (0 means no limit)\n"))
             try:
                 env = environments_utils.name2env(session, a, workload)
             except NoResultFound:
-                sys.stderr.write(_("No such environment %s (--delenv)\n") % a)
+                sys.stderr.write(_("No such environment %s (--delenv)\n")
+                                 % a.decode('utf-8'))
                 return 1
             for e in job.job_environment:
                 if env.id == e.env_id:
@@ -463,6 +485,9 @@ the number of minutes allowed for the job to complete (0 means no limit)\n"))
         elif o == "--disableenv":
             job.has_env = 0
 
+        elif o == "--description":
+            job.description = a.decode('utf-8')
+
         elif o == "--addfile":
             try:
                 h, exist, filename = a.split(',', 2)
@@ -474,11 +499,12 @@ the number of minutes allowed for the job to complete (0 means no limit)\n"))
                 host = host_utils.name2host(session, h)
             except NoResultFound:
                 sys.stderr.write(_("No such host %s (--addfile=%s)\n")
-                                 % (h, a))
+                                 % (h.decode('utf-8'), a.decode('utf-8')))
                 return 1
             except MultipleResultsFound:
                 sys.stderr.write(_("More than one host matches the provided \
-name %s (--addfile=%s)\n") % (h, a))
+name %s (--addfile=%s)\n")
+                                 % (h.decode('utf-8'), a.decode('utf-8')))
                 return 1
             try:
                 constraint_files.remove(constraint_file_s(host.id, filename,
@@ -507,11 +533,12 @@ name %s (--addfile=%s)\n") % (h, a))
                 host = host_utils.name2host(session, h)
             except NoResultFound:
                 sys.stderr.write(_("No such host %s (--delfile=%s)\n")
-                                 % (h, a))
+                                 % (h.decode('utf-8'), a.decode('utf-8')))
                 return 1
             except MultipleResultsFound:
                 sys.stderr.write(_("More than one host match the provided \
-name %s (--delfile=%s)\n") % (h, a))
+name %s (--delfile=%s)\n")
+                                 % (h.decode('utf-8'), a.decode('utf-8')))
                 return 1
             try:
                 job.constraint_file.remove(constraint_file_s(host.id, filename,
@@ -530,9 +557,6 @@ name %s (--delfile=%s)\n") % (h, a))
                 sys.stderr.write(_("Unknown status %s (--status)\n") % a)
                 return 1
 
-        elif o == "--description":
-            job.description = a.decode('utf-8')
-
         elif o in ("-h", "--help"):
             usage()
 
