@@ -160,7 +160,7 @@ def stat(sql_session, current_cwd, arguments):
         return 1
     first = True
     for p in paths:
-        if first == False:
+        if first is False:
             sys.stdout.write("\n")
         else:
             first = False
