@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2011-2013 Herve Quatremain
+# Copyright (C) 2011-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -520,8 +520,7 @@ Echo the STRING(s) to standard output.
         if self.context == JOB:
             if self.workload is None:
                 self.last_return_code = cmd_job.cat.cat(self.sql_session,
-                                                        self.cwd, args,
-                                                        self.workload)
+                                                        self.cwd, args)
             else:
                 self.last_return_code = cmd_job.cat.cat(self.sql_session,
                                                         self.cwd_workload,
@@ -747,7 +746,7 @@ Echo the STRING(s) to standard output.
             return []
 
     def do_rm(self, s):
-        """Remove jobs/jobsets, hosts, environment groups or calndars"""
+        """Remove jobs/jobsets, hosts, environment groups or calendars"""
         try:
             args = self._my_shlex(s)
         except:
@@ -758,7 +757,10 @@ Echo the STRING(s) to standard output.
                 self.last_return_code = cmd_job.rm.rm(self.sql_session,
                                                       self.cwd, args)
             else:
-                self.default("rm")
+                self.last_return_code = cmd_job.rm.rm(self.sql_session,
+                                                      self.cwd_workload,
+                                                      args,
+                                                      self.workload)
         elif self.context == HOST:
             self.last_return_code = cmd_hosts.rm.rm(self.sql_session, args)
         elif self.context == ENV:
@@ -810,9 +812,15 @@ Echo the STRING(s) to standard output.
         except:
             self.last_return_code = 1
             return self.last_return_code
-        if self.context == JOB and self.workload is None:
-            self.last_return_code = cmd_job.mv.mv(self.sql_session, self.cwd,
-                                                  args)
+        if self.context == JOB:
+            if self.workload is None:
+                self.last_return_code = cmd_job.mv.mv(self.sql_session,
+                                                      self.cwd, args)
+            else:
+                self.last_return_code = cmd_job.mv.mv(self.sql_session,
+                                                      self.cwd_workload,
+                                                      args,
+                                                      self.workload)
         elif self.context == CAL:
             if self.workload is None:
                 self.last_return_code = cmd_cal.mv.mv(self.sql_session,
@@ -859,9 +867,15 @@ Echo the STRING(s) to standard output.
         except:
             self.last_return_code = 1
             return self.last_return_code
-        if self.context == JOB and self.workload is None:
-            self.last_return_code = cmd_job.cp.cp(self.sql_session, self.cwd,
-                                                  args)
+        if self.context == JOB:
+            if self.workload is None:
+                self.last_return_code = cmd_job.cp.cp(self.sql_session,
+                                                      self.cwd, args)
+            else:
+                self.last_return_code = cmd_job.cp.cp(self.sql_session,
+                                                      self.cwd_workload,
+                                                      args,
+                                                      self.workload)
         elif self.context == CAL and self.workload is None:
             self.last_return_code = cmd_cal.cp.cp(self.sql_session,
                                                   self.cwd_cal, args)
@@ -891,9 +905,16 @@ Echo the STRING(s) to standard output.
         except:
             self.last_return_code = 1
             return self.last_return_code
-        if self.context == JOB and self.workload is None:
-            self.last_return_code = cmd_job.ln.ln(self.sql_session, self.cwd,
-                                                  args)
+        if self.context == JOB:
+            if self.workload is None:
+                self.last_return_code = cmd_job.ln.ln(self.sql_session,
+                                                      self.cwd, args,
+                                                      self.workload)
+            else:
+                self.last_return_code = cmd_job.ln.ln(self.sql_session,
+                                                      self.cwd_workload,
+                                                      args,
+                                                      self.workload)
         else:
             self.default("ln")
         return self.last_return_code
@@ -920,16 +941,23 @@ Echo the STRING(s) to standard output.
         except:
             self.last_return_code = 1
             return self.last_return_code
-        if self.context == JOB and self.workload is None:
-            self.last_return_code = cmd_job.rmln.rmln(self.sql_session,
-                                                      self.cwd, args)
+        if self.context == JOB:
+            if self.workload is None:
+                self.last_return_code = cmd_job.rmln.rmln(self.sql_session,
+                                                          self.cwd, args,
+                                                          self.workload)
+            else:
+                self.last_return_code = cmd_job.rmln.rmln(self.sql_session,
+                                                          self.cwd_workload,
+                                                          args,
+                                                          self.workload)
         else:
             self.default("rmln")
         return self.last_return_code
 
     def help_mk(self):
         if self.context == JOB:
-            cmd_job.mk.usage()
+            cmd_job.mk.usage(False if self.workload is None else True)
         elif self.context == HOST:
             cmd_hosts.mk.usage()
         elif self.context == ENV:
@@ -968,15 +996,23 @@ Echo the STRING(s) to standard output.
         except:
             self.last_return_code = 1
             return self.last_return_code
-        if self.workload is None:
-            if self.context == JOB:
+        if self.context == JOB:
+            if self.workload is None:
                 self.last_return_code = cmd_job.mk.mk(self.sql_session,
                                                       self.cwd, self.cwd_cal,
                                                       args)
-            elif self.context == HOST:
+            else:
+                self.last_return_code = cmd_job.mk.mk(self.sql_session,
+                                                      self.cwd_workload,
+                                                      self.cwd_cal_workload,
+                                                      args, self.workload)
+
+        elif self.context == ENV:
+            self.last_return_code = cmd_env.mk.mk(self.sql_session, args,
+                                                  self.workload)
+        elif self.workload is None:
+            if self.context == HOST:
                 self.last_return_code = cmd_hosts.mk.mk(self.sql_session, args)
-            elif self.context == ENV:
-                self.last_return_code = cmd_env.mk.mk(self.sql_session, args)
             elif self.context == CAL:
                 self.last_return_code = cmd_cal.mk.mk(self.sql_session,
                                                       self.cwd_cal, args)
@@ -988,7 +1024,7 @@ Echo the STRING(s) to standard output.
         return self.last_return_code
 
     def help_mkjs(self):
-        cmd_job.mkjs.usage()
+        cmd_job.mkjs.usage(False if self.workload is None else True)
 
     def complete_mkjs(self, text, line, start_index, end_index):
         """Readline argument completion"""
@@ -1010,10 +1046,15 @@ Echo the STRING(s) to standard output.
         except:
             self.last_return_code = 1
             return self.last_return_code
-        if self.context == JOB and self.workload is None:
-            self.last_return_code = cmd_job.mkjs.mkjs(self.sql_session,
-                                                      self.cwd, self.cwd_cal,
-                                                      args)
+        if self.context == JOB:
+            if self.workload is None:
+                self.last_return_code = cmd_job.mkjs.mkjs(self.sql_session,
+                                                          self.cwd,
+                                                          self.cwd_cal, args)
+            else:
+                self.last_return_code = cmd_job.mkjs.mkjs(
+                    self.sql_session, self.cwd_workload, self.cwd_cal_workload,
+                    args, self.workload)
         else:
             self.default("mkjs")
         return self.last_return_code
@@ -1579,6 +1620,7 @@ directly executed instead of entering the sub-command.""")
 A calendar formula is a way to define a calendar; it specifies days in a year.
 A formula may contains several lines, each of them defining a set of days.
 A comment can be added, on a line by itself, and must start by the # character.
+An empty formula selects no day at all.
 
 The syntax of each line may take several forms.
 
