@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2011-2013 Herve Quatremain
+# Copyright (C) 2011-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -27,9 +27,8 @@ from sqlalchemy import desc
 from sqlalchemy.orm.exc import NoResultFound, MultipleResultsFound
 
 import path
+import simple_queries_job
 from tables.job_status import job_status
-from tables.job_main import job_main
-from tables.job_main_s import job_main_s
 import status_utils
 import host_utils
 import colors
@@ -165,7 +164,7 @@ provided name (--host=%s)\n") % a)
         query = query.filter(job_status.host_id == options['host'])
     query = query.filter(job_status.status.in_(options['status']))
     query = query.order_by(desc(job_status.workload_date))
-    query = query.order_by(desc(job_status.start_time))
+    query = query.order_by(desc(job_status.time_status_set))
     prev_workload = None
     counter_status = [0, 0, 0, 0, 0]
     space = ' ' * (1 - colors.CHAR_COLOR_LEN)
@@ -175,14 +174,10 @@ provided name (--host=%s)\n") % a)
             p = path.id2path(session, j.job_id, j.workload_date)
         except NoResultFound:
             continue
-        if options['workload'] is None:
-            q = session.query(job_main)
-        else:
-            q = session.query(job_main_s)
-            q = q.filter(job_main_s.workload_date == options['workload'])
         # Retrieve the job (to check if it's a job or a jobset)
         try:
-            job = q.filter_by(id=j.job_id).one()
+            job = simple_queries_job.sql_get_job(session, j.job_id,
+                                                 options['workload'])
         except NoResultFound:
             continue
         if options['only_dir'] and job.type != 0:
@@ -213,8 +208,8 @@ provided name (--host=%s)\n") % a)
             elif j.error_msg:
                 message = _(" - %s - try %d") % (j.error_msg, j.retry_num)
         if options['print_time']:
-            date_time = time.strftime(options['time_format'],
-                                      time.localtime(j.start_time)) + ' - '
+            date_time = time.strftime(options['time_format'], time.localtime(
+                                      j.time_status_set)) + ' - '
         else:
             date_time = ''
         print "%s%s%s%s%s%s%s" % (date_time,
