@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2013 Herve Quatremain
+# Copyright (C) 2013-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -72,7 +72,8 @@ def _print_ack(session, path, ack=None):
             return 1
 
     if ack.status == 0:
-        print _("%(name)s (%(wordkload)d_%(jobid)d) waiting for acknowledgement since %(datetime)s") % \
+        print _("%(name)s (%(wordkload)d_%(jobid)d) waiting for \
+acknowledgement since %(datetime)s") % \
             {
                 "name": path,
                 "wordkload": ack.workload_date,
@@ -82,7 +83,8 @@ def _print_ack(session, path, ack=None):
                     format="full",
                     locale=locale_utils.get_locale())}
     else:
-        print _("%(name)s (%(wordkload)d_%(jobid)d) acknowledged by %(username)s at %(datetime)s") % \
+        print _("%(name)s (%(wordkload)d_%(jobid)d) acknowledged by \
+%(username)s at %(datetime)s") % \
             {
                 "name": path,
                 "wordkload": ack.workload_date,
@@ -114,7 +116,7 @@ def trigger_path(session, path):
         ack = sql_get_acknowledge_request_by_job_id(session, path.id[-1],
                                                     path.workload)
     except:
-        sys.stderr.write(_("trigger: `%s': no such pending job/jobset\n")
+        sys.stderr.write(_("trigger: `%s' is not pending\n")
                          % path)
         return 1
     # Check that the job/jobset is still pending
@@ -166,7 +168,7 @@ def trigger(sql_session, current_cwd, arguments, workload=None):
             # An argument is an unknow path
             if not p:
                 sys.stderr.write(_("trigger: `%s': no such job or jobset\n")
-                                 % arg)
+                                 % arg.decode('utf-8'))
                 return 1
             paths.extend(p)
     elif not listing_mode:
