@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2013 Herve Quatremain
+# Copyright (C) 2013-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -26,11 +26,11 @@ from sqlalchemy.orm.exc import NoResultFound
 from sqlalchemy import desc
 
 from tables.job_status import job_status
+from tables.job_main import ROOT_JOBSET_ID
+from tables.job_main_s import job_main_s
 import locale_utils
 import status_utils
 
-_ROOT_JOBSET_ID = 1
-
 
 def sql_get_workload_list(sql_session):
     """Return the list of workload objects.
@@ -49,7 +49,7 @@ def sql_get_workload_list(sql_session):
         session = sql_session
 
     query = session.query(job_status).filter(job_status.job_id ==
-                                             _ROOT_JOBSET_ID)
+                                             ROOT_JOBSET_ID)
     try:
         lst = query.order_by(desc(job_status.workload_date)).all()
     except:
@@ -111,7 +111,7 @@ def does_workload_exist(sql_session, workload):
     else:
         session = sql_session
     query = session.query(job_status).filter(job_status.job_id ==
-                                             _ROOT_JOBSET_ID)
+                                             ROOT_JOBSET_ID)
     try:
         query.filter(job_status.workload_date == workload).one()
     except NoResultFound:
@@ -138,9 +138,13 @@ def num_jobs_by_status(sql_session, workload):
         session = sql_session.open_session()
     else:
         session = sql_session
+
     query = session.query(job_status)
     query = query.filter(job_status.workload_date == workload)
     query = query.filter(job_status.status == status_utils.WAITING)
+    # Do not count disabled jobs and jobsets
+    query = query.filter(job_status.job_id == job_main_s.id)
+    query = query.filter(job_main_s.enabled != 0)
     num_waiting = query.count()
 
     query = session.query(job_status)
