@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2011-2013 Herve Quatremain
+# Copyright (C) 2011-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -25,7 +25,8 @@ import time
 import sqlalchemy.orm.session
 import babel.dates
 
-from tables.job_status import job_status
+from tables.job_status import job_status, TIME
+from simple_queries_job import sql_get_job
 import colors
 import locale_utils
 
@@ -159,9 +160,9 @@ def get_status_string(sql_session, job_id, workload):
     """
     job_status_obj = get_status(sql_session, job_id, workload)
     if not job_status_obj:
-        return status2string(WAITING)
+        return _("not planned")
     time_str = babel.dates.format_time(
-        datetime.fromtimestamp(job_status_obj.start_time),
+        datetime.fromtimestamp(job_status_obj.time_status_set),
         format="short",
         locale=locale_utils.get_locale())
     reason = job_status_obj.get_waiting_message()
@@ -194,7 +195,8 @@ def get_status_duration(sql_session, job_id, workload):
 
 
 def set_status(sql_session, job_id, workload, st):
-    """Set (force) the status of the given job/jobset.
+    """Set (force) the status of the given job/jobset.  Add it in the
+    job_status table if it does not exist there.
 
     @param sql_session:
                 SQLAlchemy session (it can be an opened session)
@@ -206,8 +208,6 @@ def set_status(sql_session, job_id, workload, st):
                 the status (WAITING, RUNNING, COMPLETED, FAILED)
     @raise ValueError:
                 the given status (in st) is an unknown state.
-    @raise sqlalchemy.orm.exc.NoResultFound:
-                the given job/jobset ID is not in the database.
     """
     if st not in status_list() or st == COMPLETED_OR_FAILED:
         raise ValueError
@@ -219,12 +219,13 @@ def set_status(sql_session, job_id, workload, st):
     query = query.filter(job_status.workload_date == workload)
     try:
         status = query.one()
+        status.status = st
+        status.error_msg = _("Status forced by user").decode('utf-8')
+        status.time_status_set = int(time.time())
     except:
-        if not isinstance(sql_session, sqlalchemy.orm.session.Session):
-            sql_session.close_session(session)
-        raise
-    status.status = st
-    status.error_msg = _("Status forced by user (TUI)").decode('utf-8')
-    status.start_time = int(time.time())
+        job = sql_get_job(session, job_id, workload)
+        job.job_status = job_status(st, int(time.time()), 0,
+                                    _("Status forced by user"), 0, None,
+                                    TIME, workload)
     if not isinstance(sql_session, sqlalchemy.orm.session.Session):
         sql_session.close_session(session)
