@@ -25,9 +25,9 @@ from base import Base, convert2unicode
 class constraint_file_s(Base):
     __tablename__ = 'constraint_file_s'
     __table_args__ = (
-            ForeignKeyConstraint(['job_id', 'workload_date'],
-                                ['job_main_s.id', 'job_main_s.workload_date']),
-            {})
+        ForeignKeyConstraint(['job_id', 'workload_date'],
+                             ['job_main_s.id', 'job_main_s.workload_date']),
+        {})
 
     job_id = Column(Integer, primary_key=True)
     host_id = Column(Integer, ForeignKey('hosts.id'), primary_key=True)
@@ -42,16 +42,16 @@ class constraint_file_s(Base):
         self.workload_date = workload_date
 
     def __eq__(self, other):
-        if      self.host_id == other.host_id \
-            and self.filename == other.filename \
-            and self.workload_date == other.workload_date:
+        if self.host_id == other.host_id and \
+           self.filename == other.filename and \
+           self.workload_date == other.workload_date:
             return True
         return False
 
     def __ne__(self, other):
-        if      self.host_id == other.host_id \
-            and self.filename == other.filename \
-            and self.workload_date == other.workload_date:
+        if self.host_id == other.host_id and \
+           self.filename == other.filename and \
+           self.workload_date == other.workload_date:
             return False
         return True
 
