@@ -1,24 +1,26 @@
 # Schedwi
-# Copyright (C) 2011 Herve Quatremain
-# 
+# Copyright (C) 2011, 2012 Herve Quatremain
+#
 # This file is part of Schedwi.
-# 
+#
 # Schedwi is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
-# 
+#
 # Schedwi is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from sqlalchemy import Column, Integer, String, ForeignKey
+from sqlalchemy.schema import Column, ForeignKey
+from sqlalchemy.types import Integer, String
+
+from base import Base, convert2unicode
 
-from base import Base
 
 class job_file_err(Base):
     __tablename__ = 'job_file_err'
@@ -27,7 +29,7 @@ class job_file_err(Base):
     file_err = Column(String(255))
 
     def __init__(self, file_err):
-        self.file_err = file_err
+        self.file_err = convert2unicode(file_err)
 
     def copy(self):
         return job_file_err(self.file_err)
