@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2011-2013 Herve Quatremain
+# Copyright (C) 2011-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -32,7 +32,6 @@ from job_file_err import job_file_err
 from job_control_group import job_control_group
 from job_loadenv import job_loadenv
 from job_detach import job_detach
-from job_manual import job_manual
 from job_manual_command import job_manual_command
 from job_success_return_code import job_success_return_code
 from job_command import job_command
@@ -45,6 +44,9 @@ from job_stat import job_stat
 from link import link
 
 
+ROOT_JOBSET_ID = 1
+
+
 class job_main(Base):
     __tablename__ = 'job_main'
 
@@ -54,6 +56,7 @@ class job_main(Base):
     type = Column(Integer)   # 0 (jobset) or 1 (job)
     enabled = Column(Integer)
     has_env = Column(Integer)
+    manual = Column(Integer)
     description = Column(Text)
     x = Column(Integer)
     y = Column(Integer)
@@ -96,8 +99,6 @@ class job_main(Base):
                                cascade="all, delete, delete-orphan")
     job_detach = relationship(job_detach, uselist=False, backref="job_main",
                               cascade="all, delete, delete-orphan")
-    job_manual = relationship(job_manual, uselist=False, backref="job_main",
-                              cascade="all, delete, delete-orphan")
     job_manual_command = relationship(job_manual_command, uselist=False,
                                       backref="job_main",
                                       cascade="all, delete, delete-orphan")
@@ -135,13 +136,14 @@ class job_main(Base):
                                 primaryjoin=link.job_id_destination == id,
                                 cascade="all, delete, delete-orphan")
 
-    def __init__(self, parent, name, type, enabled, has_env,
+    def __init__(self, parent, name, type, enabled, has_env, manual,
                  description, x, y, cal_id, start_time):
         self.parent = parent
         self.name = convert2unicode(name)
         self.type = type
         self.enabled = enabled
         self.has_env = has_env
+        self.manual = manual
         self.description = convert2unicode(description)
         self.x = x
         self.y = y
@@ -150,8 +152,8 @@ class job_main(Base):
 
     def copy(self):
         j = job_main(self.parent, self.name, self.type, self.enabled,
-                     self.has_env, self.description, self.x, self.y,
-                     self.cal_id, self.start_time)
+                     self.has_env, self.manual, self.description,
+                     self.x, self.y, self.cal_id, self.start_time)
         if self.job_start_limit:
             j.job_start_limit = self.job_start_limit.copy()
         else:
@@ -192,10 +194,6 @@ class job_main(Base):
             j.job_detach = self.job_detach.copy()
         else:
             j.job_detach = self.job_detach
-        if self.job_manual:
-            j.job_manual = self.job_manual.copy()
-        else:
-            j.job_manual = self.job_manual
         if self.job_manual_command:
             j.job_manual_command = self.job_manual_command.copy()
         else:
