@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2011-2013 Herve Quatremain
+# Copyright (C) 2011-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -16,9 +16,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import sqlalchemy.orm.session
 from sqlalchemy.schema import Column
 from sqlalchemy.types import Integer, Text, String
 from sqlalchemy.orm import relationship
+from sqlalchemy.sql import func
 
 from base import Base, convert2unicode
 
@@ -32,7 +34,6 @@ from job_file_err_s import job_file_err_s
 from job_control_group_s import job_control_group_s
 from job_loadenv_s import job_loadenv_s
 from job_detach_s import job_detach_s
-from job_manual_s import job_manual_s
 from job_manual_command_s import job_manual_command_s
 from job_success_return_code_s import job_success_return_code_s
 from job_command_s import job_command_s
@@ -42,6 +43,7 @@ from job_host_s import job_host_s
 from job_cluster_s import job_cluster_s
 from constraint_file_s import constraint_file_s
 from link_s import link_s
+from job_status import job_status
 
 
 class job_main_s(Base):
@@ -50,13 +52,15 @@ class job_main_s(Base):
     id = Column(Integer, primary_key=True)
     parent = Column(Integer)
     name = Column(String(255))
-    rw_name = False
+    rw_name = True
     type = Column(Integer)   # 0 (jobset) or 1 (job)
     rw_type = False
     enabled = Column(Integer)
-    rw_enabled = False
+    rw_enabled = True
     has_env = Column(Integer)
     rw_has_env = True
+    manual = Column(Integer)
+    rw_manual = True
     description = Column(Text)
     rw_description = True
     x = Column(Integer)
@@ -64,8 +68,8 @@ class job_main_s(Base):
     y = Column(Integer)
     rw_y = True
     cal_id = Column(Integer)
-    rw_cal_id = False
-    start_time = Column(Integer)
+    rw_cal_id = True
+    start_time = Column(Integer)  # In seconds since epoch (time(2))
     rw_start_time = True
     workload_date = Column(Integer, primary_key=True)
 
@@ -117,10 +121,6 @@ class job_main_s(Base):
                               backref="job_main_s",
                               cascade="all, delete, delete-orphan")
     rw_job_detach = True
-    job_manual = relationship(job_manual_s, uselist=False,
-                              backref="job_main_s",
-                              cascade="all, delete, delete-orphan")
-    rw_job_manual = True
     job_manual_command = relationship(job_manual_command_s, uselist=False,
                                       backref="job_main_s",
                                       cascade="all, delete, delete-orphan")
@@ -158,22 +158,35 @@ class job_main_s(Base):
                                    backref="job_main_s",
                                    cascade="all, delete, delete-orphan")
     rw_constraint_file = True
-    links = relationship(link_s, backref="job_main_s",
-                         primaryjoin=link_s.job_id_source == id,
-                         cascade="all, delete, delete-orphan")
-    rw_links = False
-    link_targets = relationship(link_s,
-                                primaryjoin=link_s.job_id_destination == id,
-                                cascade="all, delete, delete-orphan")
-    rw_link_targets = False
+    links = relationship(
+        link_s, backref="job_main_s",
+        primaryjoin="and_(link_s.job_id_source==job_main_s.id, "
+                    "link_s.workload_date==job_main_s.workload_date)",
+        cascade="all, delete, delete-orphan")
+    rw_links = True
 
-    def __init__(self, parent, name, type, enabled, has_env,
+    link_targets = relationship(
+        link_s,
+        primaryjoin="and_(link_s.job_id_destination == job_main_s.id, "
+                    "link_s.workload_date == job_main_s.workload_date)",
+        cascade="all, delete, delete-orphan")
+    rw_link_targets = True
+
+    job_status = relationship(job_status,
+                              uselist=False,
+                              backref="job_main_s",
+                              cascade="all, delete, delete-orphan")
+    rw_job_status = False
+
+    def __init__(self, id, parent, name, type, enabled, has_env, manual,
                  description, x, y, cal_id, start_time, workload_date):
+        self.id = id
         self.parent = parent
         self.name = convert2unicode(name)
         self.type = type
         self.enabled = enabled
         self.has_env = has_env
+        self.manual = manual
         self.description = convert2unicode(description)
         self.x = x
         self.y = y
@@ -181,10 +194,11 @@ class job_main_s(Base):
         self.start_time = start_time
         self.workload_date = workload_date
 
-    def copy(self):
-        j = job_main_s(self.parent, self.name, self.type, self.enabled,
-                       self.has_env, self.description, self.x, self.y,
-                       self.cal_id, self.start_time, self.workload_date)
+    def copy(self, new_id):
+        j = job_main_s(new_id, self.parent, self.name, self.type, self.enabled,
+                       self.has_env, self.manual, self.description,
+                       self.x, self.y, self.cal_id, self.start_time,
+                       self.workload_date)
         if self.job_start_limit:
             j.job_start_limit = self.job_start_limit.copy()
         else:
@@ -225,10 +239,6 @@ class job_main_s(Base):
             j.job_detach = self.job_detach.copy()
         else:
             j.job_detach = self.job_detach
-        if self.job_manual:
-            j.job_manual = self.job_manual.copy()
-        else:
-            j.job_manual = self.job_manual
         if self.job_manual_command:
             j.job_manual_command = self.job_manual_command.copy()
         else:
@@ -261,4 +271,36 @@ class job_main_s(Base):
         j.links = list()
         for link in self.links:
             j.links.append(link.copy())
+        if self.job_status:
+            j.job_status = self.job_status.copy()
+        else:
+            j.job_status = self.job_status
         return j
+
+
+def get_next_id(sql_session, workload):
+    """Return the next available ID from the job_main_s database table.
+
+    @param sql_session:
+                SQLAlchemy session (it can be an opened session)
+    @param workload:
+                the workload to look for (YYYYMMDD)
+    @return:
+                The next available ID.
+    """
+    if not isinstance(sql_session, sqlalchemy.orm.session.Session):
+        session = sql_session.open_session()
+    else:
+        session = sql_session
+
+    query = session.query(func.max(job_main_s.id).label("max_id"))
+    try:
+        res = query.filter(job_main_s.workload_date == workload).one()
+    except:
+        new_id = 1
+    else:
+        new_id = res.max_id + 1
+
+    if not isinstance(sql_session, sqlalchemy.orm.session.Session):
+        sql_session.close_session(session)
+    return new_id
