@@ -28,8 +28,8 @@ class job_stat(Base):
     job_id = Column(Integer, ForeignKey('job_main.id'), primary_key=True)
     num_success = Column(Integer)
     num_failed = Column(Integer)
-    total_duration = Column(Integer)
-    last_duration = Column(Integer)
+    total_duration = Column(Integer)   # In seconds
+    last_duration = Column(Integer)    # In seconds
 
     def __init__(self, num_success, num_failed, total_duration, last_duration):
         self.num_success = num_success
