@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2011-2013 Herve Quatremain
+# Copyright (C) 2011-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -34,7 +34,7 @@ class job_status(Base):
 
     job_id = Column(Integer, primary_key=True)
     status = Column(Integer)
-    start_time = Column(Integer)  # Number of seconds since epoch
+    time_status_set = Column(Integer)  # Number of seconds since epoch
     retry_num = Column(Integer)
     wait_reason = Column(Integer)
     error_msg = Column(String(255))
@@ -42,20 +42,21 @@ class job_status(Base):
     host_id = Column(Integer)
     workload_date = Column(Integer, primary_key=True)
 
-    def __init__(self, status, start_time, retry_num, error_msg, duration,
-                 host_id, workload_date):
+    def __init__(self, status, time_status_set, retry_num, error_msg, duration,
+                 host_id, wait_reason, workload_date):
         self.status = status
-        self.start_time = start_time
+        self.time_status_set = time_status_set
         self.retry_num = retry_num
+        self.wait_reason = wait_reason
         self.error_msg = convert2unicode(error_msg)
         self.duration = duration
         self.host_id = host_id
         self.workload_date = workload_date
 
     def copy(self):
-        return job_status(self.status, self.start_time, self.retry_num,
+        return job_status(self.status, self.time_status_set, self.retry_num,
                           self.error_msg, self.duration, self.host_id,
-                          self.workload_date)
+                          self.wait_reason, self.workload_date)
 
     def is_waiting_for_parent(self):
         if self.status == 1 and self.wait_reason & PARENT:
