@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2013 Herve Quatremain
+# Copyright (C) 2013-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -46,7 +46,7 @@ from simple_queries_cal import (sql_get_cal_children, sql_count_cal_children,
 from cmd_cal.rm import rm_recursive_force
 from cmd_cal.cp import cp_recursive
 import cmd_cal.whatuses
-from tables.calendars import calendars
+from tables.calendars import (calendars, ROOT_CAL_DIR_ID)
 from tables.calendars_s import calendars_s
 
 
@@ -90,8 +90,6 @@ class CalendarWindow(Window, IClickListener, IValueChangeListener,
                      IExpandListener, ICollapseListener,
                      CutCopyPasteMenuListener):
 
-    _ROOT_DIR_ID = 1
-
     def __init__(self, refresh_obj, main_window,
                  sql_session, workload=None, cal_id_to_select=None):
         """Build the Calendar window.
@@ -250,7 +248,7 @@ class CalendarWindow(Window, IClickListener, IValueChangeListener,
             b = NativeButton()
             b.setIcon(ThemeResource('icons/copy.png'))
             b.setDescription(
-                    _("Mark the selected calendar or directory for copy"))
+                _("Mark the selected calendar or directory for copy"))
             b.setStyleName('toolbutton')
             b.setEnabled(False)
             b.addListener(self, IClickListener)
@@ -301,20 +299,21 @@ class CalendarWindow(Window, IClickListener, IValueChangeListener,
                 self._table.select(cal_id_to_select)
                 self._table.setCurrentPageFirstItemId(cal_id_to_select)
             else:
-                self._tree.select(self._ROOT_DIR_ID)
+                self._tree.select(ROOT_CAL_DIR_ID)
         elif _LAST_SELECTED is not None:
             try:
                 p = id2list(sql_session, _LAST_SELECTED, workload)
             except:
-                self._tree.expandItem(self._ROOT_DIR_ID)
-                self._tree.select(self._ROOT_DIR_ID)
+                self._tree.expandItem(ROOT_CAL_DIR_ID)
+                self._tree.select(ROOT_CAL_DIR_ID)
             else:
-                for i in p:
-                    self._tree.expandItem(i)
+                if p:
+                    for i in p:
+                        self._tree.expandItem(i)
                 self._tree.select(_LAST_SELECTED)
         else:
-            self._tree.expandItem(self._ROOT_DIR_ID)
-            self._tree.select(self._ROOT_DIR_ID)
+            self._tree.expandItem(ROOT_CAL_DIR_ID)
+            self._tree.select(ROOT_CAL_DIR_ID)
 
     def buttonClick(self, event):
         """Callback for the Close button and all the toolbar buttons."""
@@ -432,7 +431,7 @@ class CalendarWindow(Window, IClickListener, IValueChangeListener,
                 expandedIds.append(i)
 
         # Create a new container
-        self._tree.collapseItemsRecursively(self._ROOT_DIR_ID)
+        self._tree.collapseItemsRecursively(ROOT_CAL_DIR_ID)
         c = self._new_container_dir()
 
         # Re-expand the previously expanded items
@@ -457,7 +456,7 @@ class CalendarWindow(Window, IClickListener, IValueChangeListener,
             try:
                 sql_get_cal(self._sql_session, selected, self._workload)
             except:
-                self._tree.select(self._ROOT_DIR_ID)
+                self._tree.select(ROOT_CAL_DIR_ID)
 
         # Is the previously cut/copied item still in the database?
         if self._workload is None and _SELECTED_ID is not None:
@@ -472,7 +471,7 @@ class CalendarWindow(Window, IClickListener, IValueChangeListener,
         jContainer = HierarchicalContainer()
         jContainer.addContainerProperty('name', str, None)
         # Root calendar
-        item = jContainer.addItem(self._ROOT_DIR_ID)
+        item = jContainer.addItem(ROOT_CAL_DIR_ID)
         item.getItemProperty('name').setValue('/')
         self._tree.setContainerDataSource(jContainer)
         self._tree.setItemCaptionPropertyId('name')
@@ -589,9 +588,9 @@ class DeleteConfirmed(BoxCloseListener):
         self._c.repaint()
         if ret:
             self._c.get_application().showNotification(
-                    _("A calendar is in used and cannot be deleted"),
-                    _("<br/>%s is still used by a job or jobset.") % ret,
-                    Notification.TYPE_ERROR_MESSAGE)
+                _("A calendar is in used and cannot be deleted"),
+                _("<br/>%s is still used by a job or jobset.") % ret,
+                Notification.TYPE_ERROR_MESSAGE)
 
 
 class Tooltips(ItemDescriptionGenerator):
@@ -739,7 +738,7 @@ class CalendarTable(Table, IValueChangeListener, IHeaderClickListener,
                 e = Embedded(source=self._ICON_CAL)
                 item.getItemProperty('type').setValue(e)
                 item.getItemProperty('formula').setValue(
-                                                 cal.formula.encode('utf-8'))
+                    cal.formula.encode('utf-8'))
         self._dir_id = dir_id
         # Sort
         if self._sortCol == 'type':
@@ -811,8 +810,6 @@ class BreadCrumb(HorizontalLayout):
 
     """Bread crumb (path of the selected directory) UI."""
 
-    _ROOT_DIR_ID = 1
-
     def __init__(self, calendar_window_obj):
         """Create the object.
 
@@ -838,7 +835,7 @@ class BreadCrumb(HorizontalLayout):
             self.removeAllComponents()
             self._hierarchy_buttons = dict()
             for i in id2list(self._c._sql_session, dir_id, self._c._workload):
-                if i == self._ROOT_DIR_ID:
+                if i == ROOT_CAL_DIR_ID:
                     name = '/'
                 else:
                     c = sql_get_cal(self._c._sql_session, i, self._c._workload)
@@ -927,9 +924,9 @@ class CutCopyPasteMenu(GenericContextMenu):
     _ACTION_NEWCAL = Action(_('Create New Calendar...'),
                             ThemeResource('icons/calendar-new.png'))
     _ACTION_NEWDIR = Action(_('Create New Directory...'),
-                               ThemeResource('icons/dir-new.png'))
+                            ThemeResource('icons/dir-new.png'))
     _ACTION_WHAT = Action(_('List associated Jobs/Jobsets...'),
-                               ThemeResource('icons/search14.png'))
+                          ThemeResource('icons/search14.png'))
 
     def __init__(self, obj, sql_session, workload=None):
         """Initialize the object.
@@ -999,7 +996,7 @@ class CutCopyPasteMenu(GenericContextMenu):
             return None
         if _SELECTED_ID in id2list(self._sql_session, target, self._workload):
             self._c.getWindow().showNotification(
-                _("Cannot move a directory into itself") if _IS_CUT else \
+                _("Cannot move a directory into itself") if _IS_CUT else
                 _("Cannot copy a directory into itself"),
                 _("<br/>The destination directory is inside the source one."),
                 Notification.TYPE_ERROR_MESSAGE)
@@ -1013,9 +1010,9 @@ class CutCopyPasteMenu(GenericContextMenu):
         except:
             self._sql_session.close_session(session)
             self._c.getWindow().showNotification(
-                                _("Cannot get the source calendar details"),
-                                _("<br/>Maybe someone else just removed it."),
-                                Notification.TYPE_ERROR_MESSAGE)
+                _("Cannot get the source calendar details"),
+                _("<br/>Maybe someone else just removed it."),
+                Notification.TYPE_ERROR_MESSAGE)
             return None
         name = cal.name
 
@@ -1085,9 +1082,9 @@ class CutCopyPasteMenu(GenericContextMenu):
         except:
             self._sql_session.close_session(session)
             self._c.get_application().showNotification(
-                        _("Cannot get the source calendar details"),
-                        _("<br/>Maybe someone else just removed it."),
-                        Notification.TYPE_ERROR_MESSAGE)
+                _("Cannot get the source calendar details"),
+                _("<br/>Maybe someone else just removed it."),
+                Notification.TYPE_ERROR_MESSAGE)
             return
         if _IS_CUT:
             src_cal.parent = target
@@ -1098,9 +1095,9 @@ class CutCopyPasteMenu(GenericContextMenu):
             except:
                 self._sql_session.close_session(session)
                 self._c.get_application().showNotification(
-                            _("Cannot get the destination directory details"),
-                            _("<br/>Maybe someone else just removed it."),
-                            Notification.TYPE_ERROR_MESSAGE)
+                    _("Cannot get the destination directory details"),
+                    _("<br/>Maybe someone else just removed it."),
+                    Notification.TYPE_ERROR_MESSAGE)
                 return
             cp_recursive(session, src_cal, dst_cal, name.encode('utf-8'))
         self._sql_session.close_session(session)
@@ -1116,12 +1113,13 @@ class CutCopyPasteMenu(GenericContextMenu):
             obj = sql_get_cal(self._sql_session, target, self._workload)
         except:
             return
-        d = DeleteBox(self._c.get_application(), _("Delete"),
-          _('Are you sure you want to permanently delete "%s"?') % \
-                        obj.name.encode('utf-8'),
-   _('If you delete a directory, all its content will be permanently lost.') \
-                          if obj.entry_type != 0 else \
-                  _('If you delete a calendar, it will be permanently lost.'))
+        d = DeleteBox(
+            self._c.get_application(), _("Delete"),
+            _('Are you sure you want to permanently delete "%s"?') %
+            obj.name.encode('utf-8'),
+            _('If you delete a directory, all its content will be \
+            permanently lost.') if obj.entry_type != 0 else
+            _('If you delete a calendar, it will be permanently lost.'))
         d.addListener(DeleteConfirmed(self._c, obj))
 
     def do_whatuses(self, target):
@@ -1137,9 +1135,9 @@ class CutCopyPasteMenu(GenericContextMenu):
         except:
             self._sql_session.close_session(session)
             self._c.get_application().showNotification(
-                        _("Cannot get the calendar or directory details"),
-                        _("<br/>Maybe someone else just removed it."),
-                        Notification.TYPE_ERROR_MESSAGE)
+                _("Cannot get the calendar or directory details"),
+                _("<br/>Maybe someone else just removed it."),
+                Notification.TYPE_ERROR_MESSAGE)
             return
         p = PathCal(session, id=cal.id, workload=self._workload)
         # The jobs/jobsets that are using this calendar/directory are stored
@@ -1154,8 +1152,9 @@ class CutCopyPasteMenu(GenericContextMenu):
                                             self._workload, self._gather, self)
         self._sql_session.close_session(session)
         if not self._gathered:
-            self._c.get_application().showNotification(_("Not used"),
-                        _("<br/>%s is not used.") % cal.name.encode('utf-8'))
+            self._c.get_application().showNotification(
+                _("Not used"),
+                _("<br/>%s is not used.") % cal.name.encode('utf-8'))
         else:
             WhereWindow(self._c, self._gathered, cal.entry_type)
 
@@ -1176,17 +1175,15 @@ class CutCopyPasteMenu(GenericContextMenu):
 
 class CutCopyPasteMenuDirectoryTree(CutCopyPasteMenu):
 
-    _ROOT_DIR_ID = 1
-
     def __init__(self, calendar_window_obj):
         super(CutCopyPasteMenuDirectoryTree, self).__init__(
-                                            calendar_window_obj,
-                                            calendar_window_obj._sql_session,
-                                            calendar_window_obj._workload)
+            calendar_window_obj,
+            calendar_window_obj._sql_session,
+            calendar_window_obj._workload)
 
     def getActions(self, target, sender):
         if target is not None:
-            if target == self._ROOT_DIR_ID:
+            if target == ROOT_CAL_DIR_ID:
                 # Root Jobset
                 return [self._ACTION_PASTE]
             else:
@@ -1198,9 +1195,9 @@ class CutCopyPasteMenuDirectoryTree(CutCopyPasteMenu):
 class CutCopyPasteMenuCalendarTable(CutCopyPasteMenu):
     def __init__(self, calendar_table_obj):
         super(CutCopyPasteMenuCalendarTable, self).__init__(
-                                            calendar_table_obj,
-                                            calendar_table_obj._sql_session,
-                                            calendar_table_obj._workload)
+            calendar_table_obj,
+            calendar_table_obj._sql_session,
+            calendar_table_obj._workload)
 
     def getActions(self, target, sender):
         if not target:
@@ -1266,9 +1263,9 @@ class DirPopup(IClickListener):
                                 self._c._workload)
             except:
                 self._c._main_window.showNotification(
-                                _("Cannot get the directory details"),
-                                _("<br/>Maybe someone else just removed it."),
-                                Notification.TYPE_ERROR_MESSAGE)
+                    _("Cannot get the directory details"),
+                    _("<br/>Maybe someone else just removed it."),
+                    Notification.TYPE_ERROR_MESSAGE)
                 return
             self._old_name = c.name
             self._name.setValue(c.name.encode('utf-8'))
@@ -1295,10 +1292,10 @@ class DirPopup(IClickListener):
         dir_name = self._name.getValue().strip()
         if not dir_name:
             self._c._main_window.showNotification(
-               _("Invalid directory name"),
-               _("<br/>The directory name cannot be empty or \
-                  just contain spaces"),
-               Notification.TYPE_ERROR_MESSAGE)
+                _("Invalid directory name"),
+                _("<br/>The directory name cannot be empty or \
+                just contain spaces"),
+                Notification.TYPE_ERROR_MESSAGE)
             self._name.focus()
             return
 
@@ -1308,7 +1305,7 @@ class DirPopup(IClickListener):
             query = session.query(calendars)
         else:
             query = session.query(calendars_s)
-            query = query.filter(calendars_s.workload_date == \
+            query = query.filter(calendars_s.workload_date ==
                                  self._c._workload)
         query = query.filter_by(parent=self._parent_id)
         query = query.filter_by(name=dir_name.decode('utf-8'))
@@ -1317,15 +1314,15 @@ class DirPopup(IClickListener):
         except:
             pass
         else:
-            if (self._dir_id is None or
-                self._old_name != dir_name.decode('utf-8')):
-                    self._c._sql_session.close_session(session)
-                    self._c._main_window.showNotification(
-                        _("The name is already used"),
-                        _("<br/><br/>The specified name is already taken."),
-                        Notification.TYPE_ERROR_MESSAGE)
-                    self._name.focus()
-                    return
+            if self._dir_id is None or \
+               self._old_name != dir_name.decode('utf-8'):
+                self._c._sql_session.close_session(session)
+                self._c._main_window.showNotification(
+                    _("The name is already used"),
+                    _("<br/><br/>The specified name is already taken."),
+                    Notification.TYPE_ERROR_MESSAGE)
+                self._name.focus()
+                return
 
         # New directory
         if self._dir_id is None:
@@ -1341,9 +1338,9 @@ class DirPopup(IClickListener):
                 cal = sql_get_cal(session, self._dir_id, self._c._workload)
             except:
                 self._c._main_window.showNotification(
-                                _("Cannot get the directory details"),
-                                _("<br/>Maybe someone else just removed it."),
-                                Notification.TYPE_ERROR_MESSAGE)
+                    _("Cannot get the directory details"),
+                    _("<br/>Maybe someone else just removed it."),
+                    Notification.TYPE_ERROR_MESSAGE)
             else:
                 cal.name = dir_name.decode('utf-8')
         self._c._sql_session.close_session(session)
