@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2013 Herve Quatremain
+# Copyright (C) 2013-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -24,6 +24,7 @@ from muntjac.ui.window import Notification
 from muntjac.event.shortcut_listener import ShortcutListener
 from muntjac.event.shortcut_action import KeyCode
 
+from tables.job_main import ROOT_JOBSET_ID
 from web.boxes import DeleteBox, QuestionBox, BoxCloseListener
 from web.jobwindow import JobWindow
 from web.forcewindow import ForceWindow
@@ -65,7 +66,7 @@ class DeleteConfirmed(BoxCloseListener):
             _SELECTED_ID = None
         session = self._c._sql_session.open_session()
         p = id2path(session, self._id, self._c._workload)
-        rm_recursive(session, p, True, True)
+        rm_recursive(session, p, True, True, workload=self._c._workload)
         self._c._sql_session.close_session(session)
         self._c.repaint()
 
@@ -138,7 +139,7 @@ def _start_stop_job(obj, item_id, do_start):
     """
     s = status_utils.get_status(obj._sql_session, item_id, obj._workload)
     if do_start:
-        if s.status == status_utils.RUNNING:
+        if s and s.status == status_utils.RUNNING:
             n = Notification(
                 _('"%s" is already running') % obj.get_name(item_id),
                 Notification.TYPE_WARNING_MESSAGE)
@@ -151,7 +152,7 @@ def _start_stop_job(obj, item_id, do_start):
                             _('Are you sure you want to start "%s" now?') %
                             obj.get_name(item_id))
     else:
-        if s.status != status_utils.RUNNING:
+        if not s or s.status != status_utils.RUNNING:
             n = Notification(
                 _('"%s" is already stopped') % obj.get_name(item_id),
                 Notification.TYPE_WARNING_MESSAGE)
@@ -369,8 +370,8 @@ class CutCopyPasteMenu(GenericContextMenu):
         job_assoc = {}
         job_links = {}
         cp_recursive(self._sql_session, src_job, dest_jobset,
-                     job_assoc, job_links, name)
-        relink(self._sql_session, job_assoc, job_links)
+                     job_assoc, job_links, name, self._workload)
+        relink(self._sql_session, job_assoc, job_links, self._workload)
 
     def is_cut_or_copy(self):
         """Tell if an item has been marked for copy/cut.
@@ -501,25 +502,23 @@ class CutCopyPasteMenu(GenericContextMenu):
 
 class CutCopyPasteMenuJobsetTree(CutCopyPasteMenu):
 
-    _ROOT_JOBSET_ID = 1
-
     def __init__(self, jobsetTree):
         super(CutCopyPasteMenuJobsetTree, self).__init__(
             jobsetTree, jobsetTree._sql_session, jobsetTree._workload)
 
     def getActions(self, target, sender):
         if target is not None:
+            actions = [self._ACTION_EDIT]
             if self._workload is not None:
-                return [self._ACTION_EDIT,
-                        self._ACTION_START, self._ACTION_STOP,
-                        self._ACTION_FORCE]
-            if target == self._ROOT_JOBSET_ID:
+                actions.extend([self._ACTION_START, self._ACTION_STOP,
+                                self._ACTION_FORCE])
+            if target == ROOT_JOBSET_ID:
                 # Root Jobset
-                return [self._ACTION_EDIT, self._ACTION_PASTE]
+                actions.append(self._ACTION_PASTE)
             else:
-                return [self._ACTION_EDIT, self._ACTION_CUT,
-                        self._ACTION_COPY, self._ACTION_PASTE,
-                        self._ACTION_DELETE]
+                actions.extend([self._ACTION_CUT, self._ACTION_COPY,
+                                self._ACTION_PASTE, self._ACTION_DELETE])
+            return actions
 
 
 class CutCopyPasteMenuJobTable(CutCopyPasteMenu):
@@ -531,24 +530,22 @@ class CutCopyPasteMenuJobTable(CutCopyPasteMenu):
     def getActions(self, target, sender):
         if not target:
             # Background
-            if self._workload is None:
-                return [self._ACTION_NEWJOBSET, self._ACTION_NEWJOB,
-                        self._ACTION_PASTE]
-            else:
-                return None
+            return [self._ACTION_NEWJOBSET, self._ACTION_NEWJOB,
+                    self._ACTION_PASTE]
 
+        actions = [self._ACTION_EDIT]
         if self._workload is not None:
-            return [self._ACTION_EDIT,
-                    self._ACTION_START, self._ACTION_STOP, self._ACTION_FORCE]
+            actions.extend([self._ACTION_START, self._ACTION_STOP,
+                            self._ACTION_FORCE])
         if self._c.is_jobset(target):
             # Jobset
-            return [self._ACTION_EDIT, self._ACTION_CUT,
-                    self._ACTION_COPY, self._ACTION_PASTE,
-                    self._ACTION_DELETE]
+            actions.extend([self._ACTION_CUT, self._ACTION_COPY,
+                            self._ACTION_PASTE, self._ACTION_DELETE])
         else:
             # Job
-            return [self._ACTION_EDIT, self._ACTION_CUT,
-                    self._ACTION_COPY, self._ACTION_DELETE]
+            actions.extend([self._ACTION_CUT, self._ACTION_COPY,
+                            self._ACTION_DELETE])
+        return actions
 
 
 class DeleteShortcut(ShortcutListener):
