@@ -38,7 +38,7 @@ from web.cutcopypastemenu import GenericContextMenu
 import environments_utils
 import cmd_env.whatuses
 from tables.environments import environments
-from tables.environments_s import environments_s
+from tables.environments_s import (environments_s, get_next_id)
 from tables.environment_var import environment_var
 from tables.environment_var_s import environment_var_s
 
@@ -816,7 +816,8 @@ class NewEnvGroup(IClickListener):
                 if self._c._workload is None:
                     e = environments(name, descr)
                 else:
-                    e = environments_s(name, descr, self._c._workload)
+                    e = environments_s(get_next_id(session, self._c._workload),
+                                       name, descr, self._c._workload)
                 session.add(e)
 
             # Edit the environment group
@@ -833,7 +834,9 @@ class NewEnvGroup(IClickListener):
                         if self._c._workload is None:
                             e = environments(name, descr)
                         else:
-                            e = environments_s(name, descr, self._c._workload)
+                            e = environments_s(get_next_id(session,
+                                                           self._c._workload),
+                                               name, descr, self._c._workload)
                         session.add(e)
                 e.name = name.decode('utf-8')
                 e.description = descr.decode('utf-8')
