@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2012, 2013 Herve Quatremain
+# Copyright (C) 2012-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -31,7 +31,7 @@ import path
 import path_cal
 import simple_queries_job
 import environments_utils
-from tables.job_main import job_main
+from tables.job_main import (job_main, ROOT_JOBSET_ID)
 from tables.job_main_s import job_main_s
 from tables.calendars import calendars
 from tables.calendars_s import calendars_s
@@ -1080,8 +1080,6 @@ class ResultPopup(IClickListener):
 
     """Popup to display the find results."""
 
-    _ROOT_JOBSET_ID = 1
-
     def __init__(self, find_obj, container):
         """Create the popup.
 
@@ -1164,7 +1162,7 @@ class ResultPopup(IClickListener):
         obj_id = item.getItemProperty('id').getValue()
         obj_attr = item.getItemProperty('attr').getValue()
         if obj_type == Find._JOB:
-            if obj_id == self._ROOT_JOBSET_ID:
+            if obj_id == ROOT_JOBSET_ID:
                 ids = []
             else:
                 try:
