@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2012, 2013 Herve Quatremain
+# Copyright (C) 2012-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -748,6 +748,13 @@ class DeleteConfirmed(BoxCloseListener):
         except:
             pass
         else:
+            # Detach from the assosiated environment groups
+            q = session.query(host_environment)
+            for e in q.filter(host_environment.host_id == h.id):
+                session.delete(e)
+            q = session.query(host_environment_s)
+            for e in q.filter(host_environment_s.host_id == h.id):
+                session.delete(e)
             session.delete(h)
         self._c._sql_session.close_session(session)
         self._c.refresh_host_list(self._c.get_previous_host_id(self._host_id))
