@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2012, 2013 Herve Quatremain
+# Copyright (C) 2012-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -21,11 +21,13 @@
 from muntjac.api import Panel, Tree, HorizontalLayout, NativeButton, Alignment
 from muntjac.data.util.hierarchical_container import HierarchicalContainer
 from muntjac.data.property import IValueChangeListener
-from muntjac.ui.tree import IExpandListener, ICollapseListener
+from muntjac.ui.tree import (IExpandListener, ICollapseListener,
+                             IItemStyleGenerator)
 from muntjac.ui.button import IClickListener
 from muntjac.ui.abstract_select import ItemDescriptionGenerator
 from muntjac.terminal.theme_resource import ThemeResource
 
+from tables.job_main import ROOT_JOBSET_ID
 from simple_queries_job import (sql_get_children, sql_count_children,
                                 sql_count_children2, sql_get_job)
 from web.cutcopypastemenu import (CutCopyPasteMenuJobsetTree,
@@ -40,7 +42,6 @@ class JobsetTree(Panel, CutCopyPasteMenuListener,
 
     """Jobset tree UI."""
 
-    _ROOT_JOBSET_ID = 1
     _ICON_STATUS = {
         status_utils.WAITING: ThemeResource(
             status_utils.status2icon(status_utils.WAITING)),
@@ -70,14 +71,14 @@ class JobsetTree(Panel, CutCopyPasteMenuListener,
         self._workload = workload
 
         self._listeners = list()
-        self._selected = self._ROOT_JOBSET_ID
+        self._selected = ROOT_JOBSET_ID
 
         self.setCaption(_("Jobsets:"))
         self._tree = Tree()
         self._tree.setSizeFull()
         self._tree.setImmediate(True)
         self._tree.setNullSelectionAllowed(False)
-        self._tree.setItemDescriptionGenerator(Tooltips(sql_session, workload))
+        self._tree.setItemDescriptionGenerator(Tooltips(self))
         self._tree.addStyleName("jobsettree")
         self.addComponent(self._tree)
 
@@ -85,6 +86,7 @@ class JobsetTree(Panel, CutCopyPasteMenuListener,
         self._tree.setContainerDataSource(self._new_container())
         self._tree.setItemCaptionPropertyId('name')
         if self._workload is not None:
+            self._tree.setItemStyleGenerator(TreeStyleGenerator(self))
             self._tree.setItemIconPropertyId('icon')
 
         # Callbacks
@@ -98,8 +100,8 @@ class JobsetTree(Panel, CutCopyPasteMenuListener,
         self.add_listener(self._bread_crumb)
 
         # Expand the first tree level
-        self._tree.expandItem(self._ROOT_JOBSET_ID)
-        self._tree.select(self._ROOT_JOBSET_ID)
+        self._tree.expandItem(ROOT_JOBSET_ID)
+        self._tree.select(ROOT_JOBSET_ID)
 
     def get_breadcrumb(self):
         """Return the breadcrumb L{muntjac.api.HorizontalLayout}."""
@@ -125,11 +127,11 @@ class JobsetTree(Panel, CutCopyPasteMenuListener,
         if self._workload is not None:
             c.addContainerProperty('icon', ThemeResource, None)
         # Root jobset
-        item = c.addItem(self._ROOT_JOBSET_ID)
+        item = c.addItem(ROOT_JOBSET_ID)
         item.getItemProperty('name').setValue('/')
         if self._workload is not None:
             status = status_utils.get_status(self._sql_session,
-                                             self._ROOT_JOBSET_ID,
+                                             ROOT_JOBSET_ID,
                                              self._workload)
             item.getItemProperty('icon').setValue(
                 self._ICON_STATUS[status.status])
@@ -210,8 +212,9 @@ class JobsetTree(Panel, CutCopyPasteMenuListener,
             if self._workload is not None:
                 status = status_utils.get_status(session, child_id,
                                                  self._workload)
-                item.getItemProperty('icon').setValue(
-                    self._ICON_STATUS[status.status])
+                if status:
+                    item.getItemProperty('icon').setValue(
+                        self._ICON_STATUS[status.status])
             c.setParent(child_id, jobset_id)
             # Only show the expand arrow if the jobset has children
             if sql_count_children(session, child_id, True, self._workload):
@@ -264,7 +267,7 @@ class JobsetTree(Panel, CutCopyPasteMenuListener,
                 expandedIds.append(i)
 
         # Create a new container
-        self._tree.collapseItemsRecursively(self._ROOT_JOBSET_ID)
+        self._tree.collapseItemsRecursively(ROOT_JOBSET_ID)
         c = self._new_container()
         self._tree.setContainerDataSource(c)
 
@@ -289,7 +292,7 @@ class JobsetTree(Panel, CutCopyPasteMenuListener,
             try:
                 sql_get_job(self._sql_session, selected, self._workload)
             except:
-                self._tree.select(self._ROOT_JOBSET_ID)
+                self._tree.select(ROOT_JOBSET_ID)
 
     def get_parent_id(self):
         """From the L{web.cutcopypastemenu.CutCopyPasteMenuListener} class.
@@ -455,29 +458,51 @@ class Tooltips(ItemDescriptionGenerator):
 
     """Jobset tree item tooltips."""
 
-    def __init__(self, sql_session, workload=None):
+    def __init__(self, jobset_tree_obj):
         """Initialize the callback.
 
-        @param sql_session:
-                    SQLAlchemy session.
-        @param workload:
-                    workload to consider.
+        @param jobset_tree_obj:
+                    the associated L{JobsetTree} object.
         """
-        self._sql_session = sql_session
-        self._workload = workload
+        self._c = jobset_tree_obj
 
     def generateDescription(self, source, itemId, propertyId):
+        s = ''
+        if self._c._workload is not None and itemId:
+            c = self._c.get_datasource()
+            if not c.getItem(itemId).getItemProperty('icon').getValue():
+                s = _("Not planned") + '<br/>'
         try:
-            nb_jobs, nb_jobsets = sql_count_children2(self._sql_session,
-                                                      itemId, self._workload)
+            nb_jobs, nb_jobsets = sql_count_children2(self._c._sql_session,
+                                                      itemId,
+                                                      self._c._workload)
         except:
             nb_jobs = nb_jobsets = 0
         if nb_jobs == 1:
-            s = _("1 job")
+            s += _("1 job")
         else:
-            s = _("%d jobs") % nb_jobs
+            s += _("%d jobs") % nb_jobs
         if nb_jobsets == 1:
             s += '<br/>' + _("1 jobset")
         else:
             s += '<br/>' + _("%d jobsets") % nb_jobsets
         return s
+
+
+class TreeStyleGenerator(IItemStyleGenerator):
+
+    """IItemStyleGenerator object to style cells."""
+
+    def __init__(self, jobset_tree_obj):
+        """Initialize the callback.
+
+        @param jobset_tree_obj:
+                    the associated L{JobsetTree} object.
+        """
+        self._c = jobset_tree_obj
+
+    def getStyle(self, itemId):
+        if itemId:
+            c = self._c.get_datasource()
+            if not c.getItem(itemId).getItemProperty('icon').getValue():
+                return "notplanned"
