@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2012, 2013 Herve Quatremain
+# Copyright (C) 2012-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -26,7 +26,7 @@ from muntjac.api import (Table, VerticalLayout, HorizontalLayout, Label,
                          NativeButton, Alignment, ProgressIndicator)
 from muntjac.data.util.indexed_container import IndexedContainer
 from muntjac.data.property import IValueChangeListener
-from muntjac.ui.table import IHeaderClickListener
+from muntjac.ui.table import (IHeaderClickListener, ICellStyleGenerator)
 from muntjac.ui.button import IClickListener
 from muntjac.ui.window import Notification
 from muntjac.terminal.theme_resource import ThemeResource
@@ -54,7 +54,6 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
 
     """List of job and jobset UI."""
 
-    _ROOT_JOBSET_ID = 1
     _ICON_JOB = ThemeResource('icons/job.png')
     _ICON_JOBSET = ThemeResource('icons/jobset.png')
     _ICON_ENABLED = ThemeResource('icons/check.png')
@@ -109,67 +108,7 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
         btbox.addComponent(b)
         btbox.setComponentAlignment(b, Alignment.MIDDLE_CENTER)
 
-        if workload is None:
-            b = NativeButton()
-            b.setIcon(ThemeResource('icons/jobset-new.png'))
-            b.setDescription(_("Create a new Jobset"))
-            b.setStyleName('toolbutton')
-            b.setEnabled(False)
-            b.addListener(NewJobsetBtHandler(self), IClickListener)
-            btbox.addComponent(b)
-            self._btaddjobset = b
-
-            b = NativeButton()
-            b.setIcon(ThemeResource('icons/job-new.png'))
-            b.setDescription(_("Create a new Job"))
-            b.setStyleName('toolbutton')
-            b.setEnabled(False)
-            b.addListener(NewJobBtHandler(self), IClickListener)
-            btbox.addComponent(b)
-            self._btaddjob = b
-
-            b = NativeButton()
-            b.setIcon(ThemeResource('icons/delete.png'))
-            b.setDescription(_("Delete the selected job or jobset"))
-            b.setStyleName('toolbutton')
-            b.setEnabled(False)
-            b.addListener(DelBtHandler(self), IClickListener)
-            btbox.addComponent(b)
-            self._btdel = b
-
-            b = Label()  # Separator
-            b.setIcon(ThemeResource('icons/sep.png'))
-            btbox.addComponent(b)
-            btbox.setComponentAlignment(b, Alignment.MIDDLE_CENTER)
-
-            b = NativeButton()
-            b.setIcon(ThemeResource('icons/cut.png'))
-            b.setDescription(_("Cut the selected job or jobset"))
-            b.setStyleName('toolbutton')
-            b.setEnabled(False)
-            b.addListener(CutBtHandler(self), IClickListener)
-            btbox.addComponent(b)
-            self._btcut = b
-
-            b = NativeButton()
-            b.setIcon(ThemeResource('icons/copy.png'))
-            b.setDescription(_("Mark the selected job or jobset for copy"))
-            b.setStyleName('toolbutton')
-            b.setEnabled(False)
-            b.addListener(CopyBtHandler(self), IClickListener)
-            btbox.addComponent(b)
-            self._btcopy = b
-
-            b = NativeButton()
-            b.setIcon(ThemeResource('icons/paste.png'))
-            b.setDescription(
-                _("Paste the previously copied or cut job or jobset"))
-            b.setStyleName('toolbutton')
-            b.setEnabled(False)
-            b.addListener(PasteBtHandler(self), IClickListener)
-            btbox.addComponent(b)
-            self._btpaste = b
-        else:
+        if workload is not None:
             b = NativeButton()
             b.setIcon(ThemeResource('icons/start.png'))
             b.setDescription(_("Force Start"))
@@ -206,6 +145,71 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
             btbox.addComponent(b)
             self._btforce = b
 
+            b = Label()  # Separator
+            b.setIcon(ThemeResource('icons/sep.png'))
+            btbox.addComponent(b)
+            btbox.setComponentAlignment(b, Alignment.MIDDLE_CENTER)
+
+        b = NativeButton()
+        b.setIcon(ThemeResource('icons/jobset-new.png'))
+        b.setDescription(_("Create a new Jobset"))
+        b.setStyleName('toolbutton')
+        b.setEnabled(False)
+        b.addListener(NewJobsetBtHandler(self), IClickListener)
+        btbox.addComponent(b)
+        self._btaddjobset = b
+
+        b = NativeButton()
+        b.setIcon(ThemeResource('icons/job-new.png'))
+        b.setDescription(_("Create a new Job"))
+        b.setStyleName('toolbutton')
+        b.setEnabled(False)
+        b.addListener(NewJobBtHandler(self), IClickListener)
+        btbox.addComponent(b)
+        self._btaddjob = b
+
+        b = NativeButton()
+        b.setIcon(ThemeResource('icons/delete.png'))
+        b.setDescription(_("Delete the selected job or jobset"))
+        b.setStyleName('toolbutton')
+        b.setEnabled(False)
+        b.addListener(DelBtHandler(self), IClickListener)
+        btbox.addComponent(b)
+        self._btdel = b
+
+        b = Label()  # Separator
+        b.setIcon(ThemeResource('icons/sep.png'))
+        btbox.addComponent(b)
+        btbox.setComponentAlignment(b, Alignment.MIDDLE_CENTER)
+
+        b = NativeButton()
+        b.setIcon(ThemeResource('icons/cut.png'))
+        b.setDescription(_("Cut the selected job or jobset"))
+        b.setStyleName('toolbutton')
+        b.setEnabled(False)
+        b.addListener(CutBtHandler(self), IClickListener)
+        btbox.addComponent(b)
+        self._btcut = b
+
+        b = NativeButton()
+        b.setIcon(ThemeResource('icons/copy.png'))
+        b.setDescription(_("Mark the selected job or jobset for copy"))
+        b.setStyleName('toolbutton')
+        b.setEnabled(False)
+        b.addListener(CopyBtHandler(self), IClickListener)
+        btbox.addComponent(b)
+        self._btcopy = b
+
+        b = NativeButton()
+        b.setIcon(ThemeResource('icons/paste.png'))
+        b.setDescription(
+            _("Paste the previously copied or cut job or jobset"))
+        b.setStyleName('toolbutton')
+        b.setEnabled(False)
+        b.addListener(PasteBtHandler(self), IClickListener)
+        btbox.addComponent(b)
+        self._btpaste = b
+
         # Job/jobset table
         self._table = Table()
         self._table.setSizeFull()
@@ -256,6 +260,7 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
                                           _("Message")])
             self._table.setColumnWidth('status', 45)
             self._table.setColumnAlignment('status', Table.ALIGN_CENTER)
+            self._table.setCellStyleGenerator(TableStyleGenerator(self))
         self._table.setColumnWidth('type', 30)
         self._table.setColumnAlignment('type', Table.ALIGN_CENTER)
         self._table.setColumnWidth('enabled', 45)
@@ -333,22 +338,21 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
         """Set the state of the toolbar buttons."""
         if self._selected is not None:
             self._btedit.setEnabled(True)
-            if self._workload is None:
-                self._btdel.setEnabled(True)
-                self._btcut.setEnabled(True)
-                self._btcopy.setEnabled(True)
-            else:
+            self._btdel.setEnabled(True)
+            self._btcut.setEnabled(True)
+            self._btcopy.setEnabled(True)
+            if self._workload is not None:
                 session = self._sql_session.open_session()
                 s = status_utils.get_status(session, self._selected,
                                             self._workload)
-                if s.status != status_utils.RUNNING:
+                if not s or s.status != status_utils.RUNNING:
                     self._btstart.setEnabled(True)
                     self._btstop.setEnabled(False)
                 else:
                     self._btstart.setEnabled(False)
                     self._btstop.setEnabled(True)
                 self._btforce.setEnabled(True)
-                if s.status == status_utils.WAITING:
+                if s and s.status == status_utils.WAITING:
                     try:
                         ack = sql_get_acknowledge_request_by_job_id(
                             session, self._selected, self._workload)
@@ -364,22 +368,20 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
                 self._sql_session.close_session(session)
         else:
             self._btedit.setEnabled(False)
-            if self._workload is None:
-                self._btdel.setEnabled(False)
-                self._btcut.setEnabled(False)
-                self._btcopy.setEnabled(False)
-            else:
+            self._btdel.setEnabled(False)
+            self._btcut.setEnabled(False)
+            self._btcopy.setEnabled(False)
+            if self._workload is not None:
                 self._btstart.setEnabled(False)
                 self._btstop.setEnabled(False)
                 self._bttrigger.setEnabled(False)
                 self._btforce.setEnabled(False)
-        if self._workload is None:
-            if self._popup_menu.is_cut_or_copy():
-                self._btpaste.setEnabled(True)
-            else:
-                self._btpaste.setEnabled(False)
-            self._btaddjobset.setEnabled(True)
-            self._btaddjob.setEnabled(True)
+        if self._popup_menu.is_cut_or_copy():
+            self._btpaste.setEnabled(True)
+        else:
+            self._btpaste.setEnabled(False)
+        self._btaddjobset.setEnabled(True)
+        self._btaddjob.setEnabled(True)
 
     def headerClick(self, event):
         """Callback when the hearder of a column is clicked."""
@@ -474,17 +476,22 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
             if job.enabled:
                 e = Embedded(source=self._ICON_ENABLED)
                 item.getItemProperty('enabled').setValue(e)
+            # Get the current status of the job/jobset
+            if self._workload is not None:
+                status = status_utils.get_status(session, job.id,
+                                                 self._workload)
+            else:
+                status = None
             # Host/Cluster
             # If the job is running, then display the host on which it is
             # running rather than the cluster/host defined for this job.
             host = None
-            if self._workload is not None:
-                st = status_utils.get_status(session, job.id, self._workload)
-                if st.status == status_utils.RUNNING and st.host_id:
-                    try:
-                        host = host_utils.get_host_by_id(session, st.host_id)
-                    except:
-                        host = None
+            if status and status.status == status_utils.RUNNING and \
+               status.host_id:
+                try:
+                    host = host_utils.get_host_by_id(session, status.host_id)
+                except:
+                    host = None
             if host is None:
                 in_object, obj = sql_hierarchy.get_cluster_or_host_by_id(
                     session, jobset_ids, self._workload)
@@ -519,15 +526,13 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
                     unicode(s).encode('utf-8'))
             # Start time
             hour_str = None
-            if self._workload is not None:
-                status = status_utils.get_status(session, job.id,
-                                                 self._workload)
+            if status:
                 if status.status != status_utils.WAITING:
                     if status.error_msg:
                         item.getItemProperty('message').setValue(
                             status.error_msg.encode('utf-8'))
                     # Display the status change time
-                    st = time.localtime(status.start_time)
+                    st = time.localtime(status.time_status_set)
                     hour_str = "%02dh%02d" % (st.tm_hour, st.tm_min)
                 else:
                     item.getItemProperty('message').setValue(
@@ -542,13 +547,21 @@ class JobTable(VerticalLayout, IValueChangeListener, IHeaderClickListener,
                         session, jobset_ids, self._workload)
                     if obj is not None:
                         start_time = obj.start_time
-                        hour_str = "%02dh%02d" % (start_time / 100,
-                                                  start_time % 100)
+                        if self._workload is None:
+                            hour_str = "%02dh%02d" % (start_time / 100,
+                                                      start_time % 100)
+                        else:
+                            hour_str = time.strftime('%Hh%M', time.localtime(
+                                                     start_time))
                     else:
                         hour_str = '00h00'
                 else:
-                    hour_str = "%02dh%02d" % (job.start_time / 100,
-                                              job.start_time % 100)
+                    if self._workload is None:
+                        hour_str = "%02dh%02d" % (job.start_time / 100,
+                                                  job.start_time % 100)
+                    else:
+                        hour_str = time.strftime('%Hh%M', time.localtime(
+                                                 job.start_time))
             item.getItemProperty('start').setValue(hour_str)
             # Progress status
             if self._workload is not None:
@@ -930,3 +943,17 @@ class DoubleClick(IItemClickListener):
                 self._c._popup_menu.do_edit(item_id,
                                             event.getClientX(),
                                             event.getClientY())
+
+
+class TableStyleGenerator(ICellStyleGenerator):
+
+    """ICellStyleGenerator object to style de cells."""
+
+    def __init__(self, c):
+        self._c = c
+
+    def getStyle(self, itemId, propertyId):
+        if not propertyId and itemId:
+            c = self._c.get_datasource()
+            if not c.getItem(itemId).getItemProperty('status').getValue():
+                return "notplanned"
