@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2012, 2013 Herve Quatremain
+# Copyright (C) 2012-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -18,6 +18,9 @@
 
 """Widgets for the job/jobset parameters."""
 
+import time
+from datetime import datetime, timedelta
+
 from muntjac.api import CheckBox, TextField, HorizontalLayout, Label
 from muntjac.data.validators.integer_validator import IntegerValidator
 from muntjac.data.validators.regexp_validator import RegexpValidator
@@ -52,8 +55,6 @@ from tables.job_loadenv import job_loadenv
 from tables.job_loadenv_s import job_loadenv_s
 from tables.job_detach import job_detach
 from tables.job_detach_s import job_detach_s
-from tables.job_manual import job_manual
-from tables.job_manual_s import job_manual_s
 from tables.job_manual_command import job_manual_command
 from tables.job_manual_command_s import job_manual_command_s
 from web.autorefresh import AutoRefresh
@@ -741,59 +742,6 @@ class Detach(JobWidgetSimple):
         return None
 
 
-class Manual(JobWidgetSimple):
-    def __init__(self, jobset_ids, sql_session, workload=None, job_id=None):
-        super(Manual, self).__init__(
-            jobset_ids,
-            sql_session,
-            job_manual_s if workload else job_manual,
-            workload,
-            job_id)
-        self._savedValue = ''
-        self._w = CheckBox()
-        self._w.setDescription(_("Whether a confirmation must be asked to\
-                                 operators before starting the job"))
-        self._w.setImmediate(True)
-        self._addInheritedWidget(self._w)
-
-        if self._obj is not None:
-            self._w.setValue(bool(self._obj.manual))
-        else:
-            self._savedValue = bool(self._default_obj.manual)
-            self._setDefaultValue()
-            self._inherited.setValue(True)
-            self._doGreyOut()
-
-    def getFieldWidget(self):
-        return self._w
-
-    def _setDefaultValue(self):
-        self._w.setValue(bool(self._default_obj.manual))
-
-    def _saveValue(self):
-        self._savedValue = self._w.getValue()
-
-    def _restoreValue(self):
-        self._w.setValue(self._savedValue)
-
-    def setFocus(self):
-        self._w.focus()
-
-    def updateJob(self, job):
-        if self.isInherited():
-            try:
-                del job.job_manual
-            except:
-                pass
-            return None
-        v = int(self._w.getValue())
-        if self._workload is None:
-            job.job_manual = job_manual(v)
-        else:
-            job.job_manual = job_manual_s(v, self._workload)
-        return None
-
-
 class StartTimeError(Exception):
 
     """Syntax error in start time exception."""
@@ -862,8 +810,11 @@ class StartTime(JobWidget):
             self._doGreyOut()
 
     def _obj2str(self, start_time):
-        return ("%02d" % (start_time / 100),
-                "%02d" % (start_time % 100))
+        if self._workload is None:
+            return ("%02d" % (start_time / 100), "%02d" % (start_time % 100))
+        else:
+            t = datetime.fromtimestamp(start_time)
+            return (t.hour, t.minute)
 
     def getFieldWidget(self):
         return self._hb
@@ -910,7 +861,13 @@ class StartTime(JobWidget):
             self._m.focus()
             raise StartTimeError(_('Minute must be a number \
                                     between 00 and 59'))
-        return h * 100 + m
+        if self._workload is None:
+            return h * 100 + m
+        else:
+            now = datetime.now()
+            if h * 100 + m < now.hour * 100 + now.minute:
+                now = now + timedelta(days=1)
+            return int(time.mktime(now.replace(hour=h, minute=m).timetuple()))
 
     def updateJob(self, job):
         try:
