@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2012, 2013 Herve Quatremain
+# Copyright (C) 2012-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -18,6 +18,8 @@
 
 """Edit/Create job/jobset popup window."""
 
+import time
+
 from muntjac.api import (Window, CheckBox, TextField, TextArea, TabSheet,
                          HorizontalLayout, Button, Alignment, GridLayout,
                          Label, VerticalLayout)
@@ -30,8 +32,10 @@ import web.commandargswidget
 import web.calendarwidget
 import web.envwidget
 from simple_queries_job import sql_get_job, sql_get_children
+from status_utils import WAITING
 from tables.job_main import job_main
-from tables.job_main_s import job_main_s
+from tables.job_main_s import (job_main_s, get_next_id)
+from tables.job_status import (job_status, TIME)
 
 
 (FOCUS_NONE, FOCUS_NAME, FOCUS_DESCR, FOCUS_CMD, FOCUS_ARG,
@@ -123,12 +127,19 @@ class JobWindow(Window, IClickListener):
         # Components
         #
         self._enabled = CheckBox()
+        self._manual = CheckBox()
         self._name = TextField()
         self._descr = TextArea(_("Description"))
         if self._job_id is not None:
             self._enabled.setValue(bool(job.enabled))
+            self._manual.setValue(bool(job.manual))
             self._name.setValue(job.name.encode('utf-8'))
             self._descr.setValue(job.description.encode('utf-8'))
+        elif workload is not None:
+            # For a job/jobset in a workload set the enabled flag to false
+            # by default to prevent the job/jobset to start automatically
+            # immediately after been created
+            self._enabled.setValue(False)
         else:
             self._enabled.setValue(True)
 
@@ -182,7 +193,7 @@ class JobWindow(Window, IClickListener):
         t1.addComponent(self._enabled, 1, 0)
         t1.setComponentAlignment(self._enabled, Alignment.MIDDLE_LEFT)
         if workload is not None:
-            self._enabled.setEnabled(job.rw_enabled)
+            self._enabled.setEnabled(job_main_s.rw_enabled)
 
         # General/Name
         if not self._is_root:
@@ -195,7 +206,7 @@ class JobWindow(Window, IClickListener):
             t1.addComponent(self._name, 1, 1, 2, 1)
             t1.setComponentAlignment(self._name, Alignment.MIDDLE_LEFT)
             if workload is not None:
-                self._name.setEnabled(job.rw_name)
+                self._name.setEnabled(job_main_s.rw_name)
 
         # General/Host Name
         l = Label(_("Host/Cluster:"))
@@ -206,7 +217,7 @@ class JobWindow(Window, IClickListener):
                                 self._workload, self._job_id)
         t1.addComponent(w.getFieldWidget(), 1, 2)
         w.getFieldWidget().setWidth('100%')
-        if workload is not None and job.rw_job_host is False:
+        if workload is not None and job_main_s.rw_job_host is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
             t1.addComponent(w.getInheritedCheckbox(), 2, 2)
@@ -222,7 +233,7 @@ class JobWindow(Window, IClickListener):
         w = web.jobwidgets.Retries(self._jobset_ids, session,
                                    self._workload, self._job_id)
         t1.addComponent(w.getFieldWidget(), 1, 3)
-        if workload is not None and job.rw_job_retries is False:
+        if workload is not None and job_main_s.rw_job_retries is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
             t1.addComponent(w.getInheritedCheckbox(), 2, 3)
@@ -238,7 +249,8 @@ class JobWindow(Window, IClickListener):
         w = web.jobwidgets.RetryInterval(self._jobset_ids, session,
                                          self._workload, self._job_id)
         t1.addComponent(w.getFieldWidget(), 1, 4)
-        if workload is not None and job.rw_job_retries_interval is False:
+        if workload is not None and \
+           job_main_s.rw_job_retries_interval is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
             t1.addComponent(w.getInheritedCheckbox(), 2, 4)
@@ -248,7 +260,7 @@ class JobWindow(Window, IClickListener):
 
         # General/Description
         if workload is not None:
-            self._descr.setEnabled(job.rw_description)
+            self._descr.setEnabled(job_main_s.rw_description)
         if not self._is_root:
             self._descr.setSizeFull()
             t1.addComponent(self._descr, 0, 5, 2, 5)
@@ -271,7 +283,7 @@ class JobWindow(Window, IClickListener):
                                         self._sql_session,
                                         self._workload, self._job_id)
         t2.addComponent(w.getFieldWidget(), 1, 0)
-        if workload is not None and job.rw_cal_id is False:
+        if workload is not None and job_main_s.rw_cal_id is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
             t2.addComponent(w.getInheritedCheckbox(), 2, 0)
@@ -287,7 +299,7 @@ class JobWindow(Window, IClickListener):
         w = web.jobwidgets.StartTime(self._jobset_ids, session,
                                      self._workload, self._job_id)
         t2.addComponent(w.getFieldWidget(), 1, 1)
-        if workload is not None and job.rw_start_time is False:
+        if workload is not None and job_main_s.rw_start_time is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
             t2.addComponent(w.getInheritedCheckbox(), 2, 1)
@@ -303,7 +315,7 @@ class JobWindow(Window, IClickListener):
         w = web.jobwidgets.StartLimit(self._jobset_ids, session,
                                       self._workload, self._job_id)
         t2.addComponent(w.getFieldWidget(), 1, 2)
-        if workload is not None and job.rw_job_start_limit is False:
+        if workload is not None and job_main_s.rw_job_start_limit is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
             t2.addComponent(w.getInheritedCheckbox(), 2, 2)
@@ -319,7 +331,7 @@ class JobWindow(Window, IClickListener):
         w = web.jobwidgets.MaxDuration(self._jobset_ids, session,
                                        self._workload, self._job_id)
         t2.addComponent(w.getFieldWidget(), 1, 3)
-        if workload is not None and job.rw_job_max_duration is False:
+        if workload is not None and job_main_s.rw_job_max_duration is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
             t2.addComponent(w.getInheritedCheckbox(), 2, 3)
@@ -332,16 +344,12 @@ class JobWindow(Window, IClickListener):
         l.setWidth(None)
         t2.addComponent(l, 0, 4)
         t2.setComponentAlignment(l, Alignment.MIDDLE_RIGHT)
-        w = web.jobwidgets.Manual(self._jobset_ids, session,
-                                  self._workload, self._job_id)
-        t2.addComponent(w.getFieldWidget(), 1, 4)
-        if workload is not None and job.rw_job_manual is False:
-            w.getFieldWidget().setEnabled(False)
-        elif not self._is_root:
-            t2.addComponent(w.getInheritedCheckbox(), 2, 4)
-            t2.setComponentAlignment(w.getInheritedCheckbox(),
-                                     Alignment.MIDDLE_RIGHT)
-        self._manual = w
+        self._manual.setDescription(_("Whether a confirmation must be asked to\
+                                 operators before starting the job"))
+        t2.addComponent(self._manual, 1, 4)
+        t2.setComponentAlignment(self._manual, Alignment.MIDDLE_LEFT)
+        if workload is not None:
+            self._manual.setEnabled(job_main_s.rw_manual)
 
         # Triggers/Manual Command
         l = Label(_("Command:"))
@@ -356,10 +364,11 @@ class JobWindow(Window, IClickListener):
                set: SCHEDWI_TEMPLATE (the path to a text file that contains \
                the message to send to operators), SCHEDWI_JOBPATH, \
                SCHEDWI_JOBID, SCHEDWI_START_TIME, SCHEDWI_START_TIME_EPOCH, \
-               SCHEDWI_TIME_LIMIT and SCHEDWI_TIME_LIMIT_EPOCH"),
+               SCHEDWI_TIME_LIMIT, SCHEDWI_TIME_LIMIT_EPOCH, SCHEDWI_URN and \
+               SCHEDWI_PASSWORD"),
             self._workload, self._job_id)
         t2.addComponent(w.getFieldWidget(), 1, 5)
-        if workload is not None and job.rw_job_manual_command is False:
+        if workload is not None and job_main_s.rw_job_manual_command is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
             t2.addComponent(w.getInheritedCheckbox(), 2, 5)
@@ -388,7 +397,7 @@ class JobWindow(Window, IClickListener):
                                    self._workload,
                                    self._job_id)
         t3.addComponent(w.getFieldWidget(), 1, 0)
-        if workload is not None and job.rw_job_command is False:
+        if workload is not None and job_main_s.rw_job_command is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
             t3.addComponent(w.getInheritedCheckbox(), 2, 0)
@@ -408,7 +417,7 @@ class JobWindow(Window, IClickListener):
             self._workload,
             self._job_id)
         t3.addComponent(w.getFieldWidget(), 1, 1)
-        if workload is not None and job.rw_job_username is False:
+        if workload is not None and job_main_s.rw_job_username is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
             t3.addComponent(w.getInheritedCheckbox(), 2, 1)
@@ -427,7 +436,7 @@ class JobWindow(Window, IClickListener):
                                   self._workload,
                                   self._job_id)
         t3.addComponent(w.getFieldWidget(), 1, 2)
-        if workload is not None and job.rw_job_file_out is False:
+        if workload is not None and job_main_s.rw_job_file_out is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
             t3.addComponent(w.getInheritedCheckbox(), 2, 2)
@@ -446,7 +455,7 @@ class JobWindow(Window, IClickListener):
                                   self._workload,
                                   self._job_id)
         t3.addComponent(w.getFieldWidget(), 1, 3)
-        if workload is not None and job.rw_job_file_err is False:
+        if workload is not None and job_main_s.rw_job_file_err is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
             t3.addComponent(w.getInheritedCheckbox(), 2, 3)
@@ -462,7 +471,8 @@ class JobWindow(Window, IClickListener):
         w = web.jobwidgets.ReturnCode(self._jobset_ids, session,
                                       self._workload, self._job_id)
         t3.addComponent(w.getFieldWidget(), 1, 4)
-        if workload is not None and job.rw_job_success_return_code is False:
+        if workload is not None and \
+           job_main_s.rw_job_success_return_code is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
             t3.addComponent(w.getInheritedCheckbox(), 2, 4)
@@ -478,7 +488,7 @@ class JobWindow(Window, IClickListener):
         w = web.jobwidgets.Detach(self._jobset_ids, session,
                                   self._workload, self._job_id)
         t3.addComponent(w.getFieldWidget(), 1, 5)
-        if workload is not None and job.rw_job_detach is False:
+        if workload is not None and job_main_s.rw_job_detach is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
             t3.addComponent(w.getInheritedCheckbox(), 2, 5)
@@ -497,7 +507,7 @@ class JobWindow(Window, IClickListener):
                                   self._workload,
                                   self._job_id)
         t3.addComponent(w.getFieldWidget(), 1, 6)
-        if workload is not None and job.rw_job_control_group is False:
+        if workload is not None and job_main_s.rw_job_control_group is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
             t3.addComponent(w.getInheritedCheckbox(), 2, 6)
@@ -511,7 +521,7 @@ class JobWindow(Window, IClickListener):
                                               self._workload, self._job_id)
         w.getFieldWidget().setWidth("100%")
         t3.addComponent(w.getFieldWidget(), 0, 7, 1, 7)
-        if workload is not None and job.rw_job_arguments is False:
+        if workload is not None and job_main_s.rw_job_arguments is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
             t3.addComponent(w.getInheritedCheckbox(), 2, 7)
@@ -536,7 +546,7 @@ class JobWindow(Window, IClickListener):
                                    self._workload, self._job_id)
         le.addComponent(w.getFieldWidget())
         le.setExpandRatio(w.getFieldWidget(), 1.0)
-        if workload is not None and job.rw_job_loadenv is False:
+        if workload is not None and job_main_s.rw_job_loadenv is False:
             w.getFieldWidget().setEnabled(False)
         elif not self._is_root:
             le.addComponent(w.getInheritedCheckbox())
@@ -551,7 +561,7 @@ class JobWindow(Window, IClickListener):
                                     self._job_id)
         t4.addComponent(e)
         t4.setExpandRatio(e, 1.0)
-        if workload is not None and job.rw_job_environment is False:
+        if workload is not None and job_main_s.rw_job_environment is False:
             e.setEnabled(False)
         self._env = e
 
@@ -631,6 +641,7 @@ class JobWindow(Window, IClickListener):
                     self._name.focus()
                     return
             enabled = self._enabled.getValue()
+            manual = self._manual.getValue()
             description = self._descr.getValue()
             cal_id = self._cal.get_value()
             try:
@@ -647,12 +658,24 @@ class JobWindow(Window, IClickListener):
                 if self._workload is None:
                     job = job_main(self._jobset_ids[-1], name,
                                    1 if self._is_job else 0, int(enabled), 1,
+                                   int(manual),
                                    description, 0, 0, cal_id, start_time)
                 else:
-                    job = job_main_s(self._jobset_ids[-1], name,
+                    job = job_main_s(get_next_id(session, self._workload),
+                                     self._jobset_ids[-1], name,
                                      1 if self._is_job else 0, int(enabled), 1,
+                                     int(manual),
                                      description, 0, 0, cal_id, start_time,
                                      self._workload)
+                    job.job_status = job_status(status=WAITING,
+                                                time_status_set=int(
+                                                    time.time()),
+                                                retry_num=0,
+                                                error_msg=_("Manually added"),
+                                                duration=0,
+                                                host_id=None,
+                                                wait_reason=TIME,
+                                                workload_date=self._workload)
             else:
                 try:
                     job = sql_get_job(session, self._job_id, self._workload)
@@ -667,6 +690,7 @@ class JobWindow(Window, IClickListener):
                     return
                 job.name = name.decode('utf-8')
                 job.enabled = int(enabled)
+                job.manual = int(manual)
                 job.description = description.decode('utf-8')
                 job.cal_id = cal_id
                 job.start_time = start_time
@@ -716,7 +740,6 @@ class JobWindow(Window, IClickListener):
             self._env.updateJob(job)
             self._loadenv.updateJob(job)
             self._detach.updateJob(job)
-            self._manual.updateJob(job)
             self._manual_command.updateJob(job)
             msg = self._return_code.updateJob(job)
             if msg:
