@@ -195,9 +195,9 @@ class Links(HorizontalLayout, JobTableListener):
                 item = self._container.addItem(i)
                 item.getItemProperty('name').setValue(destination)
                 item.getItemProperty('mustbe').setValue(
-                            status_utils.status2string(lnk.required_status))
+                    status_utils.status2string(lnk.required_status))
                 item.getItemProperty('job_id').setValue(
-                                                long(lnk.job_id_destination))
+                    long(lnk.job_id_destination))
                 item.getItemProperty('link_type').setValue(lnk.required_status)
     #            if f.filename == filename and f.host_id == host_id:
     #                new_selection_id = i
@@ -297,8 +297,8 @@ class DeleteBtHandler(IClickListener):
         if self._c._selected is not None:
             r = self._c.getLinkDetails(self._c._selected)
             d = DeleteBox(self._c, _("Delete"),
-                  _('Are you sure you want to delete this link?'),
-                  _('%s (should be %s)') % (r['name'], r['mustbe']))
+                          _('Are you sure you want to delete this link?'),
+                          _('%s (should be %s)') % (r['name'], r['mustbe']))
             d.addListener(DeleteConfirmed(self._c, r['job_id']))
 
 
@@ -370,8 +370,8 @@ class LinkContextMenu(GenericContextMenu):
         elif a.getCaption() == self._ACTION_DELETE.getCaption():
             r = self._c.getLinkDetails(target)
             d = DeleteBox(self._c, _("Delete"),
-                  _('Are you sure you want to delete this link?'),
-                  _('%s (should be %s)') % (r['name'], r['mustbe']))
+                          _('Are you sure you want to delete this link?'),
+                          _('%s (should be %s)') % (r['name'], r['mustbe']))
             d.addListener(DeleteConfirmed(self._c, r['job_id']))
 
 
@@ -474,10 +474,9 @@ class WindowLink(IClickListener):
             dest_item_ids = self._select_job.getSelected()
             if not dest_item_ids:
                 self._c.getWindow().showNotification(
-                            _("No job nor jobset selected"),
-                            _("<br/>A destination job or jobset must be \
-                                  selected."),
-                            Notification.TYPE_ERROR_MESSAGE)
+                    _("No job nor jobset selected"),
+                    _("<br/>A destination job or jobset must be selected."),
+                    Notification.TYPE_ERROR_MESSAGE)
                 return
 
             # Get the job details from the database
@@ -487,9 +486,9 @@ class WindowLink(IClickListener):
             except:
                 self._c._sql_session.close_session(session)
                 self._c.getWindow().showNotification(
-                            _("Cannot get the selected job details"),
-                            _("<br/>Maybe someone else just removed it."),
-                            Notification.TYPE_ERROR_MESSAGE)
+                    _("Cannot get the selected job details"),
+                    _("<br/>Maybe someone else just removed it."),
+                    Notification.TYPE_ERROR_MESSAGE)
                 # Close the window
                 self._c.getWindow().removeWindow(self._w)
                 return
