@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2012 Herve Quatremain
+# Copyright (C) 2012-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -24,6 +24,7 @@ from muntjac.terminal.theme_resource import ThemeResource
 from muntjac.data.property import IValueChangeListener
 from muntjac.ui.tree import IExpandListener, ICollapseListener
 
+from tables.calendars import ROOT_CAL_DIR_ID
 from path_cal import id2list
 from simple_queries_cal import sql_get_cal_children, sql_count_cal_children
 
@@ -39,7 +40,6 @@ class SelectCalendar(Panel,
 
     _ICON_DIR = ThemeResource('icons/dir.png')
     _ICON_CAL = ThemeResource('icons/calendar.png')
-    _ROOT_DIR_ID = 1
 
     def __init__(self, sql_session, workload=None, selected_cal=None):
         """Build the calendar selection widget.
@@ -70,7 +70,7 @@ class SelectCalendar(Panel,
         jContainer.addContainerProperty('type', int, None)
         jContainer.addContainerProperty('icon', ThemeResource, None)
         # Root calendar
-        item = jContainer.addItem(self._ROOT_DIR_ID)
+        item = jContainer.addItem(ROOT_CAL_DIR_ID)
         item.getItemProperty('name').setValue('/')
         item.getItemProperty('type').setValue(1)
         item.getItemProperty('icon').setValue(self._ICON_DIR)
@@ -95,12 +95,12 @@ class SelectCalendar(Panel,
             try:
                 p = id2list(sql_session, _LAST_SELECTED, workload)
             except:
-                self._tree.expandItem(self._ROOT_DIR_ID)
+                self._tree.expandItem(ROOT_CAL_DIR_ID)
             else:
                 for i in p[:-1]:
                     self._tree.expandItem(i)
         else:
-            self._tree.expandItem(self._ROOT_DIR_ID)
+            self._tree.expandItem(ROOT_CAL_DIR_ID)
 
     def getSelected(self):
         """Return the path of the selected calendar.
