@@ -1,5 +1,5 @@
 # Schedwi
-# Copyright (C) 2012, 2013 Herve Quatremain
+# Copyright (C) 2012-2015 Herve Quatremain
 #
 # This file is part of Schedwi.
 #
@@ -96,7 +96,7 @@ class Status(Table, JobTableListener):
                          s.workload_date % 100)
                 date_str = dates.format_date(d, format='short',
                                              locale=locale_utils.get_locale())
-                dt = datetime.fromtimestamp(s.start_time)
+                dt = datetime.fromtimestamp(s.time_status_set)
                 dt_str = dates.format_datetime(
                     dt,
                     format='full',
