@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -159,19 +159,33 @@
 
 #include <schedwi.h>
 
-#include <time.h>
-#include <strings.h>
+#if STDC_HEADERS
 #include <stdlib.h>
 #include <string.h>
-#include <ctype.h>
-#include <assert.h>
+#else
+#if HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
+#if HAVE_STRING_H
+#include <string.h>
+#endif
+#endif
 
-#include <lib_functions.h>
+#if HAVE_TIME_H
+#include <time.h>
+#endif
+
+#if HAVE_CTYPE_H
+#include <ctype.h>
+#endif
+
+#if HAVE_ASSERT_H
+#include <assert.h>
+#endif
+
+#include <xmem.h>
 #include <calendar.h>
 
-#ifndef HAVE_STRNCASECMP
-#define strncasecmp(s1,s2,n) schedwi_strncasecmp(s1,s2,n)
-#endif
 
 /*
  * Check if the provided year is a leap year
@@ -223,6 +237,7 @@ day_of_week (int day, int month, int year)
 {
 	int y, m;
 
+
 	if (month < 1 || month > 12 || year < 0 || day < 1 || day > 31) {
 		return -1;
 	}
@@ -249,7 +264,10 @@ get_open_day (int month, int year, int inc)
 {
 	int wday, nb_week, mday;
 
+
+#if HAVE_ASSERT_H
 	assert (month > 0 && month < 13);
+#endif
 
 	if (inc > 0) {
 		inc--;
@@ -296,6 +314,7 @@ get_easter (int year, int *easter_month, int *easter_day)
 {
 	int a, b, c ,d, e, f, g ,h ,i ,k ,l ,m ,p;
 
+
 	a = year % 19;
 	b = year / 100;
 	c = year % 100;
@@ -322,6 +341,7 @@ get_paskha (int year)
 {
 	int a,b ,c, d, e, cumdays;
 
+
 	a=year % 19;
 	b=year %  4;
 	c=year %  7;
@@ -341,7 +361,9 @@ get_paskha (int year)
 static int
 is_bit_set (unsigned long int bit_field, int val)
 {
+#if HAVE_ASSERT_H
 	assert (val > 0);
+#endif
 
 	return bit_field & (1 << (val - 1));
 }
@@ -349,7 +371,9 @@ is_bit_set (unsigned long int bit_field, int val)
 static void
 add_day (cal_t *cal, int month, int day)
 {
+#if HAVE_ASSERT_H
 	assert (cal != NULL &&  month > 0 && month < 13 && day > 0 && day < 32);
+#endif
 
 	cal->month |= 1 << (month - 1);
 	cal->year[month - 1] |= 1 << (day - 1);
@@ -358,7 +382,9 @@ add_day (cal_t *cal, int month, int day)
 static void
 remove_day (cal_t *cal, int month, int day)
 {
+#if HAVE_ASSERT_H
 	assert (cal != NULL &&  month > 0 && month < 13 && day > 0 && day < 32);
+#endif
 
 	cal->year[month - 1] &= ~(1 << (day - 1));
 	if (cal->year[month - 1] == 0) {
@@ -369,7 +395,9 @@ remove_day (cal_t *cal, int month, int day)
 static void
 add_range (unsigned long int *bit_field, int min, int max, int length)
 {
+#if HAVE_ASSERT_H
 	assert (bit_field != NULL);
+#endif
 
 	if (min <= 0) {
 		min = 1;
@@ -390,7 +418,9 @@ add_range (unsigned long int *bit_field, int min, int max, int length)
 static void
 add_range_week (void *user_data, int min, int max)
 {
+#if HAVE_ASSERT_H
 	assert (user_data != NULL);
+#endif
 
 	add_range (user_data, min, max, 7);
 }
@@ -398,7 +428,9 @@ add_range_week (void *user_data, int min, int max)
 static void
 add_range_month (void *user_data, int min, int max)
 {
+#if HAVE_ASSERT_H
 	assert (user_data != NULL);
+#endif
 
 	add_range (user_data, min, max, 31);
 }
@@ -413,7 +445,10 @@ convert_mday (int val, int year, int month)
 {
 	int last_day, ret;;
 
+
+#if HAVE_ASSERT_H
 	assert (month > 0 && month < 13);
+#endif
 
 	/* If the value is positive, nothing has to be done */
 	if (val > 0) {
@@ -433,7 +468,10 @@ add_range_all_month (void *user_data, int min, int max)
 	int m, i, j;
 	cal_t *cal = user_data;
 
+
+#if HAVE_ASSERT_H
 	assert (user_data != NULL);
+#endif
 
 	for (m = 0; m < 12; m++) {
 		if (is_bit_set (cal->month, m + 1)) {
@@ -455,7 +493,10 @@ add_week (cal_t *cal, unsigned long int wday, int year)
 	int m, dow;
 	unsigned long int days;
 
+
+#if HAVE_ASSERT_H
 	assert (cal != NULL);
+#endif
 
 	/* Duplicate the week structure to create a month structure */
 	days = 0;
@@ -491,7 +532,10 @@ add_one_week (cal_t *cal, unsigned long int wday, int year, int week)
 	int m, i, dow, last;
 	unsigned long int days, d;
 
+
+#if HAVE_ASSERT_H
 	assert (cal != NULL);
+#endif
 
 	days = wday | (wday << 7);
 
@@ -556,7 +600,10 @@ parse_range (	char *str, int *error_idx_in_str,
 	int min, max, idx;
 	cal_errcode_t error;
 
+
+#if HAVE_ASSERT_H
 	assert (str != NULL && parse != NULL && set_range != NULL);
+#endif
 
 	idx = 0;
 	while (isspace (*str)) {
@@ -641,7 +688,10 @@ parse_list (	const char *str, int *error_idx_in_str,
 	char *s, *svg, *tok;
 	cal_errcode_t ret;
 
+
+#if HAVE_ASSERT_H
 	assert (str != NULL && parse != NULL && set_range != NULL);
+#endif
 
 	s = (char *) malloc (strlen (str) + 1);
 	if (s == NULL) {
@@ -685,7 +735,9 @@ parse_list (	const char *str, int *error_idx_in_str,
 static int
 get_month_number (const char *month_name)
 {
+#if HAVE_ASSERT_H
 	assert (month_name != NULL);
+#endif
 
 	if (strncasecmp (month_name, "Jan", 3) == 0) {
 		return 1;
@@ -739,7 +791,10 @@ parse_month (const char *month_str, cal_errcode_t *error)
 {
 	int i, m, ret;
 
+
+#if HAVE_ASSERT_H
 	assert (month_str != NULL);
+#endif
 
 	for (i = 0; isspace (month_str[i]); i++);
 	if (isdigit (month_str[i])) {
@@ -770,7 +825,9 @@ parse_month (const char *month_str, cal_errcode_t *error)
 static int
 get_day_number (const char *day_name)
 {
+#if HAVE_ASSERT_H
 	assert (day_name != NULL);
+#endif
 
 	if (strncasecmp (day_name, "Sun", 3) == 0) {
 		return 1;
@@ -809,7 +866,10 @@ parse_wday (const char *day_str, cal_errcode_t *error)
 {
 	int i, ret;
 
+
+#if HAVE_ASSERT_H
 	assert (day_str != NULL);
+#endif
 
 	for (i = 0; isspace (day_str[i]); i++);
 	ret = get_day_number (day_str + i);
@@ -834,7 +894,10 @@ parse_mday (const char *day_str, cal_errcode_t *error)
 {
 	int i, d;
 
+
+#if HAVE_ASSERT_H
 	assert (day_str != NULL);
+#endif
 
 	for (i = 0; isspace (day_str[i]); i++);
 	d = atoi (day_str + i);
@@ -859,7 +922,10 @@ set_day_increment (cal_t *cal, int year, int month, int day, int increment)
 	struct tm stm;
 	time_t tt;
 
+
+#if HAVE_ASSERT_H
 	assert (cal != NULL);
+#endif
 
 	stm.tm_year = year - 1900;
 	stm.tm_mon  = month - 1;
@@ -883,7 +949,9 @@ set_day_increment (cal_t *cal, int year, int month, int day, int increment)
 static void
 move_day (cal_t *cal, int year, int month, int day, int increment)
 {
+#if HAVE_ASSERT_H
 	assert (cal != NULL);
+#endif
 
 	remove_day (cal, month, day);
 	set_day_increment (cal, year, month, day, increment);
@@ -898,6 +966,7 @@ move_week_day (cal_t *cal, int year, int wday, int increment)
 {
 	int m, d, last_day;
 
+
 	for (m = 1; m <= 12; m++) {
 		if (is_bit_set (cal->month, m)) {
 			last_day = get_last_day (year, m);
@@ -927,7 +996,10 @@ parse_and_move_week_day (	cal_t *cal, int year, const char *day_str,
 {
 	int i, wday;
 
+
+#if HAVE_ASSERT_H
 	assert (cal != NULL && day_str != NULL);
+#endif
 
 	for (i = 0; isspace (day_str[i]); i++);
 	wday = get_day_number (day_str + i);
@@ -989,7 +1061,10 @@ parse_option_day_move (	cal_t *cal, int year, const char *str,
 	char *s, *svg, *tok;
 	cal_errcode_t ret;
 
+
+#if HAVE_ASSERT_H
 	assert (cal != NULL && str != NULL);
+#endif
 
 	s = (char *) malloc (strlen (str) + 1);
 	if (s == NULL) {
@@ -1033,7 +1108,10 @@ calcomp_easter (cal_t *cal, const char *date_str, int year)
 {
 	int month, day;
 
+
+#if HAVE_ASSERT_H
 	assert (cal != NULL && date_str != NULL);
+#endif
 
 	get_easter (year, &month, &day);
 	set_day_increment (cal, year, month, day, atoi (date_str));
@@ -1052,7 +1130,10 @@ calcomp_paskha (cal_t *cal, const char *date_str, int year)
 	time_t paskha_t;
 	struct tm paskha_tm;
 
+
+#if HAVE_ASSERT_H
 	assert (cal != NULL && date_str != NULL);
+#endif
 
 	yday = get_paskha (year);
 
@@ -1096,7 +1177,9 @@ calcomp_paskha (cal_t *cal, const char *date_str, int year)
 static cal_errcode_t
 calcomp_month (cal_t *cal, const char *month_str, int *error_idx_in_str)
 {
+#if HAVE_ASSERT_H
 	assert (cal != NULL && month_str != NULL);
+#endif
 
 	if (*month_str == '*') {
 		cal->month = ~0;
@@ -1120,7 +1203,10 @@ parse_inc (const char *day_opt)
 {
 	int val;
 
+
+#if HAVE_ASSERT_H
 	assert (day_opt != NULL);
+#endif
 
 	val = atoi (day_opt);
 	if (val == 0) {
@@ -1167,7 +1253,10 @@ parse_option (	cal_t *cal, const char *day_opt,
 {
 	int val;
 
+
+#if HAVE_ASSERT_H
 	assert (cal != NULL && day_opt != NULL);
+#endif
 
 	val = parse_inc (day_opt);
 	if (val == 0) {
@@ -1197,7 +1286,10 @@ parse_open_day (cal_t *cal, const char *day_opt, int year,
 	int val, m, n, ret;
 	unsigned long int wday;
 
+
+#if HAVE_ASSERT_H
 	assert (cal != NULL);
+#endif
 
 	for (n = 0; day_opt != NULL && isspace (day_opt[n]); n++);
 	if (day_opt == NULL || day_opt[n] == '\0') {
@@ -1277,7 +1369,10 @@ calcomp_day (	cal_t *cal, const char *day_str, const char *day_opt, int year,
 	unsigned long int day;
 	cal_errcode_t ret;
 
+
+#if HAVE_ASSERT_H
 	assert (cal != NULL && day_str != NULL);
+#endif
 
 	for (n = 0; isspace (day_str[n]); n++);
 
@@ -1353,7 +1448,10 @@ calinvert (cal_t *cal)
 {
 	int m;
 
+
+#if HAVE_ASSERT_H
 	assert (cal != NULL);
+#endif
 
 	for (m = 0; m < 12; m++) {
 		if (is_bit_set (cal->month, m + 1)) {
@@ -1405,6 +1503,7 @@ calcomp (cal_t *cal, const char *calendar, int year, int *error_idx_in_str)
 	int n;
 	cal_errcode_t ret;
 
+
 	if (cal == NULL || calendar == NULL) {
 		return CAL_NOERROR;
 	}
@@ -1438,11 +1537,7 @@ calcomp (cal_t *cal, const char *calendar, int year, int *error_idx_in_str)
 	strcpy (s, calendar + n);
 
 	/* Initialize the calendar structure */
-#if HAVE_MEMSET
 	memset (cal, 0, sizeof (cal_t));
-#else
-	schedwi_memset (cal, 0, sizeof (cal_t));
-#endif
 	cal->cal_year = year;
 
 	month_str = strtok_r (s, "/", &svg);
@@ -1520,7 +1615,9 @@ calcomp (cal_t *cal, const char *calendar, int year, int *error_idx_in_str)
 cal_errcode_t
 calmatch (const cal_t *cal, int day, int month, int year)
 {
+#if HAVE_ASSERT_H
 	assert (cal != NULL);
+#endif
 
 	if (	   cal->cal_year != year
 		|| is_bit_set (cal->month, month) == 0
@@ -1544,6 +1641,7 @@ copy_and_replace_LF (char *dest, const char *src)
 	size_t i;
 	unsigned int num_lines;
 
+
 	num_lines = 0;
 	for (i = 0; src[i] != '\0'; i++) {
 		if (src[i] == '\n') {
@@ -1603,7 +1701,12 @@ str2cal (cal_t *cal, const char *calendar, int year, int *error_idx_in_str)
 	cal_t *array_cal, cal_tmp;
 	cal_errcode_t ret;
 
-	if (cal == NULL || calendar == NULL) {
+
+	if (cal == NULL) {
+		return CAL_NOERROR;
+	}
+	if (calendar == NULL || calendar[0] == '\0') {
+		memset (cal, 0, sizeof (cal_t));
 		return CAL_NOERROR;
 	}
 
@@ -1621,11 +1724,7 @@ str2cal (cal_t *cal, const char *calendar, int year, int *error_idx_in_str)
 		free (work_str);
 		return CAL_MALLOC;
 	}
-#if HAVE_MEMSET
 	memset (array_cal, 0, sizeof (cal_t) * num_lines);
-#else
-	schedwi_memset (array_cal, 0, sizeof (cal_t) * num_lines);
-#endif
 	idx_add = 0;
 	idx_remove = num_lines - 1;
 
@@ -1682,11 +1781,7 @@ str2cal (cal_t *cal, const char *calendar, int year, int *error_idx_in_str)
 	free (work_str);
 
 	/* Initialize the calendar structure */
-#if HAVE_MEMSET
 	memset (cal, 0, sizeof (cal_t));
-#else
-	schedwi_memset (cal, 0, sizeof (cal_t));
-#endif
 	cal->cal_year = year;
 
 	/* Add all the cal_t object to the returned calendar */
