@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -51,10 +51,11 @@ typedef struct _calendar_list_t calendar_list_t;
 typedef struct _calendar_list_t *calendar_list_t_ptr;
 
 
-extern calendar_list_t_ptr new_calendar_list OF((schedwi_date workload_date));
+extern calendar_list_t_ptr new_calendar_list OF((
+				const schedwi_date *workload_date));
 extern void destroy_calendar_list OF((calendar_list_t_ptr ptr));
-extern int get_calendar_list_for_the_day OF((calendar_list_t_ptr ptr,
-					schedwi_date date, char **str));
+extern char *get_calendar_list_for_the_day OF((	calendar_list_t_ptr ptr,
+						const schedwi_date *date));
 
 #ifdef __cplusplus
 }
