@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2011-2013 Herve Quatremain
+   Copyright (C) 2011-2014 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -79,10 +79,10 @@ extern int errno;
 #include <gcrypt.h>
 
 
-#include <lib_functions.h>
 #include <utils.h>
 #include <lwc_log.h>
 #include <conf.h>
+#include <xmem.h>
 #include <cert_utils.h>
 #include <cert_ca.h>
 
@@ -99,8 +99,7 @@ static unsigned char buffer[4 * 1024];
  * Get hostname.
  *
  * Return:
- *   The hostname (to be freed by free()) OR
- *   NULL in case of memory allocation error.
+ *   The hostname (to be freed by free())
  */
 static char *
 get_hostname ()
@@ -115,10 +114,7 @@ get_hostname ()
 	len_name = 256;
 #endif
 
-	name = (char *) malloc (len_name);
-	if (name == NULL) {
-		return NULL;
-	}
+	name = (char *) xmalloc (len_name);
 
 	/*
 	 * First get the hostname.  If it contain a `.' then it's
@@ -145,13 +141,7 @@ get_hostname ()
 		return name;
 	}
 
-	s = (char *) malloc (	  schedwi_strlen (name)
-				+ schedwi_strlen (domain) + 2);
-	if (s == NULL) {
-		free (name);
-		return NULL;
-	}
-
+	s = (char *) xmalloc (strlen (name) + strlen (domain) + 2);
 	strcpy (s, name);
 	strcat (s, ".");
 	strcat (s, domain);
@@ -202,19 +192,10 @@ get_host_names ()
 #endif
 
 	if (conf_cn != NULL && conf_cn[0] != '\0') {
-		hostname = (char *) malloc (schedwi_strlen (conf_cn) + 1);
-		if (hostname == NULL) {
-			lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-			return NULL;
-		}
-		strcpy (hostname, conf_cn);
+		hostname = xstrdup (conf_cn);
 	}
 	else {
 		hostname = get_hostname ();
-		if (hostname == NULL) {
-			lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-			return NULL;
-		}
 	}
 
 	if (getifaddrs (&ifaddr) < 0) {
@@ -229,14 +210,7 @@ get_host_names ()
 		i++;
 	}
 
-	lst = (char **) malloc (sizeof (char *) * (i + 2));
-	if (lst == NULL) {
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		freeifaddrs (ifaddr);
-		free (hostname);
-		return NULL;
-	}
-
+	lst = (char **) xmalloc (sizeof (char *) * (i + 2));
 	lst[0] = hostname;
 	for (i = 1, ifa = ifaddr; ifa != NULL; ifa = ifa->ifa_next) {
 		family = ifa->ifa_addr->sa_family;
@@ -255,7 +229,7 @@ get_host_names ()
 					}
 				}
 				free (lst);
-				freeifaddrs(ifaddr);
+				freeifaddrs (ifaddr);
 				return NULL;
 			}
 
@@ -266,27 +240,13 @@ get_host_names ()
 				}
 			}
 			if (j == i) {
-				lst[i] = (char *) malloc (schedwi_strlen (host)
-								+ 1);
-				if (lst[i] == NULL) {
-					lwc_writeLog (LOG_CRIT,
-						_("Memory allocation error"));
-					while (--i >= 0) {
-						if (lst[i] != NULL) {
-							free (lst[i]);
-						}
-					}
-					free (lst);
-					freeifaddrs(ifaddr);
-					return NULL;
-				}
-				strcpy (lst[i], host);
+				lst[i] = xstrdup (host);
 				i++;
 			}
 		}
 	}
 	lst[i] = NULL;
-	freeifaddrs(ifaddr);
+	freeifaddrs (ifaddr);
 	return lst;
 }
 
@@ -445,8 +405,9 @@ generate_signed_certificate (	gnutls_x509_privkey_t ca_key,
 	/* Copy the CRL distribution points */
 	gnutls_x509_crt_cpy_crl_dist_points (crt, ca_crt);
 
-	/* Signing (SHA1) */
-	ret = gnutls_x509_crt_sign2 (crt, ca_crt, ca_key, GNUTLS_DIG_SHA1, 0);
+	/* Signing (SHA256) */
+	ret = gnutls_x509_crt_sign2 (	crt, ca_crt, ca_key, GNUTLS_DIG_SHA256,
+					0);
 	if (ret < 0) {
 		lwc_writeLog (	LOG_ERR,
 				_("SSL: Failed to sign the certificat: %s"),
@@ -535,7 +496,7 @@ generate_self_signed_certificate (gnutls_x509_privkey_t key,
 	/* Set the DN */
 	ret = gnutls_x509_crt_set_dn_by_oid (crt,
 				GNUTLS_OID_X520_COUNTRY_NAME, 0,
-				conf_c, schedwi_strlen (conf_c));
+				conf_c, strlen (conf_c));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the COUNTRY (%s): %s"),
@@ -546,7 +507,7 @@ generate_self_signed_certificate (gnutls_x509_privkey_t key,
 
 	ret = gnutls_x509_crt_set_dn_by_oid (crt,
 			GNUTLS_OID_X520_ORGANIZATION_NAME, 0,
-			conf_o, schedwi_strlen (conf_o));
+			conf_o, strlen (conf_o));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the ORGANIZATION (%s): %s"),
@@ -557,7 +518,7 @@ generate_self_signed_certificate (gnutls_x509_privkey_t key,
 
 	ret = gnutls_x509_crt_set_dn_by_oid (crt,
 				GNUTLS_OID_X520_ORGANIZATIONAL_UNIT_NAME, 0,
-				conf_ou, schedwi_strlen (conf_ou));
+				conf_ou, strlen (conf_ou));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the ORGANIZATIONAL UNIT (%s): %s"),
@@ -568,7 +529,7 @@ generate_self_signed_certificate (gnutls_x509_privkey_t key,
 
 	ret = gnutls_x509_crt_set_dn_by_oid (crt,
 				GNUTLS_OID_X520_LOCALITY_NAME, 0,
-				conf_l, schedwi_strlen (conf_l));
+				conf_l, strlen (conf_l));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the LOCALITY (%s): %s"),
@@ -579,7 +540,7 @@ generate_self_signed_certificate (gnutls_x509_privkey_t key,
 
 	ret = gnutls_x509_crt_set_dn_by_oid (crt,
 				GNUTLS_OID_X520_STATE_OR_PROVINCE_NAME, 0,
-				conf_st, schedwi_strlen (conf_st));
+				conf_st, strlen (conf_st));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the STATE (%s): %s"),
@@ -589,7 +550,7 @@ generate_self_signed_certificate (gnutls_x509_privkey_t key,
 	}
 
 	ret = gnutls_x509_crt_set_dn_by_oid (crt, GNUTLS_OID_X520_COMMON_NAME,
-					0, conf_cn, schedwi_strlen (conf_cn));
+					0, conf_cn, strlen (conf_cn));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the COMMON NAME (%s): %s"),
@@ -652,7 +613,7 @@ generate_self_signed_certificate (gnutls_x509_privkey_t key,
 		ret = gnutls_x509_crt_set_subject_alt_name (crt,
 					GNUTLS_SAN_RFC822NAME,
 					conf_email,
-					schedwi_strlen (conf_email),
+					strlen (conf_email),
 					GNUTLS_FSAN_APPEND);
 		if (ret < 0) {
 			lwc_writeLog (LOG_ERR,
@@ -704,8 +665,8 @@ generate_self_signed_certificate (gnutls_x509_privkey_t key,
 		return -1;
 	}
 
-	/* Self-signing (SHA1) */
-	ret = gnutls_x509_crt_sign2 (crt, crt, key, GNUTLS_DIG_SHA1, 0);
+	/* Self-signing (SHA256) */
+	ret = gnutls_x509_crt_sign2 (crt, crt, key, GNUTLS_DIG_SHA256, 0);
 	if (ret < 0) {
 		lwc_writeLog (	LOG_ERR,
 			_("SSL: Failed to self-sign the certificat: %s"),
@@ -851,6 +812,8 @@ load_request_from_file (const char *infile)
 	dat.data = (unsigned char *)read_file (infile, &size);
 	dat.size = size;
 	if (dat.data == NULL) {
+		lwc_writeLog (	LOG_ERR, _("SSL: %s: read error: %s"),
+				infile, strerror (errno));
 		gnutls_x509_crq_deinit (crq);
 		return NULL;
 	}
@@ -896,6 +859,8 @@ load_cert_from_file (const char *infile)
 
 	s = read_file (infile, &l);
 	if (s == NULL) {
+		lwc_writeLog (	LOG_ERR, _("SSL: %s: read error: %s"),
+				infile, strerror (errno));
 		return NULL;
 	}
 
@@ -971,6 +936,8 @@ cert_revoke (	gnutls_x509_privkey_t ca_key,
 		dat.data = (unsigned char *)read_file (crl_file, &size);
 		dat.size = size;
 		if (dat.data == NULL) {
+			lwc_writeLog (	LOG_ERR, _("SSL: %s: read error: %s"),
+					crl_file, strerror (errno));
 			gnutls_x509_crl_deinit (crl);
 			return -1;
 		}
@@ -1097,7 +1064,7 @@ cert_revoke (	gnutls_x509_privkey_t ca_key,
 		}
 
 		ret = gnutls_x509_crl_privkey_sign (	crl, ca_cert, abs_key,
-							GNUTLS_DIG_SHA1, 0);
+							GNUTLS_DIG_SHA256, 0);
 		gnutls_privkey_deinit (abs_key);
 	}
 #endif
@@ -1122,19 +1089,15 @@ cert_revoke (	gnutls_x509_privkey_t ca_key,
 
 	gnutls_x509_crl_deinit (crl);
 
-	tmp_file = (char *) malloc (	  schedwi_strlen (crl_file)
-					+ schedwi_strlen (TMP_EXTENSION)
+	tmp_file = (char *) xmalloc (strlen (crl_file) + strlen (TMP_EXTENSION)
 					+ 1);
-	if (tmp_file == NULL) {
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		return -1;
-	}
 	strcpy (tmp_file, crl_file);
 	strcat (tmp_file, TMP_EXTENSION);
 
 	file = fopen (tmp_file, "wb");
 	if (file == NULL) {
-		lwc_writeLog (LOG_ERR, _("%s: %s"), tmp_file, strerror (errno));
+		lwc_writeLog (LOG_ERR, _("%s: %s"), tmp_file,
+			      strerror (errno));
 		free (tmp_file);
 		return -1;
 	}
@@ -1148,7 +1111,8 @@ cert_revoke (	gnutls_x509_privkey_t ca_key,
 	}
 	if (fclose(file) != 0) {
 		my_unlink (tmp_file);
-		lwc_writeLog (LOG_ERR, _("%s: %s"), tmp_file, strerror (errno));
+		lwc_writeLog (LOG_ERR, _("%s: %s"), tmp_file,
+			      strerror (errno));
 		free (tmp_file);
 		return -1;
 	}
@@ -1411,10 +1375,7 @@ get_hostname_from_cert (gnutls_x509_crt_t cert)
 	assert (cert != NULL);
 #endif
 
-	dnsname = (char *) malloc (512);
-	if (dnsname == NULL) {
-		return NULL;
-	}
+	dnsname = (char *) xmalloc (512);
 
 	/*
 	 * First try to get a DNS name in an alternative name (subjectAltName)
@@ -1443,4 +1404,3 @@ get_hostname_from_cert (gnutls_x509_crt_t cert)
 }
 
 /*-----------------============== End Of File ==============-----------------*/
-
