@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2011-2013 Herve Quatremain
+   Copyright (C) 2011-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -80,10 +80,10 @@ extern int errno;
 #include <assert.h>
 #endif
 
-#include <lib_functions.h>
 #include <utils.h>
 #include <lwc_log.h>
 #include <conf.h>
+#include <xmem.h>
 #include <cert_utils.h>
 
 
@@ -97,8 +97,7 @@ extern int errno;
  * one (`newc') in the provided string.
  *
  * Return:
- *   A newly allocated string with all the occurences of `oldc' replaced OR
- *   NULL in case of memory allocation error.
+ *   A newly allocated string with all the occurences of `oldc' replaced
  */
 static char *
 tr (const char *instr, const char *oldc, const char *newc)
@@ -106,16 +105,14 @@ tr (const char *instr, const char *oldc, const char *newc)
 	char *outstr;
 	size_t i, j, len_newc;
 
+
 #if HAVE_ASSERT_H
 	assert (instr != NULL && oldc != NULL && newc != NULL);
 #endif
 
-	outstr = (char *) malloc (schedwi_strlen (instr) + 1);
-	if (outstr == NULL) {
-		return NULL;
-	}
+	outstr = (char *) xmalloc (strlen (instr) + 1);
 
-	len_newc = schedwi_strlen (newc);
+	len_newc = strlen (newc);
 	for (i = 0; instr[i] != '\0'; i++) {
 		outstr[i] = instr[i];
 		for (j = 0; oldc[j] != '\0'; j++) {
@@ -135,8 +132,7 @@ tr (const char *instr, const char *oldc, const char *newc)
  * Serialize a PEM encoded string (replace \n by @)
  *
  * Return:
- *   The serialized string (to be freed by free()) OR
- *   NULL in case of memory allocation error.
+ *   The serialized string (to be freed by free())
  */
 char *
 PEM2string (const char *pemstr)
@@ -149,8 +145,7 @@ PEM2string (const char *pemstr)
  * Unserialize a PEM encoded string (replace @ by \n)
  *
  * Return:
- *   The unserialized PEM string (to be freed by free()) OR
- *   NULL in case of memory allocation error.
+ *   The unserialized PEM string (to be freed by free())
  */
 char *
 string2PEM (const char *pemstr)
@@ -174,6 +169,7 @@ my_chown (const char *filename, const char *user, const char *group)
 	uid_t uid;
 	gid_t gid;
 
+
 	if (filename == NULL) {
 		return 0;
 	}
@@ -207,6 +203,7 @@ generate_private_key_int ()
 	gnutls_x509_privkey_t key;
 	int ret;
 
+
 	ret = gnutls_x509_privkey_init (&key);
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
@@ -244,6 +241,7 @@ write_private_key (	gnutls_x509_privkey_t key, const char *outfile,
 	size_t size;
 	FILE *file;
 
+
 	if (key == NULL || outfile == NULL) {
 		return 0;
 	}
@@ -299,6 +297,7 @@ generate_private_key (const char *outfile, const char *user, const char *group)
 {
 	gnutls_x509_privkey_t key;
 
+
 #if HAVE_ASSERT_H
 	assert (outfile != NULL);
 #endif
@@ -327,7 +326,8 @@ generate_private_key (const char *outfile, const char *user, const char *group)
 static int
 string_to_ip (unsigned char *ip, const char *str)
 {
-	int len = schedwi_strlen (str);
+	int len = strlen (str);
+
 
 #if defined AF_INET6
 	if (strchr (str, ':') != NULL || len > 16)
@@ -393,7 +393,7 @@ generate_request (gnutls_x509_privkey_t key,
 	/* Set the DN */
 	ret = gnutls_x509_crq_set_dn_by_oid (crq,
 				GNUTLS_OID_X520_COUNTRY_NAME, 0,
-				conf_c, schedwi_strlen (conf_c));
+				conf_c, strlen (conf_c));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the COUNTRY (%s): %s"),
@@ -404,7 +404,7 @@ generate_request (gnutls_x509_privkey_t key,
 
 	ret = gnutls_x509_crq_set_dn_by_oid (crq,
 			GNUTLS_OID_X520_ORGANIZATION_NAME, 0,
-			conf_o, schedwi_strlen (conf_o));
+			conf_o, strlen (conf_o));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the ORGANIZATION (%s): %s"),
@@ -415,7 +415,7 @@ generate_request (gnutls_x509_privkey_t key,
 
 	ret = gnutls_x509_crq_set_dn_by_oid (crq,
 				GNUTLS_OID_X520_ORGANIZATIONAL_UNIT_NAME, 0,
-				conf_ou, schedwi_strlen (conf_ou));
+				conf_ou, strlen (conf_ou));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the ORGANIZATIONAL UNIT (%s): %s"),
@@ -426,7 +426,7 @@ generate_request (gnutls_x509_privkey_t key,
 
 	ret = gnutls_x509_crq_set_dn_by_oid (crq,
 				GNUTLS_OID_X520_LOCALITY_NAME, 0,
-				conf_l, schedwi_strlen (conf_l));
+				conf_l, strlen (conf_l));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the LOCALITY (%s): %s"),
@@ -437,7 +437,7 @@ generate_request (gnutls_x509_privkey_t key,
 
 	ret = gnutls_x509_crq_set_dn_by_oid (crq,
 				GNUTLS_OID_X520_STATE_OR_PROVINCE_NAME, 0,
-				conf_st, schedwi_strlen (conf_st));
+				conf_st, strlen (conf_st));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the STATE (%s): %s"),
@@ -449,7 +449,7 @@ generate_request (gnutls_x509_privkey_t key,
 	/* The first name in the array is used as CN */
 	ret = gnutls_x509_crq_set_dn_by_oid (crq,
 					GNUTLS_OID_X520_COMMON_NAME, 0,
-					*dnsnames, schedwi_strlen (*dnsnames));
+					*dnsnames, strlen (*dnsnames));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the COMMON NAME (%s): %s"),
@@ -466,10 +466,10 @@ generate_request (gnutls_x509_privkey_t key,
 	 * data have to be stored, we'll then try to choose the best we can
 	 * the ones that are going to make it in the certificate.
 	 */
-	len = 	  schedwi_strlen (dnsnames[0]) * 2 /* In the CN and alt name */
-		+ ((ip != NULL) ? schedwi_strlen (ip) : 0);
+	len = 	  strlen (dnsnames[0]) * 2 /* In the CN and alt name */
+		+ ((ip != NULL) ? strlen (ip) : 0);
 	for (i = 1; dnsnames[i] != NULL; i++) {
-		len += schedwi_strlen (dnsnames[i]);
+		len += strlen (dnsnames[i]);
 	}
 
 	for (i = 0; dnsnames[i] != NULL; i++) {
@@ -481,7 +481,7 @@ generate_request (gnutls_x509_privkey_t key,
 				    || strcmp (dnsnames[i], "localhost") == 0
 				    || strcmp (dnsnames[i], "localhost6") == 0)
 				{
-					len -= schedwi_strlen (dnsnames[i]);
+					len -= strlen (dnsnames[i]);
 					if (   (ip == NULL || *ip == '\0')
 					    && isdigit (dnsnames[i][0]) != 0)
 					{
@@ -497,7 +497,7 @@ generate_request (gnutls_x509_privkey_t key,
 	 		ret = gnutls_x509_crq_set_subject_alt_name (crq,
 						GNUTLS_SAN_DNSNAME,
 						dnsnames[i],
-						schedwi_strlen (dnsnames[i]),
+						strlen (dnsnames[i]),
 						GNUTLS_FSAN_APPEND);
 			if (ret < 0) {
 				lwc_writeLog (LOG_ERR,
@@ -535,17 +535,11 @@ generate_request (gnutls_x509_privkey_t key,
 	/* Email */
 /* As the crq buffer has a limited size, just skip the useless Email
 
-	s = (char *) malloc (	  schedwi_strlen(CSR_EMAIL_PREFIX)
-				+ schedwi_strlen(*dnsnames) + 1);
-	if (s == NULL) {
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		gnutls_x509_crq_deinit (crq);
-		return NULL;
-	}
+	s = (char *) xmalloc(strlen(CSR_EMAIL_PREFIX) + strlen(*dnsnames) + 1);
 	strcpy (s, CSR_EMAIL_PREFIX);
 	strcat (s, *dnsnames);
 	ret = gnutls_x509_crq_set_subject_alt_name (crq, GNUTLS_SAN_RFC822NAME,
-						s, schedwi_strlen (s),
+						s, strlen (s),
 						GNUTLS_FSAN_APPEND);
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
@@ -634,7 +628,7 @@ generate_request (gnutls_x509_privkey_t key,
 			return NULL;
 		}
 		ret = gnutls_x509_crq_privkey_sign (	crq, abs_key,
-							GNUTLS_DIG_SHA1, 0);
+							GNUTLS_DIG_SHA256, 0);
 		gnutls_privkey_deinit (abs_key);
 	}
 #endif
@@ -682,6 +676,7 @@ my_gnutls_x509_crt_check_hostname (	void *cert_or_crq, type_data t,
 	gnutls_x509_crt_t cert;
 	gnutls_x509_crq_t crq;
 
+
 	if (t == CERT) {
 		cert = (gnutls_x509_crt_t) cert_or_crq;
 		crq = NULL;
@@ -717,9 +712,7 @@ my_gnutls_x509_crt_check_hostname (	void *cert_or_crq, type_data t,
 		if (ret == GNUTLS_SAN_DNSNAME) {
 			found_dnsname = 1;
 			for (j = 0; hostnames[j] != NULL; j++) {
-				if (schedwi_strcasecmp (hostnames[j],
-							dnsname) == 0)
-				{
+				if (strcasecmp (hostnames[j], dnsname) == 0) {
 					return (j + 1);
 				}
 			}
@@ -733,8 +726,8 @@ my_gnutls_x509_crt_check_hostname (	void *cert_or_crq, type_data t,
 					dnsname, name, 50) != NULL)
 			{
 				for (j = 0; hostnames[j] != NULL; j++) {
-					if (schedwi_strcasecmp (hostnames[j],
-								name) == 0)
+					if (strcasecmp (hostnames[j],
+							name) == 0)
 					{
 						return (j + 1);
 					}
@@ -762,7 +755,7 @@ my_gnutls_x509_crt_check_hostname (	void *cert_or_crq, type_data t,
 			return 0;
 		}
 		for (j = 0; hostnames[j] != NULL; j++) {
-			if (schedwi_strcasecmp (hostnames[j], dnsname) == 0) {
+			if (strcasecmp (hostnames[j], dnsname) == 0) {
 				return (j + 1);
 			}
 		}
@@ -773,67 +766,6 @@ my_gnutls_x509_crt_check_hostname (	void *cert_or_crq, type_data t,
 }
 
 
-/*
- * Read a file and return a newly allocated string with the content,
- * and set `*length' to the length of the string.  The string is
- * zero-terminated, but the terminating zero byte is not counted in
- * `*length'.
- *
- * Return:
- *   The content of the file (to be freed by free()) OR
- *   NULL in case of error (`*length' is undefined). A message has been logged.
- */
-char *
-read_file (const char *filename, size_t *length)
-{
-	struct stat stat_str;
-	FILE *f;
-	char *file_content;
-
-#if HAVE_ASSERT_H
-	assert (filename != NULL);
-#endif
-
-	/* Retrieve the file size */
-	if (stat (filename, &stat_str) != 0) {
-		lwc_writeLog (	LOG_ERR, _("%s: %s"),
-				filename, strerror (errno));
-		return NULL;
-	}
-
-	/* Create a buffer for reading the whole file */
-	file_content = (char *) malloc (stat_str.st_size + 1);
-	if (file_content == NULL) {
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		return NULL;
-	}
-
-	/* Open and read the whole file */
-	f = fopen (filename, "rb");
-	if (f == NULL) {
-		lwc_writeLog (	LOG_ERR, _("%s: %s"),
-				filename, strerror (errno));
-		free (file_content);
-		return NULL;
-	}
-
-	if (fread (file_content, 1, stat_str.st_size, f) != stat_str.st_size) {
-		lwc_writeLog (	LOG_ERR, _("%s: read error: %s"),
-				filename, strerror (errno));
-		fclose (f);
-		free (file_content);
-		return NULL;
-	}
-	fclose (f);
-
-	file_content[stat_str.st_size] = '\0';
-	if (length != NULL) {
-		*length = stat_str.st_size;
-	}
-	return file_content;
-}
-
-
 /*
  * Load a private key from a file.
  *
@@ -861,6 +793,8 @@ load_private_key (const char *infile)
 	dat.data = (unsigned char *)read_file (infile, &size);
 	dat.size = size;
 	if (dat.data == NULL) {
+		lwc_writeLog (	LOG_ERR, _("%s: read error: %s"),
+				infile, strerror (errno));
 		gnutls_x509_privkey_deinit (key);
 		return NULL;
 	}
