@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2013 Herve Quatremain
+   Copyright (C) 2013-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -23,17 +23,24 @@
 #define _CHECK_WAITING_CAN_START_H
 
 #include <schedwi.h>
-#include <schedwi_time.h>
-#include <schedwi_jobtree.h>
+
+#if HAVE_TIME_H
+#include <time.h>
+#endif
+
+#include <job_status_node.h>
+#include <lwc_linkedlist.h>
+#include <job_status_state.h>
 
 /* Allow the use in C++ code.  */
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-extern int check_waiting_can_start OF((	int workload_date,
-				 	schedwi_jobtree_node_ptr ptr,
-				 	schedwi_time current_time));
+extern int check_waiting_can_start OF((	job_status_node_ptr ptr,
+					lwc_LL *hierarchy_list,
+					time_t now,
+					job_status_state parent_status));
 
 #ifdef __cplusplus
 }
