@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2013 Herve Quatremain
+   Copyright (C) 2007-2014 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -33,14 +33,10 @@
 #endif
 #endif
 
-#if HAVE_ASSERT_H
-#include <assert.h>
-#endif
-
 #include <utils.h>
 #include <lwc_log.h>
 #include <sql_commands.h>
-#include <lib_functions.h>
+#include <xmem.h>
 #include <commands.h>
 
 
@@ -76,11 +72,10 @@ command_from_int (int cmd)
  * Create a new command_action object
  *
  * Return:
- *   The new object (to be freed by the caller by command_action_destroy()) or
- *   NULL in case of memory allocation error
+ *   The new object (to be freed by the caller by command_action_destroy())
  */
 static command_action_ptr
-command_action_new (	unsigned int workload,
+command_action_new (	int workload,
 			unsigned long long int job_id,
 			const char *user_details,
 			int cmd,
@@ -88,24 +83,16 @@ command_action_new (	unsigned int workload,
 {
 	command_action_ptr ptr;
 
-	ptr = (command_action_ptr) malloc (sizeof (command_action));
-	if (ptr == NULL) {
-		return NULL;
-	}
+
+	ptr = (command_action_ptr) xmalloc (sizeof (command_action));
 	if (user_details != NULL) {
-		ptr->user_details = (char *) malloc (
-					schedwi_strlen (user_details) + 1);
-		if (ptr->user_details == NULL) {
-			free (ptr);
-			return NULL;
-		}
-		strcpy (ptr->user_details, user_details);
+		ptr->user_details = xstrdup (user_details);
 	}
 	else {
 		ptr->user_details = NULL;
 	}
 
-	schedwi_date_from_int (workload, &(ptr->workload));
+	ptr->workload = workload;
 	ptr->job_id = job_id;
 	ptr->cmd = command_from_int (cmd);
 	ptr->parameter = parameter;
@@ -139,7 +126,8 @@ command_action_cmp (const void *key, const void *obj)
 	const command_action_ptr o = (command_action_ptr)obj;
 	int ret;
 
-	ret = schedwi_date_compar (&(k->workload), &(o->workload));
+
+	ret = k->workload - o->workload;
 	return (ret != 0)? ret: (k->job_id - o->job_id);
 }
 
@@ -172,18 +160,15 @@ sql_command_update_error_logger (	void *data, const char *msg,
 int
 command_done (command_action_ptr ptr)
 {
-	char id_str[25];
-	int wl_date;
-	int ret;
-
-	if (ptr != NULL) {
-		wl_date = schedwi_date_to_int (ptr->workload);
-		copy_ulltostr (ptr->job_id, id_str);
-		ret =  sql_command_done (wl_date, id_str,
+	if (	   ptr != NULL
+		&& sql_command_done (	ptr->workload,
+					ptr->job_id,
 					command_to_int (ptr->cmd),
 					ptr->parameter,
-					sql_command_update_error_logger, NULL);
-		return (ret != 0)? -1: 0;
+					sql_command_update_error_logger,
+					NULL) != 0)
+	{
+		return -1;
 	}
 	return 0;
 }
@@ -199,46 +184,13 @@ command_done (command_action_ptr ptr)
 int
 command_failed (command_action_ptr ptr)
 {
-	char id_str[25];
-	int wl_date;
-	int ret;
-
-	if (ptr != NULL) {
-		wl_date = schedwi_date_to_int (ptr->workload);
-		copy_ulltostr (ptr->job_id, id_str);
-		ret =  sql_command_failed (wl_date, id_str,
+	if (	   ptr != NULL
+		&& sql_command_failed (	ptr->workload,
+					ptr->job_id,
 					command_to_int (ptr->cmd),
 					ptr->parameter,
-					sql_command_update_error_logger, NULL);
-		return (ret != 0)? -1: 0;
-	}
-	return 0;
-}
-
-
-/*
- * Add a new command to the database commands table
- *
- * Return:
- *   0 --> No error
- *  -1 --> Error.  If not NULL, err_msg contains the error message and
- *         must be freed by the caller by free()
- */
-int
-command_add (	schedwi_date workload, unsigned long long int job_id,
-		const char *username, command_t cmd, int parameter,
-		char **err_msg)
-{
-	char id_str[25];
-	int wl_date;
-
-	wl_date = schedwi_date_to_int (workload);
-	copy_ulltostr (job_id, id_str);
-	if (sql_command_add (	wl_date, id_str,
-				username,
-				command_to_int (cmd),
-				parameter,
-				err_msg) != 0)
+					sql_command_update_error_logger,
+					NULL) != 0)
 	{
 		return -1;
 	}
@@ -267,31 +219,21 @@ sql_command_get_error_logger (	void *data, const char *msg,
  * Callback function for the sql_command_get_commands() function.  Add the
  * new command to the list
  *
- * Return:
- *   0 --> No error
- *  -1 --> Memory allocation error.  An error message has been logged by
- *         lwc_writeLog()
+ * @return Always 0
  */
 static int
 command_get_list_cb (	void *lst,
-			unsigned int workload, unsigned long long int job_id,
+			int workload, unsigned long long int job_id,
 			const char *user_name, int cmd, int parameter)
 {
 	lwc_LL *list = (lwc_LL *) lst;
 	command_action_ptr ptr;
 	void *old;
 
+
 	ptr = command_action_new (workload, job_id, user_name, cmd, parameter);
-	if (ptr == NULL) {
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		return -1;
-	}
 	old = NULL;
-	if (lwc_replaceUnsortedLL (list, ptr, command_action_cmp, &old) != 0) {
-		command_action_destroy (ptr);
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		return -1;
-	}
+	lwc_replaceUnsortedLL (list, ptr, command_action_cmp, &old);
 	/* Ignore the previous command for the same job/jobset */
 	if (old != NULL) {
 		/* Say that it's done */
@@ -317,20 +259,14 @@ command_get_list ()
 	lwc_LL *list;
 	int ret;
 
-	list = lwc_newLL ();
-	if (list == NULL) {
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		return NULL;
-	}
 
+	list = lwc_newLL ();
 	ret = sql_command_get_commands (command_get_list_cb, list,
 					sql_command_get_error_logger, NULL);
 	if (ret != 0) {
-		lwc_delLL (list,
-			(void (*)(const void *))command_action_destroy);
+		command_destroy_list (list);
 		return NULL;
 	}
-
 	return list;
 }
 
