@@ -24,7 +24,6 @@
 
 #include <schedwi.h>
 #include <lwc_linkedlist.h>
-#include <schedwi_time.h>
 
 
 /* Allow the use in C++ code.  */
@@ -40,7 +39,7 @@ typedef enum {
 
 
 struct _command_action {
-	schedwi_date workload;
+	int workload;
 	unsigned long long int job_id;
 	command_t cmd;
 	int parameter;
@@ -51,10 +50,6 @@ typedef struct _command_action *command_action_ptr;
 
 extern int command_done OF((command_action_ptr ptr));
 extern int command_failed OF((command_action_ptr ptr));
-extern int command_add OF((	schedwi_date workload,
-				unsigned long long int job_id,
-				const char *username,
-				command_t cmd, int parameter, char **err_msg));
 extern lwc_LL *command_get_list OF(());
 extern void command_destroy_list OF((lwc_LL *list));
 
