@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2013 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -68,10 +68,11 @@ extern int errno;
 #include <assert.h>
 #endif
 
-#include <lib_functions.h>
 #include <module.h>
-#include <conf.h>
 #include <addrmatch.h>
+#include <xmem.h>
+#include <utils.h>
+#include <conf.h>
 
 
 /*
@@ -95,9 +96,7 @@ string2facility (const char *val, long int *facility)
 #endif
 
 #ifdef LOG_LOCAL0
-	if (	   !schedwi_strcasecmp (val, "LOG_LOCAL0")
-		|| !schedwi_strcasecmp (val, "LOCAL0"))
-	{
+	if (!strcasecmp (val, "LOG_LOCAL0") || !strcasecmp (val, "LOCAL0")) {
 		if (facility != NULL) {
 			*facility = LOG_LOCAL0;
 		}
@@ -105,9 +104,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_LOCAL1
-	if (	   !schedwi_strcasecmp (val, "LOG_LOCAL1")
-		|| !schedwi_strcasecmp (val, "LOCAL1"))
-	{
+	if (!strcasecmp (val, "LOG_LOCAL1") || !strcasecmp (val, "LOCAL1")) {
 		if (facility != NULL) {
 			*facility = LOG_LOCAL1;
 		}
@@ -115,9 +112,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_LOCAL2
-	if (	   !schedwi_strcasecmp (val, "LOG_LOCAL2")
-		|| !schedwi_strcasecmp (val, "LOCAL2"))
-	{
+	if (!strcasecmp (val, "LOG_LOCAL2") || !strcasecmp (val, "LOCAL2")) {
 		if (facility != NULL) {
 			*facility = LOG_LOCAL2;
 		}
@@ -125,9 +120,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_LOCAL3
-	if (	   !schedwi_strcasecmp (val, "LOG_LOCAL3")
-		|| !schedwi_strcasecmp (val, "LOCAL3"))
-	{
+	if (!strcasecmp (val, "LOG_LOCAL3") || !strcasecmp (val, "LOCAL3")) {
 		if (facility != NULL) {
 			*facility = LOG_LOCAL3;
 		}
@@ -135,9 +128,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_LOCAL4
-	if (	   !schedwi_strcasecmp (val, "LOG_LOCAL4")
-		|| !schedwi_strcasecmp (val, "LOCAL4"))
-	{
+	if (!strcasecmp (val, "LOG_LOCAL4") || !strcasecmp (val, "LOCAL4")) {
 		if (facility != NULL) {
 			*facility = LOG_LOCAL4;
 		}
@@ -145,9 +136,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_LOCAL5
-	if (	   !schedwi_strcasecmp (val, "LOG_LOCAL5")
-		|| !schedwi_strcasecmp (val, "LOCAL5"))
-	{
+	if (!strcasecmp (val, "LOG_LOCAL5") || !strcasecmp (val, "LOCAL5")) {
 		if (facility != NULL) {
 			*facility = LOG_LOCAL5;
 		}
@@ -155,9 +144,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_LOCAL6
-	if (	   !schedwi_strcasecmp (val, "LOG_LOCAL6")
-		|| !schedwi_strcasecmp (val, "LOCAL6"))
-	{
+	if (!strcasecmp (val, "LOG_LOCAL6") || !strcasecmp (val, "LOCAL6")) {
 		if (facility != NULL) {
 			*facility = LOG_LOCAL6;
 		}
@@ -165,9 +152,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_LOCAL7
-	if (	   !schedwi_strcasecmp (val, "LOG_LOCAL7")
-		|| !schedwi_strcasecmp (val, "LOCAL7"))
-	{
+	if (!strcasecmp (val, "LOG_LOCAL7") || !strcasecmp (val, "LOCAL7")) {
 		if (facility != NULL) {
 			*facility = LOG_LOCAL7;
 		}
@@ -175,9 +160,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_DAEMON
-	if (	   !schedwi_strcasecmp (val, "LOG_DAEMON")
-		|| !schedwi_strcasecmp (val, "DAEMON"))
-	{
+	if (!strcasecmp (val, "LOG_DAEMON") || !strcasecmp (val, "DAEMON")) {
 		if (facility != NULL) {
 			*facility = LOG_DAEMON;
 		}
@@ -185,9 +168,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_USER
-	if (	   !schedwi_strcasecmp (val, "LOG_USER")
-		|| !schedwi_strcasecmp (val, "USER"))
-	{
+	if (!strcasecmp (val, "LOG_USER") || !strcasecmp (val, "USER")) {
 		if (facility != NULL) {
 			*facility = LOG_USER;
 		}
@@ -195,9 +176,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_AUTH
-	if (	   !schedwi_strcasecmp (val, "LOG_AUTH")
-		|| !schedwi_strcasecmp (val, "AUTH"))
-	{
+	if (!strcasecmp (val, "LOG_AUTH") || !strcasecmp (val, "AUTH")) {
 		if (facility != NULL) {
 			*facility = LOG_AUTH;
 		}
@@ -205,8 +184,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_AUTHPRIV
-	if (	   !schedwi_strcasecmp (val, "LOG_AUTHPRIV")
-		|| !schedwi_strcasecmp (val, "AUTHPRIV"))
+	if (!strcasecmp (val, "LOG_AUTHPRIV") || !strcasecmp (val, "AUTHPRIV"))
 	{
 		if (facility != NULL) {
 			*facility = LOG_AUTHPRIV;
@@ -215,9 +193,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_CRON
-	if (	   !schedwi_strcasecmp (val, "LOG_CRON")
-		|| !schedwi_strcasecmp (val, "CRON"))
-	{
+	if (!strcasecmp (val, "LOG_CRON") || !strcasecmp (val, "CRON")) {
 		if (facility != NULL) {
 			*facility = LOG_CRON;
 		}
@@ -225,9 +201,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_KERN
-	if (	   !schedwi_strcasecmp (val, "LOG_KERN")
-		|| !schedwi_strcasecmp (val, "KERN"))
-	{
+	if (!strcasecmp (val, "LOG_KERN") || !strcasecmp (val, "KERN")) {
 		if (facility != NULL) {
 			*facility = LOG_KERN;
 		}
@@ -235,9 +209,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_LPR
-	if (	   !schedwi_strcasecmp (val, "LOG_LPR")
-		|| !schedwi_strcasecmp (val, "LPR"))
-	{
+	if (!strcasecmp (val, "LOG_LPR") || !strcasecmp (val, "LPR")) {
 		if (facility != NULL) {
 			*facility = LOG_LPR;
 		}
@@ -245,9 +217,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_MAIL
-	if (	   !schedwi_strcasecmp (val, "LOG_MAIL")
-		|| !schedwi_strcasecmp (val, "MAIL"))
-	{
+	if (!strcasecmp (val, "LOG_MAIL") || !strcasecmp (val, "MAIL")) {
 		if (facility != NULL) {
 			*facility = LOG_MAIL;
 		}
@@ -255,9 +225,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_NEWS
-	if (	   !schedwi_strcasecmp (val, "LOG_NEWS")
-		|| !schedwi_strcasecmp (val, "NEWS"))
-	{
+	if (!strcasecmp (val, "LOG_NEWS") || !strcasecmp (val, "NEWS")) {
 		if (facility != NULL) {
 			*facility = LOG_NEWS;
 		}
@@ -265,9 +233,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_SYSLOG
-	if (	   !schedwi_strcasecmp (val, "LOG_SYSLOG")
-		|| !schedwi_strcasecmp (val, "SYSLOG"))
-	{
+	if (!strcasecmp (val, "LOG_SYSLOG") || !strcasecmp (val, "SYSLOG")) {
 		if (facility != NULL) {
 			*facility = LOG_SYSLOG;
 		}
@@ -275,9 +241,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_UUCP
-	if (	   !schedwi_strcasecmp (val, "LOG_UUCP")
-		|| !schedwi_strcasecmp (val, "UUCP"))
-	{
+	if (!strcasecmp (val, "LOG_UUCP") || !strcasecmp (val, "UUCP")) {
 		if (facility != NULL) {
 			*facility = LOG_UUCP;
 		}
@@ -285,9 +249,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_CONSOLE
-	if (	   !schedwi_strcasecmp (val, "LOG_CONSOLE")
-		|| !schedwi_strcasecmp (val, "CONSOLE"))
-	{
+	if (!strcasecmp (val, "LOG_CONSOLE") || !strcasecmp (val, "CONSOLE")) {
 		if (facility != NULL) {
 			*facility = LOG_CONSOLE;
 		}
@@ -295,9 +257,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_FTP
-	if (	   !schedwi_strcasecmp (val, "LOG_FTP")
-		|| !schedwi_strcasecmp (val, "FTP"))
-	{
+	if (!strcasecmp (val, "LOG_FTP") || !strcasecmp (val, "FTP")) {
 		if (facility != NULL) {
 			*facility = LOG_FTP;
 		}
@@ -305,8 +265,7 @@ string2facility (const char *val, long int *facility)
 	}
 #endif
 #ifdef LOG_SECURITY
-	if (	   !schedwi_strcasecmp (val, "LOG_SECURITY")
-		|| !schedwi_strcasecmp (val, "SECURITY"))
+	if (!strcasecmp (val, "LOG_SECURITY") || !strcasecmp (val, "SECURITY"))
 	{
 		if (facility != NULL) {
 			*facility = LOG_SECURITY;
@@ -331,7 +290,7 @@ check_syslog_facility (const char *s)
 	assert (s != NULL);
 #endif
 
-	if (string2facility (s, NULL) != 0){
+	if (string2facility (s, NULL) != 0) {
 		return _("unknown facility name (see syslog(3))");
 	}
 	return NULL;
@@ -353,15 +312,16 @@ is_bool_true (const char *value)
 #endif
 
 	if (	   value[0] == '1'
-		|| value[0] == 'y' || value[0] == 'Y'		/* Yes */
-		|| value[0] == 't' || value[0] == 'T'		/* True */
-		|| schedwi_strncasecmp (value, "ON", 2) == 0)	/* On */
+		|| value[0] == 'y' || value[0] == 'Y'	/* Yes */
+		|| value[0] == 't' || value[0] == 'T'	/* True */
+		|| strncasecmp (value, "ON", 2) == 0)	/* On */
 	{
 		return 1;
 	}
 	return 0;
 }
 
+
 /*
  * Does the string correspond to a boolean FALSE value?
  *
@@ -377,15 +337,16 @@ is_bool_false (const char *value)
 #endif
 
 	if (	   value[0] == '0'
-		|| value[0] == 'n' || value[0] == 'N'		/* No */
-		|| value[0] == 'f' || value[0] == 'F'		/* False */
-		|| schedwi_strncasecmp (value, "OFF", 3) == 0)	/* Off */
+		|| value[0] == 'n' || value[0] == 'N'	/* No */
+		|| value[0] == 'f' || value[0] == 'F'	/* False */
+		|| strncasecmp (value, "OFF", 3) == 0)	/* Off */
 	{
 		return 1;
 	}
 	return 0;
 }
 
+
 /*
  * Check if the provided string contain a boolean value
  *
@@ -402,6 +363,7 @@ check_bool (const char *s)
 	return NULL;
 }
 
+
 /*
  * Check if the provided string contain an integer
  *
@@ -413,6 +375,7 @@ check_int (const char *s)
 {
 	char *ptr;
 
+
 #if HAVE_ASSERT_H
 	assert (s != NULL);
 #endif
@@ -427,6 +390,7 @@ check_int (const char *s)
 	return _("invalid integer value");
 }
 
+
 /*
  * Check if the provided string contain an valid directory name
  *
@@ -438,6 +402,7 @@ check_dirname (const char *s)
 {
 	struct stat file_info;
 
+
 #if HAVE_ASSERT_H
 	assert (s != NULL);
 #endif
@@ -454,6 +419,7 @@ check_dirname (const char *s)
 	return NULL;
 }
 
+
 /*
  * Check if the provided string contain an valid address family (any, inet
  * or inet6)
@@ -468,15 +434,16 @@ check_addrfamily (const char *s)
 	assert (s != NULL);
 #endif
 
-	if (	   schedwi_strcasecmp (s, "any") == 0
-		|| schedwi_strcasecmp (s, "inet") == 0
-		|| schedwi_strcasecmp (s, "inet6") == 0)
+	if (	   strcasecmp (s, "any") == 0
+		|| strcasecmp (s, "inet") == 0
+		|| strcasecmp (s, "inet6") == 0)
 	{
 		return NULL;
 	}
 	return _("the parameter value should be `any', `inet' (use IPv4 only), or `inet6' (use IPv6 only)");
 }
 
+
 /*
  * Check if the provided network list is properly built.
  *
@@ -510,6 +477,7 @@ my_strtok (char *s, char delim)
 	static char *save = NULL;
 	char *end, *ret;
 
+
 	if (s == NULL && save == NULL) {
 		return NULL;
 	}
@@ -524,7 +492,7 @@ my_strtok (char *s, char delim)
 		save = end + 1;
 	}
 	else {
-		end = save + schedwi_strlen (save);
+		end = save + strlen (save);
 		save = NULL;
 	}
 
@@ -550,7 +518,6 @@ my_strtok (char *s, char delim)
  * Return:
  *   0 --> No error. mod_name and mod_key are set and must be freed by the
  *         caller with free()
- *  -1 --> Memory allocation error
  *   1 --> Wrong format
  */
 static int
@@ -561,14 +528,13 @@ split_module (	const char *name, size_t name_len,
 	char *mod_k, *s, *k;
 	size_t l;
 
+
 #if HAVE_ASSERT_H
 	assert (   name != NULL && name_len > 0
 		&& mod_name != NULL && mod_key != NULL);
 #endif
 
-	if (	   name_len < 10
-		|| schedwi_strncasecmp ("module:", name, 7) != 0)
-	{
+	if (name_len < 10 || strncasecmp ("module:", name, 7) != 0) {
 		return 1;
 	}
 
@@ -583,19 +549,12 @@ split_module (	const char *name, size_t name_len,
 	}
 
 	l = mod_k - mod_s;
-	s = (char *) malloc (l + 1);
-	if (s == NULL) {
-		return -1;
-	}
+	s = (char *) xmalloc (l + 1);
 	strncpy (s, mod_s, l);
 	s[l] = '\0';
 
 	l = name_len - (mod_k - name) - 1;
-	k = (char *) malloc (l + 1);
-	if (k == NULL) {
-		free (s);
-		return -1;
-	}
+	k = (char *) xmalloc (l + 1);
 	strncpy (k, mod_k + 1, l);
 	k[l] = '\0';
 
@@ -613,6 +572,7 @@ conf_destroy ()
 {
 	int i;
 
+
 	if (params != NULL) {
 		for (i = 0;  params[i].name != NULL; i++) {
 			if (	   params[i].type == STRING
@@ -635,7 +595,6 @@ conf_destroy ()
  *
  * Return:
  *   0 --> No error
- *  -1 --> Memory allocation error
  *  -2 --> System error while accessing the configuration file (errno is set)
  *  -3 --> Syntax error in the configuration file.  The errors are sent to
  *         stderr
@@ -643,15 +602,14 @@ conf_destroy ()
 int
 conf_init (const char *file_name, conf_param_t *params_array)
 {
-	FILE *fd;
-	struct stat file_info;
 	char *file_content, *save_file_content;
 	char *line, *name, *value, *save_line, *mod_name, *mod_key;
 	const char *err_msg;
-	size_t nb_read, name_len;
-	int save_errno, num_line, nb_errors, i, ret;
+	size_t name_len;
+	int num_line, nb_errors, i, ret;
 	long int facility;
 
+
 #if HAVE_ASSERT_H
 	assert (params_array != NULL);
 #endif
@@ -661,35 +619,12 @@ conf_init (const char *file_name, conf_param_t *params_array)
 		return 0;
 	}
 
-	if (stat (file_name, &file_info) != 0) {
-		return -2;
-	}
-
-	/* Buffer to read all the file in once */
-	file_content = (char *) malloc (file_info.st_size + 1);
+	/* Read the whole file */
+	file_content = read_file (file_name, NULL);
 	if (file_content == NULL) {
-		return -1;
-	}
-
-	fd = fopen (file_name, "r");
-	if (fd == NULL) {
-		free (file_content);
 		return -2;
 	}
 
-	clearerr (fd);
-	nb_read = fread (file_content, 1, file_info.st_size, fd);
-	if (nb_read != file_info.st_size && ferror (fd) != 0) {
-		save_errno = errno;
-		free (file_content);
-		fclose (fd);
-		errno = save_errno;
-		return -2;
-	}
-	file_content[nb_read] = '\0';
-
-	fclose (fd);
-
 	conf_destroy ();
 	params = params_array;
 	num_line = nb_errors = 0;
@@ -714,11 +649,9 @@ conf_init (const char *file_name, conf_param_t *params_array)
 		if (name_len == 0) {
 			/* ie. '= value' (missing parameter name) */
 			nb_errors++;
-			fprintf (stderr, _("%s: syntax error on line %d: "),
-					file_name, num_line);
-			fputs (_("missing parameter name:\n"), stderr);
-			fputs (save_line, stderr);
-			fputc ('\n', stderr);
+			fprintf (stderr,
+		_("%s: syntax error on line %d: missing parameter name: %s\n"),
+				file_name, num_line, save_line);
 			continue;
 		}
 
@@ -729,12 +662,9 @@ conf_init (const char *file_name, conf_param_t *params_array)
 		if (*line != '=') {
 			/* ie. 'name  value' (missing '=') */
 			nb_errors++;
-			fprintf (stderr, _("%s: syntax error on line %d: "),
-					file_name, num_line);
-			fputs (_("missing `=' sign between name and value:\n"),
-					stderr);
-			fputs (save_line, stderr);
-			fputc ('\n', stderr);
+			fprintf (stderr,
+_("%s: syntax error on line %d: missing `=' sign between name and value: %s\n"),
+				file_name, num_line, save_line);
 			continue;
 		}
 		line++;
@@ -747,11 +677,9 @@ conf_init (const char *file_name, conf_param_t *params_array)
 		if (*line == '\0' || *line == '#' || *line == ';') {
 			/* ie. 'name =' (missing value) */
 			nb_errors++;
-			fprintf (stderr, _("%s: syntax error on line %d: "),
-					file_name, num_line);
-			fputs (_("missing value:\n"), stderr);
-			fputs (save_line, stderr);
-			fputc ('\n', stderr);
+			fprintf (stderr,
+			_("%s: syntax error on line %d: missing value: %s\n"),
+				file_name, num_line, save_line);
 			continue;
 		}
 
@@ -759,8 +687,7 @@ conf_init (const char *file_name, conf_param_t *params_array)
 
 		/* Find the parameter name */
 		for (i = 0;  params[i].name != NULL; i++) {
-			if (schedwi_strncasecmp (	params[i].name,
-							name, name_len) == 0)
+			if (strncasecmp (params[i].name, name, name_len) == 0)
 			{
 				break;
 			}
@@ -772,21 +699,14 @@ conf_init (const char *file_name, conf_param_t *params_array)
 			 * its a module variable
 			 * (i.e. module:<modname>:<varname>)
 			 */
-			switch (split_module (	name, name_len,
-						&mod_name, &mod_key))
+			if (split_module (name, name_len,
+					  &mod_name, &mod_key) != 0)
 			{
-				case -1:
-					free (save_file_content);
-					conf_destroy ();
-					return -1;
-				case 1:
-					nb_errors++;
-					fprintf (stderr,
-				_("%s: unknown parameter name on line %d:\n"),
-						file_name, num_line);
-					fputs (save_line, stderr);
-					fputc ('\n', stderr);
-					continue;
+				nb_errors++;
+				fprintf (stderr,
+			_("%s: unknown parameter name on line %d: %s\n"),
+					file_name, num_line, save_line);
+				continue;
 			}
 
 			ret = module_conf (mod_name, mod_key, value);
@@ -804,52 +724,40 @@ conf_init (const char *file_name, conf_param_t *params_array)
 			if (err_msg != 0) {
 				nb_errors++;
 				fprintf (stderr,
-			_("%s: erroneous value parameter on line %d: "),
-					file_name, num_line);
-				fputs (err_msg, stderr);
-				fputs (":\n", stderr);
-				fputs (save_line, stderr);
-				fputc ('\n', stderr);
+		_("%s: erroneous value parameter on line %d: %s: %s\n"),
+					file_name, num_line,
+					err_msg, save_line);
 				continue;
 			}
 		}
 
 		/* Save the parameter */
 		switch (params[i].type) {
-			case INT:
-				params[i].value.value_int = strtol (	value,
-									NULL,
-									0);
-				break;
+		case INT:
+			params[i].value.value_int = strtol (value, NULL, 0);
+			break;
 
-			case BOOL:
-				params[i].value.value_bool = is_bool_true (value);
-				break;
+		case BOOL:
+			params[i].value.value_bool = is_bool_true (value);
+			break;
 
-			case STRING:
-				params[i].value.value_string = (char *) malloc (
-						schedwi_strlen (value) + 1);
-				if (params[i].value.value_string == NULL) {
-					free (save_file_content);
-					conf_destroy ();
-					return -1;
-				}
-				strcpy (params[i].value.value_string, value);
-				break;
-			case SYSLOG_FACILITY:
-				facility = -1;
-				string2facility (value, &facility);
-				params[i].value.value_int = facility;
-				break;
-			case FUNCTION:
-				if (	   params[i].set != NULL
-					&& (*(params[i].set)) (value) != 0)
-				{
-					free (save_file_content);
-					conf_destroy ();
-					return -3;
-				}
-				break;
+		case STRING:
+			params[i].value.value_string = xstrdup (value);
+			break;
+		case SYSLOG_FACILITY:
+			facility = -1;
+			string2facility (value, &facility);
+			params[i].value.value_int = facility;
+			break;
+		case FUNCTION:
+			if (   params[i].set != NULL
+			    && (*(params[i].set)) (value) != 0)
+			{
+				free (save_file_content);
+				conf_destroy ();
+				return -3;
+			}
+			break;
 		}
 		params[i].is_set = 1;
 	}
@@ -861,6 +769,7 @@ conf_init (const char *file_name, conf_param_t *params_array)
 	return 0;
 }
 
+
 /*
  * Get the value associated with the provided parameter name
  *
@@ -873,13 +782,14 @@ conf_get_param_string (const char *name, const char **value)
 {
 	int i;
 
+
 	if (params == NULL) {
 		return -1;
 	}
 
 	for (i = 0;  params[i].name != NULL; i++) {
 		if (	   params[i].type == STRING
-			&& schedwi_strcasecmp (params[i].name, name) == 0)
+			&& strcasecmp (params[i].name, name) == 0)
 		{
 			if (value != NULL) {
 				if (params[i].is_set == 0) {
@@ -895,6 +805,7 @@ conf_get_param_string (const char *name, const char **value)
 	return -1;
 }
 
+
 /*
  * Get the value associated with the provided parameter name
  *
@@ -907,13 +818,14 @@ conf_get_param_int (const char *name, long int *value)
 {
 	int i;
 
+
 	if (params == NULL) {
 		return -1;
 	}
 
 	for (i = 0;  params[i].name != NULL; i++) {
 		if (	   params[i].type == INT
-			&& schedwi_strcasecmp (params[i].name, name) == 0)
+			&& strcasecmp (params[i].name, name) == 0)
 		{
 			if (value != NULL) {
 				if (params[i].is_set == 0) {
@@ -936,6 +848,7 @@ conf_get_param_int (const char *name, long int *value)
 	return -1;
 }
 
+
 /*
  * Get the value associated with the provided parameter name
  *
@@ -948,13 +861,14 @@ conf_get_param_bool (const char *name, char *value)
 {
 	int i;
 
+
 	if (params == NULL) {
 		return -1;
 	}
 
 	for (i = 0;  params[i].name != NULL; i++) {
 		if (	   params[i].type == BOOL
-			&& schedwi_strcasecmp (params[i].name, name) == 0)
+			&& strcasecmp (params[i].name, name) == 0)
 		{
 			if (value != NULL) {
 				if (params[i].is_set == 0) {
@@ -976,6 +890,7 @@ conf_get_param_bool (const char *name, char *value)
 	return -1;
 }
 
+
 /*
  * Get the value associated with the provided parameter name
  *
@@ -988,13 +903,14 @@ conf_get_param_syslog_facility (const char *name, long int *value)
 {
 	int i;
 
+
 	if (params == NULL) {
 		return -1;
 	}
 
 	for (i = 0;  params[i].name != NULL; i++) {
 		if (	   params[i].type == SYSLOG_FACILITY
-			&& schedwi_strcasecmp (params[i].name, name) == 0)
+			&& strcasecmp (params[i].name, name) == 0)
 		{
 			if (value != NULL) {
 				if (params[i].is_set == 0) {
