@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2013 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -38,6 +38,7 @@ static conf_param_t params_clnt[] = {
 	{ "MANUAL_TRIGGER_TEMPLATE_FILE", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_MANUAL_TRIGGER_TEMPLATE_FILE},
 	{ "WORKLOAD_PURGE_COMPLETED", INT, {0}, check_int, 0, 0, SCHEDWI_DEFAULT_WORKLOAD_PURGE_COMPLETED},
 	{ "WORKLOAD_PURGE_FAILED", INT, {0}, check_int, 0, 0, SCHEDWI_DEFAULT_WORKLOAD_PURGE_FAILED},
+	{ "TODAY_WORKLOAD_SKIP", INT, {0}, check_int, 0, 0, SCHEDWI_DEFAULT_TODAY_WORKLOAD_SKIP},
 	{ "ALLOW_FROM", STRING, {0}, check_netlist, 0, 0, ""},
 	{ "SERVER_PORT", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_SRVPORT},
 	{ "REGISTRAR_PORT", STRING, {0}, 0, 0, 0, SCHEDWI_DEFAULT_REGPORT},
@@ -90,7 +91,6 @@ static conf_param_t params_clnt[] = {
  *
  * Return:
  *   0 --> No error
- *  -1 --> Memory allocation error
  *  -2 --> System error while accessing the configuration file (errno is set)
  *  -3 --> Syntax error in the configuration file.  The errors are sent to
  *	   stderr
