@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2013 Herve Quatremain
+   Copyright (C) 2013-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -23,15 +23,23 @@
 #define _MANUAL_TRIGGER_H
 
 #include <schedwi.h>
-#include <schedwi_jobtree.h>
+
+#if HAVE_TIME_H
+#include <time.h>
+#endif
+
+#include <job_status_node.h>
+#include <lwc_linkedlist.h>
 
 /* Allow the use in C++ code.  */
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-extern int check_manual_trigger OF((	int workload_date,
-					schedwi_jobtree_node_ptr ptr));
+extern int check_manual_trigger OF((	job_status_node_ptr ptr,
+					lwc_LL *hierarchy_list,
+					time_t start_time,
+					short int start_limit));
 
 #ifdef __cplusplus
 }
