@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -36,16 +36,14 @@
 #endif
 
 #include <ltdl.h>
-#include <pthread.h>
 
-#include <lib_functions.h>
 #include <lwc_linkedlist.h>
 #include <lwc_log.h>
 #include <utils.h>
+#include <xmem.h>
 #include <module.h>
 
 
-static pthread_mutex_t lock = PTHREAD_MUTEX_INITIALIZER;
 static lwc_LL *module_list = NULL;
 static char initialized = 0;
 
@@ -55,9 +53,10 @@ struct module_node {
 	lt_dlhandle handle;
 	int (*mod_init)();
 	int (*mod_conf)(const char *, const char *);
-	int (*mod_status)(	int, const schedwi_jobtree_node_ptr,
-				job_status_state, job_status_state);
-	int (*mod_check)(int, const schedwi_jobtree_node_ptr);
+	int (*mod_status)(	const result_t * const, const char *,
+				job_status_state, job_status_state,
+				long int, int, const char *);
+	int (*mod_check)(const job_status_node_ptr const, time_t, short int);
 	void (*mod_exit)();
 };
 
@@ -66,7 +65,7 @@ struct module_node {
  * Free the provided module node
  */
 static void
-free_module_list (struct module_node *ptr)
+free_module_node (struct module_node *ptr)
 {
 	if (ptr != NULL) {
 		if (ptr->name != NULL) {
@@ -159,8 +158,9 @@ module_init ()
 	}
 
 	if (lt_dladdsearchdir (PKGLIBDIR) != 0) {
-		fprintf (	stderr, _("Module path initialization: %s\n"),
-				lt_dlerror ());
+		fprintf (	stderr,
+				_("Module path initialization: %s: %s\n"),
+				PKGLIBDIR, lt_dlerror ());
 		lt_dlexit ();
 		return -1;
 	}
@@ -176,10 +176,8 @@ module_init ()
 void
 module_exit ()
 {
-	pthread_mutex_lock (&lock);
-	lwc_delLL (module_list, (void (*)(const void *))free_module_list);
+	lwc_delLL (module_list, (void (*)(const void *))free_module_node);
 	module_list = NULL;
-	pthread_mutex_unlock (&lock);
 	initialized = 0;
 	lt_dlexit ();
 }
@@ -196,8 +194,9 @@ int
 module_path (const char *path)
 {
 	if (path != NULL && lt_dladdsearchdir (path) != 0) {
-		fprintf (	stderr, _("Module path initialization: %s\n"),
-				lt_dlerror ());
+		fprintf (	stderr,
+				_("Module path initialization: %s: %s\n"),
+				path, lt_dlerror ());
 		return -1;
 	}
 	return 0;
@@ -229,19 +228,13 @@ module_load (const char *file)
 	 * without the extension)
 	 */
 	name = base_name (file);
-	n = (char *)malloc (schedwi_strlen (name) + 1);
-	if (n == NULL) {
-		fprintf (stderr, _("Memory allocation error\n"));
-		return -1;
-	}
-	strcpy (n, name);
+	n = xstrdup (name);
 	s = strchr (n, '.');
 	if (s != NULL && s != n) {
 		*s = '\0';
 	}
 
 	/* Check if the module is already loaded */
-	pthread_mutex_lock (&lock);
 	ptr = (struct module_node *) lwc_searchSortLL (module_list, n,
 		(int (*)(const void *, const void *)) compar_module_node1);
 	if (ptr != NULL) {
@@ -256,37 +249,16 @@ module_load (const char *file)
 				_("Module %s already loaded from %s\n"),
 				file, ptr->filename);
 		}
-		pthread_mutex_unlock (&lock);
 		return 0;
 	}
 
 	/* Create the list if need be */
 	if (module_list == NULL) {
 		module_list = lwc_newLL ();
-		if (module_list == NULL) {
-			pthread_mutex_unlock (&lock);
-			free (n);
-			fprintf (stderr, _("Memory allocation error\n"));
-			return -1;
-		}
-	}
-	pthread_mutex_unlock (&lock);
-
-	ptr = (struct module_node *)malloc (sizeof (struct module_node));
-	if (ptr == NULL) {
-		free (n);
-		fprintf (stderr, _("Memory allocation error\n"));
-		return -1;
 	}
 
-	ptr->filename = (char *)malloc (schedwi_strlen (file) + 1);
-	if (ptr->filename == NULL) {
-		free (ptr);
-		free (n);
-		fprintf (stderr, _("Memory allocation error\n"));
-		return -1;
-	}
-	strcpy (ptr->filename, file);
+	ptr = (struct module_node *) xmalloc (sizeof (struct module_node));
+	ptr->filename = xstrdup (file);
 
 	/* Open the module */
 	ptr->handle = lt_dlopenext (file);
@@ -303,8 +275,12 @@ module_load (const char *file)
 	ptr->mod_init = (int (*)()) lt_dlsym (ptr->handle, "schedwi_init");
 	ptr->mod_conf = (int (*)(const char *, const char *))
 				lt_dlsym (ptr->handle, "schedwi_conf");
-	ptr->mod_status = (int (*)(int,const schedwi_jobtree_node_ptr,job_status_state,job_status_state)) lt_dlsym (ptr->handle, "schedwi_status");
-	ptr->mod_check = (int (*)(int,const schedwi_jobtree_node_ptr))
+	ptr->mod_status = (int (*)(const result_t * const, const char *,
+				job_status_state, job_status_state,
+				long int, int, const char *)) lt_dlsym (
+						ptr->handle, "schedwi_status");
+	ptr->mod_check = (int (*)(	const job_status_node_ptr const,
+					time_t, short int))
 				lt_dlsym (ptr->handle, "schedwi_check");
 	ptr->mod_exit = (void (*)()) lt_dlsym (ptr->handle, "schedwi_exit");
 
@@ -320,22 +296,9 @@ module_load (const char *file)
 
 	/* Link the new module object to the list of modules */
 	ptr->name = n;
-	pthread_mutex_lock (&lock);
-	if (lwc_addLL (module_list, ptr, (int (*)(const void *, const void *))
-			compar_module_node2) != 0)
-	{
-		pthread_mutex_unlock (&lock);
-		if (ptr->mod_exit != NULL) {
-			(*(ptr->mod_exit)) ();
-		}
-		lt_dlclose (ptr->handle);
-		free (ptr->filename);
-		free (ptr);
-		free (n);
-		fprintf (stderr, _("Memory allocation error\n"));
-		return -1;
-	}
-	pthread_mutex_unlock (&lock);
+	lwc_addLL (module_list,
+		   ptr,
+		   (int (*)(const void *, const void *))compar_module_node2);
 	return 0;
 }
 
@@ -353,16 +316,15 @@ module_conf (const char *name, const char *key, const char *value)
 {
 	struct module_node *ptr;
 
+
 	if (name == NULL || key == NULL || value == NULL) {
 		return 0;
 	}
 
 	/* Retrieve the module object */
-	pthread_mutex_lock (&lock);
 	ptr = (struct module_node *) lwc_searchSortLL (module_list, name,
 		(int (*)(const void *, const void *)) compar_module_node1);
 	if (ptr == NULL) {
-		pthread_mutex_unlock (&lock);
 		fprintf (stderr,
 			_("Unknown module `%s' for parameter `%s=%s'\n"),
 			name, key, value);
@@ -370,107 +332,120 @@ module_conf (const char *name, const char *key, const char *value)
 	}
 
 	if (ptr->mod_conf != NULL && (*(ptr->mod_conf)) (key, value) != 0) {
-		pthread_mutex_unlock (&lock);
 		fprintf (	stderr,
 				_("Module %s: error: parameter `%s=%s'\n"),
 				name, key, value);
 		return -1;
 	}
-	pthread_mutex_unlock (&lock);
 	return 0;
 }
 
 
-/*
+/**
  * Call all the module `schedwi_status' functions for the provided job with
  * the provided status
  *
- * Return:
- *   0 --> No error
- *  -1 --> At least a `schedwi_status' function returned non-zero.  An error
- *         message is logged by lwc_writeLog().
+ * @param[in] result A result_t object which contains the job workload, id, ...
+ * @param[in] job_name_with_path Full name of the job (with its path)
+ * @param[in] new_state New state of the job/jobset
+ * @param[in] previous_state Previous state of the job/jobset
+ * @param[in] duration How long (in secondes) the job was in the previous_state
+ * @param[in] retry_num Retry number if the job has failed and is going to be
+ *                      retried
+ * @param[in] status_message Description.  For a fail job it may be the reason
+ *                           why it failed. May be empty or NULL
+ *
+ * @return 0 on sucess or -1 if at least one `schedwi_status' function returned
+ *         a non-zero code.  An error message is logged by lwc_writeLog().
  */
 int
-module_status (	int workload, const schedwi_jobtree_node_ptr job,
-		job_status_state old_status, job_status_state new_status)
+module_status (	const result_t * const result, const char *job_name_with_path,
+		job_status_state new_state, job_status_state previous_state,
+		long int duration, int retry_num, const char *status_message)
 {
 	int ret;
 	struct module_node *ptr;
 
+
 #if HAVE_ASSERT_H
-	assert (job != NULL);
+	assert (result != NULL && job_name_with_path != NULL);
 #endif
 
 	ret = 0;
-	pthread_mutex_lock (&lock);
 	lwc_rewindLL (module_list);
 	while ((ptr = (struct module_node *)lwc_nextLL (module_list)) != NULL)
 	{
 		if (	   ptr->mod_status != NULL
-			&& (*(ptr->mod_status)) (	workload, job,
-							old_status,
-							new_status) != 0)
+			&& (*(ptr->mod_status)) (	result,
+							job_name_with_path,
+							new_state,
+							previous_state,
+							duration,
+							retry_num,
+							status_message) != 0)
 		{
 			lwc_writeLog (	LOG_ERR,
 _("Module %s: schedwi_status: Workload %d: %s (id %lld): from %s to %s: error"),
 					ptr->name,
-					workload,
-					job->path,
-					job->id,
-					job_status_state2str (old_status),
-					job_status_state2str (new_status));
+					result->workload_int,
+					job_name_with_path,
+					result->job_id_int,
+					job_status_state2str (previous_state),
+					job_status_state2str (new_state));
 			ret = -1;
 		}
 	}
-	pthread_mutex_unlock (&lock);
 	return ret;
 }
 
 
-/*
+/**
  * Call all the module `schedwi_check' functions for the provided job
  *
- * Return:
- *   0 --> No error. The job can be run (all the `schedwi_check' functions
- *         returned 0)
- *   1 --> No error. The job cannot be started yet (a `schedwi_check' function
- *         returned a code greater than 0)
- *  -1 --> Error.  A `schedwi_check' function returned a code lower than 0.
- *         A message has been logged by lwc_writeLog().
+ * @param[in] job_details A job_status_node_ptr object which contains the
+ *                        job/jobset details.
+ * @param[in] start_time Time (time(2) format) at which the job should start.
+ * @param[in] start_limit Number of minutes for the job/jobset to start past
+ *                        its start time. 0 means no limit.
+ * @return 0 if no error (the job/jobset can be started: all the
+ *         `schedwi_check' functions returned 0). 1 if the job/jobset cannot be
+ *         started yet (a `schedwi_check' function returned a code greater than
+ *         0). -1 in case of error (A `schedwi_check' function returned a code
+ *         lower than 0).  A message has been logged by lwc_writeLog().
  */
 int
-module_check (int workload, const schedwi_jobtree_node_ptr job)
+module_check (	const job_status_node_ptr const job_details, time_t start_time,
+		short int start_limit)
 {
 	int ret;
 	struct module_node *ptr;
 
+
 #if HAVE_ASSERT_H
-	assert (job != NULL);
+	assert (job_details != NULL);
 #endif
 
-	pthread_mutex_lock (&lock);
 	lwc_rewindLL (module_list);
 	while ((ptr = (struct module_node *)lwc_nextLL (module_list)) != NULL)
 	{
 		if (ptr->mod_check != NULL) {
-			ret = (*(ptr->mod_check)) (workload, job);
+			ret = (*(ptr->mod_check)) (	job_details,
+							start_time,
+							start_limit);
 			if (ret > 0) {
-				pthread_mutex_unlock (&lock);
 				return 1;
 			}
 			if (ret < 0) {
 				lwc_writeLog (	LOG_ERR,
 	_("Module %s: schedwi_check: Workload %d: %s (id %lld): error"),
 					ptr->name,
-					workload,
-					job->path,
-					job->id);
-				pthread_mutex_unlock (&lock);
+					job_details->workload_date,
+					job_details->job_name_with_path,
+					job_details->job_id);
 				return -1;
 			}
 		}
 	}
-	pthread_mutex_unlock (&lock);
 	return 0;
 }
 
