@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2014 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -31,7 +31,7 @@
 extern "C" {
 #endif
 
-extern int net_parse OF((schedwi_BIO *b, void *obj));
+extern int net_parse OF((schedwi_BIO *b));
 
 #ifdef __cplusplus
 }
