@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2010 Herve Quatremain
+   Copyright (C) 2007-2014 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -87,16 +87,13 @@ extern int errno;
 #define closesocket(x) close(x)
 #endif
 
-#include <pthread.h>
-
-#include <thread_init.h>
-#include <lib_functions.h>
 #include <lwc_log.h>
 #include <sql_hosts.h>
 #include <net_utils_sock.h>
 #include <net_utils_ssl.h>
 #include <parse_json_result.h>
 #include <addrmatch.h>
+#include <xmem.h>
 #include <net_utils.h>
 
 
@@ -106,189 +103,6 @@ int deny_severity;
 #endif
 
 
-/*
- * Structure used to exchange parameters between the net_accept() function and
- * the new thread which manages the agent connection
- */
-struct _net_utils_data {
-	struct sockaddr_storage in;
-	socklen_t inlen;
-	int (*run)(schedwi_BIO *, void *);
-	void *user_data;
-	int s;
-};
-typedef struct _net_utils_data net_utils_data;
-typedef struct _net_utils_data *net_utils_data_ptr;
-
-
-/*
- * Create a new net_utils_data_ptr object
- *
- * Return:
- *   The new object (to be freed by the caller by net_utils_data_destroy()) or
- *   NULL in case of memory allocation error.
- */
-static net_utils_data_ptr
-net_utils_data_new (	int s, struct sockaddr_storage *in, socklen_t inlen,
-			int (*run)(schedwi_BIO *, void *), void *user_data)
-{
-	net_utils_data_ptr ptr;
-
-#if HAVE_ASSERT_H
-	assert (in != NULL && run != NULL);
-#endif
-
-	ptr = (net_utils_data_ptr) malloc (sizeof (net_utils_data));
-	if (ptr == NULL) {
-		return NULL;
-	}
-	ptr->in        = *in;
-	ptr->inlen     = inlen;
-	ptr->s         = s;
-	ptr->run       = run;
-	ptr->user_data = user_data;
-	return ptr;
-}
-
-
-/*
- * Free the provided net_utils_data_ptr object.  The associated socket is
- * also closed.
- */
-static void
-net_utils_data_destroy (net_utils_data_ptr ptr)
-{
-	if (ptr != NULL) {
-		if (ptr->s >= 0) {
-			net_close_sock (ptr->s);
-		}
-		free (ptr);
-	}
-}
-
-
-/*
- * Error callback function for the sql_host_certificate() function
- */
-static void
-sql_host_certificate_error_logger (	void *data, const char *msg,
-					int err_code)
-{
-	if (msg != NULL) {
-		lwc_writeLog (LOG_ERR, msg);
-	}
-	else {
-		lwc_writeLog (LOG_ERR,
-	_("Database error while trying to retrieve the agent parameters"));
-	}
-}
-
-
-/*
- * Thread function used to manage the new agent connection
- */
-static void *
-net_utils_server_thread (void *data)
-{
-	net_utils_data_ptr ptr = (net_utils_data_ptr) data;
-	char **names;
-	char use_ssl, *client_certificate;
-	unsigned long int len_client_certificate;
-	schedwi_BIO in;
-
-	if (ptr == NULL) {
-		pthread_exit (NULL);
-	}
-
-	/* Initialize the thread */
-	thread_init ();
-
-	/* Install the cleanup callback */
-	pthread_cleanup_push (thread_clean, NULL);
-
-	/* Retrieve the names associated with the in_addr structure */
-	if (build_client_names_from_addr (&(ptr->in), ptr->inlen, &names) != 0)
-	{
-		net_utils_data_destroy (ptr);
-		pthread_exit (NULL);
-	}
-
-	/*
-	 * Retrieve whether SSL must be used for the connexion and retrieve
-	 * the associated certificate
-	 */
-	client_certificate = NULL;
-	if (sql_host_certificate (	names, &use_ssl, &client_certificate,
-					&len_client_certificate,
-					sql_host_certificate_error_logger,
-					NULL) != 0)
-	{
-		net_utils_data_destroy (ptr);
-		destroy_client_names (names);
-		pthread_exit (NULL);
-	}
-
-	/*
-	 * No SSL
-	 */
-	if (use_ssl == 0) {
-		in.use_ssl = 0;
-		in.trusted_cert_ptr = NULL;
-		in.fd = ptr->s;
-		if (client_certificate != NULL) {
-			free (client_certificate);
-		}
-		destroy_client_names (names);
-		(ptr->run)(&in, ptr->user_data);
-		net_utils_data_destroy (ptr);
-		pthread_exit (NULL);
-	}
-
-
-	/*
-	 * SSL
-	 */
-	in.trusted_cert_ptr = (gnutls_certificate_credentials_t *) malloc (
-				sizeof (gnutls_certificate_credentials_t));
-	if (in.trusted_cert_ptr == NULL) {
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		if (client_certificate != NULL) {
-			free (client_certificate);
-		}
-		destroy_client_names (names);
-		net_utils_data_destroy (ptr);
-		pthread_exit (NULL);
-	}
-	in.use_ssl = 1;
-	in.fd = ptr->s;
-
-	if (net_server_ssl (&(in.session), in.fd, in.trusted_cert_ptr,
-			(const char **)names,
-			client_certificate, len_client_certificate) != 0)
-	{
-		if (client_certificate != NULL) {
-			free (client_certificate);
-		}
-		destroy_client_names (names);
-		net_utils_data_destroy (ptr);
-		free (in.trusted_cert_ptr);
-		pthread_exit (NULL);
-	}
-
-	if (client_certificate != NULL) {
-		free (client_certificate);
-	}
-	destroy_client_names (names);
-	(ptr->run)(&in, ptr->user_data);
-	net_close_ssl (in.session, in.fd, in.trusted_cert_ptr);
-	ptr->s = -1; /* Socket already closed */
-	net_utils_data_destroy (ptr);
-
-	pthread_cleanup_pop (1);
-	pthread_exit (NULL);
-}
-
-
 /*
  * Retrieve the next waiting connection from the provided set.
  * sock_set and nb_set are updated accordingly.
@@ -303,8 +117,8 @@ net_utils_server_thread (void *data)
  *      lwc_writeLog())
  *   -2 No more socket waiting (the set is empty)
  */
-static int
-net_accept_next (fd_set *sock_set, int max_set, int *nb_set,
+int
+net_accept (	fd_set *sock_set, int max_set, int *nb_set,
 		const char *allow_from,
 		struct sockaddr_storage *out_sockname, socklen_t *out_len)
 {
@@ -404,10 +218,6 @@ net_accept_next (fd_set *sock_set, int max_set, int *nb_set,
 						_("Connection refused for %s"),
 						name);
 				break;
-			case -1:
-				lwc_writeLog (	LOG_CRIT,
-						_("Memory allocation error"));
-				break;
 			case -2:
 				/*
 				 * Should not occur (checked at start time
@@ -450,8 +260,8 @@ net_accept_sock (fd_set *sock_set, int sock_max,
 #endif
 
 	/* First, manage the connections still waiting from a previous call */
-	s = net_accept_next (	&waiting_set, sock_max, &still_waiting,
-				allow_from, &sockname, &len);
+	s = net_accept (&waiting_set, sock_max, &still_waiting,
+			allow_from, &sockname, &len);
 	if (s == -1) {
 		return -1;
 	}
@@ -481,8 +291,8 @@ net_accept_sock (fd_set *sock_set, int sock_max,
 		waiting_set = rfds;
 		still_waiting = ret;
 
-		s = net_accept_next (	&waiting_set, sock_max, &still_waiting,
-					allow_from, &sockname, &len);
+		s = net_accept (&waiting_set, sock_max, &still_waiting,
+				allow_from, &sockname, &len);
 		if (s == -1) {
 			return -1;
 		}
@@ -498,106 +308,6 @@ net_accept_sock (fd_set *sock_set, int sock_max,
 }
 
 
-/*
- * Manage all the network request on the provided socket.  For each request
- * a new thread is started.
- * The run function is called to interract with the agent (its second
- * parameter is the provided user_data parameter).
- *
- * Return:
- *   Never or
- *   -1 in case of error (errno is set and a message is displayed using
- *      lwc_writeLog())
- */
-int
-net_accept (	fd_set *sock_set, int sock_max, const char *allow_from,
-		int (*run)(schedwi_BIO *, void *), void *user_data)
-{
-	pthread_attr_t attr;
-	pthread_t thread;
-	net_utils_data_ptr ptr;
-	int s, ret, save_errno;
-	fd_set rfds;
-	struct sockaddr_storage sockname;
-	socklen_t len;
-
-#if HAVE_ASSERT_H
-	assert (run != NULL && sock_set != NULL);
-#endif
-
-	/* Initialize the thread attribute object */
-	pthread_attr_init (&attr);
-	pthread_attr_setdetachstate (&attr, PTHREAD_CREATE_DETACHED);
-
-	/*
-	 * In case this function is in a thread, make sure that if the thread
-	 * is cancelled the attr object if freed
-	 */
-	pthread_cleanup_push (	(void (*) (void *))pthread_attr_destroy,
-				(void *)&attr);
-
-	/*
-	 * For each received connection, a new detached thread is started
-	 * to manage the new connection
-	 */
-	while (1) {
-		pthread_testcancel ();
-		rfds = *sock_set;
-		ret = select (sock_max, &rfds, NULL, NULL, NULL);
-		if (ret < 0) {
-			if (errno == EINTR || errno == EAGAIN) {
-				continue;
-			}
-			save_errno = errno;
-			lwc_writeLog (	LOG_CRIT,
-					_("Network error: select: %s"),
-					strerror (errno));
-			pthread_attr_destroy (&attr);
-			errno = save_errno;
-			return -1;
-		}
-
-		do {
-			pthread_testcancel ();
-			s = net_accept_next (	&rfds, sock_max,
-						&ret, allow_from,
-						&sockname, &len);
-			if (s == -1) {
-				save_errno = errno;
-				pthread_attr_destroy (&attr);
-				errno = save_errno;
-				return -1;
-			}
-			if (s >= 0) {
-				ptr = net_utils_data_new (s, &sockname, len,
-							run, user_data);
-				if (ptr == NULL) {
-					closesocket (s);
-					lwc_writeLog (	LOG_CRIT,
-						_("Memory allocation error"));
-					continue;
-				}
-				if (pthread_create (	&thread, &attr,
-							net_utils_server_thread,
-							ptr) != 0)
-				{
-					lwc_writeLog (	LOG_CRIT,
-_("Cannot create a new thread to manage the network connection: %s"),
-						strerror (errno));
-					net_utils_data_destroy (ptr);
-					continue;
-				}
-			}
-
-		} while (s != -2);
-	}
-	/* Never reach this point */
-	pthread_attr_destroy (&attr);
-	pthread_cleanup_pop (0);
-	return -1;
-}
-
-
 /*
  * Initialize the network layer (SSL algorithms) for a server
  *
@@ -666,11 +376,7 @@ net_client (	const char *port_number, const char *hostname, char use_ssl,
 #endif
 
 	/* Allocate space for the returned schedwi_BIO object */
-	out = (schedwi_BIO *) malloc (sizeof (schedwi_BIO));
-	if (out == NULL) {
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		return NULL;
-	}
+	out = (schedwi_BIO *) xmalloc (sizeof (schedwi_BIO));
 
 	/*
 	 * No SSL, only socket
@@ -690,14 +396,8 @@ net_client (	const char *port_number, const char *hostname, char use_ssl,
 	 * SSL
 	 */
 	out->use_ssl = 1;
-	out->trusted_cert_ptr = (gnutls_certificate_credentials_t *) malloc (
+	out->trusted_cert_ptr = (gnutls_certificate_credentials_t *) xmalloc (
 				sizeof (gnutls_certificate_credentials_t));
-	if (out->trusted_cert_ptr == NULL) {
-		free (out);
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		return NULL;
-	}
-
 	ret = net_client_ssl (	port_number, hostname,
 				&(out->session), &(out->fd),
 				out->trusted_cert_ptr,
@@ -766,6 +466,7 @@ net_read_result (schedwi_BIO *in, char **result_msg)
 	size_t len;
 	int nb_read, ret;
 
+
 	if (result_msg != NULL) {
 		*result_msg = NULL;
 	}
@@ -821,6 +522,55 @@ net_write (schedwi_BIO *out, const char *buff, int len)
 }
 
 
+/*
+ * Write the given strings to the provided handler.  The list of strings must
+ * be ended by NULL. Only strings (no binary data) can be writen this way.
+ */
+int
+net_write_strings (schedwi_BIO *out, ...)
+{
+	va_list ap;
+	char *s, **a;
+	int i, j, ret;
+	size_t len, a_len;
+	size_t *l;
+
+
+#if HAVE_ASSERT_H
+	assert (out != NULL);
+#endif
+	
+	a = NULL;
+	l = NULL;
+	len = a_len = 0;
+	va_start (ap, out);
+	for (i = 0; (s = va_arg (ap, char *)) != NULL; i++) {
+		if (i >= a_len) {
+			a_len += 20;
+			a = (char **) xrealloc (a, a_len * sizeof (char *));
+			l = (size_t *) xrealloc (l, a_len * sizeof (size_t));
+		}
+		a[i] = s;
+		l[i] = strlen (s);
+		len += l[i];
+	}
+
+	s = (char *) xmalloc (len + 1);
+	s[0] = '\0';
+	len = 0;
+	for (j = 0; j < i; j++) {
+		strcpy (s + len, a[j]);
+		len += l[j];
+	}
+	free (l);
+	free (a);
+	va_end (ap);
+	ret = net_write (out, s, len);
+	free (s);
+	return ret;
+}
+
+
 /*
  * Close the handler
  */
