@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2013 Herve Quatremain
+   Copyright (C) 2007-2014 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -103,10 +103,10 @@ extern int errno;
 #define closesocket(x) close(x)
 #endif
 
-#include <lib_functions.h>
 #include <lwc_log.h>
-#include <net_utils_sock.h>
+#include <xmem.h>
 #include <JSON_parser.h>
+#include <net_utils_sock.h>
 
 #define BUFFER_LEN 1024
 
@@ -130,7 +130,7 @@ check_port (const char *port)
 	assert (port != NULL);
 #endif
 
-	schedwi_memset (&hints, 0, sizeof (struct addrinfo));
+	memset (&hints, 0, sizeof (struct addrinfo));
 	hints.ai_family   = AF_UNSPEC;     /* Allow IPv4 or IPv6 */
 	hints.ai_socktype = SOCK_STREAM;   /* Stream socket */
 	hints.ai_flags    = 0;
@@ -209,7 +209,8 @@ net_create_sock (int domain, int type, int protocol_s,
  *             the interfaces)
  *
  * Return:
- *   0 --> No error (sock_set and sock_max are set)
+ *   0 --> No error.  sock_set and sock_max are set and must be closed by the
+ *          caller by net_close_sock_set (sock_set, sock_max)
  *  -1 --> Error (an error message has been logged by lwc_writeLog())
  */
 int
@@ -234,14 +235,14 @@ net_server (	const char *port_number, const char *iface,
 	assert (port_number != NULL);
 #endif
 
-	schedwi_memset (&hints, 0, sizeof (struct addrinfo));
+	memset (&hints, 0, sizeof (struct addrinfo));
 	hints.ai_family = AF_UNSPEC;   /* Allow IPv4 and IPv6 */
 	if (address_family != NULL) {
-		if (schedwi_strcasecmp (address_family, "inet") == 0) {
+		if (strcasecmp (address_family, "inet") == 0) {
 			hints.ai_family = AF_INET; /* Only allow IPv4 */
 		}
 		else {
-			if (schedwi_strcasecmp (address_family, "inet6") == 0) {
+			if (strcasecmp (address_family, "inet6") == 0) {
 				hints.ai_family = AF_INET6; /* Only IPv6 */
 			}
 		}
@@ -350,18 +351,8 @@ build_client_names_from_addr (	const struct sockaddr_storage *in,
 	assert (names != NULL);
 #endif
 
-	lst = (char **) malloc (3 * sizeof (char *));
-	if (lst == NULL) {
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		return -1;
-	}
-
-	lst[0] = (char *) malloc (50);
-	if (lst[0] == NULL) {
-		free (lst);
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		return -1;
-	}
+	lst = (char **) xmalloc (3 * sizeof (char *));
+	lst[0] = (char *) xmalloc (50);
 
 	/* First retrieve the host in dot notation */
 	ret = getnameinfo (	(const struct sockaddr *)in, inlen,
@@ -378,16 +369,7 @@ build_client_names_from_addr (	const struct sockaddr_storage *in,
 	}
 
 	/* Then, retrieve the associated host name */
-	lst[i] = (char *)malloc (NI_MAXHOST);
-	if (lst[i] == NULL) {
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		for (j = 0; j < i; j++) {
-			free (lst[j]);
-		}
-		free (lst);
-		return -1;
-	}
-
+	lst[i] = (char *) xmalloc (NI_MAXHOST);
 	try_no = 0;
 	do {
 		ret = getnameinfo (	(const struct sockaddr *)in, inlen,
@@ -464,11 +446,7 @@ parse_ipv6 (const char *host_name, char **name, char **port)
 
 	/* Name part */
 	if (host_name[i] == '[') {
-		n = (char *) malloc (schedwi_strlen (host_name + i + 1) + 1);
-		if (n == NULL) {
-			lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-			return -1;
-		}
+		n = (char *) xmalloc (strlen (host_name + i + 1) + 1);
 		strcpy (n, host_name + i + 1);
 		s = strchr (n, ']');
 		if (s == NULL) {
@@ -494,12 +472,7 @@ parse_ipv6 (const char *host_name, char **name, char **port)
 		}
 	}
 	else {
-		n = (char *) malloc (schedwi_strlen (host_name + i) + 1);
-		if (n == NULL) {
-			lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-			return -1;
-		}
-		strcpy (n, host_name + i);
+		n = xstrdup (host_name + i);
 		s = NULL;
 	}
 
@@ -509,13 +482,7 @@ parse_ipv6 (const char *host_name, char **name, char **port)
 		s = SCHEDWI_DEFAULT_AGTPORT;
 	}
 
-	p = (char *) malloc (schedwi_strlen (s) + 1);
-	if (p == NULL) {
-		free (n);
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		return -1;
-	}
-	strcpy (p, s);
+	p = xstrdup (s);
 	*name = n;
 	*port = p;
 	return 0;
@@ -549,12 +516,7 @@ parse_ipv4 (const char *host_name, char **name, char **port)
 	}
 
 	/* Name part */
-	n = (char *) malloc (schedwi_strlen (host_name + i) + 1);
-	if (n == NULL) {
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		return -1;
-	}
-	strcpy (n, host_name + i);
+	n = xstrdup (host_name + i);
 
 	/* Port part */
 	s = strchr (n, ':');
@@ -568,13 +530,7 @@ parse_ipv4 (const char *host_name, char **name, char **port)
 		/* Default port */
 		s = SCHEDWI_DEFAULT_AGTPORT;
 	}
-	p = (char *) malloc (schedwi_strlen (s) + 1);
-	if (p == NULL) {
-		free (n);
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		return -1;
-	}
-	strcpy (p, s);
+	p = xstrdup (s);
 	*name = n;
 	*port = p;
 	return 0;
@@ -631,7 +587,7 @@ build_client_names_from_name (	const char *host_name, char ***names,
 				char **port)
 {
 	int try_no, ret;
-	unsigned int i, j, length;
+	unsigned int i, length;
 	struct addrinfo hints;
 	struct addrinfo *result, *rp;
 	char **lst;
@@ -653,7 +609,7 @@ build_client_names_from_name (	const char *host_name, char ***names,
 		return -1;
 	}
 
-	schedwi_memset (&hints, 0, sizeof (struct addrinfo));
+	memset (&hints, 0, sizeof (struct addrinfo));
 	hints.ai_family    = AF_UNSPEC;
 	hints.ai_socktype  = SOCK_STREAM;
 	hints.ai_flags     = AI_CANONNAME;
@@ -714,16 +670,7 @@ build_client_names_from_name (	const char *host_name, char ***names,
 		 */
 		length = (2 * i) + 3;
 	}
-	lst = (char **) malloc (length * sizeof (char *));
-	if (lst == NULL) {
-		free (n);
-		free (p);
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		if (result != NULL) {
-			freeaddrinfo (result);
-		}
-		return -1;
-	}
+	lst = (char **) xmalloc (length * sizeof (char *));
 
 	/* Add the canonical name in the array */
 	i = 0;
@@ -731,20 +678,7 @@ build_client_names_from_name (	const char *host_name, char ***names,
 		&& result->ai_canonname != NULL
 		&& (result->ai_canonname)[0] != '\0')
 	{
-		lst[i] = (char *)malloc (schedwi_strlen (result->ai_canonname)
-						+ 1);
-		if (lst[i] == NULL) {
-			free (n);
-			free (p);
-			lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-			for (j = 0; j < i; j++) {
-				free (lst[j]);
-			}
-			free (lst);
-			freeaddrinfo (result);
-			return -1;
-		}
-		strcpy (lst[i++], result->ai_canonname);
+		lst[i++] = xstrdup (result->ai_canonname);
 	}
 
 	/* Add the name provided as a parameter */
@@ -752,17 +686,7 @@ build_client_names_from_name (	const char *host_name, char ***names,
 
 	for (rp = result; rp != NULL; rp = rp->ai_next) {
 		/* First add the numeric host value */
-		lst[i] = (char *)malloc (50);
-		if (lst[i] == NULL) {
-			free (p);
-			lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-			for (j = 0; j < i; j++) {
-				free (lst[j]);
-			}
-			free (lst);
-			freeaddrinfo (result);
-			return -1;
-		}
+		lst[i] = (char *) xmalloc (50);
 		ret = getnameinfo (	rp->ai_addr, rp->ai_addrlen,
 					lst[i], 50, NULL, 0, NI_NUMERICHOST);
 		if (ret != 0) {
@@ -775,18 +699,7 @@ build_client_names_from_name (	const char *host_name, char ***names,
 		}
 
 		/* Then, do a reverse lookup to add a host name */
-		lst[i] = (char *)malloc (NI_MAXHOST);
-		if (lst[i] == NULL) {
-			free (p);
-			lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-			for (j = 0; j < i; j++) {
-				free (lst[j]);
-			}
-			free (lst);
-			freeaddrinfo (result);
-			return -1;
-		}
-
+		lst[i] = (char *) xmalloc (NI_MAXHOST);
 		try_no = 0;
 		do {
 			ret = getnameinfo (rp->ai_addr, rp->ai_addrlen,
@@ -872,7 +785,7 @@ net_client_sock (const char *port_number, const char *hostname)
 	assert (port_number != NULL && hostname != NULL);
 #endif
 
-	schedwi_memset (&hints, 0, sizeof (struct addrinfo));
+	memset (&hints, 0, sizeof (struct addrinfo));
 	hints.ai_family   = AF_UNSPEC;     /* Allow IPv4 or IPv6 */
 	hints.ai_socktype = SOCK_STREAM;   /* Stream socket */
 	hints.ai_flags    = AI_ADDRCONFIG;
@@ -992,12 +905,7 @@ net_read_sock (int sock, char **buff, size_t *len)
 #endif
 
 	if (*buff == NULL || *len == 0) {
-		*buff = (char *) malloc (BUFFER_LEN);
-		if (*buff == NULL) {
-			*len = 0;
-			lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-			return -1;
-		}
+		*buff = (char *) xmalloc (BUFFER_LEN);
 		*len = BUFFER_LEN;
 	}
 
@@ -1010,6 +918,8 @@ net_read_sock (int sock, char **buff, size_t *len)
 	config.allow_comments         = 0;
 	config.handle_floats_manually = 0;
 	config.callback_ctx           = &nb_open_brackets;
+	config.malloc                 = xmalloc;
+	config.free                   = free;
 
 	jc = new_JSON_parser (&config);
 
@@ -1065,7 +975,7 @@ net_read_sock (int sock, char **buff, size_t *len)
 		 * been received.
 		 */
 		for (i = 0; i < nb_read; i++) {
-			if (! JSON_parser_char (jc, b[i])) {
+			if (! JSON_parser_char (jc, (unsigned char)(b[i]))) {
 				lwc_writeLog (	LOG_ERR,
 					_("Syntax error in received data"));
 				delete_JSON_parser (jc);
@@ -1090,13 +1000,7 @@ net_read_sock (int sock, char **buff, size_t *len)
 				return -2;
 			}
 
-			tmp = (char *) realloc (*buff, *len + BUFFER_LEN);
-			if (tmp == NULL) {
-				lwc_writeLog (	LOG_CRIT,
-						_("Memory allocation error"));
-				delete_JSON_parser (jc);
-				return -1;
-			}
+			tmp = (char *) xrealloc (*buff, *len + BUFFER_LEN);
 			*buff = tmp;
 			*len += BUFFER_LEN;
 			b = *buff + total;
