@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2011 Herve Quatremain
+   Copyright (C) 2007-2014 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -64,11 +64,11 @@ extern int errno;
 GCRY_THREAD_OPTION_PTHREAD_IMPL;
 #endif
 
-#include <lib_functions.h>
 #include <lwc_log.h>
 #include <net_utils_sock.h>
 #include <net_utils_ssl.h>
 #include <JSON_parser.h>
+#include <xmem.h>
 #include <cert_utils.h>
 
 
@@ -124,7 +124,7 @@ check_string_request_names (char *s, const char *const *names)
 	}
 
 	dat.data = (unsigned char *) s;
-	dat.size = schedwi_strlen (s);
+	dat.size = strlen (s);
 
 	ret = gnutls_x509_crq_import (crq, &dat, GNUTLS_X509_FMT_PEM);
 	if (	   ret < 0
@@ -558,6 +558,7 @@ net_init_gnutls (char quick_random)
 {
 	int ret;
 
+
 	/* For the support of threads in libgcrypt */
 #if GNUTLS_VERSION_NUMBER <= 0x020b00
 	gcry_control (GCRYCTL_SET_THREAD_CBS, &gcry_threads_pthread);
@@ -671,53 +672,10 @@ _("SSL: Cannot load the provided certificat `%s' with the key `%s': %s"),
 	gnutls_certificate_free_credentials (x509_cred);
 
 	/* Save the path to the provided files */
-	schedwisrv_crt = (char *) malloc (
-				schedwi_strlen (schedwisrv_crt_file) + 1);
-	if (schedwisrv_crt == NULL) {
-		gnutls_global_deinit ();
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		return -1;
-	}
-	strcpy (schedwisrv_crt, schedwisrv_crt_file);
-
-	schedwisrv_key = (char *) malloc (
-				schedwi_strlen (schedwisrv_key_file) + 1);
-	if (schedwisrv_key == NULL) {
-		free (schedwisrv_crt);
-		schedwisrv_crt = NULL;
-		gnutls_global_deinit ();
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		return -1;
-	}
-	strcpy (schedwisrv_key, schedwisrv_key_file);
-
-	schedwisrv_ca = (char *) malloc (
-				schedwi_strlen (schedwisrv_ca_file) + 1);
-	if (schedwisrv_ca == NULL) {
-		free (schedwisrv_key);
-		free (schedwisrv_crt);
-		schedwisrv_key = NULL;
-		schedwisrv_crt = NULL;
-		gnutls_global_deinit ();
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		return -1;
-	}
-	strcpy (schedwisrv_ca, schedwisrv_ca_file);
-
-	schedwisrv_crl = (char *) malloc (
-				schedwi_strlen (schedwisrv_crl_file) + 1);
-	if (schedwisrv_crl == NULL) {
-		free (schedwisrv_ca);
-		free (schedwisrv_key);
-		free (schedwisrv_crt);
-		schedwisrv_ca = NULL;
-		schedwisrv_key = NULL;
-		schedwisrv_crt = NULL;
-		gnutls_global_deinit ();
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		return -1;
-	}
-	strcpy (schedwisrv_crl, schedwisrv_crl_file);
+	schedwisrv_crt = xstrdup (schedwisrv_crt_file);
+	schedwisrv_key = xstrdup (schedwisrv_key_file);
+	schedwisrv_ca = xstrdup (schedwisrv_ca_file);
+	schedwisrv_crl = xstrdup (schedwisrv_crl_file);
 
 	return 0;
 }
@@ -1077,12 +1035,7 @@ net_read_ssl (gnutls_session_t session, char **buff, size_t *len)
 #endif
 
 	if (*buff == NULL || *len == 0) {
-		*buff = (char *) malloc (BUFFER_LEN);
-		if (*buff == NULL) {
-			*len = 0;
-			lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-			return -1;
-		}
+		*buff = (char *) xmalloc (BUFFER_LEN);
 		*len = BUFFER_LEN;
 	}
 
@@ -1095,6 +1048,8 @@ net_read_ssl (gnutls_session_t session, char **buff, size_t *len)
 	config.allow_comments         = 0;
 	config.handle_floats_manually = 0;
 	config.callback_ctx           = &nb_open_brackets;
+	config.malloc                 = xmalloc;
+	config.free                   = free;
 
 	jc = new_JSON_parser (&config);
 
@@ -1129,7 +1084,7 @@ net_read_ssl (gnutls_session_t session, char **buff, size_t *len)
 		 * been receved.
 		 */
 		for (i = 0; i < nb_read; i++) {
-			if (! JSON_parser_char (jc, b[i])) {
+			if (! JSON_parser_char (jc, (unsigned char)(b[i]))) {
 				lwc_writeLog (  LOG_ERR,
 					_("Syntax error in received data"));
 				delete_JSON_parser (jc);
@@ -1154,13 +1109,7 @@ net_read_ssl (gnutls_session_t session, char **buff, size_t *len)
 				return -2;
 			}
 
-			tmp = (char *) realloc (*buff, *len + BUFFER_LEN);
-			if (tmp == NULL) {
-				lwc_writeLog (	LOG_CRIT,
-						_("Memory allocation error"));
-				delete_JSON_parser (jc);
-				return -1;
-			}
+			tmp = (char *) xrealloc (*buff, *len + BUFFER_LEN);
 			*buff = tmp;
 			*len += BUFFER_LEN;
 			b = *buff + total;
