@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -68,7 +68,7 @@
 #include <assert.h>
 #endif
 
-#include <lib_functions.h>
+#include <xmem.h>
 #include <parsevar.h>
 
 /*
@@ -78,44 +78,31 @@
  * calling copy_str, *dst can contain a pointer to a malloc()-allocated
  * buffer *dst_len in size.  If the buffer is not large enough, copy_str
  * resizes the buffer, updating *dst and *dst_len.
- *
- * Return:
- *    0 --> No error
- *   -1 --> Memory allocation error (dst is not modified)
  */
-static int
+static void
 copy_str (	char **dst, size_t *dst_len, int dst_idx,
 		const char *src, size_t src_len)
 {
-	char *tmp;
 	size_t l;
 
+
 #if HAVE_ASSERT_H
 	assert (dst != NULL && dst_len != NULL && src != NULL);
 #endif
 
 	if (*dst == NULL || *dst_len == 0) {
-		*dst = NULL;
-		*dst_len = 0;
+		*dst = (char *) xmalloc (src_len + 128);
+		*dst_len = src_len + 128;
 	}
 
 	if (*dst_len - dst_idx <= src_len) {
 		l = src_len + dst_idx + 128;
-		tmp = (char *) malloc (l);
-		if (tmp == NULL) {
-			return -1;
-		}
-		if (*dst != NULL && *dst_len > 0) {
-			schedwi_memcpy (tmp, *dst, *dst_len);
-			free (*dst);
-		}
-		*dst = tmp;
+		*dst = (char *) xrealloc (*dst, l);
 		*dst_len = l;
 	}
 
-	schedwi_memcpy (*dst + dst_idx, src, src_len);
+	memcpy (*dst + dst_idx, src, src_len);
 	(*dst)[dst_idx + src_len] = '\0';
-	return 0;
 }
 
 
@@ -132,6 +119,7 @@ parse_name (const char *param, size_t param_len)
 {
 	size_t i;
 
+
 #if HAVE_ASSERT_H
 	assert (param != NULL);
 #endif
@@ -162,8 +150,6 @@ parse_name (const char *param, size_t param_len)
  *
  * Return:
  *    The number of characters parsed in the param string or
- *    -1 in case of memory allocation error (the previous value of *out and
- *    *out_len are not modified)
  *    -2 in case of syntax error
  */
 static ssize_t
@@ -176,6 +162,7 @@ parse_variable (const char *param, size_t param_len,
 	const char *env_val;
 	size_t val_len;
 
+
 #if HAVE_ASSERT_H
 	assert (param != NULL && out != NULL && out_len != NULL);
 #endif
@@ -191,10 +178,7 @@ parse_variable (const char *param, size_t param_len,
 	/* Not found, the associated value will be the empty string */
 	if (idx_env == -1) {
 		if (*out_len < 1) {
-			*out = (char *) malloc (128);
-			if (*out == NULL) {
-				return -1;
-			}
+			*out = (char *) xmalloc (128);
 			*out_len = 128;
 		}
 		(*out)[0] = '\0';
@@ -205,12 +189,9 @@ parse_variable (const char *param, size_t param_len,
 	env_val = getvar_environment (env, idx_env);
 	equal = strchr (env_val, '=');
 	equal++;
-	val_len = schedwi_strlen (equal);
+	val_len = strlen (equal);
 	if (*out_len < val_len + 1) {
-		tmp = (char *) malloc (val_len + 128);
-		if (tmp == NULL) {
-			return -1;
-		}
+		tmp = (char *) xmalloc (val_len + 128);
 		if (*out_len > 0 && *out != NULL) {
 			free (*out);
 		}
@@ -266,8 +247,6 @@ find_matching_bracket (const char *s, size_t len)
  *
  * Return:
  *    The index in param of the caracter following the parsed parameter OR
- *    -1 in case of memory allocation error (the previous value of *out and
- *       *out_len are not modified) OR
  *    -2 in case of syntax error (The content of *out and *out_len is
  *       unspecified)
  */
@@ -281,6 +260,7 @@ expand_param (	const char *param, size_t param_len,
 	int ret;
 	size_t val_len;
 
+
 #if HAVE_ASSERT_H
 	assert (param != NULL && out != NULL && out_len != NULL);
 #endif
@@ -356,14 +336,8 @@ expand_param (	const char *param, size_t param_len,
 			}
 
 			end_key_idx = parse_name (param + 1, param_len - 1);
-			ret = add_env_s (	env,
-						param + 1, end_key_idx,
-						val, schedwi_strlen (val));
-			if (ret < 0) {
-				free (val);
-				return ret;
-			}
-
+			add_env_s (env, param + 1, end_key_idx,
+					val, strlen (val));
 			*out = val;
 			*out_len = val_len;
 			return end + i + 3;
@@ -386,14 +360,9 @@ expand_param (	const char *param, size_t param_len,
 					free (val);
 				}
 				msg = _("parameter null or not set");
-				*out = (char *)malloc (	  schedwi_strlen (msg)
-							+ 1);
-				if (*out == NULL) {
-					*out_len = 0;
-					return -1;
-				}
+				*out = (char *) xmalloc (strlen (msg) + 1);
 				strcpy (*out, msg);
-				*out_len = schedwi_strlen (msg) + 1;
+				*out_len = strlen (msg) + 1;
 			}
 			else {
 				*out = val;
@@ -430,8 +399,6 @@ expand_param (	const char *param, size_t param_len,
  *
  * Return:
  *    0 --> No error
- *   -1 --> Memory allocation error (the previous value of *out and
- *          *out_len are not modified)
  *   -2 --> Syntax error (the previous value of *out and *out_len are not
  *          modified)
  */
@@ -445,14 +412,13 @@ parse_string (	const char *string, size_t string_len,
 	ssize_t substr_len;
 	int idx_out;
 
+
 	if (out == NULL || out_len == NULL) {
 		return 0;
 	}
 
 	if (string == NULL) {
-		if (copy_str (out, out_len, 0, "", 0) < 0) {
-			return -1;
-		}
+		copy_str (out, out_len, 0, "", 0);
 		return 0;
 	}
 
@@ -472,17 +438,10 @@ parse_string (	const char *string, size_t string_len,
 			 * Copy until the dollar (included) but
 			 * without the \ character
 			 */
-			if (	   copy_str (	out, out_len, idx_out,
-						val, dollar - 1 - val) < 0
-				|| copy_str (	out, out_len,
-						idx_out + dollar - 1 - val,
-						"$", 1) < 0)
-			{
-				if (expand != NULL && expand_len > 0) {
-					free (expand);
-				}
-				return -1;
-			}
+			copy_str (out, out_len, idx_out,
+					val, dollar - 1 - val);
+			copy_str (out, out_len, idx_out + dollar - 1 - val,
+					"$", 1);
 			idx_out += dollar - val;
 			val = dollar + 1;
 		}
@@ -490,15 +449,7 @@ parse_string (	const char *string, size_t string_len,
 		/* $VAR */
 		else {
 			/* Copy up to the dollar (not included) */
-			if (copy_str (	out, out_len, idx_out,
-					val, dollar - val) < 0)
-			{
-				if (expand != NULL && expand_len > 0) {
-					free (expand);
-				}
-				return -1;
-			}
-
+			copy_str (out, out_len, idx_out, val, dollar - val);
 			idx_out += dollar - val;
 			val = dollar + 1;
 
@@ -514,16 +465,11 @@ parse_string (	const char *string, size_t string_len,
 			}
 
 			/* Copy the expanded value */
-			l = schedwi_strlen (expand);
-			if (copy_str (out, out_len, idx_out, expand, l) < 0) {
-				free (expand);
-				return -1;
-			}
-
+			l = strlen (expand);
+			copy_str (out, out_len, idx_out, expand, l);
 			idx_out += l;
 			val += substr_len;
 		}
-
 		dollar = strchr (val, '$');
 	}
 
@@ -532,11 +478,7 @@ parse_string (	const char *string, size_t string_len,
 	}
 
 	/* Copy the end (no more expansion to do) */
-	if (copy_str (	out, out_len, idx_out,
-			val, string_len - (val - string)) < 0)
-	{
-		return -1;
-	}
+	copy_str (out, out_len, idx_out, val, string_len - (val - string));
 	return 0;
 }
 
@@ -551,8 +493,6 @@ parse_string (	const char *string, size_t string_len,
  *
  * Return:
  *    0 --> No error
- *   -1 --> Memory allocation error (the previous value of *out and
- *          *out_len are not modified)
  *   -2 --> Syntax error (the previous value of *out and *out_len are not
  *          modified)
  */
@@ -563,6 +503,7 @@ parse_key (const char *key, char **out, size_t *out_len)
 	size_t l;
 	char *tmp;
 
+
 #if HAVE_ASSERT_H
 	assert (key != NULL && out != NULL && out_len != NULL);
 #endif
@@ -576,12 +517,9 @@ parse_key (const char *key, char **out, size_t *out_len)
 	}
 
 	/* Allocate a memory buffer for copying the variable name */
-	l = schedwi_strlen (key + i) + 1;
+	l = strlen (key + i) + 1;
 	if (*out_len < l) {
-		tmp = (char *) malloc (l + 128);
-		if (tmp == NULL) {
-			return -1;
-		}
+		tmp = (char *) xmalloc (l + 128);
 		if (*out != NULL && *out_len > 0) {
 			free (*out);
 		}
@@ -618,7 +556,6 @@ parse_key (const char *key, char **out, size_t *out_len)
  *
  * Return:
  *    0 --> No error
- *   -1 --> Memory allocation error
  *   -2 --> Syntax error in the key part (variable name)
  *   -3 --> Syntax error in the value part
  */
@@ -629,6 +566,7 @@ parse_param (const environment_t *env, environment_t *new_env, int *error_idx)
 	char *val, *key, *equal;
 	size_t key_len, val_len;
 
+
 	if (env == NULL || new_env == NULL) {
 		return 0;
 	}
@@ -670,7 +608,7 @@ parse_param (const environment_t *env, environment_t *new_env, int *error_idx)
 		}
 
 		/* Get the variable value */
-		ret = parse_string (	equal + 1, schedwi_strlen (equal + 1),
+		ret = parse_string (	equal + 1, strlen (equal + 1),
 					new_env, &val, &val_len);
 		if (ret != 0 ) {
 			free (key);
@@ -684,15 +622,7 @@ parse_param (const environment_t *env, environment_t *new_env, int *error_idx)
 		}
 
 		/* Add the variable to the environment array */
-		ret = add_env (new_env, key, val);
-		if (ret != 0 ) {
-			free (key);
-			free (val);
-			if (error_idx != NULL) {
-				*error_idx = i;
-			}
-			return ret;
-		}
+		add_env (new_env, key, val);
 	}
 	if (key_len > 0 && key != NULL) {
 		free (key);
@@ -703,89 +633,4 @@ parse_param (const environment_t *env, environment_t *new_env, int *error_idx)
 	return 0;
 }
 
-
-/*
- * Parse each variable of the provided argument array.  The parameters
- * in the variables are expanded using the provided environment object.
- * A new argument array is returned int arg.
- *
- * Return:
- *    0 --> No error
- *   -1 --> Memory allocation error
- *   -2 --> Syntax error in the value part
- */
-int
-parse_args (const argument_t *arg, argument_t *new_arg, environment_t *env,
-		int *error_idx)
-{
-	int i, ret;
-	char *val;
-	size_t val_len;
-
-	if (arg == NULL || new_arg == NULL) {
-		return 0;
-	}
-
-	val = NULL;
-	val_len = 0;
-
-	for (i = 0; i < arg->idx; i++) {
-
-		/* Get the variable value */
-		ret = parse_string (	(arg->arg)[i],
-					schedwi_strlen ((arg->arg)[i]),
-					env, &val, &val_len);
-		if (ret != 0 ) {
-			if (val_len > 0 && val != NULL) {
-				free (val);
-			}
-			if (error_idx != NULL) {
-				*error_idx = i;
-			}
-			return ret;
-		}
-
-		/* Add the variable to the environment array */
-		ret = add_arg (new_arg, val);
-		if (ret != 0 ) {
-			free (val);
-			if (error_idx != NULL) {
-				*error_idx = i;
-			}
-			return ret;
-		}
-	}
-	if (val_len > 0 && val != NULL) {
-		free (val);
-	}
-	return 0;
-}
-
-
-/*
- * Check the syntax of a key
- *
- * Return:
- *   0 --> Syntax OK
- *  -1 --> Syntax error
- */
-int
-check_key_syntax (const char *key)
-{
-	int i;
-
-	if (	   key == NULL
-		|| key[0] == '0'
-		|| (key[0] != '_' && isalpha (key[0]) == 0))
-	{
-		return -1;
-	}
-	for (i = 1; key[i] != 0; i++) {
-		if (key[i] != '_' && isalnum (key[i]) == 0) {
-			return -1;
-		}
-	}
-	return 0;
-}
-
 /*-----------------============== End Of File ==============-----------------*/
