@@ -41,22 +41,4 @@ reg_error_to_string (error_reason_t reason)
 	}
 }
 
-
-/*
- * Convert the provided int to an error code
- */
-error_reason_t
-int_to_reg_error (int reason)
-{
-	switch (reason) {
-		case 1:		return REG_SYSTEM_ERROR;
-		case 2:		return REG_NO_CSR;
-		case 3:		return REG_NOT_READY_YET;
-		case 4:		return REG_CRT_PRESENT;
-		case 5:		return REG_CSR_PRESENT;
-		case 6:		return REG_ERROR_CSR;
-		default:	return REG_SYSTEM_ERROR;
-	}
-}
-
 /*-----------------============== End Of File ==============-----------------*/
