@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2013 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -34,10 +34,10 @@
 #include <assert.h>
 #endif
 
-#include <lib_functions.h>
 #include <utils.h>
+#include <xmem.h>
+#include <memsend.h>
 #include <net_utils_sock.h>
-#include <cert_ca.h>
 #include <cert_utils.h>
 #include <conf.h>
 #include <lwc_log.h>
@@ -70,6 +70,7 @@ json_char_callback (void* ctx, int type, const JSON_value* value)
 {
 	struct json_cb *s = (struct json_cb *)ctx;
 
+
 	switch (type) {
 		case JSON_T_ARRAY_BEGIN:
 			if (s->step == S_START) {
@@ -88,8 +89,8 @@ json_char_callback (void* ctx, int type, const JSON_value* value)
 			break;
 		case JSON_T_KEY:
 			if (s->step == S_DATA) {
-				if (schedwi_strcasecmp (value->vu.str.value,
-							"port") == 0)
+				if (strcasecmp (value->vu.str.value,
+						"port") == 0)
 				{
 					s->step = S_KEY_PORT;
 				}
@@ -115,24 +116,24 @@ json_char_callback (void* ctx, int type, const JSON_value* value)
 static void
 send_error (int sock, const char *error_message, error_reason_t reason)
 {
-	const char *s;
+	memsend_t *membuff;
 
-	s = "{ \"success\" : false, \"reason\" : ";
-	net_write_sock (sock, s, schedwi_strlen (s));
-	s = reg_error_to_string (reason);
-	net_write_sock (sock, s, schedwi_strlen (s));
-	s = ", \"data\" : \"";
-	net_write_sock (sock, s, schedwi_strlen (s));
+
+	membuff = memsend_new ();
+	memsend_append (membuff, "{ \"success\" : false, \"reason\" : ");
+	memsend_append (membuff, reg_error_to_string (reason));
+	memsend_append (membuff, ", \"data\" : \"");
 	if (error_message != NULL) {
-		net_write_sock (sock, error_message,
-				schedwi_strlen (error_message));
+		memsend_append (membuff, error_message);
 	}
 	else {
-		s = _("Cannot get the agent certificate");
-		net_write_sock (sock, s, schedwi_strlen (s));
+		memsend_append (membuff,
+				_("Cannot get the agent certificate"));
 	}
-	s = "\" }";
-	net_write_sock (sock, s, schedwi_strlen (s));
+	memsend_append (membuff, "\" }");
+	net_write_sock (sock, memsend_getstring (membuff),
+			memsend_getlength (membuff));
+	memsend_destroy (membuff);
 }
 
 
@@ -142,7 +143,6 @@ send_error (int sock, const char *error_message, error_reason_t reason)
  * Return:
  *   0 --> file exists (`outfilenames' contains the file name - use free())
  *   1 --> file does not exists
- *  -1 --> Error (a message has been logged)
  */
 static int
 check_file (	const char *dir, const char *name, 
@@ -151,22 +151,19 @@ check_file (	const char *dir, const char *name,
 	size_t l;
 	char *s;
 
+
 #if HAVE_ASSERT_H
 	assert (dir != NULL && name != NULL && port != NULL && ext != NULL);
 #endif
 
-	l =	  schedwi_strlen (dir)
-		+ schedwi_strlen (DIR_SEP)
-		+ schedwi_strlen (port)
+	l =	  strlen (dir)
+		+ strlen (DIR_SEP)
+		+ strlen (port)
 		+ 1 /* "_" separator */
-		+ schedwi_strlen (name)
-		+ schedwi_strlen (ext)
+		+ strlen (name)
+		+ strlen (ext)
 		+ 1;
-	s  = (char *) malloc (l);
-	if (s == NULL) {
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		return -1;
-	}
+	s  = (char *) xmalloc (l);
 	strcpy (s, dir);
 	strcat (s, DIR_SEP);
 	strcat (s, port);
@@ -198,6 +195,7 @@ reg_getmycrt (	int sock, const char *buff, ssize_t buff_len,
 	struct JSON_parser_struct *jc;
 	struct json_cb cb_data;
 	char sport[7];
+	memsend_t *membuff;
 
 
 	ret =  conf_get_param_string (	"SSLAgentCertificateDir",
@@ -224,6 +222,8 @@ reg_getmycrt (	int sock, const char *buff, ssize_t buff_len,
 	config.allow_comments         = 0;
 	config.handle_floats_manually = 0;
 	config.callback_ctx           = &cb_data;
+	config.malloc                 = xmalloc;
+	config.free                   = free;
 
 	jc = new_JSON_parser (&config);
 
@@ -233,13 +233,7 @@ reg_getmycrt (	int sock, const char *buff, ssize_t buff_len,
 		 * No need to check the return code as the JSON string has
 		 * already been parsed once in net_parse_reg.c
 		 */
-		JSON_parser_char (jc, buff[i]);
-		if (cb_data.error != 0) {
-			delete_JSON_parser (jc);
-			lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-			send_error (sock, NULL, REG_SYSTEM_ERROR);
-			return -1;
-		}
+		JSON_parser_char (jc, (unsigned char)(buff[i]));
 	}
 	delete_JSON_parser (jc);
 
@@ -250,10 +244,6 @@ reg_getmycrt (	int sock, const char *buff, ssize_t buff_len,
 		/* SSL */
 		ret = check_file (	client_cert_dir, client_names[i],
 					sport, CRT_EXTENSION, &s);
-		if (ret < 0) {
-			send_error (sock, NULL, REG_SYSTEM_ERROR);
-			return -1;
-		}
 		if (ret == 0) {
 			content = read_file (s, NULL);
 			free (s);
@@ -263,32 +253,24 @@ reg_getmycrt (	int sock, const char *buff, ssize_t buff_len,
 			}
 			serialized = PEM2string (content);
 			free (content);
-			if (serialized == NULL) {
-				lwc_writeLog (	LOG_CRIT,
-						_("Memory allocation error"));
-				send_error (sock, NULL, REG_SYSTEM_ERROR);
-				return -1;
-			}
 
-			s = "{ \"success\" : true, \"data\" : \"";
-			net_write_sock (sock, s, schedwi_strlen (s));
-			net_write_sock (	sock, serialized,
-						schedwi_strlen (serialized));
+			membuff = memsend_new ();
+			memsend_append (membuff,
+				"{ \"success\" : true, \"data\" : \"");
+			memsend_append (membuff, serialized);
 			free (serialized);
-			s = "\" }";
-			net_write_sock (sock, s, schedwi_strlen (s));
+			memsend_append (membuff, "\" }");
+			net_write_sock (sock, memsend_getstring (membuff),
+					memsend_getlength (membuff));
+			memsend_destroy (membuff);
 			return 0;
 		}
 		/* No SSL */
 		ret = check_file (	client_cert_dir, client_names[i],
 					sport, NOSSL_EXTENSION, NULL);
-		if (ret < 0) {
-			send_error (sock, NULL, REG_SYSTEM_ERROR);
-			return -1;
-		}
 		if (ret == 0) {
 			s = "{ \"success\" : true, \"data\" : \"OK\" }";
-			net_write_sock (sock, s, schedwi_strlen (s));
+			net_write_sock (sock, s, strlen (s));
 			return 0;
 		}
 	}
@@ -298,10 +280,6 @@ reg_getmycrt (	int sock, const char *buff, ssize_t buff_len,
 		/* SSL */
 		ret = check_file (	client_csr_dir, client_names[i],
 					sport, CSR_EXTENSION, NULL);
-		if (ret < 0) {
-			send_error (sock, NULL, REG_SYSTEM_ERROR);
-			return -1;
-		}
 		if (ret == 0) {
 			send_error (	sock, _("Certificate still not ready"),
 					REG_NOT_READY_YET);
@@ -310,10 +288,6 @@ reg_getmycrt (	int sock, const char *buff, ssize_t buff_len,
 		/* No SSL */
 		ret = check_file (	client_csr_dir, client_names[i],
 					sport, NOSSL_EXTENSION, NULL);
-		if (ret < 0) {
-			send_error (sock, NULL, REG_SYSTEM_ERROR);
-			return -1;
-		}
 		if (ret == 0) {
 			send_error (	sock, _("Certificate still not ready"),
 					REG_NOT_READY_YET);
@@ -322,8 +296,9 @@ reg_getmycrt (	int sock, const char *buff, ssize_t buff_len,
 	}
 
 	/* No certificate and no request! */
-	lwc_writeLog (LOG_INFO,
-_("Agent %s (port %s) is asking for its certificate but I don't even have the pending request"), client_names[0], sport);
+	lwc_writeLog (	LOG_INFO,
+_("Agent %s (port %s) is asking for its certificate but I don't even have the pending request"),
+			client_names[0], sport);
 	send_error (sock,
 		_("I don't have a request for you. Send a request first"),
 		REG_NO_CSR);
