@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2013 Herve Quatremain
+   Copyright (C) 2013, 2014 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -23,15 +23,15 @@
 #define _SCHEDWI_SYSTEM_H
 
 #include <schedwi.h>
-#include <schedwi_jobtree.h>
 
 /* Allow the use in C++ code.  */
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-extern int schedwi_system OF((	const char *line, int workload,
-				const schedwi_jobtree_node_ptr job,
+extern int schedwi_system OF((	const char *command,
+				const char *workload_jobid,
+				const char *job_name_with_path,
 				const char * const *variables, size_t len));
 
 #ifdef __cplusplus
