@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2011 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -74,7 +74,7 @@ extern int errno;
 
 #if HAVE_DIRENT_H
 # include <dirent.h>
-# define NAMLEN(dirent) schedwi_strlen((dirent)->d_name)
+# define NAMLEN(dirent) strlen((dirent)->d_name)
 #else
 # define dirent direct
 # define NAMLEN(dirent) (dirent)->d_namlen
@@ -89,6 +89,7 @@ extern int errno;
 # endif
 #endif
 
+#include <error.h>
 
 #include <sql_common.h>
 #include <utils.h>
@@ -99,8 +100,8 @@ extern int errno;
 #include <net_utils_ssl.h>
 #include <sql_hosts.h>
 #include <module.h>
-#include <lib_functions.h>
 #include <cert_utils.h>
+#include <xmem.h>
 #include <cert_ca.h>
 
 static const char *configuration_file = NULL;
@@ -114,7 +115,7 @@ static char force, quiet;
  * Print a help message to stderr
  */
 static void
-help (const char * prog_name)
+help ()
 {
 	int i;
 	char * msg[] = {
@@ -162,33 +163,33 @@ N_("  -h                 display this help and exit"),
 N_("  -V                 print version information and exit"),
 #endif /* ! HAVE_GETOPT_LONG */
 "",
-"~",
-N_("Exit status is 1 on error (0 means no error)."),
 NULL
 	};
 
 #if HAVE_ASSERT_H
-	assert (prog_name != NULL && configuration_file != NULL);
+	assert (configuration_file != NULL);
 #endif
 
-	fprintf (stderr, _("Usage: %s [OPTION]... -l|-S\n"), prog_name);
+	fprintf (stderr, _("Usage: %s [OPTION]... -l|-S\n"),
+			program_invocation_name);
 	fprintf (stderr, _("   OR  %s [OPTION]... -s|-r HOSTNAME[:PORT]...\n"),
-			prog_name);
+			program_invocation_name);
 	fprintf (stderr, _("   OR  %s [OPTION]... CERTFILE\n"),
-			prog_name);
+			program_invocation_name);
 
 	for (i = 0; msg[i] != NULL; i++) {
-		if (msg[i][0] == '~') {
-			fputs (	_("The default configuration file is "),
-				stderr);
-			fputs (configuration_file, stderr);
-		}
-		else {
-			fputs ((msg[i][0] == '\0')? msg[i]: _(msg[i]), stderr);
+		if (msg[i][0] != '\0') {
+			fputs (_(msg[i]), stderr);
 		}
 		fputc ('\n', stderr);
 	}
 
+	fputs (	_("The default configuration file is "), stderr);
+	fputs (configuration_file, stderr);
+	fputc ('\n', stderr);
+	fprintf (stderr,
+		 _("Exit status is %d on error (%d means no error).\n"),
+		 EXIT_FAILURE, EXIT_SUCCESS);
 	fputc ('\n', stderr);
 	fputs (_("Report bugs to "), stderr);
 	fputs (PACKAGE_BUGREPORT, stderr);
@@ -233,6 +234,7 @@ certificate_to_database (	const char *filename,
 	size_t l;
 	gnutls_x509_crt_t cert_obj;
 
+
 #if HAVE_ASSERT_H
 	assert (hostname != NULL && port != NULL);
 #endif
@@ -244,11 +246,13 @@ certificate_to_database (	const char *filename,
 		return -1;
 	}
 
-	cert = client_name = NULL;
+	cert = NULL;
 	/* Retrieve the certificate */
 	if (filename != NULL) {
 		cert = read_file (filename, &l);
 		if (cert == NULL) {
+			fprintf (	stderr, _("%s: read error: %s\n"),
+					filename, strerror (errno));
 			return -1;
 		}
 		cert_obj = load_cert_from_mem (cert, l, filename);
@@ -269,7 +273,7 @@ certificate_to_database (	const char *filename,
 		}
 
 		/* Check that the provided agent name matches the cert */
-		if (force == 0 && hostname != NULL) {
+		if (force == 0) {
 			h[0] = hostname;
 			h[1] = NULL;
 			if (my_gnutls_x509_crt_check_hostname (cert_obj, CERT,
@@ -284,19 +288,19 @@ certificate_to_database (	const char *filename,
 				return -1;
 			}
 		}
+		free (client_name);
 		gnutls_x509_crt_deinit (cert_obj);
 	}
 
 	/* Update the database */
-	ret = sql_host_replace ((hostname != NULL) ? hostname: client_name,
+	ret = sql_host_replace (hostname,
 				port,
 				ssl,
 				(filename != NULL) ? cert : "",
 				descr,
 				sql_host_replace_error, NULL);
-	if (filename != NULL) {
+	if (cert != NULL) {
 		free (cert);
-		free (client_name);
 	}
 	return (ret == 0) ? 0: -1;
 }
@@ -315,21 +319,17 @@ save_csr (const char *filecsr)
 	char *s;
 	const char *base;
 
+
 #if HAVE_ASSERT_H
 	assert (filecsr != NULL);
 #endif
 
 	base = base_name (filecsr);
 
-	s = (char *) malloc (	  schedwi_strlen (client_savecsr_dir)
-				+ schedwi_strlen (DIR_SEP)
-				+ schedwi_strlen (base)
+	s = (char *) xmalloc (	  strlen (client_savecsr_dir)
+				+ strlen (DIR_SEP)
+				+ strlen (base)
 				+ 1);
-	if (s == NULL) {
-		fputs (_("Memory allocation error\n"), stderr);
-		return NULL;
-	}
-
 	strcpy (s, client_savecsr_dir);
 	strcat (s, DIR_SEP);
 	strcat (s, base);
@@ -354,7 +354,6 @@ save_csr (const char *filecsr)
  *          set and must be freed by free()
  *    2 --> A file with the `ext2' extension has been found. `outfilename' is
  *          set and must be freed by free()
- *   -1 --> Memory allocation error
  */
 static int
 find_file (	const char *basedir, const char *name, const char *port,
@@ -370,20 +369,16 @@ find_file (	const char *basedir, const char *name, const char *port,
 		&& outfilename != NULL);
 #endif
 
-	l_base =  schedwi_strlen (basedir)
-		+ schedwi_strlen (DIR_SEP)
-		+ schedwi_strlen (port)
+	l_base =  strlen (basedir)
+		+ strlen (DIR_SEP)
+		+ strlen (port)
 		+ 1 /* Separator `_' */
-		+ schedwi_strlen (name);
+		+ strlen (name);
 	l =	  l_base
-		+ ((ext1 != NULL) ? schedwi_strlen (ext1) : 0)
-		+ ((ext2 != NULL) ? schedwi_strlen (ext2) : 0)
+		+ ((ext1 != NULL) ? strlen (ext1) : 0)
+		+ ((ext2 != NULL) ? strlen (ext2) : 0)
 		+ 1;
-	s = (char *) malloc (l);
-	if (s == NULL) {
-		return -1;
-	}
-
+	s = (char *) xmalloc (l);
 	strcpy (s, basedir);
 	strcat (s, DIR_SEP);
 	strcat (s, port);
@@ -425,7 +420,6 @@ find_file (	const char *basedir, const char *name, const char *port,
  *    0 --> No such file
  *    1 --> A CSR file has been found (path in `outfilename' - use free())
  *    2 --> A file (no SSL) has been found (path in `outfilename' - use free())
- *   -1 --> Memory allocation error
  */
 static int
 find_csr (const char *name, const char *port, char **outfilename)
@@ -433,7 +427,6 @@ find_csr (const char *name, const char *port, char **outfilename)
 #if HAVE_ASSERT_H
 	assert (name != NULL && outfilename != NULL);
 #endif
-
 	return find_file (	client_csr_dir, name, port,
 				CSR_EXTENSION, NOSSL_EXTENSION,
 				outfilename);
@@ -457,18 +450,13 @@ sign_csr (const char *agent_name)
 	row_item_t *host_details;
 	int ret, typecsr;
 
+
 	if (parse_hostname (agent_name, &name, &port) != 0) {
 		return -1;
 	}
 
 	/* Get the file name of the pending request */
 	typecsr = find_csr (name, port, &filecsr);
-	if (typecsr < 0) {
-		free (name);
-		free (port);
-		fputs (_("Memory allocation error\n"), stderr);
-		return -1;
-	}
 	if (typecsr == 0) {
 		free (name);
 		free (port);
@@ -510,20 +498,13 @@ sign_csr (const char *agent_name)
 	}
 
 	/* Compose the certificate file name */
-	filecrt = (char *) malloc (	  schedwi_strlen (client_cert_dir)
-					+ schedwi_strlen (DIR_SEP)
-					+ schedwi_strlen (port)
+	filecrt = (char *) xmalloc (	  strlen (client_cert_dir)
+					+ strlen (DIR_SEP)
+					+ strlen (port)
 					+ 1 /* Separator `_' */
-					+ schedwi_strlen (name)
-					+ schedwi_strlen (CRT_EXTENSION)
-					+ schedwi_strlen (NOSSL_EXTENSION));
-	if (filecrt == NULL) {
-		free (filecsr);
-		free (name);
-		free (port);
-		fputs (_("Memory allocation error\n"), stderr);
-		return -1;
-	}
+					+ strlen (name)
+					+ strlen (CRT_EXTENSION)
+					+ strlen (NOSSL_EXTENSION));
 	strcpy (filecrt, client_cert_dir);
 	strcat (filecrt, DIR_SEP);
 	strcat (filecrt, port);
@@ -652,23 +633,16 @@ _("%s is still defined in the database. You can use the -f option\nto bypass but
 	}
 
 	found = 0;
-	s =  (char *) malloc (	  schedwi_strlen (client_cert_dir)
-				+ schedwi_strlen (client_csr_dir)
-				+ schedwi_strlen (client_savecsr_dir)
-				+ schedwi_strlen (DIR_SEP)
-				+ schedwi_strlen (port)
+	s =  (char *) xmalloc (	  strlen (client_cert_dir)
+				+ strlen (client_csr_dir)
+				+ strlen (client_savecsr_dir)
+				+ strlen (DIR_SEP)
+				+ strlen (port)
 				+ 1  /* Separator `_' */
-				+ schedwi_strlen (name)
-				+ schedwi_strlen (CSR_EXTENSION)
-				+ schedwi_strlen (NOSSL_EXTENSION)
-				+ schedwi_strlen (CRT_EXTENSION));
-	if (s == NULL) {
-		free (name);
-		free (port);
-		fputs (_("Memory allocation error\n"), stderr);
-		return -1;
-	}
-
+				+ strlen (name)
+				+ strlen (CSR_EXTENSION)
+				+ strlen (NOSSL_EXTENSION)
+				+ strlen (CRT_EXTENSION));
 	/* Remove from SSLAgentRequestDir */
 	strcpy (s, client_csr_dir);
 	strcat (s, DIR_SEP);
@@ -783,7 +757,7 @@ _("%s is still defined in the database. You can use the -f option\nto bypass but
 	free (port);
 
 	if (found == 0) {
-		fprintf (stderr, _("Nothing find for %s\n"), agent_name);
+		fprintf (stderr, _("Nothing found for %s\n"), agent_name);
 		return 1;
 	}
 	return 0;
@@ -799,16 +773,12 @@ sign_ssl (const char *file, int idx)
 	char *s, *u;
 	int ret;
 
+
 #if HAVE_ASSERT_H
 	assert (file != NULL);
 #endif
 
-	s = (char *) malloc (idx + 1);
-	if (s == NULL) {
-		fputs (_("Memory allocation error\n"), stderr);
-		return -1;
-	}
-
+	s = (char *) xmalloc (idx + 1);
 	u = strchr (file, '_');
 	if (u == NULL) {
 		strncpy (s, file, idx);
@@ -854,6 +824,7 @@ print_ssl (const char *file, int idx)
 {
 	char *s;
 
+
 #if HAVE_ASSERT_H
 	assert (file != NULL);
 #endif
@@ -865,9 +836,7 @@ print_ssl (const char *file, int idx)
 	else {
 		fwrite (s + 1, 1, idx - (s - file + 1), stdout);
 		/* Only print the port if it's not the default one */
-		if (schedwi_strncmp (	file, SCHEDWI_DEFAULT_AGTPORT,
-					s - file) != 0)
-		{
+		if (strncmp (file, SCHEDWI_DEFAULT_AGTPORT, s - file) != 0) {
 			fwrite (":", 1, 1, stdout);
 			fwrite (file, 1, s - file, stdout);
 		}
@@ -876,11 +845,13 @@ print_ssl (const char *file, int idx)
 	return 0;
 }
 
+
 static int
 print_nossl (const char *file, int idx)
 {
 	char *s;
 
+
 #if HAVE_ASSERT_H
 	assert (file != NULL);
 #endif
@@ -892,9 +863,7 @@ print_nossl (const char *file, int idx)
 	else {
 		fwrite (s + 1, 1, idx - (s - file + 1), stdout);
 		/* Only print the port if it's not the default one */
-		if (schedwi_strncmp (	file, SCHEDWI_DEFAULT_AGTPORT,
-					s - file) != 0)
-		{
+		if (strncmp (file, SCHEDWI_DEFAULT_AGTPORT, s - file) != 0) {
 			fwrite (":", 1, 1, stdout);
 			fwrite (file, 1, s - file, stdout);
 		}
@@ -903,6 +872,7 @@ print_nossl (const char *file, int idx)
 	return 0;
 }
 
+
 static int
 print_end (int nb)
 {
@@ -942,6 +912,7 @@ csr_list (	int (*callback_ssl)(const char *, int),
 	size_t ext_ssl_length, ext_nossl_length, name_length;
 	int idx, nb;
 
+
 	d = opendir (client_csr_dir);
 	if (d == NULL) {
 		fprintf (stderr,
@@ -950,12 +921,12 @@ csr_list (	int (*callback_ssl)(const char *, int),
 		return -1;
 	}
 
-	ext_ssl_length   = schedwi_strlen (CSR_EXTENSION);
-	ext_nossl_length = schedwi_strlen (NOSSL_EXTENSION);
+	ext_ssl_length   = strlen (CSR_EXTENSION);
+	ext_nossl_length = strlen (NOSSL_EXTENSION);
 	nb = 0;
 
 	while ((f = readdir (d)) != NULL) {
-		name_length = schedwi_strlen (f->d_name);
+		name_length = strlen (f->d_name);
 		idx = name_length - ext_ssl_length;
 		if (idx > 0 && strcmp (f->d_name + idx, CSR_EXTENSION) == 0) {
 			if (	   callback_ssl != NULL
@@ -1000,11 +971,9 @@ main (int argc, char **argv)
 {
 	const char *server_key, *server_crt;
 	const char *agent_host, *certificate_file;
-	const char *prog_name;
 	int ret, i;
 	char *err_msg, *port, *name;
 	char quick_random, list, sign, sign_all, clean, load_cert;
-
 #if HAVE_GETOPT_LONG
 	int option_index;
 	struct option long_options[] =
@@ -1034,14 +1003,11 @@ main (int argc, char **argv)
 	textdomain (PACKAGE);
 #endif
 
-
 	/* Set default values for options */
 	configuration_file = SCHEDWI_DEFAULT_CONFFILE_SRV;
 	agent_host = descr = NULL;
 	force = list = sign = sign_all = clean = quiet = 0;
 
-	prog_name = base_name (argv[0]);
-
 	/* Parse options */
 	while (1) {
 #if HAVE_GETOPT_LONG
@@ -1051,18 +1017,17 @@ main (int argc, char **argv)
 #else
 		ret = getopt (argc, argv, "hVc:a:d:flsSrq");
 #endif
-
 		if (ret == -1) {
 			break;
 		}
 
 		switch (ret) {
 			case 'h':
-				help (prog_name);
-				return 0;
+				help ();
+				return EXIT_SUCCESS;
 			case 'V':
-				version (prog_name);
-				return 0;
+				version ();
+				return EXIT_SUCCESS;
 			case 'c':
 				configuration_file = optarg;
 				break;
@@ -1091,8 +1056,8 @@ main (int argc, char **argv)
 				quiet = 1;
 				break;
 			default:
-				help (prog_name);
-				return 1;
+				help ();
+				return EXIT_FAILURE;
 		}
 	}
 
@@ -1105,8 +1070,8 @@ main (int argc, char **argv)
 		else {
 			fputs (_("Certificate file name required\n"), stderr);
 		}
-		help (prog_name);
-		return 1;
+		help ();
+		return EXIT_FAILURE;
 	}
 
 	/* Too many parameters */
@@ -1114,8 +1079,8 @@ main (int argc, char **argv)
 		&& sign_all == 0 && list == 0)
 	{
 		fputs (_("Too many parameters\n"), stderr);
-		help (prog_name);
-		return 1;
+		help ();
+		return EXIT_FAILURE;
 	}
 
 
@@ -1123,34 +1088,27 @@ main (int argc, char **argv)
 	 * Initialize the module engine
 	 */
 	if (module_init () != 0) {
-		return 1;
+		return EXIT_FAILURE;
 	}
 
 	/*
 	 * Read the configuration file
 	 */
 	ret = conf_init_srv (configuration_file);
-	switch (ret) {
-		case -1:
-			fputs (_("Memory allocation error\n"), stderr);
-			break;
-
-		case -2:
-			perror (configuration_file);
-			break;
+	if (ret == -2) {
+		error (EXIT_FAILURE, errno, "%s", configuration_file);
 	}
 	if (ret != 0) {
 		module_exit ();
-		return 1;
+		return EXIT_FAILURE;
 	}
-
+	
 	ret =  conf_get_param_string ("SSLCACertificateFile", &ca_crt);
 	ret += conf_get_param_string ("SSLCACertificateKeyFile", &ca_key);
 	ret += conf_get_param_string ("SSLCertificateFile", &server_crt);
 	ret += conf_get_param_string ("SSLCACRLFile", &ca_crl);
 	ret += conf_get_param_string ("SSLCertificateKeyFile", &server_key);
 	ret += conf_get_param_bool ("SSLQuickRandom", &quick_random);
-
 	ret += conf_get_param_string (	"SSLAgentCertificateDir",
 					&client_cert_dir);
 	ret += conf_get_param_string (	"SSLAgentRequestDir",
@@ -1167,7 +1125,7 @@ main (int argc, char **argv)
 	if (net_init_gnutls (quick_random) != 0) {
 		conf_destroy_srv ();
 		module_exit ();
-		return 1;
+		return EXIT_FAILURE;
 	}
 
 
@@ -1180,7 +1138,7 @@ main (int argc, char **argv)
 		net_destroy ();
 		conf_destroy_srv ();
 		module_exit ();
-		return 1;
+		return EXIT_FAILURE;
 	}
 
 	/*
@@ -1197,10 +1155,10 @@ main (int argc, char **argv)
 		else {
 			fputs (_("Failed to connect to database\n"), stderr);
 		}
+		net_destroy ();
 		conf_destroy_srv ();
 		module_exit ();
-		net_destroy ();
-		return 1;
+		return EXIT_FAILURE;
 	}
 
 	load_cert = 1;
@@ -1211,10 +1169,10 @@ main (int argc, char **argv)
 			ret = revoke_crt (argv[i]);
 			if (ret < 0) {
 				end_sql ();
+				net_destroy ();
 				conf_destroy_srv ();
 				module_exit ();
-				net_destroy ();
-				return 1;
+				return EXIT_FAILURE;
 			}
 			if (ret == 0 && quiet == 0) {
 				printf (
@@ -1231,10 +1189,10 @@ main (int argc, char **argv)
 				(quiet == 0) ? print_end : NULL) != 0)
 		{
 			end_sql ();
+			net_destroy ();
 			conf_destroy_srv ();
 			module_exit ();
-			net_destroy ();
-			return 1;
+			return EXIT_FAILURE;
 		}
 		load_cert = 0;
 	}
@@ -1245,10 +1203,10 @@ main (int argc, char **argv)
 			ret = sign_csr (argv[i]);
 			if (ret < 0) {
 				end_sql ();
+				net_destroy ();
 				conf_destroy_srv ();
 				module_exit ();
-				net_destroy ();
-				return 1;
+				return EXIT_FAILURE;
 			}
 			if (ret == 0 && quiet == 0) {
 				printf (
@@ -1265,10 +1223,10 @@ main (int argc, char **argv)
 				(quiet == 0) ? sign_end : NULL) != 0)
 		{
 			end_sql ();
+			net_destroy ();
 			conf_destroy_srv ();
 			module_exit ();
-			net_destroy ();
-			return 1;
+			return EXIT_FAILURE;
 		}
 		load_cert = 0;
 	}
@@ -1279,10 +1237,10 @@ main (int argc, char **argv)
 		certificate_file = argv[optind];
 		if (parse_hostname (agent_host, &name, &port) != 0) {
 			end_sql ();
+			net_destroy ();
 			conf_destroy_srv ();
 			module_exit ();
-			net_destroy ();
-			return 1;
+			return EXIT_FAILURE;
 		}
 		if (certificate_to_database (	certificate_file, name, port,
 						1) != 0)
@@ -1290,20 +1248,20 @@ main (int argc, char **argv)
 			free (name);
 			free (port);
 			end_sql ();
+			net_destroy ();
 			conf_destroy_srv ();
 			module_exit ();
-			net_destroy ();
-			return 1;
+			return EXIT_FAILURE;
 		}
 		free (name);
 		free (port);
 	}
 
 	end_sql ();
+	net_destroy ();
 	conf_destroy_srv ();
 	module_exit ();
-	net_destroy ();
-	return 0;
+	return EXIT_SUCCESS;
 }
 
 /*------------------------======= End Of File =======------------------------*/
