@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2013 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -49,16 +49,25 @@
 #include <locale.h>
 #endif
 
+#if HAVE_ERRNO_H
+#include <errno.h>
+#endif
+#ifndef errno
+extern int errno;
+#endif
+
 #if HAVE_ASSERT_H
 #include <assert.h>
 #endif
 
+#include <error.h>
+
 #include <sql_common.h>
 #include <utils.h>
 #include <conf.h>
 #include <conf_srv.h>
 #include <module.h>
-#include <lib_functions.h>
+#include <xmem.h>
 #include <schedwi_time.h>
 #include <sql_status.h>
 #include <sql_db_checks.h>
@@ -86,7 +95,7 @@ static int x, y;
  * Print a help message to stderr
  */
 void
-help (const char * prog_name)
+help ()
 {
 	int i;
 	char * msg[] = {
@@ -111,30 +120,30 @@ N_("  -v                 verbose database checks"),
 N_("  -f                 try to repair the database"),
 #endif /* ! HAVE_GETOPT_LONG */
 "",
-"~",
-N_("Exit status is 1 on error and 2 in case of database inconsistency"),
-N_("(0 means no error)."),
 NULL
 	};
 
 #if HAVE_ASSERT_H
-	assert (prog_name != NULL && configuration_file != NULL);
+	assert (configuration_file != NULL);
 #endif
 
-	fprintf (stderr, _("Usage: %s [OPTION]...\n"), prog_name);
+	fprintf (stderr, _("Usage: %s [OPTION]...\n"),
+			program_invocation_name);
 
 	for (i = 0; msg[i] != NULL; i++) {
-		if (msg[i][0] == '~') {
-			fputs (	_("The default configuration file is "),
-				stderr);
-			fputs (configuration_file, stderr);
-		}
-		else {
-			fputs ((msg[i][0] == '\0')? msg[i]: _(msg[i]), stderr);
+		if (msg[i][0] != '\0') {
+			fputs (_(msg[i]), stderr);
 		}
 		fputc ('\n', stderr);
 	}
 
+	fputs (	_("The default configuration file is "), stderr);
+	fputs (configuration_file, stderr);
+	fputc ('\n', stderr);
+	fprintf (stderr,
+ _("Exit status is %d on error and 2 in case of database inconsistency\n"),
+ 		EXIT_FAILURE);
+	fprintf (stderr, _("(%d means no error).\n"), EXIT_SUCCESS);
 	fputc ('\n', stderr);
 	fputs (_("Report bugs to "), stderr);
 	fputs (PACKAGE_BUGREPORT, stderr);
@@ -365,7 +374,6 @@ static char *job_tables[][3] = {
   { "job_control_group", "control_group",	N_("Linux Control Group") },
   { "job_loadenv",	"loadenv",	N_("load user environment variables") },
   { "job_detach",	"detach",	N_("start job in detach mode") },
-  { "job_command",	"command",	N_("manual job") },
   { "job_manual_command", "manual_command", N_("manual job alert command") },
   { "job_success_return_code",	"success_ret",	N_("return codes") },
   { "job_command",	"command",		N_("remote commands") },
@@ -633,11 +641,7 @@ comment_lines (const char *src)
 	char *d, *found;
 	unsigned int len;
 
-	dst = (char *) malloc (schedwi_strlen (src) * 2 + 2);
-	if (dst == NULL) {
-		return NULL;
-	}
-
+	dst = (char *) xmalloc (strlen (src) * 2 + 2);
 	dst[0] = '#';
 
 	d = dst + 1;
@@ -1685,9 +1689,9 @@ check_workload_retention_cb (	void *data, const char *table_name,
  * Look for too old workloads
  */
 static int
-check_workload_retention (long int max_retention)
+check_workload_retention (time_t now, long int max_retention)
 {
-	schedwi_date now, old;
+	time_t old;
 	int ret;
 
 	if (verbose_level == VERBOSE) {
@@ -1696,11 +1700,9 @@ check_workload_retention (long int max_retention)
 			stdout);
 	}
 
-	schedwi_date_now (&now);
-	schedwi_date_add_days (now, &old, (int)(-(max_retention + 1)));
-
+	old = now - ((max_retention + 1) * 24 * 60 * 60);
 	ret = 0;
-	switch (sql_status_get_old (schedwi_date_to_int (old),
+	switch (sql_status_get_old (schedwi_time_to_date_int (old),
 				check_workload_retention_cb, NULL,
 				sql_error_logger, NULL))
 	{
@@ -1725,16 +1727,11 @@ check_workload_retention (long int max_retention)
 int
 main (int argc, char **argv)
 {
-	const char *prog_name;
 	int ret, global_ret;
 	dbi_conn sql_handler;
 	char *err_msg;
-	time_t t;
-	struct tm stm;
-	size_t r;
-	unsigned int len;
+	time_t now;
 	long int retention_completed, retention_failed;
-
 #if HAVE_GETOPT_LONG
 	int option_index;
 	struct option long_options[] =
@@ -1749,6 +1746,7 @@ main (int argc, char **argv)
 	};
 #endif
 
+
 #if HAVE_SETLOCALE
 	setlocale (LC_ALL, "");
 #endif
@@ -1759,12 +1757,9 @@ main (int argc, char **argv)
 	textdomain (PACKAGE);
 #endif
 
-
 	/* Set default values for options */
 	configuration_file = SCHEDWI_DEFAULT_CONFFILE_SRV;
 
-	prog_name = base_name (argv[0]);
-
 	/* Parse options */
 	while (1) {
 #if HAVE_GETOPT_LONG
@@ -1774,18 +1769,17 @@ main (int argc, char **argv)
 #else
 		ret = getopt (argc, argv, "hVc:qvf");
 #endif
-
 		if (ret == -1) {
 			break;
 		}
 
 		switch (ret) {
 			case 'h':
-				help (prog_name);
-				return 0;
+				help ();
+				return EXIT_SUCCESS;
 			case 'V':
-				version (prog_name);
-				return 0;
+				version ();
+				return EXIT_SUCCESS;
 			case 'c':
 				configuration_file = optarg;
 				break;
@@ -1799,8 +1793,8 @@ main (int argc, char **argv)
 				autofix = 1;
 				break;
 			default:
-				help (prog_name);
-				return 1;
+				help ();
+				return EXIT_FAILURE;
 		}
 	}
 
@@ -1810,26 +1804,18 @@ main (int argc, char **argv)
 	 * jobset.  The same applies for orphan calendars (attached to a
 	 * calendar forlder with the same name)
 	 */
-	len = schedwi_strlen (LOST_FOUND_STRFTIME) + 100;
-	lost_found_name = (char *) malloc (len + 1);
+	now = time (NULL);
+	lost_found_name = schedwi_time_strftime (LOST_FOUND_STRFTIME, &now);
 	if (lost_found_name == NULL) {
-		fputs (_("Memory allocation error\n"), stderr);
-		return 1;
-	}
-	t = time (NULL);
-	localtime_r (&t, &stm);
-	r = strftime (lost_found_name, len, LOST_FOUND_STRFTIME, &stm);
-	if (r == 0 || r == len) {
-		free (lost_found_name);
 		fputs (_("Internal error: buffer too small\n"), stderr);
-		return 1;
+		return EXIT_FAILURE;
 	}
 
 	/*
 	 * Compute the coordinates (x and y) of the lost+found jobset on the
 	 * canvas of the root jobset
 	 */
-	srand ((unsigned int) t);
+	srand ((unsigned int) now);
 	x = 50 + (int) (150.0 * (rand() / (RAND_MAX + 1.0)));
 	y = 50 + (int) (150.0 * (rand() / (RAND_MAX + 1.0)));
 
@@ -1838,29 +1824,21 @@ main (int argc, char **argv)
 	 */
 	if (module_init () != 0) {
 		free (lost_found_name);
-		return 1;
+		return EXIT_FAILURE;
 	}
 
 	/*
 	 * Read the configuration file
 	 */
 	ret = conf_init_srv (configuration_file);
-	switch (ret) {
-		case -1:
-			fputs (_("Memory allocation error\n"), stderr);
-			break;
-
-		case -2:
-			perror (configuration_file);
-			break;
+	if (ret == -2) {
+		error (EXIT_FAILURE, errno, "%s", configuration_file);
 	}
 	if (ret != 0) {
-		module_exit ();
 		free (lost_found_name);
-		return 1;
+		return EXIT_FAILURE;
 	}
 
-
 	/*
 	 * Retrieve the retention duration from the configuration file
 	 */
@@ -1891,14 +1869,14 @@ main (int argc, char **argv)
 		conf_destroy_srv ();
 		module_exit ();
 		free (lost_found_name);
-		return 1;
+		return EXIT_FAILURE;
 	}
 
 
 	/*
 	 * Checks
 	 */
-	global_ret = 0;
+	global_ret = EXIT_SUCCESS;
 
 	ret = check_job_main ();
 	if (ret < 0) {
@@ -1906,7 +1884,7 @@ main (int argc, char **argv)
 		conf_destroy_srv ();
 		module_exit ();
 		free (lost_found_name);
-		return 1;
+		return EXIT_FAILURE;
 	}
 	if (ret != 0) {
 		global_ret = 2;
@@ -1918,7 +1896,7 @@ main (int argc, char **argv)
 		conf_destroy_srv ();
 		module_exit ();
 		free (lost_found_name);
-		return 1;
+		return EXIT_FAILURE;
 	}
 	if (ret != 0) {
 		global_ret = 2;
@@ -1931,7 +1909,7 @@ main (int argc, char **argv)
 		conf_destroy_srv ();
 		module_exit ();
 		free (lost_found_name);
-		return 1;
+		return EXIT_FAILURE;
 	}
 	if (ret != 0) {
 		global_ret = 2;
@@ -1944,7 +1922,7 @@ main (int argc, char **argv)
 		conf_destroy_srv ();
 		module_exit ();
 		free (lost_found_name);
-		return 1;
+		return EXIT_FAILURE;
 	}
 	if (ret != 0) {
 		global_ret = 2;
@@ -1956,7 +1934,7 @@ main (int argc, char **argv)
 		conf_destroy_srv ();
 		module_exit ();
 		free (lost_found_name);
-		return 1;
+		return EXIT_FAILURE;
 	}
 	if (ret != 0) {
 		global_ret = 2;
@@ -1968,7 +1946,7 @@ main (int argc, char **argv)
 		conf_destroy_srv ();
 		module_exit ();
 		free (lost_found_name);
-		return 1;
+		return EXIT_FAILURE;
 	}
 	if (ret != 0) {
 		global_ret = 2;
@@ -1980,7 +1958,7 @@ main (int argc, char **argv)
 		conf_destroy_srv ();
 		module_exit ();
 		free (lost_found_name);
-		return 1;
+		return EXIT_FAILURE;
 	}
 	if (ret != 0) {
 		global_ret = 2;
@@ -1992,7 +1970,7 @@ main (int argc, char **argv)
 		conf_destroy_srv ();
 		module_exit ();
 		free (lost_found_name);
-		return 1;
+		return EXIT_FAILURE;
 	}
 	if (ret != 0) {
 		global_ret = 2;
@@ -2004,7 +1982,7 @@ main (int argc, char **argv)
 		conf_destroy_srv ();
 		module_exit ();
 		free (lost_found_name);
-		return 1;
+		return EXIT_FAILURE;
 	}
 	if (ret != 0) {
 		global_ret = 2;
@@ -2016,7 +1994,7 @@ main (int argc, char **argv)
 		conf_destroy_srv ();
 		module_exit ();
 		free (lost_found_name);
-		return 1;
+		return EXIT_FAILURE;
 	}
 	if (ret != 0) {
 		global_ret = 2;
@@ -2028,7 +2006,7 @@ main (int argc, char **argv)
 		conf_destroy_srv ();
 		module_exit ();
 		free (lost_found_name);
-		return 1;
+		return EXIT_FAILURE;
 	}
 	if (ret != 0) {
 		global_ret = 2;
@@ -2040,13 +2018,13 @@ main (int argc, char **argv)
 		conf_destroy_srv ();
 		module_exit ();
 		free (lost_found_name);
-		return 1;
+		return EXIT_FAILURE;
 	}
 	if (ret != 0) {
 		global_ret = 2;
 	}
 
-	ret = check_workload_retention (
+	ret = check_workload_retention (now,
 		(retention_completed > retention_failed)
 			? retention_completed :retention_failed);
 	if (ret < 0) {
@@ -2054,7 +2032,7 @@ main (int argc, char **argv)
 		conf_destroy_srv ();
 		module_exit ();
 		free (lost_found_name);
-		return 1;
+		return EXIT_FAILURE;
 	}
 	if (ret != 0) {
 		global_ret = 2;
