@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2013 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -54,10 +54,19 @@
 #include <locale.h>
 #endif
 
+#if HAVE_ERRNO_H
+#include <errno.h>
+#endif
+#ifndef errno
+extern int errno;
+#endif
+
 #if HAVE_ASSERT_H
 #include <assert.h>
 #endif
 
+#include <error.h>
+
 #include <sql_common.h>
 #include <utils.h>
 #include <conf.h>
@@ -66,7 +75,6 @@
 #include <net_utils.h>
 #include <net_utils_ssl.h>
 #include <ping.h>
-#include <lib_functions.h>
 
 static const char *configuration_file = NULL;
 
@@ -75,7 +83,7 @@ static const char *configuration_file = NULL;
  * Print a help message to stderr
  */
 void
-help (const char * prog_name)
+help ()
 {
 	int i;
 	char * msg[] = {
@@ -94,29 +102,29 @@ N_("  -h                 display this help and exit"),
 N_("  -V                 print version information and exit"),
 #endif /* ! HAVE_GETOPT_LONG */
 "",
-"~",
-N_("Exit status is 1 on error (0 means no error)."),
 NULL
 	};
 
 #if HAVE_ASSERT_H
-	assert (prog_name != NULL && configuration_file != NULL);
+	assert (configuration_file != NULL);
 #endif
 
-	fprintf (stderr, _("Usage: %s [OPTION]... HOST[:PORT]\n"), prog_name);
+	fprintf (stderr, _("Usage: %s [OPTION]... HOST[:PORT]\n"),
+			program_invocation_name);
 
 	for (i = 0; msg[i] != NULL; i++) {
-		if (msg[i][0] == '~') {
-			fputs (	_("The default configuration file is "),
-				stderr);
-			fputs (configuration_file, stderr);
-		}
-		else {
-			fputs ((msg[i][0] == '\0')? msg[i]: _(msg[i]), stderr);
+		if (msg[i][0] != '\0') {
+			fputs (_(msg[i]), stderr);
 		}
 		fputc ('\n', stderr);
 	}
 
+	fputs (	_("The default configuration file is "), stderr);
+	fputs (configuration_file, stderr);
+	fputc ('\n', stderr);
+	fprintf (stderr,
+		 _("Exit status is %d on error (%d means no error).\n"),
+		 EXIT_FAILURE, EXIT_SUCCESS);
 	fputc ('\n', stderr);
 	fputs (_("Report bugs to "), stderr);
 	fputs (PACKAGE_BUGREPORT, stderr);
@@ -133,13 +141,11 @@ int
 main (int argc, char **argv)
 {
 	const char *server_key, *server_crt, *ca_crt, *ca_crl;
-	const char *prog_name;
 	char quick_random;
 	char *agent_name;
 	int ret;
 	dbi_conn sql_handler;
 	char *err_msg;
-
 #if HAVE_GETOPT_LONG
 	int option_index;
 	struct option long_options[] =
@@ -151,6 +157,7 @@ main (int argc, char **argv)
 	};
 #endif
 
+
 #if HAVE_SETLOCALE
 	setlocale (LC_ALL, "");
 #endif
@@ -161,12 +168,9 @@ main (int argc, char **argv)
 	textdomain (PACKAGE);
 #endif
 
-
 	/* Set default values for options */
 	configuration_file = SCHEDWI_DEFAULT_CONFFILE_SRV;
 
-	prog_name = base_name (argv[0]);
-
 	/* Parse options */
 	while (1) {
 #if HAVE_GETOPT_LONG
@@ -183,32 +187,32 @@ main (int argc, char **argv)
 
 		switch (ret) {
 			case 'h':
-				help (prog_name);
-				return 0;
+				help ();
+				return EXIT_SUCCESS;
 			case 'V':
-				version (prog_name);
-				return 0;
+				version ();
+				return EXIT_SUCCESS;
 			case 'c':
 				configuration_file = optarg;
 				break;
 			default:
-				help (prog_name);
-				return 1;
+				help ();
+				return EXIT_FAILURE;
 		}
 	}
 
 	/* Agent host name missing */
 	if (optind >= argc) {
 		fputs (_("Agent host name required\n"), stderr);
-		help (prog_name);
-		return 1;
+		help ();
+		return EXIT_FAILURE;
 	}
 
 	/* Too many parameters */
 	if (optind + 1 != argc) {
 		fputs (_("Too many parameters\n"), stderr);
-		help (prog_name);
-		return 1;
+		help ();
+		return EXIT_FAILURE;
 	}
 
 	agent_name = argv[optind];
@@ -217,25 +221,19 @@ main (int argc, char **argv)
 	 * Initialize the module engine
 	 */
 	if (module_init () != 0) {
-		return 1;
+		return EXIT_FAILURE;
 	}
 
 	/*
 	 * Read the configuration file
 	 */
 	ret = conf_init_srv (configuration_file);
-	switch (ret) {
-		case -1:
-			fputs (_("Memory allocation error\n"), stderr);
-			break;
-
-		case -2:
-			perror (configuration_file);
-			break;
+	if (ret == -2) {
+		error (EXIT_FAILURE, errno, "%s", configuration_file);
 	}
 	if (ret != 0) {
 		module_exit ();
-		return 1;
+		return EXIT_FAILURE;
 	}
 
 	ret =  conf_get_param_string ("SSLCACertificateFile", &ca_crt);
@@ -253,7 +251,7 @@ main (int argc, char **argv)
 	if (net_init_gnutls (quick_random) != 0) {
 		conf_destroy_srv ();
 		module_exit ();
-		return 1;
+		return EXIT_FAILURE;
 	}
 
 	/*
@@ -265,7 +263,7 @@ main (int argc, char **argv)
 		net_destroy ();
 		conf_destroy_srv ();
 		module_exit ();
-		return 1;
+		return EXIT_FAILURE;
 	}
 
 	/*
@@ -283,23 +281,23 @@ main (int argc, char **argv)
 		else {
 			fputs (_("Failed to connect to database\n"), stderr);
 		}
+		net_destroy ();
 		conf_destroy_srv ();
 		module_exit ();
-		net_destroy ();
-		return 1;
+		return EXIT_FAILURE;
 	}
 
 	ret = ping_by_names (agent_name);
 	end_sql ();
+	net_destroy ();
 	conf_destroy_srv ();
 	module_exit ();
-	net_destroy ();
 	if (ret == 0) {
 		fputs (_("The agent is running.\n"), stdout);
-		return 0;
+		return EXIT_SUCCESS;
 	}
 
-	return 1;
+	return EXIT_FAILURE;
 }
 
 /*------------------------======= End Of File =======------------------------*/
