@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2011 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -52,7 +52,7 @@
 #include <unistd.h>
 #endif
 
-#if !_GNU_SOURCE
+#ifndef _GNU_SOURCE
 extern char **environ;
 #endif
 
@@ -83,21 +83,21 @@ extern int errno;
 #include <assert.h>
 #endif
 
+#include <error.h>
+
 #include <utils.h>
 #include <conf.h>
 #include <conf_srv.h>
 #include <module.h>
 #include <signal_utils.h>
 #include <lwc_log.h>
-#include <lib_functions.h>
-#include <net_parse_reg.h>
 #include <net_utils.h>
 #include <net_utils_ssl.h>
 #include <net_utils_sock.h>
 #include <net_parse_reg.h>
+#include <xmem.h>
 
 
-static const char *pid_file = NULL;
 static const char *configuration_file = NULL;
 static char **save_argv, **save_env;
 #if HAVE_CHDIR && HAVE_GETCWD
@@ -110,7 +110,7 @@ static char save_cwd[MAX_SIZE_CWD];
  * Print a help message to stderr
  */
 void
-help (const char * prog_name)
+help ()
 {
 	int i;
 	char * msg[] = {
@@ -142,29 +142,29 @@ N_("  -h                 display this help and exit"),
 N_("  -V                 print version information and exit"),
 #endif
 "",
-"~",
-N_("Exit status is 1 on error (0 means no error)."),
 NULL
 	};
 
 #if HAVE_ASSERT_H
-	assert (prog_name != NULL && configuration_file != NULL);
+	assert (configuration_file != NULL);
 #endif
 
-	fprintf (stderr, _("Usage: %s [OPTION]...\n"), prog_name);
+	fprintf (stderr, _("Usage: %s [OPTION]...\n"),
+		 program_invocation_name);
 
 	for (i = 0; msg[i] != NULL; i++) {
-		if (msg[i][0] == '~') {
-			fputs (	_("The default configuration file is "),
-				stderr);
-			fputs (configuration_file, stderr);
-		}
-		else {
-			fputs ((msg[i][0] == '\0')? msg[i]: _(msg[i]), stderr);
+		if (msg[i][0] != '\0') {
+			fputs (_(msg[i]), stderr);
 		}
 		fputc ('\n', stderr);
 	}
 
+	fputs (	_("The default configuration file is "), stderr);
+	fputs (configuration_file, stderr);
+	fputc ('\n', stderr);
+	fprintf (stderr,
+		 _("Exit status is %d on error (%d means no error).\n"),
+		 EXIT_FAILURE, EXIT_SUCCESS);
 	fputc ('\n', stderr);
 	fputs (_("Report bugs to "), stderr);
 	fputs (PACKAGE_BUGREPORT, stderr);
@@ -188,19 +188,19 @@ sighup_action (int sig)
 		return;
 	}
 
-	close_pid_file (pid_file);
+	lwc_closeLog ();
+	close_pid_file ();
+	net_destroy_ssl ();
 	conf_destroy_srv ();
 	module_exit ();
-	lwc_closeLog ();
-	sanitise (-1);
+	sanitise ();
 #if HAVE_CHDIR && HAVE_GETCWD
 	if (save_cwd[0] != '\0') {
 		chdir (save_cwd);
 	}
 #endif
 	execve (save_argv[0], save_argv, save_env);
-	perror ("execve");
-	exit (1);
+	error (EXIT_FAILURE, errno, "execve");
 }
 
 
@@ -213,17 +213,12 @@ sigterm_action (int sig)
 	int i;
 
 	lwc_writeLog (LOG_INFO, _("schedwireg exiting"));
-	lwc_closeLog ();
-	close_pid_file (pid_file);
-	net_destroy_ssl ();
-	conf_destroy_srv ();
-	module_exit ();
-	free (save_argv);
 	for (i = 0; save_env[i] != NULL; i++) {
 		free (save_env[i]);
 	}
 	free (save_env);
-	exit (0);
+	free (save_argv);
+	exit (EXIT_SUCCESS);
 }
 
 
@@ -242,15 +237,14 @@ wait_for_ca_cert (const char *ca_crt)
 #if HAVE_NANOSLEEP
 	struct timespec req;
 
+
 	req.tv_sec = 10;
 	req.tv_nsec = 0;
 #endif
-
-
 	count = 0;
 	while (1) {
 		if (access (ca_crt, F_OK) == 0) {
-			if (access (ca_crt, R_OK) == 0) { 
+			if (access (ca_crt, R_OK) == 0) {
 				return 0;
 			}
 			lwc_writeLog (LOG_ERR,
@@ -282,7 +276,7 @@ _("I'll recheck a little bit latter"));
 #elif HAVE_USLEEP
 		usleep (10 * 1000000);
 #endif
-	} while (1);
+	}
 }
 
 
@@ -303,13 +297,11 @@ main (int argc, char **argv)
 	const char *client_cert_dir, *client_csr_dir, *client_savecsr_dir;
 	const char *ca_crt;
 	struct sigaction sa;
-	const char *log_file, *date_format;
+	const char *pid_file, *log_file, *date_format;
 	const char *iface, *registrar_port, *address_family, *allow_from;
 	long int facility;
 	char test, foreground;
-	const char *prog_name;
 	char **client_names;
-
 #if HAVE_GETOPT_LONG
 	int option_index;
 	struct option long_options[] =
@@ -323,6 +315,7 @@ main (int argc, char **argv)
 	};
 #endif
 
+
 #if HAVE_SETLOCALE
 	setlocale (LC_ALL, "");
 #endif
@@ -333,12 +326,10 @@ main (int argc, char **argv)
 	textdomain (PACKAGE);
 #endif
 
-
 	/* Set default values for options */
 	test = foreground = 0;
 	configuration_file = SCHEDWI_DEFAULT_CONFFILE_SRV;
 
-	prog_name = base_name (argv[0]);
 
 	/* Parse options */
 	while (1) {
@@ -356,11 +347,11 @@ main (int argc, char **argv)
 
 		switch (ret) {
 			case 'h':
-				help (prog_name);
-				return 0;
+				help ();
+				return EXIT_SUCCESS;
 			case 'V':
-				version (prog_name);
-				return 0;
+				version ();
+				return EXIT_SUCCESS;
 			case 't':
 				test = 1;
 				break;
@@ -371,8 +362,8 @@ main (int argc, char **argv)
 				configuration_file = optarg;
 				break;
 			default:
-				help (prog_name);
-				return 1;
+				help ();
+				return EXIT_FAILURE;
 		}
 	}
 
@@ -384,86 +375,95 @@ main (int argc, char **argv)
 	 * Initialize the module engine
 	 */
 	if (module_init () != 0) {
-		return 1;
+		return EXIT_FAILURE;
 	}
+	atexit (module_exit);
 
 	/*
 	 * Read the configuration file
 	 */
 	ret = conf_init_srv (configuration_file);
-	switch (ret) {
-		case -1:
-			fputs (_("Memory allocation error\n"), stderr);
-			break;
-
-		case -2:
-			perror (configuration_file);
-			break;
+	if (ret == -2) {
+		error (EXIT_FAILURE, errno, "%s", configuration_file);
 	}
 	if (ret != 0) {
-		module_exit ();
-		return 1;
+		return EXIT_FAILURE;
 	}
+	atexit (conf_destroy_srv);
+
+	/*
+	 * Close opened files (but keep the standard fd 0, 1 and 2 because
+	 * some error messages may be printed on stderr)
+	 * This has to be done before the net_init_gnutls() function below
+	 * because the gnutls_global_init() library call will open a file
+	 * descriptor on /dev/urandom.
+	 */
+	close_opened_files ();
 
 	/*
 	 * Initialize the GnuTLS layer
 	 */
 	if (net_init_gnutls (1) != 0) {
-		conf_destroy_srv ();
-		module_exit ();
-		return 1;
+		return EXIT_FAILURE;
 	}
-
+	atexit (net_destroy_ssl);
 
 	/*
-	 * Create the directory that will hold the PID file
+	 * For a daemon that is going to run in background, create a PID file
+	 * and change owner.  This is for sysV daemons.
+	 * Systemd daemons are started in the foreground (systemd will set
+	 * the owner and manage the PID file - see the daemon man page for
+	 * systemd)
 	 */
-	ret =  conf_get_param_string ("USER", &user_id);
-	ret += conf_get_param_string ("GROUP", &group_id);
-	ret += conf_get_param_string ("PID_FILE_REGISTRAR", &pid_file);
+	if (foreground == 0) {
+
+		/*
+		 * Create the directory that will hold the PID file
+		 */
+		ret =  conf_get_param_string ("USER", &user_id);
+		ret += conf_get_param_string ("GROUP", &group_id);
+		ret += conf_get_param_string ("PID_FILE_REGISTRAR", &pid_file);
 #if HAVE_ASSERT_H
-	assert (ret == 0);
+		assert (ret == 0);
 #endif
 
-	mkpath (pid_file, user_id, group_id);
-
-	/*
-	 * Change the group id and the user id of the process
-	 */
-	ret = change_group (group_id);
-	if (ret != 0) {
-		if (ret == -2) {
-			fprintf (stderr,
-				_("Unknown group name: %s\n"),
-				group_id);
-		}
-		else {
-			fprintf (stderr,
+		/*
+		 * Create the directory that will hold the PID file
+		 */
+		mkpath (pid_file, user_id, group_id);
+	
+		/*
+		 * Change the group id and the user id of the process
+		 */
+		ret = change_group (group_id);
+		if (ret != 0) {
+			if (ret == -2) {
+				fprintf (stderr,
+					_("Unknown group name: %s\n"),
+					group_id);
+			}
+			else {
+				fprintf (stderr,
 				_("Failed to change the group ID to %s: %s\n"),
-				group_id, strerror (errno));
+					group_id, strerror (errno));
+			}
+			return EXIT_FAILURE;
 		}
-		net_destroy_ssl ();
-		conf_destroy_srv ();
-		module_exit ();
-		return 1;
-	}
-
-	ret = change_user (user_id);
-	if (ret != 0) {
-		if (ret == -2) {
-			fprintf (stderr,
-				_("Unknown user name: %s\n"),
-				user_id);
-		}
-		else {
-			fprintf (stderr,
+	
+		ret = change_user (user_id);
+		if (ret != 0) {
+			if (ret == -2) {
+				fprintf (stderr,
+					_("Unknown user name: %s\n"),
+					user_id);
+			}
+			else {
+				fprintf (stderr,
 				_("Failed to change the user ID to %s: %s\n"),
-				user_id, strerror (errno));
+					user_id, strerror (errno));
+			}
+			return EXIT_FAILURE;
 		}
-		net_destroy_ssl ();
-		conf_destroy_srv ();
-		module_exit ();
-		return 1;
 	}
 
 	/*
@@ -512,63 +512,27 @@ main (int argc, char **argv)
 	}
 
 	if (ret != 0) {
-		net_destroy_ssl ();
-		conf_destroy_srv ();
-		module_exit ();
-		return 1;
+		return EXIT_FAILURE;
 	}
 
-
 	/* It was only a test of the configuration file */
 	if (test == 1) {
 		fputs (_("Fine."), stdout);
 		fputc ('\n', stdout);
-		net_destroy_ssl ();
-		conf_destroy_srv ();
-		module_exit ();
-		return 0;
+		return EXIT_SUCCESS;
 	}
 
 	/* Copy argv and environ to use them to exec the process on SIGHUP */
-	save_argv = (char **) malloc (sizeof (char *) * (argc + 1));
-	if (save_argv == NULL) {
-		fputs (_("Memory allocation error\n"), stderr);
-		net_destroy_ssl ();
-		conf_destroy_srv ();
-		module_exit ();
-		return 1;
-	}
+	save_argv = (char **) xmalloc (sizeof (char *) * (argc + 1));
 	for (i = 0; i < argc; i++) {
 		save_argv[i] = argv[i];
 	}
 	save_argv[i] = NULL;
 
-
 	for (i = 0; environ[i] != NULL; i++);
-	save_env = (char **) malloc (sizeof (char *) * (i + 1));
-	if (save_env == NULL) {
-		fputs (_("Memory allocation error\n"), stderr);
-		free (save_argv);
-		net_destroy_ssl ();
-		conf_destroy_srv ();
-		module_exit ();
-		return 1;
-	}
+	save_env = (char **) xmalloc (sizeof (char *) * (i + 1));
 	for (i = 0; environ[i] != NULL; i++) {
-		save_env[i] = (char *) malloc (schedwi_strlen (environ[i])+ 1);
-		if (save_env[i] == NULL) {
-			fputs (_("Memory allocation error\n"), stderr);
-			while (--i >= 0) {
-				free (save_env[i]);
-			}
-			free (save_env);
-			free (save_argv);
-			net_destroy_ssl ();
-			conf_destroy_srv ();
-			module_exit ();
-			return 1;
-		}
-		strcpy (save_env[i], environ[i]);
+		save_env[i] = xstrdup (environ[i]);
 	}
 	save_env[i] = NULL;
 
@@ -582,81 +546,73 @@ main (int argc, char **argv)
 	/*
 	 * Go background
 	 */
+	if (foreground == 0 && go_daemon () != 0) {
+		error (EXIT_FAILURE, errno, "fork");
+	}
+
+
+	/*
+	 * For sysV daemons, open the log file and write the PID file.
+	 * For systemd service (foreground = 1), systemd will already have done
+	 * all that.
+	 */
 	if (foreground == 0) {
-		if (go_daemon () != 0) {
-			perror ("fork");
-			free (save_argv);
+
+		/*
+		 * Open the log file
+		 */
+		log_file = date_format = NULL;
+		facility = -1;
+		ret = conf_get_param_string ("LOG_FILE", &log_file);
+		ret += conf_get_param_syslog_facility ("SYSLOG", &facility);
+		ret += conf_get_param_string ("DATE_FORMAT", &date_format);
+#if HAVE_ASSERT_H
+		assert (ret == 0);
+#endif
+	
+		lwc_newLog (    PACKAGE_NAME,
+				(facility != -1) ? 1 : 0,
+				(facility != -1) ? (int)facility : 0,
+				log_file,
+				date_format);
+		atexit (lwc_closeLog);
+		lwc_writeLog (LOG_INFO, _("schedwireg starting"));
+	
+	
+		/*
+		 * Create the PID file and check that an other process is not
+		 * already running
+		 */
+		ret = write_pid_file (pid_file);
+		switch (ret) {
+			case -1:
+				lwc_writeLog (	LOG_CRIT,
+					_("Cannot create the PID file %s: %s"),
+						pid_file,
+						strerror (errno));
+				break;
+	
+			case 1:
+				lwc_writeLog (LOG_CRIT,
+				_("An other daemon is already running"));
+				break;
+		}
+		if (ret != 0) {
 			for (i = 0; save_env[i] != NULL; i++) {
 				free (save_env[i]);
 			}
 			free (save_env);
-			net_destroy_ssl ();
-			conf_destroy_srv ();
-			module_exit ();
-			return 1;
+			free (save_argv);
+			return EXIT_FAILURE;
 		}
-	}
-	else {
-		clean_process ();
-	}
-
-
-	/*
-	 * Open the log file
-	 */
-	log_file = date_format = NULL;
-	facility = -1;
-	ret = conf_get_param_string ("LOG_FILE", &log_file);
-	ret += conf_get_param_syslog_facility ("SYSLOG", &facility);
-	ret += conf_get_param_string ("DATE_FORMAT", &date_format);
-#if HAVE_ASSERT_H
-	assert (ret == 0);
-#endif
-
-	lwc_newLog (    PACKAGE_NAME,
-			(facility != -1) ? 1 : 0,
-			(facility != -1) ? (int)facility : 0,
-			log_file,
-			date_format);
-	lwc_writeLog (LOG_INFO, _("schedwireg starting"));
-
-
-	/*
-	 * Create the PID file and check that an other process is not already
-	 * running
-	 */
-	ret = write_pid_file (pid_file);
-	switch (ret) {
-		case -1:
-			lwc_writeLog (	LOG_CRIT,
-					_("Cannot create the PID file %s: %s"),
-					pid_file,
-					strerror (errno));
-			break;
-		
-		case 1:
-			lwc_writeLog (LOG_CRIT,
-				_("An other daemon is already running"));
-			break;
-	}
-	if (ret != 0) {
-		lwc_closeLog ();
-		free (save_argv);
-		for (i = 0; save_env[i] != NULL; i++) {
-			free (save_env[i]);
-		}
-		free (save_env);
-		net_destroy_ssl ();
-		conf_destroy_srv ();
-		module_exit ();
-		return 1;
+		atexit (close_pid_file);
 	}
 
 
 	/*
 	 * Signal handlers
 	 */
-	schedwi_memset (&sa, 0, sizeof (struct sigaction));
+	memset (&sa, 0, sizeof (struct sigaction));
 	sa.sa_handler = sigterm_action;
 	sigemptyset (&(sa.sa_mask));
 	sa.sa_flags = 0;
@@ -665,20 +621,15 @@ main (int argc, char **argv)
 			LOG_CRIT,
 			_("Cannot install signal handler for SIGTERM: %s"),
 			strerror (errno));
-		lwc_closeLog ();
-		close_pid_file (pid_file);
-		free (save_argv);
 		for (i = 0; save_env[i] != NULL; i++) {
 			free (save_env[i]);
 		}
 		free (save_env);
-		net_destroy_ssl ();
-		conf_destroy_srv ();
-		module_exit ();
-		return 1;
+		free (save_argv);
+		return EXIT_FAILURE;
 	}
 
-	schedwi_memset (&sa, 0, sizeof (struct sigaction));
+	memset (&sa, 0, sizeof (struct sigaction));
 	sa.sa_handler = sighup_action;
 	sigemptyset (&(sa.sa_mask));
 	sa.sa_flags = 0;
@@ -687,20 +638,15 @@ main (int argc, char **argv)
 			LOG_CRIT,
 			_("Cannot install signal handler for SIGHUP: %s"),
 			strerror (errno));
-		lwc_closeLog ();
-		close_pid_file (pid_file);
-		free (save_argv);
 		for (i = 0; save_env[i] != NULL; i++) {
 			free (save_env[i]);
 		}
 		free (save_env);
-		net_destroy_ssl ();
-		conf_destroy_srv ();
-		module_exit ();
-		return 1;
+		free (save_argv);
+		return EXIT_FAILURE;
 	}
 
-	schedwi_memset (&sa, 0, sizeof (struct sigaction));
+	memset (&sa, 0, sizeof (struct sigaction));
 	sa.sa_handler = SIG_IGN;
 	sigemptyset (&(sa.sa_mask));
 	sa.sa_flags = 0;
@@ -709,17 +655,12 @@ main (int argc, char **argv)
 			LOG_CRIT,
 			_("Cannot install signal handler for SIGPIPE: %s"),
 			strerror (errno));
-		lwc_closeLog ();
-		close_pid_file (pid_file);
-		free (save_argv);
 		for (i = 0; save_env[i] != NULL; i++) {
 			free (save_env[i]);
 		}
 		free (save_env);
-		net_destroy_ssl ();
-		conf_destroy_srv ();
-		module_exit ();
-		return 1;
+		free (save_argv);
+		return EXIT_FAILURE;
 	}
 
 
@@ -727,17 +668,12 @@ main (int argc, char **argv)
 	 * Wait until the CA certificate file is available
 	 */
 	if (wait_for_ca_cert (ca_crt) != 0) {
-		lwc_closeLog ();
-		close_pid_file (pid_file);
-		free (save_argv);
 		for (i = 0; save_env[i] != NULL; i++) {
 			free (save_env[i]);
 		}
 		free (save_env);
-		net_destroy_ssl ();
-		conf_destroy_srv ();
-		module_exit ();
-		return 1;
+		free (save_argv);
+		return EXIT_FAILURE;
 	}
 
 
@@ -756,17 +692,12 @@ main (int argc, char **argv)
 	if (net_server (registrar_port, iface, address_family,
 			&sock_set, &sock_max) != 0)
 	{
-		lwc_closeLog ();
-		close_pid_file (pid_file);
-		free (save_argv);
 		for (i = 0; save_env[i] != NULL; i++) {
 			free (save_env[i]);
 		}
 		free (save_env);
-		net_destroy_ssl ();
-		conf_destroy_srv ();
-		module_exit ();
-		return 1;
+		free (save_argv);
+		return EXIT_FAILURE;
 	}
 
 
@@ -778,28 +709,23 @@ main (int argc, char **argv)
 	do {
 		ret = conf_get_param_string ("ALLOW_FROM", &allow_from);
 #if HAVE_ASSERT_H
-	assert (ret == 0);
+		assert (ret == 0);
 #endif
 		/* Wait for connections */
 		client_names = NULL;
 		in_sock = net_accept_sock (	&sock_set, sock_max,
 						allow_from, &client_names);
 		if (in_sock < 0) {
-			lwc_closeLog ();
-			close_pid_file (pid_file);
-			free (save_argv);
+			if (buff != NULL) {
+				free (buff);
+			}
 			for (i = 0; save_env[i] != NULL; i++) {
 				free (save_env[i]);
 			}
 			free (save_env);
+			free (save_argv);
 			net_close_sock_set (&sock_set, &sock_max);
-			net_destroy_ssl ();
-			conf_destroy_srv ();
-			module_exit ();
-			if (buff != NULL) {
-				free (buff);
-			}
-			return 1;
+			return EXIT_FAILURE;
 		}
 
 		/* Parse the request */
@@ -810,7 +736,7 @@ main (int argc, char **argv)
 		net_close_sock (in_sock);
 		signal_unmask ();
 	} while (1);
-	return 0;
+	return EXIT_SUCCESS;
 }
 
 /*------------------------======= End Of File =======------------------------*/
