@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2013 Herve Quatremain
+   Copyright (C) 2007-2014 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -31,21 +31,22 @@ extern "C" {
 #endif
 
 extern int sql_command_get_commands OF((
-		int (*callback)(void *, unsigned int, unsigned long long int,
+		int (*callback)(void *, int, unsigned long long int,
 				const char *, int, int),
 		void *user_data,
 		void (*error_func)(void *, const char *, int),
 		void *user_data_error_func));
-extern int sql_command_add OF((int workload_date, const char *job_id,
+extern int sql_command_add OF((	int workload_date,
+				unsigned long long int job_id,
 				const char *user, int command,
 				int parameter, char **err_msg));
 extern int sql_command_done OF((
-			int workload_date, const char *job_id,
+			int workload_date, unsigned long long int job_id,
 			int command, int parameter,
 			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
 extern int sql_command_failed OF((
-			int workload_date, const char *job_id,
+			int workload_date, unsigned long long int job_id,
 			int command, int parameter,
 			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
