@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2013 Herve Quatremain
+   Copyright (C) 2007-2014 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -41,6 +41,10 @@
 #include <time.h>
 #endif
 
+#if TM_IN_SYS_TIME
+#include <sys/time.h>
+#endif
+
 #if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -51,7 +55,7 @@
 
 #include <pthread.h>
 
-#include <lib_functions.h>
+#include <xmem.h>
 #include <conf.h>
 #include <sql_common.h>
 
@@ -127,12 +131,9 @@ end_sql ()
  * Built an SQL error message
  * Warning - a mutex must be set before calling this function.
  *
- * Return:
- *   0 --> No error (if not NULL, msg_out contains the error message
- *         to be freed by the caller)
- *  -1 --> Memory allocation error
+ * If not NULL, msg_out contains the error message (to be freed by the caller)
  */
-int
+void
 compose_error_message (const char *msg, char **msg_out)
 {
 	const char *msg_sql;
@@ -140,7 +141,7 @@ compose_error_message (const char *msg, char **msg_out)
 	unsigned int msg_len;
 
 	if (msg_out == NULL) {
-		return 0;
+		return;
 	}
 
 	dbi_conn_error(sql, &msg_sql);
@@ -149,18 +150,14 @@ compose_error_message (const char *msg, char **msg_out)
 		msg_len = 0;
 	}
 	else {
-		msg_len = schedwi_strlen (msg);
+		msg_len = strlen (msg);
 	}
 
 	separator = _(": ");
-	*msg_out = (char *) malloc (	  msg_len
-					+ schedwi_strlen (separator)
-					+ schedwi_strlen (msg_sql)
+	*msg_out = (char *) xmalloc (	  msg_len
+					+ strlen (separator)
+					+ strlen (msg_sql)
 					+ 1);
-	if (*msg_out == NULL) {
-		return -1;
-	}
-
 	(*msg_out)[0] = '\0';
 	if (msg != NULL) {
 		strcpy (*msg_out, msg);
@@ -169,7 +166,6 @@ compose_error_message (const char *msg, char **msg_out)
 		strcat (*msg_out, separator);
 	}
 	strcat (*msg_out, msg_sql);
-	return 0;
 }
 
 
@@ -192,7 +188,7 @@ sql_escape (dbi_conn sql, const char *s)
 	assert (sql != NULL);
 #endif
 
-	if (dbi_conn_quote_string_copy (sql, (s == NULL)?"":s, &res) == 0) {
+	if (dbi_conn_quote_string_copy (sql, (s == NULL) ? "": s, &res) == 0) {
 		return NULL;
 	}
 	return res;
@@ -332,66 +328,60 @@ sql_request (dbi_conn sql, dbi_result *result,
 		i++)
 	{
 		args[i].type = t;
+
 		switch (t) {
-			case SQL_INT:
-				args[i].value_int = va_arg (ap, long int);
-				req_len += 22;
-				break;
 
-			case SQL_BOOL:
-				c = va_arg (ap, int);
-				args[i].value_bool = (c == 0 || c == '0') ?0:1;
-				req_len += 1;
-				break;
+		case SQL_INT:
+			args[i].value_int = va_arg (ap, long int);
+			req_len += 22;
+			break;
 
-			case SQL_STRING:
-				/* Escape the provided string */
-				s = sql_escape (sql, va_arg (ap, char *));
-				if (s == NULL) {
-					free_args (args, i);
-					if (err_msg != NULL) {
-						s =_("Memory allocation error");
-						*err_msg = (char *) malloc (
-							schedwi_strlen(s) + 1);
-						if (*err_msg != NULL) {
-							strcpy (*err_msg, s);
-						}
-					}
-					return -1;
+		case SQL_BOOL:
+			c = va_arg (ap, int);
+			args[i].value_bool = (c == 0 || c == '0') ? 0 : 1;
+			req_len += 1;
+			break;
+
+		case SQL_STRING:
+			/* Escape the provided string */
+			s = sql_escape (sql, va_arg (ap, char *));
+			if (s == NULL) {
+				free_args (args, i);
+				if (err_msg != NULL) {
+					s =_("Memory allocation error");
+					*err_msg = xstrdup (s);
 				}
-				args[i].value_string = s;
-				req_len += schedwi_strlen (s);
-				break;
+				return -1;
+			}
+			args[i].value_string = s;
+			req_len += strlen (s);
+			break;
 
-			case SQL_STRING_NON_ESCAPE:
-				s = va_arg (ap, char *);
-				args[i].value_string = s;
-				req_len += schedwi_strlen (s);
-				break;
+		case SQL_STRING_NON_ESCAPE:
+			s = va_arg (ap, char *);
+			args[i].value_string = s;
+			req_len += strlen (s);
+			break;
 
-			case SQL_BIN:
-				/* Escape the binary string */
-				us = va_arg (ap, unsigned char *);
-				bin_len = va_arg (ap, size_t);
-				us = sql_escape_bin (sql, us, bin_len);
-				if (us == NULL) {
-					free_args (args, i);
-					if (err_msg != NULL) {
-						s =_("Memory allocation error");
-						*err_msg = (char *) malloc (
-							schedwi_strlen (s) + 1);
-						if (*err_msg != NULL) {
-							strcpy (*err_msg, s);
-						}
-					}
-					return -1;
+		case SQL_BIN:
+			/* Escape the binary string */
+			us = va_arg (ap, unsigned char *);
+			bin_len = va_arg (ap, size_t);
+			us = sql_escape_bin (sql, us, bin_len);
+			if (us == NULL) {
+				free_args (args, i);
+				if (err_msg != NULL) {
+					s =_("Memory allocation error");
+					*err_msg = xstrdup (s);
 				}
-				args[i].value_string = (char *)us;
-				req_len += schedwi_strlen ((char *)us);
-				break;
+				return -1;
+			}
+			args[i].value_string = (char *)us;
+			req_len += strlen ((char *)us);
+			break;
 
-			default:
-				break;
+		default:
+			break;
 		}
 	}
 
@@ -403,22 +393,10 @@ sql_request (dbi_conn sql, dbi_result *result,
 	}
 
 	/* Allocate memory for the SQL request */
-	req_len += schedwi_strlen (fmt) + 1;
+	req_len += strlen (fmt) + 1;
 	if (buf == NULL || buf_len == NULL) {
 		/* Create a new buffer */
-		req = (char *) malloc (req_len);
-		if (req == NULL) {
-			free_args (args, MAX_NUM_ARGS);
-			if (err_msg != NULL) {
-				s = _("Memory allocation error");
-				*err_msg = (char *) malloc (schedwi_strlen (s)
-								+ 1);
-				if (*err_msg != NULL) {
-					strcpy (*err_msg, s);
-				}
-			}
-			return -1;
-		}
+		req = (char *) xmalloc (req_len);
 		req_to_free = 1;
 	}
 	else {
@@ -427,20 +405,7 @@ sql_request (dbi_conn sql, dbi_result *result,
 			if (*buf != NULL) {
 				free (*buf);
 			}
-			*buf = (char *) malloc (req_len);
-			if (*buf == NULL) {
-				free_args (args, MAX_NUM_ARGS);
-				*buf_len = 0;
-				if (err_msg != NULL) {
-					s = _("Memory allocation error");
-					*err_msg = (char *) malloc (
-							schedwi_strlen (s) + 1);
-					if (*err_msg != NULL) {
-						strcpy (*err_msg, s);
-					}
-				}
-				return -1;
-			}
+			*buf = (char *) xmalloc (req_len);
 			*buf_len = req_len;
 		}
 		req = *buf;
@@ -722,14 +687,12 @@ sql_non_select (	char **buf, unsigned int *buf_len, char **err_msg,
 		 */
 		if (*id == 0 && tablename != NULL && tablename[0] != '\0') {
 			s = "_id_seq";
-			sequence = (char *) malloc (schedwi_strlen (tablename)
-						+ schedwi_strlen (s) + 1);
-			if (sequence != NULL) {
-				strcpy (sequence, tablename);
-				strcat (sequence, s);
-				*id = dbi_conn_sequence_last (sql, sequence);
-				free (sequence);
-			}
+			sequence = (char *) xmalloc (	  strlen (tablename)
+							+ strlen (s) + 1);
+			strcpy (sequence, tablename);
+			strcat (sequence, s);
+			*id = dbi_conn_sequence_last (sql, sequence);
+			free (sequence);
 		}
 	}
 
@@ -778,44 +741,14 @@ sql_row_item2ll (const row_item_t *item)
 							: item->value_uint);
 		}
 		if (item->type == RES_STRING) {
-			return (long long int)strtoull(item->value_string,
-							NULL, 0);
+			return (long long int) strtoull (item->value_string,
+							 NULL, 0);
 		}
 	}
 	return 0;
 }
 
 
-/*
- * Compare two row_item_t objects
- *
- * Return:
- *   0 --> the two object have the same value
- *  -1 --> they differ
- */
-char
-sql_row_item_cmp (const row_item_t *a, const row_item_t *b)
-{
-	if (a == NULL) {
-		return (b == NULL) ? 0 : -1;
-	}
-	if (b == NULL || a->type != b->type) {
-		return -1;
-	}
-	if (	   a->type == RES_END
-		|| (a->type == RES_TIME && a->value_time == b->value_time)
-		|| (	   (a->type == RES_INT || a->type == RES_UINT)
-			&& sql_row_item2ll (a) == sql_row_item2ll (b))
-		|| (	   (a->type == RES_STRING || a->type == RES_BIN)
-			&& a->len == b->len
-			&& ! memcmp (a->value_string, b->value_string, b->len)))
-	{
-		return 0;
-	}
-	return -1;
-}
-
-
 /*
  * Run a select database request
  *
@@ -873,16 +806,6 @@ sql_select (	char **buf, unsigned int *buf_len, char **err_msg,
 
     /* Allocate memory for the linked list */
     list = lwc_newLL ();
-    if (list == NULL) {
-        if (err_msg != NULL) {
-            s = _("Memory allocation error");
-            *err_msg = (char *) malloc (schedwi_strlen (s) + 1);
-            if (*err_msg != NULL) {
-                strcpy (*err_msg, s);
-            }
-        }
-        return -1;
-    }
 
     /* Connect to the database */
     sql = begin_sql (err_msg);
@@ -919,21 +842,7 @@ sql_select (	char **buf, unsigned int *buf_len, char **err_msg,
     while (dbi_result_next_row (result)) {
 
         /* Allocate a new row array */
-        row_array = (row_item_t *) malloc (sizeof (row_item_t) * (cols + 1));
-        if (row_array == NULL) {
-            dbi_result_free (result);
-            pthread_mutex_unlock (&lock);
-            end_sql ();
-            lwc_delLL (list, (void (*)(const void *))sql_free_row);
-            if (err_msg != NULL) {
-                s = _("Memory allocation error");
-                *err_msg = (char *) malloc (schedwi_strlen (s) + 1);
-                if (*err_msg != NULL) {
-                    strcpy (*err_msg, s);
-                }
-            }
-            return -1;
-        }
+        row_array = (row_item_t *) xmalloc (sizeof (row_item_t) * (cols + 1));
         row_array[cols].type = RES_END;
 
         /* Copy the returned row */
@@ -1031,10 +940,7 @@ sql_select (	char **buf, unsigned int *buf_len, char **err_msg,
                         else {
                             if (err_msg != NULL) {
                                 s = _("Memory allocation error");
-                                *err_msg =(char *) malloc(schedwi_strlen(s)+1);
-                                if (*err_msg != NULL) {
-                                    strcpy (*err_msg, s);
-                                }
+                                *err_msg = xstrdup (s);
                             }
                         }
                         dbi_result_free (result);
@@ -1065,10 +971,7 @@ sql_select (	char **buf, unsigned int *buf_len, char **err_msg,
                         else {
                             if (err_msg != NULL) {
                                 s = _("Memory allocation error");
-                                *err_msg =(char *) malloc(schedwi_strlen(s)+1);
-                                if (*err_msg != NULL) {
-                                    strcpy (*err_msg, s);
-                                }
+                                *err_msg = xstrdup (s);
                             }
                         }
                         dbi_result_free (result);
@@ -1090,21 +993,7 @@ sql_select (	char **buf, unsigned int *buf_len, char **err_msg,
         }
 
         /* Add the new row to the linked list */
-        if (lwc_addEndLL (list, row_array) != 0) {
-            dbi_result_free (result);
-            pthread_mutex_unlock (&lock);
-            end_sql ();
-            lwc_delLL (list, (void (*)(const void *))sql_free_row);
-            sql_free_row (row_array);
-            if (err_msg != NULL) {
-                s = _("Memory allocation error");
-                *err_msg = (char *) malloc (schedwi_strlen (s) + 1);
-                if (*err_msg != NULL) {
-                    strcpy (*err_msg, s);
-                }
-            }
-            return -1;
-        }
+        lwc_addEndLL (list, row_array);
     }
 
     dbi_result_free (result);
@@ -1123,8 +1012,7 @@ sql_select (	char **buf, unsigned int *buf_len, char **err_msg,
  * be negative to compute a date/time in the past)
  *
  * Return:
- *   NULL in case of memory allocation error OR
- *   the date/string to be freed by the caller by free()
+ *   The date/string to be freed by the caller by free()
  */
 char *
 sql_date_interval (int sec)
@@ -1133,13 +1021,10 @@ sql_date_interval (int sec)
 	time_t t;
 	struct tm stm;
 
-	d = (char *) malloc (25);
-	if (d == NULL) {
-		return NULL;
-	}
 	time (&t);
 	t += sec;
 	localtime_r (&t, &stm);
+	d = (char *) xmalloc (25);
 	strftime (d, 24, "%Y-%m-%d %H:%M:%S", &stm);
 	return d;
 }
