@@ -72,7 +72,7 @@ typedef struct row_item row_item_t;
 
 extern dbi_conn begin_sql OF((char **err_msg));
 extern void end_sql OF(());
-extern int compose_error_message OF((const char *msg, char **msg_out));
+extern void compose_error_message OF((const char *msg, char **msg_out));
 extern char *sql_escape OF((dbi_conn sql, const char *s));
 extern int sql_non_select OF((	char **buf, unsigned int *buf_len,
 				char **err_msg,
@@ -82,7 +82,6 @@ extern int sql_non_select OF((	char **buf, unsigned int *buf_len,
 				const char *fmt, ...));
 extern void sql_free_row OF((row_item_t *row));
 extern long long int sql_row_item2ll OF((const row_item_t *item));
-extern char sql_row_item_cmp OF((const row_item_t *a, const row_item_t *b));
 extern int sql_select OF((	char **buf, unsigned int *buf_len,
 				char **err_msg,
 				unsigned int *num_columns,
