@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2012 Herve Quatremain
+   Copyright (C) 2007-2014 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -17,10 +17,9 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-/*
- * sql_get_environment.c -- Get the environment for a job searching its
- *                          ancestors (the job inherit the environments of its
- *                          ancestors).
+/* @file sql_get_environment.c
+ * Get the environment for a job searching its ancestors (the job inherit the
+ * environments of its ancestors).
  */
 
 #include <schedwi.h>
@@ -43,11 +42,12 @@
 
 #include <sql_common.h>
 #include <sql_hierarchy.h>
+#include <xmem.h>
 #include <sql_get_environment.h>
 
-#define SQL_GET_JOB_NOENV "SELECT job_main_s.id FROM job_main_s WHERE job_main_s.workload_date=%d AND job_main_s.id IN (%s) AND job_main_s.has_env=0"
-#define SQL_GET_ENVIRONMENT_REQ "SELECT job_environment_s.job_id,job_environment_s.position,environment_var_s.position,environment_var_s.env_key,environment_var_s.env_value FROM environment_var_s,job_environment_s WHERE job_environment_s.workload_date=%d AND environment_var_s.workload_date=%d AND job_environment_s.job_id IN (%s) AND job_environment_s.env_id=environment_var_s.env_id ORDER BY job_environment_s.position,environment_var_s.position"
-#define SQL_GET_ENVIRONMENT_HOST_REQ "SELECT host_environment_s.position,environment_var_s.position,environment_var_s.env_key,environment_var_s.env_value FROM environment_var_s,host_environment_s WHERE host_environment_s.workload_date=%d AND environment_var_s.workload_date=%d AND host_environment_s.host_id=%ld AND host_environment_s.env_id=environment_var_s.env_id ORDER BY host_environment_s.position,environment_var_s.position"
+#define SQL_GET_JOB_NOENV "SELECT job_main_s.id FROM job_main_s WHERE job_main_s.id IN (%s) AND job_main_s.has_env=0 AND job_main_s.workload_date=%d"
+#define SQL_GET_ENVIRONMENT_REQ "SELECT job_environment_s.job_id,job_environment_s.position,environment_var_s.position,environment_var_s.env_key,environment_var_s.env_value FROM environment_var_s,job_environment_s WHERE job_environment_s.job_id IN (%s) AND job_environment_s.workload_date=%d AND environment_var_s.workload_date=%d AND job_environment_s.env_id=environment_var_s.env_id ORDER BY job_environment_s.position,environment_var_s.position"
+#define SQL_GET_ENVIRONMENT_HOST_REQ "SELECT host_environment_s.position,environment_var_s.position,environment_var_s.env_key,environment_var_s.env_value FROM environment_var_s,host_environment_s WHERE host_environment_s.host_id=%ld AND host_environment_s.workload_date=%d AND environment_var_s.workload_date=%d AND host_environment_s.env_id=environment_var_s.env_id ORDER BY host_environment_s.position,environment_var_s.position"
 
 
 /*
@@ -83,7 +83,8 @@ sql_get_environment (int workload_date, lwc_LL *lst, unsigned int next_pos,
 	int ret;
 	lwc_LL *rows, **lists;
 	row_item_t *row;
-	unsigned long long int jobid, *id, *ids;
+	unsigned long long int jobid, *ids;
+
 
 #if HAVE_ASSERT_H
 	assert (lwc_getNumNode (lst) > 0 && callback != NULL);
@@ -91,19 +92,13 @@ sql_get_environment (int workload_date, lwc_LL *lst, unsigned int next_pos,
 
 
 	/* Build the job ID list to be used by the SQL request */
-	if (hierarchy_list_to_str (lst, &hierarchy_str) != 0) {
-		if (error_func != NULL) {
-			error_func (	user_data_error_func,
-					_("Memory allocation error"), 0);
-		}
-		return -1;
-	}
+	hierarchy_str = hierarchy_list_to_str (lst);
 
 	/* From the jobset hierarchy, get the jobsets where has_env is 0 */
 	ret = sql_select (	NULL, NULL, &err_msg, NULL, &rows,
 				SQL_GET_JOB_NOENV,
-				SQL_INT, (long int)workload_date,
 				SQL_STRING_NON_ESCAPE, hierarchy_str,
+				SQL_INT, (long int)workload_date,
 				SQL_END);
 	free (hierarchy_str);
 	if (ret != 0) {
@@ -117,33 +112,17 @@ sql_get_environment (int workload_date, lwc_LL *lst, unsigned int next_pos,
 	}
 	/* Recreate the new jobset hierarchy */
 	ids_len = lwc_getNumNode (lst);
-	ids = (unsigned long long int *) malloc (ids_len
-					* sizeof (unsigned long long int));
-	if (ids == NULL) {
-		lwc_delLL (rows, (void (*)(const void *))sql_free_row);
-		if (error_func != NULL) {
-			error_func (	user_data_error_func,
-					_("Memory allocation error"), 0);
-		}
-		return -1;
-	}
-	lwc_rewindLL(lst);
-	for (	i = 0;
-		(id = (unsigned long long int *) lwc_nextLL (lst)) != NULL;
-		i++)
-	{
-		ids[i] = *id;
-	}
+	ids = hierarchy_list_to_array (lst);
 	while ((row = (row_item_t *) lwc_delStartLL (rows)) != NULL) {
 		/* row[0] --> Job ID */
 		jobid = (unsigned long long int)sql_row_item2ll (&(row[0]));
+		sql_free_row (row);
 		for (j = 0; j < ids_len; j++) {
 			if (ids[j] == jobid) {
 				ids_len = j;
 				break;
 			}
 		}
-		sql_free_row (row);
 	}
 	lwc_delLL (rows, (void (*)(const void *))sql_free_row);
 	/* No environment variable to set */
@@ -153,51 +132,21 @@ sql_get_environment (int workload_date, lwc_LL *lst, unsigned int next_pos,
 	}
 
 	/* Build the job ID list to be used by the SQL request */
-	if (hierarchy_array_to_str (ids, ids_len, &hierarchy_str) != 0) {
-		free (ids);
-		if (error_func != NULL) {
-			error_func (	user_data_error_func,
-					_("Memory allocation error"), 0);
-		}
-		return -1;
-	}
+	hierarchy_str = hierarchy_array_to_str (ids, ids_len);
 
 	/* Create the array of environment variable lists for each job ID */
-	lists = (lwc_LL **) malloc (ids_len * sizeof (lwc_LL *));
-	if (lists == NULL) {
-		free (hierarchy_str);
-		free (ids);
-		if (error_func != NULL) {
-			error_func (	user_data_error_func,
-					_("Memory allocation error"), 0);
-		}
-		return -1;
-	}
+	lists = (lwc_LL **) xmalloc (ids_len * sizeof (lwc_LL *));
 
 	for (i = 0; i < ids_len; i++) {
 		lists[i] = lwc_newLL ();
-		if (lists[i] == NULL) {
-			for (j = 0; j < i; j++) {
-				lwc_delLL (lists[j], NULL);
-			}
-			free (lists);
-			free (hierarchy_str);
-			free (ids);
-			if (error_func != NULL) {
-				error_func (	user_data_error_func,
-						_("Memory allocation error"),
-						0);
-			}
-			return -1;
-		}
 	}
 
-	/* SQL request */
+	/* Get the environment variables from the database */
 	ret = sql_select (	NULL, NULL, &err_msg, NULL, &rows,
 				SQL_GET_ENVIRONMENT_REQ,
-				SQL_INT, (long int)workload_date,
-				SQL_INT, (long int)workload_date,
 				SQL_STRING_NON_ESCAPE, hierarchy_str,
+				SQL_INT, (long int)workload_date,
+				SQL_INT, (long int)workload_date,
 				SQL_END);
 	free (hierarchy_str);
 	if (ret != 0) {
@@ -224,26 +173,9 @@ sql_get_environment (int workload_date, lwc_LL *lst, unsigned int next_pos,
 		 * row[4] --> Environment variable value
 		 */
 		jobid = (unsigned long long int)sql_row_item2ll (&(row[0]));
-		lwc_rewindLL (lst);
 		for (i = 0; i < ids_len && ids[i] != jobid; i++);
 		if (i < ids_len) {
-			if (lwc_addEndLL (lists[i], row) != 0) {
-				for (i = 0; i < ids_len; i++) {
-					lwc_delLL (lists[i],
-					(void (*)(const void *))sql_free_row);
-				}
-				free (lists);
-				sql_free_row (row);
-				lwc_delLL (rows,
-					(void (*)(const void *))sql_free_row);
-				free (ids);
-				if (error_func != NULL) {
-					error_func (user_data_error_func,
-						_("Memory allocation error"),
-						0);
-				}
-				return -1;
-			}
+			lwc_addEndLL (lists[i], row);
 		}
 		else {
 			sql_free_row (row);
@@ -324,6 +256,7 @@ sql_get_environment_host (int workload_date, unsigned long long int host_id,
 	unsigned int i;
 	int ret;
 
+
 #if HAVE_ASSERT_H
 	assert (callback != NULL);
 #endif
@@ -331,9 +264,9 @@ sql_get_environment_host (int workload_date, unsigned long long int host_id,
 	/* SQL request */
 	ret = sql_select (	NULL, NULL, &err_msg, NULL, &rows,
 				SQL_GET_ENVIRONMENT_HOST_REQ,
-				SQL_INT, (long int)workload_date,
-				SQL_INT, (long int)workload_date,
 				SQL_INT, (long int)host_id,
+				SQL_INT, (long int)workload_date,
+				SQL_INT, (long int)workload_date,
 				SQL_END);
 	if (ret != 0) {
 		if (error_func != NULL) {
