@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2010 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -23,6 +23,11 @@
 #define _SQL_HIERARCHY_H
 
 #include <schedwi.h>
+
+#if HAVE_TIME_H
+#include <time.h>
+#endif
+
 #include <lwc_linkedlist.h>
 #include <sql_common.h>
 
@@ -31,15 +36,25 @@
 extern "C" {
 #endif
 
-extern int get_job_path OF((	unsigned long long int job_id,
-				char **path, char **err_msg));
-extern lwc_LL *get_hierarchy_list OF((	int workload_date,
+extern lwc_LL *hierarchy_list_new OF((	int workload_date,
 					unsigned long long int job_id,
 					char **err_msg));
-extern lwc_LL *duplicate_hierarchy_list OF((lwc_LL *lst, char **err_msg));
-extern int hierarchy_array_to_str OF((	unsigned long long int *a,
-					unsigned int l, char **result));
-extern int hierarchy_list_to_str OF((lwc_LL *lst, char **result));
+extern void hierarchy_list_destroy OF((lwc_LL *lst));
+extern int hierarchy_list_push_job OF((
+			lwc_LL *lst, int workload_date,
+			unsigned long long int job_id,
+			char **err_msg));
+extern void hierarchy_list_pop_job OF((lwc_LL *lst));
+extern char *hierarchy_list_to_job_full_path OF((lwc_LL *lst));
+extern char *hierarchy_array_to_str OF((unsigned long long int *a,
+					unsigned int l));
+extern char hierarchy_list_get_type OF((lwc_LL *lst));
+extern char hierarchy_list_get_manual OF((lwc_LL *lst));
+extern time_t hierarchy_list_get_start_time OF((lwc_LL *lst));
+extern time_t hierarchy_list_get_real_start_time OF((lwc_LL *lst));
+extern short int hierarchy_list_get_start_limit OF((lwc_LL *lst));
+extern char *hierarchy_list_to_str OF((lwc_LL *lst));
+extern unsigned long long int *hierarchy_list_to_array OF((lwc_LL *lst));
 extern int get_job_parameters OF((
 			int workload_date, lwc_LL *lst,
 			const char *tablename, const char *colnames,
@@ -59,19 +74,9 @@ extern int get_job_parameters_multi OF((
 			const char *sort_colname,
 			int (*callback)(void *, row_item_t *), void *user_data,
 			char **err_msg));
-extern int get_job_parameters_by_id OF((
+extern int get_job_hosts OF((
 			int workload_date, lwc_LL *lst,
-			const char *tablename, const char *colnames,
-			const row_item_t *not_defined,
-			row_item_t **values, char **err_msg));
-
-extern int get_job_id OF((
-		const char *job_name,
-		unsigned long long int *j_id,
-		unsigned long long int *j_parent_id,
-		int *j_type,
-		void (*error_func)(void *, const char *, int),
-		void *user_data_error_func));
+			lwc_LL **host_ids, char **err_msg));
 
 #ifdef __cplusplus
 }
