@@ -41,14 +41,6 @@ typedef enum
 	DESCR
 } host_columns;
 
-extern int sql_hosts_list OF((
-    int (*add_row)(void *, unsigned long long int, const char *, const char *),
-    void *user_data_add_row,
-    void (*error_func)(void *, const char *, int),
-    void *user_data_error_func));
-extern int sql_host_delete OF((const char *host_id,
-			void (*error_func)(void *, const char *, int),
-			void *user_data_error_func));
 extern int sql_host_get_by_name OF((
 			char **host_names,
 			const char *portnum,
@@ -60,20 +52,6 @@ extern int sql_host_get_by_id OF((
 			row_item_t **row_out,
 			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
-extern int sql_host_new OF((
-			const char *hostname, const char *portnum,
-			char sslenable, const char *sslcert,
-			const char *description,
-			unsigned long long int *new_host_id,
-			void (*error_func)(void *, const char *, int),
-			void *user_data_error_func));
-extern int sql_host_update OF((
-			const char *host_id,
-			const char *hostname, const char *portnum,
-			char sslenable, const char *sslcert,
-			const char *description,
-			void (*error_func)(void *, const char *, int),
-			void *user_data_error_func));
 extern int sql_host_certificate OF((char **names,
 			char *sslenable,
 			char **certificate, unsigned long int *certificate_len,
