@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2010 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -23,19 +23,16 @@
 #define _SQL_LINK_H
 
 #include <schedwi.h>
-#include <lwc_linkedlist.h>
 
 /* Allow the use in C++ code.  */
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-extern int sql_link_get_list OF((
-			lwc_LL **rows,
-			int workload_date,
-			const char *id_list,
-			void (*error_func)(void *, const char *, int),
-			void *user_data_error_func));
+extern int sql_link_are_resolved OF((int workload_date,
+				unsigned long long int job_id,
+				void (*error_func)(void *, const char *, int),
+				void *user_data_error_func));
 
 #ifdef __cplusplus
 }
