@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2010 Herve Quatremain
+   Copyright (C) 2007-2014 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -30,23 +30,13 @@
 extern "C" {
 #endif
 
-extern int sql_stat_get_duration OF((
-			const char *job_id,
-			long int *duration,
-			long int *last_run_duration,
-			void (*error_func)(void *, const char *, int),
-			void *user_data_error_func));
-extern int sql_stat_get OF((
-			const char *job_id, row_item_t **row,
-			void (*error_func)(void *, const char *, int),
-			void *user_data_error_func));
 extern int sql_stat_success OF((
-			const char *job_id,
+			unsigned long long int job_id,
 			long int duration,
 			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
 extern int sql_stat_fail OF((
-			const char *job_id,
+			unsigned long long int job_id,
 			long int duration,
 			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
