@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2013 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -38,25 +38,28 @@
 #endif
 
 #include <ping.h>
-#include <lib_functions.h>
+#include <xmem.h>
 #include <lwc_log.h>
+#include <job_status_state.h>
+#include <schedwi_time.h>
 #include <sql_common.h>
 #include <sql_hierarchy.h>
 #include <sql_status.h>
 
-#define SQLSTATUS_WORKLOAD_LIST "SELECT DISTINCT workload_date FROM job_status ORDER BY workload_date"
-#define SQLSTATUS_GET "SELECT status,start_time,retry_num,wait_reason,error_msg,duration FROM job_status WHERE workload_date=%d AND job_id=%ld"
-#define SQLSTATUS_UPDATE "UPDATE job_status SET status=%d,start_time=%u,retry_num=%d,wait_reason=%d,error_msg=%s,duration=%d WHERE workload_date=%d AND job_id=%s"
-#define SQLSTATUS_SET "INSERT INTO job_status (workload_date,job_id,status,start_time,retry_num,wait_reason,error_msg,duration) VALUES (%d,%s,%d,%u,%d,%d,%s,%d)"
-#define SQLSTATUS_UPDATE_WAIT_REASON "UPDATE job_status SET wait_reason=%d WHERE workload_date=%d AND job_id=%ld"
-#define SQLSTATUS_UPDATE_START_TIME "UPDATE job_status SET start_time=%u WHERE workload_date=%d AND job_id=%ld"
-#define SQLSTATUS_UPDATE_HOST "UPDATE job_status SET host_id=%ld WHERE workload_date=%d AND job_id=%ld"
+#define SQLSTATUS_WORKLOAD_LIST "SELECT DISTINCT workload_date FROM job_status WHERE workload_date=%d OR workload_date=%d OR time_status_set>%ld ORDER BY workload_date"
+#define SQLSTATUS_GET "SELECT status,time_status_set,retry_num,wait_reason,error_msg,duration FROM job_status WHERE job_id=%ld AND workload_date=%d"
+#define SQLSTATUS_UPDATE "UPDATE job_status SET status=%d,time_status_set=%ld,retry_num=%d,wait_reason=%d,error_msg=%s,duration=%d WHERE job_id=%ld AND workload_date=%d"
+#define SQLSTATUS_SET "INSERT INTO job_status (workload_date,job_id,status,time_status_set,retry_num,wait_reason,error_msg,duration) VALUES (%d,%ld,%d,%ld,%d,%d,%s,%d)"
+#define SQLSTATUS_UPDATE_WAIT_REASON "UPDATE job_status SET wait_reason=%d WHERE job_id=%ld AND workload_date=%d"
+#define SQLSTATUS_UPDATE_HOST "UPDATE job_status SET host_id=%ld WHERE job_id=%ld AND workload_date=%d"
 #define SQLSTATUS_DEL "DELETE FROM job_status WHERE workload_date=%d"
 #define SQLSTATUS_DEL_TABLES "DELETE FROM %s_s WHERE workload_date=%d"
 #define SQLSTATUS_CLEAN_TABLES "DELETE FROM %s WHERE workload_date=%d"
 #define SQLSTATUS_COPY "INSERT INTO %s_s SELECT *,%d FROM %s"
 #define SQLSTATUS_GET_OLD "SELECT workload_date FROM %s_s WHERE workload_date<%d"
 #define SQLSTATUS_HOST_COUNT_RUNNING "SELECT host_id,COUNT(*) FROM job_status WHERE status=2 AND host_id IN (%s) GROUP BY host_id ORDER BY COUNT(*)"
+#define SQLSTATUS_IS_JOB_PRESENT "SELECT 1 FROM job_status WHERE job_id=%ld AND workload_date=%d"
+#define SQLSTATUS_NUM_WAITING_LINKS "SELECT COUNT(*) FROM job_status WHERE workload_date=%d AND status=%d AND (wait_reason&%d)<>0"
 
 
 /*
@@ -75,7 +78,6 @@ static char * status_tables[] = {	"calendars",
 					"job_control_group",
 					"job_loadenv",
 					"job_detach",
-					"job_manual",
 					"job_manual_command",
 					"job_success_return_code",
 					"job_command",
@@ -108,10 +110,24 @@ static char * to_clean_tables[] = {
 					NULL
 				};
 
-/*
- * Get all the available workload from the job_status database table
+/**
+ * Get all the available workloads from the job_status database table that
+ * have been updated after the given time (as in time(2)).  The workload
+ * matching the given time and the one before that are always returned.
  *
- * Return:
+ * @param[out] rows The workload list to be freed by the caller by
+ *                  lwc_delLL (rows, (void (*)(const void *)) sql_free_row);
+ *                  This list may be empty if no workload has been updated
+ *                  after the given time (in time_status_set)
+ * @param[in] time_status_set The time (as in time(2)) after which to get the
+ *                            workloads.
+ * @param[in] error_func Error function to call in case of error. This function
+ *                       is called with user_data_error_func as its first
+ *                       parameter and the error message as the second
+ *                       parameter.  error_func can be NULL.
+ * @param[in] user_data_error_func User provided parameter to pass to the
+ *                                 error_func function in case of error.
+ * @return
  *     0 --> No error.  rows contains the retrieved workload date and must be
  *           freed by the caller by
  *              lwc_delLL (rows, (void (*)(const void *)) sql_free_row);
@@ -123,21 +139,29 @@ static char * to_clean_tables[] = {
  *           as the second parameter)
  */
 int
-sql_status_workload_list (lwc_LL **rows,
+sql_status_updated_workload_list (
+			lwc_LL **rows,
+			time_t time_status_set,
 			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func)
 {
 	char *err_msg = NULL;
 	int ret;
+	time_t yesterday;
+
 
 #if HAVE_ASSERT_H
 	assert (rows != NULL);
 #endif
 
-	ret = sql_select (	NULL, NULL, &err_msg, NULL, rows,
-				SQLSTATUS_WORKLOAD_LIST,
-				SQL_END);
-
+	yesterday = time_status_set - 24 * 60 * 60;
+	ret = sql_select (NULL, NULL, &err_msg, NULL, rows,
+		SQLSTATUS_WORKLOAD_LIST,
+		SQL_INT, (long int)schedwi_time_to_date_int (time_status_set),
+		SQL_INT, (long int)schedwi_time_to_date_int (
+					(yesterday >= 0) ? yesterday: 0),
+		SQL_INT, (long int)time_status_set,
+		SQL_END);
 	if (ret != 0) {
 		if (error_func != NULL) {
 			error_func (user_data_error_func, err_msg, ret);
@@ -155,8 +179,8 @@ sql_status_workload_list (lwc_LL **rows,
  * Get the status of the provided job/jobset
  *
  * Return:
- *     0 --> No error.  status contains the retrieved status and start_time
- *           the associated start time.
+ *     0 --> No error.  status contains the retrieved status and
+ *           time_status_set the associated start time.
  *    -1 --> Memory allocation error (if error_func() is not NULL, it is called
  *           with user_data_error_func as its first parameter and the error
  *           message as the second parameter)
@@ -168,7 +192,7 @@ int
 sql_status_get (int workload_date,
 		unsigned long long int job_id,
 		int *status,
-		long int *start_time,
+		time_t *time_status_set,
 		int *retry_num,
 		int *wait_reason,
 		char **message,
@@ -179,7 +203,6 @@ sql_status_get (int workload_date,
 	char *err_msg = NULL;
 	lwc_LL *rows;
 	int ret;
-	char *s;
 	row_item_t *row;
 
 
@@ -189,8 +212,8 @@ sql_status_get (int workload_date,
 
 	ret = sql_select (	NULL, NULL, &err_msg, NULL, &rows,
 				SQLSTATUS_GET,
-				SQL_INT, (long int)workload_date,
 				SQL_INT, (long int)job_id,
+				SQL_INT, (long int)workload_date,
 				SQL_END);
 
 	if (ret != 0) {
@@ -214,20 +237,7 @@ sql_status_get (int workload_date,
 			*message = NULL;
 		}
 		else {
-			s = (char *) malloc (row[4].len + 1);
-			if (s == NULL) {
-				sql_free_row (row);
-				lwc_delLL (rows,
-					(void (*)(const void *))sql_free_row);
-				if (error_func != NULL) {
-					error_func (user_data_error_func,
-						_("Memory allocation error"),
-						0);
-				}
-				return -1;
-			}
-			strcpy (s, row[4].value_string);
-			*message = s;
+			*message = xstrdup (row[4].value_string);
 		}
 	}
 
@@ -235,9 +245,9 @@ sql_status_get (int workload_date,
 	*status = (row == NULL) ? 0 : (int)sql_row_item2ll (&(row[0]));
 
 	/* Start time */
-	if (start_time != NULL) {
-		*start_time = (row == NULL) ? 0
-				: (long int)sql_row_item2ll (&(row[1]));
+	if (time_status_set != NULL) {
+		*time_status_set = (row == NULL) ? 0
+					: (time_t)sql_row_item2ll (&(row[1]));
 	}
 
 	/* Current retry number */
@@ -264,24 +274,21 @@ sql_status_get (int workload_date,
 }
 
 
-/*
+/**
  * Change the reason why the given job/jobset is in the waiting state.
  *
- * @param workload_date:
- * 			The workload date of the job/jobset.
- * @param job_id:
- * 			The database ID of the job or jobset.
- * @param wait_reason:
- * 			The reason why the job/jobset is waiting.  This is
- * 			a bit mask of the flags defined in sql_status.h:
- * 			WAIT_REASON_MASK_PARENT, WAIT_REASON_MASK_TIME, ...
- * @param error_func:
- * 			Caller error function which is called when an SQL
- * 			error occurs.  May be NULL.
- * @param user_data_error_func:
- * 			Caller data which is passed to the error_func as the
- * 			first parameter.
- * @return:
+ * @param[in] workload_date Workload date of the job/jobset (YYYYMMDD).
+ * @param[in] job_id The database ID of the job or jobset.
+ * @param[in] wait_reason The reason why the job/jobset is waiting.  This is
+ * 			  a bit mask of the flags defined in sql_status.h:
+ * 			  WAIT_REASON_MASK_PARENT, WAIT_REASON_MASK_TIME, ...
+ * @param[in] error_func Error function to call in case of error. This function
+ *                       is called with user_data_error_func as its first
+ *                       parameter and the error message as the second
+ *                       parameter.  error_func can be NULL.
+ * @param[in] user_data_error_func User provided parameter to pass to the
+ *                                 error_func function in vase of error.
+ * @return
  *     0 --> Success
  *    -1 --> Memory allocation error (if error_func() is not NULL, it is called
  *           with user_data_error_func as its first parameter and the error
@@ -304,8 +311,8 @@ sql_status_update_wait_reason (	int workload_date,
 	ret = sql_non_select (  NULL, NULL, &err_msg, NULL, NULL, NULL,
 				SQLSTATUS_UPDATE_WAIT_REASON,
 				SQL_INT, (long int)wait_reason,
-				SQL_INT, (long int)workload_date,
 				SQL_INT, (long int)job_id,
+				SQL_INT, (long int)workload_date,
 				SQL_END);
 	if (ret != 0) {
 		if (error_func != NULL) {
@@ -334,9 +341,9 @@ sql_status_update_wait_reason (	int workload_date,
  */
 int
 sql_status_set (int workload_date,
-		const char *job_id,
+		unsigned long long int job_id,
 		int status,
-		unsigned int start_time,
+		time_t time_status_set,
 		int retry_num,
 		int wait_reason,
 		const char *error_message,
@@ -348,21 +355,21 @@ sql_status_set (int workload_date,
 	int ret;
 	unsigned long long int nb = 0;
 
-#if HAVE_ASSERT_H
-	assert (job_id != NULL);
-#endif
 
+	if (time_status_set <= 0) {
+		time_status_set = time (NULL);
+	}
 	ret = sql_non_select (  NULL, NULL, &err_msg, NULL, &nb, NULL,
 				SQLSTATUS_UPDATE,
 				SQL_INT, (long int)status,
-				SQL_INT, (long int)start_time,
+				SQL_INT, (long int)time_status_set,
 				SQL_INT, (long int)retry_num,
 				SQL_INT, (long int)wait_reason,
 				SQL_STRING, (error_message != NULL)
 							? error_message: "",
 				SQL_INT, duration,
+				SQL_INT, (long int)job_id,
 				SQL_INT, (long int)workload_date,
-				SQL_STRING, job_id,
 				SQL_END);
 	if (ret != 0) {
 		if (error_func != NULL) {
@@ -384,9 +391,9 @@ sql_status_set (int workload_date,
 	ret = sql_non_select (  NULL, NULL, &err_msg, NULL, NULL, NULL,
 				SQLSTATUS_SET,
 				SQL_INT, (long int)workload_date,
-				SQL_STRING, job_id,
+				SQL_INT, (long int)job_id,
 				SQL_INT, (long int)status,
-				SQL_INT, (long int)start_time,
+				SQL_INT, (long int)time_status_set,
 				SQL_INT, (long int)retry_num,
 				SQL_INT, (long int)wait_reason,
 				SQL_STRING, (error_message != NULL)
@@ -406,52 +413,18 @@ sql_status_set (int workload_date,
 }
 
 
-/*
- * Change the start time of a running job/jobset
- *
- * Return:
- *     0 --> No error
- *    -1 --> Memory allocation error (if error_func() is not NULL, it is called
- *           with user_data_error_func as its first parameter and the error
- *           message as the second parameter)
- *    -2 --> SQL error (if error_func() is not NULL, it is called with
- *           user_data_error_func as its first parameter and the error message
- *           as the second parameter)
- */
-int
-sql_status_adjust_start_time (int workload_date,
-			unsigned long long int job_id,
-			unsigned int start_time,
-			void (*error_func)(void *, const char *, int),
-			void *user_data_error_func)
-{
-	char *err_msg = NULL;
-	int ret;
-
-	ret = sql_non_select (  NULL, NULL, &err_msg, NULL, NULL, NULL,
-				SQLSTATUS_UPDATE_START_TIME,
-				SQL_INT, (long int)start_time,
-				SQL_INT, (long int)workload_date,
-				SQL_INT, (long int)job_id,
-				SQL_END);
-	if (ret != 0) {
-		if (error_func != NULL) {
-			error_func (user_data_error_func, err_msg, ret);
-		}
-		if (err_msg != NULL) {
-			free (err_msg);
-		}
-		return ret;
-	}
-
-	return 0;
-}
-
-
-/*
+/**
  * Delete a workload
  *
- * Return:
+ * @param[in] workload_date Workload date of the job/jobsets (YYYYMMDD) to
+ *                          delete.
+ * @param[in] error_func Error function to call in case of error. This function
+ *                       is called with user_data_error_func as its first
+ *                       parameter and the error message as the second
+ *                       parameter.  error_func can be NULL.
+ * @param[in] user_data_error_func User provided parameter to pass to the
+ *                                 error_func function in vase of error.
+ * @return
  *     0 --> No error
  *    -1 --> Memory allocation error (if error_func() is not NULL, it is called
  *           with user_data_error_func as its first parameter and the error
@@ -461,9 +434,9 @@ sql_status_adjust_start_time (int workload_date,
  *           as the second parameter)
  */
 int
-sql_status_delete (int workload_date,
-		void (*error_func)(void *, const char *, int),
-		void *user_data_error_func)
+sql_status_delete (	int workload_date,
+			void (*error_func)(void *, const char *, int),
+			void *user_data_error_func)
 {
 	char *err_msg = NULL;
 	unsigned int err, i;
@@ -471,6 +444,7 @@ sql_status_delete (int workload_date,
 	char *buff;
 	unsigned int buff_len;
 
+
 	buff = NULL;
 	buff_len = 0;
 
@@ -653,6 +627,7 @@ sql_status_copy_to_workload (int workload_date,
 	char *buff;
 	unsigned int buff_len;
 
+
 	buff = NULL;
 	buff_len = 0;
 
@@ -739,17 +714,7 @@ sql_status_select_host (lwc_LL *host_ids, unsigned long long int *host_id_out,
 	}
 
 	/* Convert the list in a string suitable for the SQL request */
-	if (hierarchy_list_to_str (host_ids, &s) != 0) {
-		if (err_msg != NULL) {
-			s = _("Memory allocation error");
-			*err_msg = (char *) malloc (schedwi_strlen (s) + 1);
-			if (*err_msg != NULL) {
-				strcpy (*err_msg, s);
-			}
-		}
-		return -1;
-	}
-
+	s = hierarchy_list_to_str (host_ids);
 	ret = sql_select (	NULL, NULL, err_msg, NULL, &rows,
 				SQLSTATUS_HOST_COUNT_RUNNING,
 				SQL_STRING_NON_ESCAPE, s,
@@ -764,20 +729,8 @@ sql_status_select_host (lwc_LL *host_ids, unsigned long long int *host_id_out,
 	 * used host (so later on, these hosts will be ping in the order to
 	 * find the least used working host)
 	 */
-	a = (unsigned long long int *) malloc ((num_ids + 1)
+	a = (unsigned long long int *) xmalloc ((num_ids + 1)
 					* sizeof (unsigned long long int));
-	if (a == NULL) {
-		lwc_delLL (rows, (void (*)(const void *)) sql_free_row);
-		if (err_msg != NULL) {
-			s = _("Memory allocation error");
-			*err_msg = (char *) malloc (schedwi_strlen (s) + 1);
-			if (*err_msg != NULL) {
-				strcpy (*err_msg, s);
-			}
-		}
-		return -1;
-	}
-
 	i = 0;
 	/*
 	 * First, store all the IDs not in the returned SQL query (hosts
@@ -830,22 +783,19 @@ sql_status_select_host (lwc_LL *host_ids, unsigned long long int *host_id_out,
 }
 
 
-/*
+/**
  * Change the host ID associated with the given job/jobset.
  *
- * @param workload_date:
- * 			The workload date of the job/jobset.
- * @param job_id:
- * 			The database ID of the job or jobset.
- * @param host_id:
- * 			The new host ID.
- * @param error_func:
- * 			Caller error function which is called when an SQL
- * 			error occurs.  May be NULL.
- * @param user_data_error_func:
- * 			Caller data which is passed to the error_func as the
- * 			first parameter.
- * @return:
+ * @param[in] workload_date Workload date of the job/jobset (YYYYMMDD).
+ * @param[in] job_id The database ID of the job or jobset.
+ * @param[in] host_id The new host ID.
+ * @param[in] error_func Error function to call in case of error. This function
+ *                       is called with user_data_error_func as its first
+ *                       parameter and the error message as the second
+ *                       parameter.  error_func can be NULL.
+ * @param[in] user_data_error_func User provided parameter to pass to the
+ *                                 error_func function in vase of error.
+ * @return
  *     0 --> Success
  *    -1 --> Memory allocation error (if error_func() is not NULL, it is called
  *           with user_data_error_func as its first parameter and the error
@@ -868,8 +818,8 @@ sql_status_update_host_id (	int workload_date,
 	ret = sql_non_select (  NULL, NULL, &err_msg, NULL, NULL, NULL,
 				SQLSTATUS_UPDATE_HOST,
 				SQL_INT, (long int)host_id,
-				SQL_INT, (long int)workload_date,
 				SQL_INT, (long int)job_id,
+				SQL_INT, (long int)workload_date,
 				SQL_END);
 	if (ret != 0) {
 		if (error_func != NULL) {
@@ -883,4 +833,116 @@ sql_status_update_host_id (	int workload_date,
 	return 0;
 }
 
+
+/**
+ * Check if the given workload is already in the job_status table.
+ *
+ * @param[in] workload_date Workload date of the job/jobset (YYYYMMDD).
+ * @param[in] error_func Error function to call in case of error. This function
+ *                       is called with user_data_error_func as its first
+ *                       parameter and the error message as the second
+ *                       parameter.  error_func can be NULL.
+ * @param[in] user_data_error_func User provided parameter to pass to the
+ *                                 error_func function in vase of error.
+ * @return
+ *     0 --> The given workload is not in the job_status table.
+ *     1 --> The workload is in the job_status table.
+ *    -1 --> Memory allocation error (if error_func() is not NULL, it is called
+ *           with user_data_error_func as its first parameter and the error
+ *           message as the second parameter)
+ *    -2 --> SQL error (if error_func() is not NULL, it is called with
+ *           user_data_error_func as its first parameter and the error message
+ *           as the second parameter)
+ */
+int
+sql_status_check_workload (	int workload_date,
+				void (*error_func)(void *, const char *, int),
+				void *user_data_error_func)
+{
+	char *err_msg = NULL;
+	lwc_LL *rows;
+	int ret;
+
+
+	ret = sql_select (	NULL, NULL, &err_msg, NULL, &rows,
+				SQLSTATUS_IS_JOB_PRESENT,
+				SQL_INT, (long int)ROOT_JOBSET,
+				SQL_INT, (long int)workload_date,
+				SQL_END);
+
+	if (ret != 0) {
+		if (error_func != NULL) {
+			error_func (user_data_error_func, err_msg, ret);
+		}
+		if (err_msg != NULL) {
+			free (err_msg);
+		}
+		return ret;
+	}
+
+	if (lwc_getNumNode (rows) == 0) {
+		lwc_delLL (rows, (void (*)(const void *))sql_free_row);
+		return 0;
+	}
+	lwc_delLL (rows, (void (*)(const void *))sql_free_row);
+	return 1;
+}
+
+
+/**
+ * Return the number of jobs/jobsets waiting on links not resolved.
+ *
+ * @param[in] workload_date The workload date.
+ * @param[in] error_func Error function to call in case of error. This function
+ *                       is called with user_data_error_func as its first
+ *                       parameter and the error message as the second
+ *                       parameter.  error_func can be NULL.
+ * @param[in] user_data_error_func User provided parameter to pass to the
+ *                                 error_func function in case of error.
+ * @return
+ *     The number of jobs/jobsets waiting on links.
+ *    -1 --> Memory allocation error (if error_func() is not NULL, it is called
+ *           with user_data_error_func as its first parameter and the error
+ *           message as the second parameter)
+ *    -2 --> SQL error (if error_func() is not NULL, it is called with
+ *           user_data_error_func as its first parameter and the error message
+ *           as the second parameter)
+ */
+int
+sql_status_num_waiting_links (	int workload_date,
+				void (*error_func)(void *, const char *, int),
+				void *user_data_error_func)
+{
+	char *err_msg = NULL;
+	lwc_LL *rows;
+	int ret;
+	row_item_t *row;
+
+
+	ret = sql_select (	NULL, NULL, &err_msg, NULL, &rows,
+				SQLSTATUS_NUM_WAITING_LINKS,
+				SQL_INT, (long int)workload_date,
+				SQL_INT, JOB_STATUS_STATE_WAITING,
+				SQL_INT, WAIT_REASON_MASK_LINKS,
+				SQL_END);
+	if (ret != 0) {
+		if (error_func != NULL) {
+			error_func (user_data_error_func, err_msg, ret);
+		}
+		if (err_msg != NULL) {
+			free (err_msg);
+		}
+		return ret;
+	}
+
+	row = (row_item_t *) lwc_delStartLL (rows);
+	lwc_delLL (rows, (void (*)(const void *)) sql_free_row);
+	if (row == NULL) {
+		return 0;
+	}
+	ret = (int) sql_row_item2ll (&(row[0]));
+	sql_free_row (row);
+	return ret;
+}
+
 /*-----------------============== End Of File ==============-----------------*/
