@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2013 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -23,6 +23,11 @@
 #define _SQL_STATUS_H
 
 #include <schedwi.h>
+
+#if HAVE_TIME_H
+#include <time.h>
+#endif
+
 #include <lwc_linkedlist.h>
 #include <sql_common.h>
 
@@ -38,13 +43,14 @@
 extern "C" {
 #endif
 
-extern int sql_status_workload_list OF((lwc_LL **rows,
+extern int sql_status_updated_workload_list OF((lwc_LL **rows,
+			time_t time_status_set,
 			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
 extern int sql_status_get OF((int workload_date,
 			unsigned long long int job_id,
 			int *status,
-			long int *start_time,
+			time_t *time_status_set,
 			int *retry_num,
 			int *wait_reason,
 			char **message,
@@ -57,20 +63,15 @@ extern int sql_status_update_wait_reason OF((int workload_date,
 			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
 extern int sql_status_set OF((int workload_date,
-			const char *job_id,
+			unsigned long long int job_id,
 			int status,
-			unsigned int start_time,
+			time_t time_status_set,
 			int retry_num,
 			int wait_reason,
 			const char *error_message,
 			long int duration,
 			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
-extern int sql_status_adjust_start_time OF((int workload_date,
-			unsigned long long int job_id,
-			unsigned int start_time,
-			void (*error_func)(void *, const char *, int),
-			void *user_data_error_func));
 extern int sql_status_delete OF((int workload_date,
 			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
@@ -90,6 +91,12 @@ extern int sql_status_update_host_id OF((int workload_date,
 			unsigned long long int host_id,
 			void (*error_func)(void *, const char *, int),
 			void *user_data_error_func));
+extern int sql_status_check_workload OF((int workload_date,
+			void (*error_func)(void *, const char *, int),
+			void *user_data_error_func));
+extern int sql_status_num_waiting_links OF((int workload_date,
+			void (*error_func)(void *, const char *, int),
+			void *user_data_error_func));
 
 #ifdef __cplusplus
 }
