@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2013 Herve Quatremain
+   Copyright (C) 2007-2014 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -17,7 +17,9 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-/* startjob.c -- Start a job */
+/* @file startjob.c
+ * Start a job.
+ */
 
 #include <schedwi.h>
 
@@ -33,13 +35,6 @@
 #endif
 #endif
 
-#if HAVE_ERRNO_H
-#include <errno.h>
-#endif
-#ifndef errno
-extern int errno;
-#endif
-
 #if HAVE_ASSERT_H
 #include <assert.h>
 #endif
@@ -47,12 +42,13 @@ extern int errno;
 #include <utils.h>
 #include <lwc_log.h>
 #include <net_utils.h>
+#include <sql_hosts.h>
 #include <sql_status.h>
 #include <sql_common.h>
 #include <sql_hierarchy.h>
-#include <sql_hosts.h>
-#include <request.h>
-#include <lib_functions.h>
+#include <sql_get_environment.h>
+#include <startjob_json_builder.h>
+#include <xmem.h>
 #include <startjob.h>
 
 /*
@@ -89,22 +85,60 @@ sql_status_update_host_id_error_logger (void *data, const char *msg,
 }
 
 
+/*
+ * Error callback function for the sql_get_environment*() functions
+ */
+static void
+sql_get_environment_error_logger (	void *data, const char *msg,
+					int err_code)
+{
+	if (msg != NULL) {
+		lwc_writeLog (LOG_ERR, msg);
+	}
+	else {
+		lwc_writeLog (LOG_ERR,
+_("Database error while trying to retrieve a job environment variables"));
+	}
+}
+
+
+/*
+ * Callback for the sql_get_environment() function which retrieves the command
+ * environment variables
+ *
+ * Return: Always 0
+ */
+static int
+environment_callback (	void *obj, unsigned int pos,
+			const char *name, const char *value)
+{
+	startjob_json_builder_ptr json_obj = (startjob_json_builder_ptr) obj;
+
+
+#if HAVE_ASSERT_H
+	assert (json_obj != NULL && name != NULL && value != NULL);
+#endif
+
+	startjob_json_builder_add_environment (json_obj, name, value);
+	return 0;
+}
+
+
 /*
  * Callback for the SQL function which retrieves the command arguments
  *
  * Return:
  *   0 --> No error
- *  -1 --> Memory allocation error (lwc_writeLog() is used to log an
- *         error message)
  *   1 --> Stop the sql function.  No arguments for this job
  */
 static int
 argument_callback (void *obj, row_item_t *row)
 {
-	startjob_request_ptr request = (startjob_request_ptr) obj;
+	startjob_json_builder_ptr json_obj = (startjob_json_builder_ptr) obj;
+
 
 #if HAVE_ASSERT_H
-	assert (request != NULL);
+	assert (json_obj != NULL);
 #endif
 
 	if (row == NULL) {
@@ -120,9 +154,10 @@ argument_callback (void *obj, row_item_t *row)
 		/* No argument for the command */
 		return 1;
 	}
-	return startjob_request_add_argument (request,
-					"1", 1, /* Ignored */
-					row[1].value_string, row[1].len);
+	startjob_json_builder_add_argument (	json_obj,
+						row[1].value_string,
+						row[1].len);
+	return 0;
 }
 
 
@@ -146,41 +181,33 @@ argument_callback (void *obj, row_item_t *row)
  *         out_message must be freed by the caller by free()
  */
 int
-startjob (	int workload_date, unsigned long long int job_id,
+startjob (	lwc_LL *hierarchy_list, const char *path,
+		int workload_date, unsigned long long int job_id,
 		char **out_message)
 {
-	lwc_LL *hierarchy_list;
+	startjob_json_builder_ptr json_obj;
 	row_item_t value;
 	unsigned long long int host_id;
+	lwc_LL *host_ids;
 	char *s, *err_msg = NULL;
 	int ret;
 	char detach;
-	startjob_request_ptr request;
 	row_item_t *host_details;
 	schedwi_BIO *b;
+	unsigned int last_pos;
 
-	if (request_job_init (	workload_date, job_id,
-				&host_id, &request, &hierarchy_list) != 0)
-	{
-		if (out_message != NULL) {
-			err_msg =
-			_("Server error: cannot retrieve job parameters");
-			*out_message = (char *)malloc (schedwi_strlen (err_msg)
-								+ 1);
-			if (*out_message != NULL) {
-				strcpy (*out_message, err_msg);
-			}
-		}
-		return -1;
-	}
 
-	/* Get the command */
-	if (get_job_parameter (	workload_date, hierarchy_list,
-				"job_command_s", "command",
-				&value, &err_msg) != 0)
+	/*
+	 * Find a host to run the job
+	 */
+
+	/*
+ 	 * First, get the list of host IDs (from the clusters and hosts
+	 * tables) associated with the job.
+	 */
+	if (get_job_hosts (	workload_date, hierarchy_list,
+				&host_ids, &err_msg) != 0)
 	{
-		lwc_delLL (hierarchy_list, (void (*)(const void *))free);
-		startjob_request_destroy (request);
 		if (err_msg != NULL) {
 			lwc_writeLog (LOG_CRIT, err_msg);
 			if (out_message != NULL) {
@@ -191,17 +218,122 @@ startjob (	int workload_date, unsigned long long int job_id,
 			}
 		}
 		else {
-			lwc_writeLog (LOG_CRIT,
-				_("Job %lld: cannot retrieve the command"),
-				job_id);
+			lwc_writeLog (	LOG_CRIT,
+	_("Workload %d: %s (id %lld): cannot retrieve the agent host details"),
+					workload_date, path, job_id);
+			if (out_message != NULL) {
+				err_msg =
+		_("Server error: cannot retrieve the agent host details");
+				*out_message = xstrdup (err_msg);
+			}
+		}
+		return -1;
+	}
+	if (host_ids == NULL) {
+		lwc_writeLog (	LOG_CRIT,
+_("Workload %d: %s (id %lld): agent host name missing in the database"),
+				workload_date, path, job_id);
+		if (out_message != NULL) {
+			err_msg =
+		_("Server error: cannot retrieve the agent host details");
+			*out_message = xstrdup (err_msg);
+		}
+		return -1;
+	}
+
+	/* Then, select the host which is the least busy */
+	if (sql_status_select_host (host_ids, &host_id, &err_msg) != 0) {
+		lwc_delLL (host_ids, (void (*)(const void *))free);
+		if (err_msg != NULL) {
+			lwc_writeLog (LOG_CRIT, err_msg);
+			if (out_message != NULL) {
+				*out_message = err_msg;
+			}
+			else {
+				free (err_msg);
+			}
+		}
+		else {
+			lwc_writeLog (	LOG_CRIT,
+	_("Workload %d: %s (id %lld): cannot retrieve the agent host details"),
+					workload_date, path, job_id);
+			if (out_message != NULL) {
+				err_msg =
+		_("Server error: cannot retrieve the agent host details");
+				*out_message = xstrdup (err_msg);
+			}
+		}
+		return -1;
+	}
+	lwc_delLL (host_ids, (void (*)(const void *))free);
+
+
+	/*
+	 * Create and fill the startjob_json_builder object
+	 */
+
+	json_obj = startjob_json_builder_new ();
+	startjob_json_builder_add_jobid (json_obj, workload_date, job_id);
+	startjob_json_builder_add_path (json_obj, path, strlen(path));
+
+	/* Get the host environment variables */
+	if (sql_get_environment_host (	workload_date,
+					host_id,
+					environment_callback,
+					json_obj,
+					&last_pos,
+					sql_get_environment_error_logger,
+					NULL) != 0)
+	{
+		startjob_json_builder_destroy (json_obj);
+		if (out_message != NULL) {
+			err_msg =
+	_("Server error: cannot retrieve the host environment variables");
+			*out_message = xstrdup (err_msg);
+		}
+		return -1;
+	}
+
+	/* Get the job environment variables */
+	if (sql_get_environment (	workload_date, hierarchy_list,
+					last_pos,
+					environment_callback,
+					json_obj,
+					sql_get_environment_error_logger,
+					NULL) != 0)
+	{
+		startjob_json_builder_destroy (json_obj);
+		if (out_message != NULL) {
+			err_msg =
+	_("Server error: cannot retrieve the job environment variables");
+			*out_message = xstrdup (err_msg);
+		}
+		return -1;
+	}
+
+	/* Get the command */
+	if (get_job_parameter (	workload_date, hierarchy_list,
+				"job_command_s", "command",
+				&value, &err_msg) != 0)
+	{
+		startjob_json_builder_destroy (json_obj);
+		if (err_msg != NULL) {
+			lwc_writeLog (LOG_CRIT, err_msg);
+			if (out_message != NULL) {
+				*out_message = err_msg;
+			}
+			else {
+				free (err_msg);
+			}
+		}
+		else {
+			lwc_writeLog (	LOG_CRIT,
+		_("Workload %d: %s (id %lld): cannot retrieve the command"),
+					workload_date, path, job_id);
 			if (out_message != NULL) {
 				err_msg =
 				_("Server error: cannot retrieve job command");
-				*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-				if (*out_message != NULL) {
-					strcpy (*out_message, err_msg);
-				}
+				*out_message = xstrdup (err_msg);
 			}
 		}
 		return -1;
@@ -213,25 +345,9 @@ startjob (	int workload_date, unsigned long long int job_id,
 		&& (	   value.value_string[0] != '-'
 			|| value.value_string[1] != '\0'))
 	{
-		if (startjob_request_add_command (request,
-						value.value_string,
-						value.len) != 0)
-		{
-			free (value.value_string);
-			lwc_delLL (	hierarchy_list,
-					(void (*)(const void *))free);
-			startjob_request_destroy (request);
-			if (out_message != NULL) {
-				err_msg =
-				_("Server error: cannot retrieve job command");
-				*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-				if (*out_message != NULL) {
-					strcpy (*out_message, err_msg);
-				}
-			}
-			return -1;
-		}
+		startjob_json_builder_add_command (	json_obj,
+							value.value_string,
+							value.len);
 		free (value.value_string);
 	}
 	else {
@@ -239,8 +355,7 @@ startjob (	int workload_date, unsigned long long int job_id,
 		if (value.type != RES_END && value.value_string != NULL) {
 			free (value.value_string);
 		}
-		lwc_delLL (hierarchy_list, (void (*)(const void *))free);
-		startjob_request_destroy (request);
+		startjob_json_builder_destroy (json_obj);
 		return 2;
 	}
 
@@ -249,8 +364,7 @@ startjob (	int workload_date, unsigned long long int job_id,
 				"job_username_s", "username",
 				&value, &err_msg) != 0)
 	{
-		lwc_delLL (hierarchy_list, (void (*)(const void *))free);
-		startjob_request_destroy (request);
+		startjob_json_builder_destroy (json_obj);
 		if (err_msg != NULL) {
 			lwc_writeLog (LOG_CRIT, err_msg);
 			if (out_message != NULL) {
@@ -261,62 +375,35 @@ startjob (	int workload_date, unsigned long long int job_id,
 			}
 		}
 		else {
-			lwc_writeLog (LOG_CRIT,
-				_("Job %lld: cannot retrieve the username"),
-				job_id);
+			lwc_writeLog (	LOG_CRIT,
+		_("Workload %d: %s (id %lld): cannot retrieve the username"),
+					workload_date, path, job_id);
 			if (out_message != NULL) {
 				err_msg =
 			_("Server error: cannot retrieve the username");
-				*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-				if (*out_message != NULL) {
-					strcpy (*out_message, err_msg);
-				}
+				*out_message = xstrdup (err_msg);
 			}
 		}
 		return -1;
 	}
 
 	if (value.type != RES_END) {
-		if (startjob_request_add_username (request,
-						value.value_string,
-						value.len) != 0)
-		{
-			if (value.value_string != NULL) {
-				free (value.value_string);
-			}
-			lwc_delLL (	hierarchy_list,
-					(void (*)(const void *))free);
-			startjob_request_destroy (request);
-			if (out_message != NULL) {
-				err_msg =
-			_("Server error: cannot retrieve the username");
-				*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-				if (*out_message != NULL) {
-					strcpy (*out_message, err_msg);
-				}
-			}
-			return -1;
-		}
+		startjob_json_builder_add_username (	json_obj,
+							value.value_string,
+							value.len);
 		if (value.value_string != NULL) {
 			free (value.value_string);
 		}
 	}
 	else {
-		lwc_delLL (hierarchy_list, (void (*)(const void *))free);
-		startjob_request_destroy (request);
+		startjob_json_builder_destroy (json_obj);
 		lwc_writeLog (	LOG_CRIT,
-				_("Job %lld: cannot retrieve the username"),
-				job_id);
+		_("Workload %d: %s (id %lld): cannot retrieve the username"),
+				workload_date, path, job_id);
 		if (out_message != NULL) {
 			err_msg =
 			_("Server error: cannot retrieve the username");
-			*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-			if (*out_message != NULL) {
-				strcpy (*out_message, err_msg);
-			}
+			*out_message = xstrdup (err_msg);
 		}
 		return -1;
 	}
@@ -326,8 +413,7 @@ startjob (	int workload_date, unsigned long long int job_id,
 				"job_file_out_s", "file_out",
 				&value, &err_msg) != 0)
 	{
-		lwc_delLL (hierarchy_list, (void (*)(const void *))free);
-		startjob_request_destroy (request);
+		startjob_json_builder_destroy (json_obj);
 		if (err_msg != NULL) {
 			lwc_writeLog (LOG_CRIT, err_msg);
 			if (out_message != NULL) {
@@ -338,44 +424,22 @@ startjob (	int workload_date, unsigned long long int job_id,
 			}
 		}
 		else {
-			lwc_writeLog (LOG_CRIT,
-				_("Job %lld: cannot retrieve the output file"),
-				job_id);
+			lwc_writeLog (	LOG_CRIT,
+	_("Workload %d: %s (id %lld): cannot retrieve the output file"),
+					workload_date, path, job_id);
 			if (out_message != NULL) {
 				err_msg =
 			_("Server error: cannot retrieve the output file");
-				*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-				if (*out_message != NULL) {
-					strcpy (*out_message, err_msg);
-				}
+				*out_message = xstrdup (err_msg);
 			}
 		}
 		return -1;
 	}
 
 	if (value.type != RES_END) {
-		if (startjob_request_add_fileout (request,
-						value.value_string,
-						value.len) != 0)
-		{
-			if (value.value_string != NULL) {
-				free (value.value_string);
-			}
-			lwc_delLL (	hierarchy_list,
-					(void (*)(const void *))free);
-			startjob_request_destroy (request);
-			if (out_message != NULL) {
-				err_msg =
-			_("Server error: cannot retrieve the output file");
-				*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-				if (*out_message != NULL) {
-					strcpy (*out_message, err_msg);
-				}
-			}
-			return -1;
-		}
+		startjob_json_builder_add_fileout (	json_obj,
+							value.value_string,
+							value.len);
 		if (value.value_string != NULL) {
 			free (value.value_string);
 		}
@@ -386,8 +450,7 @@ startjob (	int workload_date, unsigned long long int job_id,
 				"job_file_err_s", "file_err",
 				&value, &err_msg) != 0)
 	{
-		lwc_delLL (hierarchy_list, (void (*)(const void *))free);
-		startjob_request_destroy (request);
+		startjob_json_builder_destroy (json_obj);
 		if (err_msg != NULL) {
 			lwc_writeLog (LOG_CRIT, err_msg);
 			if (out_message != NULL) {
@@ -398,44 +461,22 @@ startjob (	int workload_date, unsigned long long int job_id,
 			}
 		}
 		else {
-			lwc_writeLog (LOG_CRIT,
-				_("Job %lld: cannot retrieve the error file"),
-				job_id);
+			lwc_writeLog (	LOG_CRIT,
+		_("Workload %d: %s (id %lld): cannot retrieve the error file"),
+					workload_date, path, job_id);
 			if (out_message != NULL) {
 				err_msg =
 			_("Server error: cannot retrieve the error file");
-				*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-				if (*out_message != NULL) {
-					strcpy (*out_message, err_msg);
-				}
+				*out_message = xstrdup (err_msg);
 			}
 		}
 		return -1;
 	}
 
 	if (value.type != RES_END) {
-		if (startjob_request_add_filerr (request,
-						value.value_string,
-						value.len) != 0)
-		{
-			if (value.value_string != NULL) {
-				free (value.value_string);
-			}
-			lwc_delLL (	hierarchy_list,
-					(void (*)(const void *))free);
-			startjob_request_destroy (request);
-			if (out_message != NULL) {
-				err_msg =
-			_("Server error: cannot retrieve the error file");
-				*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-				if (*out_message != NULL) {
-					strcpy (*out_message, err_msg);
-				}
-			}
-			return -1;
-		}
+		startjob_json_builder_add_filerr (	json_obj,
+							value.value_string,
+							value.len);
 		if (value.value_string != NULL) {
 			free (value.value_string);
 		}
@@ -446,8 +487,7 @@ startjob (	int workload_date, unsigned long long int job_id,
 				"job_control_group_s", "control_group",
 				&value, &err_msg) != 0)
 	{
-		lwc_delLL (hierarchy_list, (void (*)(const void *))free);
-		startjob_request_destroy (request);
+		startjob_json_builder_destroy (json_obj);
 		if (err_msg != NULL) {
 			lwc_writeLog (LOG_CRIT, err_msg);
 			if (out_message != NULL) {
@@ -458,44 +498,22 @@ startjob (	int workload_date, unsigned long long int job_id,
 			}
 		}
 		else {
-			lwc_writeLog (LOG_CRIT,
-			_("Job %lld: cannot retrieve the control group"),
-				job_id);
+			lwc_writeLog (	LOG_CRIT,
+	_("Workload %d: %s (id %lld): cannot retrieve the control group"),
+					workload_date, path, job_id);
 			if (out_message != NULL) {
 				err_msg =
 			_("Server error: cannot retrieve the control group");
-				*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-				if (*out_message != NULL) {
-					strcpy (*out_message, err_msg);
-				}
+				*out_message = xstrdup (err_msg);
 			}
 		}
 		return -1;
 	}
 
 	if (value.type != RES_END) {
-		if (startjob_request_add_cgroup (request,
-						value.value_string,
-						value.len) != 0)
-		{
-			if (value.value_string != NULL) {
-				free (value.value_string);
-			}
-			lwc_delLL (	hierarchy_list,
-					(void (*)(const void *))free);
-			startjob_request_destroy (request);
-			if (out_message != NULL) {
-				err_msg =
-			_("Server error: cannot retrieve the control group");
-				*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-				if (*out_message != NULL) {
-					strcpy (*out_message, err_msg);
-				}
-			}
-			return -1;
-		}
+		startjob_json_builder_add_cgroup (	json_obj,
+							value.value_string,
+							value.len);
 		if (value.value_string != NULL) {
 			free (value.value_string);
 		}
@@ -506,8 +524,7 @@ startjob (	int workload_date, unsigned long long int job_id,
 				"job_loadenv_s", "loadenv",
 				&value, &err_msg) != 0)
 	{
-		lwc_delLL (hierarchy_list, (void (*)(const void *))free);
-		startjob_request_destroy (request);
+		startjob_json_builder_destroy (json_obj);
 		if (err_msg != NULL) {
 			lwc_writeLog (LOG_CRIT, err_msg);
 			if (out_message != NULL) {
@@ -518,17 +535,13 @@ startjob (	int workload_date, unsigned long long int job_id,
 			}
 		}
 		else {
-			lwc_writeLog (LOG_CRIT,
-	_("Job %lld: cannot retrieve the `load user environment' flag"),
-				job_id);
+			lwc_writeLog (	LOG_CRIT,
+_("Workload %d: %s (id %lld): cannot retrieve the `load user env' flag"),
+					workload_date, path, job_id);
 			if (out_message != NULL) {
 				err_msg =
-	_("Server error: cannot retrieve the `load user environment' flag");
-				*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-				if (*out_message != NULL) {
-					strcpy (*out_message, err_msg);
-				}
+	_("Server error: cannot retrieve the `load user env' flag");
+				*out_message = xstrdup (err_msg);
 			}
 		}
 		return -1;
@@ -536,21 +549,7 @@ startjob (	int workload_date, unsigned long long int job_id,
 
 	if (value.type != RES_END) {
 		s = (sql_row_item2ll(&value) == 0) ? "0" : "1";
-		if (startjob_request_add_loadenv (request, s, 1) != 0) {
-			lwc_delLL (	hierarchy_list,
-					(void (*)(const void *))free);
-			startjob_request_destroy (request);
-			if (out_message != NULL) {
-				err_msg =
-	_("Server error: cannot retrieve the `load user environment' flag");
-				*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-				if (*out_message != NULL) {
-					strcpy (*out_message, err_msg);
-				}
-			}
-			return -1;
-		}
+		startjob_json_builder_add_loadenv (json_obj, s, 1);
 	}
 
 	/* Get the detach mode flag */
@@ -558,8 +557,7 @@ startjob (	int workload_date, unsigned long long int job_id,
 				"job_detach_s", "detach",
 				&value, &err_msg) != 0)
 	{
-		lwc_delLL (hierarchy_list, (void (*)(const void *))free);
-		startjob_request_destroy (request);
+		startjob_json_builder_destroy (json_obj);
 		if (err_msg != NULL) {
 			lwc_writeLog (LOG_CRIT, err_msg);
 			if (out_message != NULL) {
@@ -570,17 +568,13 @@ startjob (	int workload_date, unsigned long long int job_id,
 			}
 		}
 		else {
-			lwc_writeLog (LOG_CRIT,
-			_("Job %lld: cannot retrieve the `detach mode' flag"),
-				job_id);
+			lwc_writeLog (	LOG_CRIT,
+	_("Workload %d: %s (id %lld): cannot retrieve the `detach mode' flag"),
+					workload_date, path, job_id);
 			if (out_message != NULL) {
 				err_msg =
 		_("Server error: cannot retrieve the `detach mode' flag");
-				*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-				if (*out_message != NULL) {
-					strcpy (*out_message, err_msg);
-				}
+				*out_message = xstrdup (err_msg);
 			}
 		}
 		return -1;
@@ -595,32 +589,16 @@ startjob (	int workload_date, unsigned long long int job_id,
 			s = "1";
 			detach = 1;
 		}
-		s = (sql_row_item2ll(&value) == 0) ? "0" : "1";
-		if (startjob_request_add_detach (request, s, 1) != 0) {
-			lwc_delLL (	hierarchy_list,
-					(void (*)(const void *))free);
-			startjob_request_destroy (request);
-			if (out_message != NULL) {
-				err_msg =
-			_("Server error: cannot retrieve the `detach' flag");
-				*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-				if (*out_message != NULL) {
-					strcpy (*out_message, err_msg);
-				}
-			}
-			return -1;
-		}
+		startjob_json_builder_add_detach (json_obj, s, 1);
 	}
 
 	/* Get the command arguments */
 	ret = get_job_parameters_multi (workload_date, hierarchy_list,
 				"job_arguments_s", "position,argument",
 				"position",
-				argument_callback, request, &err_msg);
+				argument_callback, json_obj, &err_msg);
 	if (ret != 0 && ret != 2) {
-		lwc_delLL (hierarchy_list, (void (*)(const void *))free);
-		startjob_request_destroy (request);
+		startjob_json_builder_destroy (json_obj);
 		if (err_msg != NULL) {
 			lwc_writeLog (LOG_CRIT, err_msg);
 			if (out_message != NULL) {
@@ -631,39 +609,29 @@ startjob (	int workload_date, unsigned long long int job_id,
 			}
 		}
 		else {
-			lwc_writeLog (LOG_CRIT,
-			_("Job %lld: cannot retrieve the command arguments"),
-				job_id);
+			lwc_writeLog (	LOG_CRIT,
+	_("Workload %d: %s (id %lld): cannot retrieve the command arguments"),
+					workload_date, path, job_id);
 			if (out_message != NULL) {
 				err_msg =
 		_("Server error: cannot retrieve the command arguments");
-				*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-				if (*out_message != NULL) {
-					strcpy (*out_message, err_msg);
-				}
+				*out_message = xstrdup (err_msg);
 			}
 		}
 		return -1;
 	}
 
-	lwc_delLL (hierarchy_list, (void (*)(const void *))free);
-
-	/* Get the host details */
-	ret= sql_host_get_by_id (	host_id,
-					&host_details,
-					sql_host_get_main_row_error_logger,
-					NULL);
-	if (ret != 0) {
-		startjob_request_destroy (request);
+	/* Get the details (IP, port, ...) for the agent host */
+	if (sql_host_get_by_id (host_id,
+				&host_details,
+				sql_host_get_main_row_error_logger,
+				NULL) != 0)
+	{
+		startjob_json_builder_destroy (json_obj);
 		if (out_message != NULL) {
 			err_msg =
 		_("Server error: cannot retrieve the remote agent details");
-			*out_message = (char *)malloc (
-					schedwi_strlen (err_msg) + 1);
-			if (*out_message != NULL) {
-				strcpy (*out_message, err_msg);
-			}
+			*out_message = xstrdup (err_msg);
 		}
 		return -1;
 	}
@@ -684,35 +652,27 @@ startjob (	int workload_date, unsigned long long int job_id,
 			(unsigned int)(host_details[4].len));
 	sql_free_row (host_details);
 	if (b == NULL) {
-		startjob_request_destroy (request);
+		startjob_json_builder_destroy (json_obj);
 		if (out_message != NULL) {
 			err_msg =
 _("Server error: cannot establish the connection with the remote agent");
-			*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-			if (*out_message != NULL) {
-				strcpy (*out_message, err_msg);
-			}
+			*out_message = xstrdup (err_msg);
 		}
 		return -1;
 	}
 
 	/* Send the request */
-	if (net_write_request (request, b, "runjob") != 0) {
+	if (net_write_request (json_obj, b, "runjob") != 0) {
 		net_close (b);
-		startjob_request_destroy (request);
+		startjob_json_builder_destroy (json_obj);
 		if (out_message != NULL) {
 			err_msg =
 	_("Server error: cannot send the request to the remote agent");
-			*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-			if (*out_message != NULL) {
-				strcpy (*out_message, err_msg);
-			}
+			*out_message = xstrdup (err_msg);
 		}
 		return -1;
 	}
-	startjob_request_destroy (request);
+	startjob_json_builder_destroy (json_obj);
 
 	/* Read the result */
 	ret = net_read_result (b, out_message);
