@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2014 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -17,19 +17,24 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-/* startjob.h -- Start a job */
+/* @file startjob.h
+ * Start a job.
+ */
 
 #ifndef _STARTJOB_H
 #define _STARTJOB_H
 
 #include <schedwi.h>
+#include <lwc_linkedlist.h>
 
 /* Allow the use in C++ code.  */
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-extern int startjob OF((int workload_date,
+extern int startjob OF((lwc_LL *hierarchy_list,
+			const char *path,
+			int workload_date,
 			unsigned long long int job_id,
 			char **out_message));
 
