@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2014 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -23,13 +23,15 @@
 #define _STOPJOB_H
 
 #include <schedwi.h>
+#include <lwc_linkedlist.h>
 
 /* Allow the use in C++ code.  */
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-extern int stopjob OF((int workload_date, unsigned long long int job_id,
+extern int stopjob OF((	lwc_LL *hierarchy_list, const char *path,
+			int workload_date, unsigned long long int job_id,
 			char **out_message));
 
 #ifdef __cplusplus
