@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2013 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -33,26 +33,37 @@
 #endif
 #endif
 
-#if HAVE_ERRNO_H
-#include <errno.h>
-#endif
-#ifndef errno
-extern int errno;
-#endif
-
 #if HAVE_ASSERT_H
 #include <assert.h>
 #endif
 
-#include <utils.h>
 #include <lwc_log.h>
-#include <net_utils.h>
 #include <sql_common.h>
 #include <sql_hosts.h>
-#include <request.h>
-#include <lib_functions.h>
+#include <sql_get_environment.h>
+#include <net_utils.h>
+#include <startjob_json_builder.h>
+#include <xmem.h>
 #include <testfile.h>
 
+
+/*
+ * Error callback function for the sql_get_environment*() functions
+ */
+static void
+sql_get_environment_error_logger (	void *data, const char *msg,
+					int err_code)
+{
+	if (msg != NULL) {
+		lwc_writeLog (LOG_ERR, msg);
+	}
+	else {
+		lwc_writeLog (LOG_ERR,
+_("Database error while trying to retrieve a job environment variables"));
+	}
+}
+
+
 /*
  * Error callback function for the sql_host_get_by_id() function
  */
@@ -70,6 +81,28 @@ sql_host_get_main_row_error_logger (	void *data, const char *msg,
 }
 
 
+/*
+ * Callback for the sql_get_environment() function which retrieves the command
+ * environment variables
+ *
+ * Return: Always 0
+ */
+static int
+environment_callback (	void *obj, unsigned int pos,
+			const char *name, const char *value)
+{
+	startjob_json_builder_ptr json_obj = (startjob_json_builder_ptr) obj;
+
+
+#if HAVE_ASSERT_H
+	assert (json_obj != NULL && name != NULL && value != NULL);
+#endif
+
+	startjob_json_builder_add_environment (json_obj, name, value);
+	return 0;
+}
+
+
 /*
  * Check the existance of the provided file on the provided host ID
  *
@@ -88,52 +121,76 @@ sql_host_get_main_row_error_logger (	void *data, const char *msg,
  *         out_message must be freed by the caller by free()
  */
 int
-testfile (	int workload_date,
-		unsigned long long int job_id,
-		unsigned long long int host_id,
-		const char *filename,
+testfile (	lwc_LL *hierarchy_list,
+		int workload_date, unsigned long long int job_id,
+		unsigned long long int host_id, const char *filename,
 		char **out_message)
 {
-	startjob_request_ptr request;
+	startjob_json_builder_ptr json_obj;
 	char *err_msg = NULL;
 	row_item_t *host_details;
-	int ret_read, ret;
+	int ret;
 	schedwi_BIO *b;
+	unsigned int last_pos;
+
 
 #if HAVE_ASSERT_H
 	assert (filename != NULL);
 #endif
 
 	/* Build the request */
-	if (request_testfile_init (	workload_date, job_id, host_id,
-					filename, &request) != 0)
+	json_obj = startjob_json_builder_new ();
+	startjob_json_builder_add_jobid (json_obj, workload_date, job_id);
+	startjob_json_builder_add_filename (	json_obj,
+						filename, strlen (filename));
+
+
+	/* Get the host environment variables */
+	if (sql_get_environment_host (	workload_date,
+					host_id,
+					environment_callback,
+					json_obj,
+					&last_pos,
+					sql_get_environment_error_logger,
+					NULL) != 0)
 	{
+		startjob_json_builder_destroy (json_obj);
 		if (out_message != NULL) {
 			err_msg =
-			_("Server error: cannot retrieve job parameters");
-			*out_message = (char *)malloc (schedwi_strlen (err_msg)
-								+ 1);
-			if (*out_message != NULL) {
-				strcpy (*out_message, err_msg);
-			}
+	_("Server error: cannot retrieve the host environment variables");
+			*out_message = xstrdup (err_msg);
 		}
 		return -1;
 	}
 
-	/* Get the host details */
-	ret = sql_host_get_by_id (host_id, &host_details,
-					sql_host_get_main_row_error_logger,
-					NULL);
-	if (ret != 0) {
-		startjob_request_destroy (request);
+	/* Get the job environment variables */
+	if (sql_get_environment (	workload_date, hierarchy_list,
+					last_pos,
+					environment_callback,
+					json_obj,
+					sql_get_environment_error_logger,
+					NULL) != 0)
+	{
+		startjob_json_builder_destroy (json_obj);
+		if (out_message != NULL) {
+			err_msg =
+	_("Server error: cannot retrieve the job environment variables");
+			*out_message = xstrdup (err_msg);
+		}
+		return -1;
+	}
+
+	/* Get the details (IP, port, ...) for the agent host */
+	if (sql_host_get_by_id (host_id,
+				&host_details,
+				sql_host_get_main_row_error_logger,
+				NULL) != 0)
+	{
+		startjob_json_builder_destroy (json_obj);
 		if (out_message != NULL) {
 			err_msg =
 		_("Server error: cannot retrieve the remote agent details");
-			*out_message = (char *)malloc (
-					schedwi_strlen (err_msg) + 1);
-			if (*out_message != NULL) {
-				strcpy (*out_message, err_msg);
-			}
+			*out_message = xstrdup (err_msg);
 		}
 		return -1;
 	}
@@ -146,40 +203,32 @@ testfile (	int workload_date,
 			(unsigned int)(host_details[4].len));
 	sql_free_row (host_details);
 	if (b == NULL) {
-		startjob_request_destroy (request);
+		startjob_json_builder_destroy (json_obj);
 		if (out_message != NULL) {
 			err_msg =
 _("Server error: cannot establish the connection with the remote agent");
-			*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-			if (*out_message != NULL) {
-				strcpy (*out_message, err_msg);
-			}
+			*out_message = xstrdup (err_msg);
 		}
 		return -1;
 	}
 
 	/* Send the request */
-	if (net_write_request (request, b, "testfile") != 0) {
+	if (net_write_request (json_obj, b, "testfile") != 0) {
 		net_close (b);
-		startjob_request_destroy (request);
+		startjob_json_builder_destroy (json_obj);
 		if (out_message != NULL) {
 			err_msg =
 	_("Server error: cannot send the request to the remote agent");
-			*out_message = (char *)malloc (
-						schedwi_strlen (err_msg) + 1);
-			if (*out_message != NULL) {
-				strcpy (*out_message, err_msg);
-			}
+			*out_message = xstrdup (err_msg);
 		}
 		return -1;
 	}
-	startjob_request_destroy (request);
+	startjob_json_builder_destroy (json_obj);
 
 	/* Read the result */
-	ret_read = net_read_result (b, out_message);
+	ret = net_read_result (b, out_message);
 	net_close (b);
-	return ret_read;
+	return ret;
 }
 
 /*-----------------============== End Of File ==============-----------------*/
