@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -23,16 +23,16 @@
 #define _TESTFILE_H
 
 #include <schedwi.h>
+#include <lwc_linkedlist.h>
 
 /* Allow the use in C++ code.  */
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-extern int testfile OF((int workload_date,
-			unsigned long long int job_id,
-			unsigned long long int host_id,
-			const char *filename,
+extern int testfile OF((lwc_LL *hierarchy_list,
+			int workload_date, unsigned long long int job_id,
+			unsigned long long int host_id, const char *filename,
 			char **out_message));
 
 #ifdef __cplusplus
