@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2013 Herve Quatremain
+   Copyright (C) 2007-2014 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -72,10 +72,10 @@
 extern int errno;
 #endif
 
-#include <lib_functions.h>
 #include <utils.h>
+#include <xmem.h>
 
-#if _GNU_SOURCE && !HAVE_CLEARENV
+#if defined(_GNU_SOURCE) && !HAVE_CLEARENV
 extern char **environ;
 #endif
 
@@ -134,7 +134,7 @@ base_name (const char *path)
 #endif
 	prev = 0;
 	s    = path;
-	sep_length = (size_t)schedwi_strlen (DIR_SEP);
+	sep_length = strlen (DIR_SEP);
 	while ((s = strstr (s, DIR_SEP)) != 0) {
 		s += sep_length;
 		prev = s;
@@ -150,10 +150,10 @@ base_name (const char *path)
  * Print copyright and version information to stdout
  */
 void
-version (const char *prog_name)
+version ()
 {
-	printf ("%s (Schedwi) %s\n", prog_name, PACKAGE_VERSION);
-	(void)puts("Copyright (C) 2007-2010 Herve Quatremain");
+	printf ("%s (Schedwi) %s\n", program_invocation_name, PACKAGE_VERSION);
+	(void)puts("Copyright (C) 2007-2015 Herve Quatremain");
 	(void)puts("Schedwi is free software, covered by the GNU");
 	(void)puts("General Public License version 3 or later.");
 	(void)puts("You may redistribute copies of Schedwi under");
@@ -201,9 +201,53 @@ my_unlink (const char *file_name)
 }
 
 
+/*
+ * Close all the opened file with a file descriptor above 2
+ */
+void
+close_opened_files ()
+{
+	static char done = 0;
+	int i;
+
+
+	if (done == 0) {
+		for (i = getdtablesize () - 1; i >= 3; i--) {
+			close (i);
+		}
+		done = 1;
+	}
+}
+
+
+/*
+ * Set the standard file descriptors (0, 1 and 2) to /dev/null
+ */
+void
+reset_standard_fd ()
+{
+	int fd;
+
+
+	close (0);
+	close (1);
+	close (2);
+
+	/*
+	 * Redirect 0 (stdin), 1 (stdout) and 2 (stderr) to /dev/null.  This
+	 * way, if sub-proccesses/modules try to inadvertently read/write to
+	 * this file descriptors it will not mess other ones (pid file,
+	 * socket, database connection, ...)
+	 */
+	fd = open ("/dev/null", O_RDWR); /* `fd' should be 0 */
+	dup2 (fd, 1);
+	dup2 (fd, 2);
+}
+
+
 /*
  * RAZ the process structures:
- *    - Close all open files (except the provided file descriptor)
+ *    - Close all open files and set the default file descriptors to /dev/null
  *    - Empty the environment
  *    - Set the default action for all the signals
  *    - Remove the signal mask
@@ -219,7 +263,7 @@ my_unlink (const char *file_name)
  *    beginning, when the program goes into background.
  *
  *    Clear the environment may cause issues.  In particular, some variables
- *    may be required by the job subprocess.  For instance, using Cygwin, the
+ *    may be required by the job subprocesses.  For instance, using Cygwin, the
  *    PATH environment variable contains the path to the Cygwin DLL
  *    (cygwin1.dll) which is required to fork/exec the job command.  This is
  *    why the environment is not cleared for Cygwin only.
@@ -229,40 +273,28 @@ my_unlink (const char *file_name)
  *    defined as an environment for the job in the Schedwi server.
  */
 void
-sanitise (int fd)
+sanitise ()
 {
 	int i;
 	struct sigaction sa;
 	sigset_t mask;
 
-	/* Close all files (except fd) */
-	for (i = getdtablesize () - 1; i >= 0; i--) {
-		if (i != fd) {
-			close (i);
-		}
-	}
 
-	/*
-	 * Redirect 0 (stdin), 1 (stdout) and 2 (stderr) to /dev/null.  This
-	 * way, if sub-proccesses/modules try to inadvertently read/write to
-	 * this file descriptors it will not mess other ones (pid file,
-	 * socket, database connection, ...)
-	 */
-	i = open ("/dev/null", O_RDWR); /* i should be 0 */
-	dup2 (i, 1);
-	dup2 (i, 2);
+	/* Close all files */
+	close_opened_files ();
+	reset_standard_fd ();
 
 	/* Clear the environment */
 #ifndef CYGWIN_IN_USE
 #if HAVE_CLEARENV
 	clearenv ();
-#elif _GNU_SOURCE
+#elif defined(_GNU_SOURCE)
 	environ = NULL;
 #endif
 #endif
 
 	/* Clear the signal actions and mask */
-	schedwi_memset (&sa, 0, sizeof (struct sigaction));
+	memset (&sa, 0, sizeof (struct sigaction));
 	sa.sa_handler = SIG_DFL;
 	sigemptyset (&sa.sa_mask);
 	for (i = 0; i < 128; i++) {
@@ -279,35 +311,16 @@ sanitise (int fd)
 void
 clean_process ()
 {
+	/* Change default directory to `/' */
 #if HAVE_CHDIR
-	char *tmp;
-#endif
-
-	/* Change to a temporary directory */
-	tmp = NULL;
-#if HAVE_CHDIR
-#if HAVE_GETENV
-	tmp = getenv ("TMPDIR");
-	if (tmp != NULL) {
-		if (chdir (tmp) != 0) {
-			tmp = NULL;
-		}
-	}
-#endif /* HAVE_GETENV */
-	if (tmp == NULL) {
-#ifdef P_tmpdir
-		(void)chdir (P_tmpdir);
-#else
-		(void)chdir ("/tmp");
-#endif
-	}
+	(void)chdir ("/");
 #endif /* HAVE_CHDIR */
 
 	/*
 	 * Clean the process.  Protect the file descriptor 3 as it may
 	 * be used by GnuTLS.
 	 */
-	sanitise (3);
+	sanitise ();
 
 #if HAVE_UMASK
 	umask (0027);
@@ -364,19 +377,15 @@ go_daemon()
  * Create the intermediate directories leading to `file_path'.  The last
  * component is not created.
  *
- * @param file_path:
- *        Full file name.
- * @param user:
- *        Owner of the created directories (if NULL or empty, the owner is not
- *        changed)
- * @param group:
- *        Group owning of the created directories (if NULL or empty, the
- *        owner is not changed)
- * @return:
- *    0 --> No error
- *   -1 --> Memory allocation error
- *   -2 --> One component already exists and is not a directory
- *   -3 --> Failed to create a directory or change its owner (errno is set)
+ * @param[in] file_path Full file name.
+ * @param[in] user      Owner of the created directories (if NULL or empty, the
+ *                      owner is not changed)
+ * @param[in] group     Group owning of the created directories (if NULL or
+ *                      empty, the owner is not changed)
+ * @return 0 on success,
+ *        -1 if one component already exists and is not a directory or
+ *        -2 on failure to create a directory or change its owner
+ *        (errno is set)
  */
 int
 mkpath (const char *file_path, const char *user, const char *group)
@@ -399,13 +408,9 @@ mkpath (const char *file_path, const char *user, const char *group)
 	assert (file_path != NULL && file_path[0] != '\0');
 #endif
 
-	path = (char *) malloc (schedwi_strlen (file_path) + 1);
-	if (path == NULL) {
-		return -1;
-	}
-	strcpy (path, file_path);
+	path = xstrdup (file_path);
 
-	sep_length = schedwi_strlen (DIR_SEP);
+	sep_length = strlen (DIR_SEP);
 	for (p = strstr (path, DIR_SEP);
 	     p != NULL;
 	     p = strstr (p + sep_length, DIR_SEP))
@@ -418,7 +423,7 @@ mkpath (const char *file_path, const char *user, const char *group)
 			if (S_ISDIR (stat_str.st_mode) == 0) {
 				/* Not a directory */
 				free (path);
-				return -2;
+				return -1;
 			}
 			*p = DIR_SEP[0];
 			continue;
@@ -427,14 +432,14 @@ mkpath (const char *file_path, const char *user, const char *group)
 			save_errno = errno;
 			free (path);
 			errno = save_errno;
-			return -3;
+			return -2;
 		}
 #if HAVE_CHOWN
 		if ((uid != -1 || gid != -1) && chown (path, uid, gid) != 0) {
 			save_errno = errno;
 			free (path);
 			errno = save_errno;
-			return -3;
+			return -2;
 		}
 #endif
 		*p = DIR_SEP[0];
@@ -445,6 +450,7 @@ mkpath (const char *file_path, const char *user, const char *group)
 
 
 static int fd_pid_file = -1;
+static char *pid_file_name = NULL;
 
 /*
  * Write the PID of the current process to the provided file.
@@ -463,6 +469,11 @@ write_pid_file (const char *file_name)
 		return 0;
 	}
 
+	if (pid_file_name != NULL) {
+		close_pid_file ();
+	}
+	pid_file_name= xstrdup (file_name);
+
 	/* If need be, create the intermediate directories */
 	mkpath (file_name, NULL, NULL);
 
@@ -489,7 +500,7 @@ write_pid_file (const char *file_name)
 	/* Write the PID to the file */
 	(void)snprintf (pid_str, 26, "%ld\n", (long int)getpid ());
 	pid_str [26 - 1] = '\0';
-	(void)write (fd_pid_file, pid_str, schedwi_strlen (pid_str));
+	(void)write (fd_pid_file, pid_str, strlen (pid_str));
 	return 0;
 }
 
@@ -498,10 +509,12 @@ write_pid_file (const char *file_name)
  * Close and remove the file containing the PID of the daemon
  */
 void
-close_pid_file (const char *file_name)
+close_pid_file ()
 {
-	if (file_name != NULL) {
-		my_unlink (file_name);
+	if (pid_file_name != NULL) {
+		my_unlink (pid_file_name);
+		free (pid_file_name);
+		pid_file_name = NULL;
 	}
 
 	if (fd_pid_file >= 0) {
@@ -764,8 +777,7 @@ change_group (const char *name)
  * argument are escaped by \.
  *
  * Return:
- *    The argument string (to be freed by the caller) or
- *    NULL on malloc error
+ *    The argument string (to be freed by the caller)
  */
 char *
 escape_string (const char *str, unsigned int str_len, char add_quotes)
@@ -794,10 +806,7 @@ escape_string (const char *str, unsigned int str_len, char add_quotes)
 		s = strchr (s, '\\');
 	}
 
-	s = (char *) malloc (str_len + i + 3);
-	if (s == NULL) {
-		return NULL;
-	}
+	s = (char *) xmalloc (str_len + i + 3);
 
 	i = 0;
 	if (add_quotes != 0) {
@@ -818,4 +827,64 @@ escape_string (const char *str, unsigned int str_len, char add_quotes)
 	return s;
 }
 
+
+/*
+ * Read a file and return a newly allocated string with the content,
+ * and set `*length' to the length of the string.  The string is
+ * zero-terminated, but the terminating zero byte is not counted in
+ * `*length'.
+ *
+ * Return:
+ *   The content of the file (to be freed by free()) OR
+ *   NULL in case of error (errno is set and `*length' is undefined)
+ */
+char *
+read_file (const char *filename, size_t *length)
+{
+	struct stat stat_str;
+	FILE *f;
+	char *file_content;
+	size_t nb_read;
+	int save_errno;
+
+
+#if HAVE_ASSERT_H
+	assert (filename != NULL);
+#endif
+
+	/* Retrieve the file size */
+	if (stat (filename, &stat_str) != 0) {
+		return NULL;
+	}
+
+	/* Create a buffer for reading the whole file */
+	file_content = (char *) xmalloc (stat_str.st_size + 1);
+
+	/* Open and read the whole file */
+	f = fopen (filename, "rb");
+	if (f == NULL) {
+		save_errno = errno;
+		free (file_content);
+		errno = save_errno;
+		return NULL;
+	}
+
+	clearerr (f);
+	nb_read  = fread (file_content, 1, stat_str.st_size, f);
+	if (nb_read != stat_str.st_size && ferror (f) != 0) {
+		save_errno = errno;
+		fclose (f);
+		free (file_content);
+		errno = save_errno;
+		return NULL;
+	}
+	fclose (f);
+
+	file_content[stat_str.st_size] = '\0';
+	if (length != NULL) {
+		*length = stat_str.st_size;
+	}
+	return file_content;
+}
+
 /*------------------------======= End Of File =======------------------------*/
