@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2013 Herve Quatremain
+   Copyright (C) 2007-2014 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -20,7 +20,7 @@
 /* utils.h -- Several functions */
 
 #ifndef _UTILS_H
-#define _UTILS_H 1
+#define _UTILS_H
 
 #include <schedwi.h>
 
@@ -50,15 +50,17 @@ extern "C" {
 #endif
 
 extern const char *base_name OF((const char *path));
-extern void version OF((const char *prog_name));
+extern void version OF(());
 extern int my_unlink OF((const char *file_name));
-extern void sanitise OF((int fd));
+extern void close_opened_files OF(());
+extern void reset_standard_fd OF(());
+extern void sanitise OF(());
 extern void clean_process OF(());
 extern int go_daemon OF(());
 extern int mkpath OF((const char *file_path,
 			const char *user, const char *group));
 extern int write_pid_file OF((const char *file_name));
-extern void close_pid_file OF((const char *file_name));
+extern void close_pid_file OF(());
 extern unsigned int copy_ulltostr OF((unsigned long long int v, char *str));
 extern int get_userid OF((const char *name, uid_t *uid));
 extern int get_groupid OF((const char *name, gid_t *gid));
@@ -66,6 +68,7 @@ extern int change_user OF((const char *name));
 extern int change_group OF((const char *name));
 extern char *escape_string OF((const char *str, unsigned int str_len,
 				char add_quotes));
+extern char *read_file OF((const char *filename, size_t *length));
 
 #ifdef __cplusplus
 }
